;;;;;Quantiz0;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
     list B=10, C=110, N=43
;
;  Copyright 2009, 2010, 2011 by Reed Lee
;
;  This program is free software:  you can redistribute it and/or
;  modify it under the terms of the GNU General Pulic License as
;  published by the Free Software Foundation, either version 3 of
;  the license or (at your option) any later version.
;
;  This program is distributed in the hope that it will be useful
;  but WITHOUT ANY WARRANTY -- WITHOUT even the implied warranty of
;  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
;  GNU Public License for more details.
;
;  You should have receved a copy of the GNU Public License with
;  this program.  If not, see <http://www.gnu.org/licenses/>.
;
;
;  SOURCE CODE AND PROGRAM LISTING
;
;  The file qunantiz0.asm should assemble to PIC (non-relocatable)
;  object code for the PIC 16F886 microcontroler using any assembler
;  appropriate for that part.  This code was develpoed using the
;  MPLAB Intergrated Development Environment (version 8.30) available
;  without charge from Microchip Technology, the manuafacturer of
;  the PIC 16F886. That IDE was used to create the quantiz0.lst file
;  which contains the source code found in quantiz0.asm along with
;  opcode and program memory information. The list file has been 
;  prepared for printing, in whole or in part, in landscape mode
;  using standard paper:  either A4 or 8-1/2 x 11 inch paper with
;  margins of approximately 12 mm or 1/2 inch (one margin slightly
;  larger to account for the greater width of 8-1/2 inch paper com-
;  pared to A4).
;
;
;
;  The source code file and the program listing, along with a copy
;  of version 3 of the GNU Public License are available for download
;  without charge at clsound.com.
;
;  Also available at that web page is an ancillary spreadsheet file:
;  quantizr.xls, which was used to generate the jump tables representing
;  the available scales.  Those who wish to replace one or more of the
;  scales represented in this program -- and who are capable of assembling
;  PIC object code -- may want to modify the spreadsheet with their pre-
;  ferred scales or scales.  Using a spreadsheet procram such as Calc
;  -- available without charge from OpenOffice.org or Excel available
;  for a fee from Microsoft -- the modified spreadsheet can then be
;  converted to an ASCII comma-separated values file.  That file can
;  then be editied -- using any common text editor (Wordpad was used
;  for the original version) to remove the separators and ensure proper
;  spacing.  The resulting ASCII file can then be patched into the
;  existing source code (replacing one or more existing scales with
;  preferred scales).  Study of the existing jump tables should readily
;  reveal the way in which quarter-tone values are represented as 240
;  ascending valuess over ten octaves.  Note that although the coding
;  results in 240 tone values for each scale, each jump table MUST
;  begin on a 256-instruction address boundary (and should be 256 lines
;  long).
;
;  Users are free under the GNU Pulic License to make other modifications
;  or improvements to the source code as well, giving proper credit to
;  this source code in any subsequent release, as specified in the GNU
;  Public License.
;
;  This source code (and also the program listing) contains very extensive
;  comments which are intended to document the program.  The comments, of
;  course, do not assemble to object code, so they do not affect the size
;  of the executable file.  As it stands, the existing program, with its
;  31 scale jump tables very nearly completely fills the program memory,
;  so modifications will have to take program space limitations into account,
;  either by making the basic program code (first 256 instructions)more
;  efficient or by sacrificing one or more jump tables (scales).
;  DEVELOPMENT HISTORY
;
;  Version 0.1	2009 Dec 14-15
;    Main Progam outer and inner loops
;    Single jump table look-up
;    Program memory location equates
;  Version 0.2	2009 Dec 19
;    Altered scale indexing to allow > 16 scales
;    Better RootTone check
;  Version 0.3	2009 Dec 26
;    Added serial output to D/A converter
;    Debugged on 2010 Jan 04
;    Software simulation traced on January 7-10, 2010
;  Version 0.4	2010 Jan 31
;    Fixed RootTone check bug
;    Added enable/disable line for output demux chip
;    Added and improved look-up tables
;    Programmed hardware (PIC 16F877)
;  Version 0.5	2010 Feb 06
;    Optimized timing of parallel processes
;    Set configuation bits for 16F876A
;    Added masks to facilitate changing I/O ports
;    Programmed new hardware (PIC 16F876A)
;  Version 0.6	2010 May 14
;    Added support for "shift switch" on scale select
;  Version 0.7	2010 Jul 05
;    Added Hold and Calibration modes
;    Optimized timing (I/O multitasking)
;    Optimized RAM and program steps
;  Version 0.8      2010 Nov 30
;    Fixed output bugs
;    Changed D/A converter gain
;    Optimized program size and timing
;    Added noise filter
;
;
;
;  Version 1.0      2011 Mar 12
;    Optimized code size (for release)
;    Prevented scale select overflow
;    Centered voltage bins to 'round' instead of 'truncate'
;    Programmed new hardware (PIC 16F886)
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
;  This program operates a microcontroller used in connection with an
;  electronic music synthesizer.  The synthesizer is built around a set
;  of voltage-controlled oscillators each of which converts an input 
;  voltage 0V < Vm < 10V into an audio frequency ranging over ten octaves.
;
;  The human ear is quite sensitive to frequency, and the voltage-controlled
;  oscillators will not produce acceptable frequencies unless the input vol-
;  tages can be controlled with considerable precision.  For this reason, the
;  analog voltages are digitized and quantized prior to being applied to the
;  voltage-controlled oscillators.  As used here, "quantized" means adjusted
;  to a standardized value which is true to a scale selected by the user.
;
;  A second reason for quantizing the voltages is to pin a randomly varying
;  or continuously sliding voltage to values which produce distinct tones which
;  are true to the selected scale.  A steadily increasing voltage will thus
;  produce a familiar rising scale.  Similarly votages produced by a sequencer
;  will avoid producing dissonant tones.  
; 
;  The quantized voltages are converted back to an analog signals before
;  being applied to control the voltage-controlled oscillators.
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
;  The quantizer operates in one of three basic modes.  The Run mode,which car-
;  ries out the quantization described above, is detailed below.  In addition,
;  a Calibrate mode places a steady root tone on each of the music channels
;  regardless of the actual input voltage levels on those channels.  The base
;  channel contains the lowest octave root tone, and each successive music
;  channel contains the root tone in the next higher octave.  The two highest
;  channels break this pattern, with higher octave root tone placed on them.
;  The user selects the Calibrate mode by activating a switch, and the device
;  returns to its standard Run mode when the user deactivates the selection
;  switch.  The other special operating mode is the Hold mode, effectively se-
;  lected whenever and for as long as the Hold mode select signal is received
;  on an input line devoted to that purpose.  In this mode, the output to each
;  music channel remains constant (i.e. unchanged from the time Hold mode com-
;  menced) regardless of the actual input voltages.  The mode selection lines
;  are sampled each time a music channel is serviced, and the transfer between
;  the standard Run mode and either of the other modes does not disrupt the ser-
;  vice cycle on the music channels.  The Calibrate mode has priority over the
;  Hold mode, so that if both special mode select lines are active, the device
;  will be in Calibrate mode.  It returns to the standard Run mode when neither
;  special mode select line is active. 
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
;  The user selects one of the preset scales by adjusting a selection switch
;  which feeds an analog voltage level to an input line of the microcontroller.
;  The microcontroller's analog-to-digital converter determines which of the
;  preset scales has been selected.  Available program memory allows for well
;  over 16 scales, but the planned rotary scale select switch would be unwieldy
;  with more than 16 positions.  For this reason, the program supports a shift
;  switch for the rotary scale select switch, effectively allowing the user to
;  select from twice as many scales as there are positions on the rotary switch.
;
;  The music synthesizer operates with up to eight musical channels carrying
;  analog voltages which are applied to voltage-controlled oscillators (one per
;  channel).  These voltages need to be quantized so that the oscillators will
;  produce acceptable frequencies.  Each channel is sampled in turn, the voltage
;  level is digitized, and then the level is quantized to a standardized value
;  based upon the chosen scale.  The multiplexing and demultiplexing of the
;  channels is controlled by the microcontoller but carried out by external
;  chips.  The same is true of the final digital-to-analog conversion.
;
;  Thus the microcontroller has three sets of input lines.  One line is multi-
;  plexed over the eight music channels and carries the synthesizer voltage(s)
;  to be quantized.  A second set of lines carries the scale selection informa-
;  tion.  The first of these lines carries an analog scale selection voltage
;  produced by a potentiometer (or equivalent) allowing the user to select one
;  of 16 pre-specified voltage levels, each representing a different scale.  The
;  other scale select input line carries a digital signal generated by a shift
;  switch (with a pull-down resistor) allowing the user to select additional
;  scales with the same selection pot.  The final set of input lines permits the
;  user to divert the device from its normal Run mode to Hold or Calibrate mode
;  and back.
;
;  The microcontroller also has the following outputs:  A 5-bit output diplays
;  the selected scale (there is room for 31 preset scales), and (on the same
;  output port) a 3-bit bus controls the multiplexing and demultiplexing of the
;  8 music channels.  A synchronous serial output line (which is supported by
;  additional serial clock and slave select lines as well as a dummy input line
;  tied to the output) is used to control the external digital-to-analog con-
;  verter.  An output enable/disable line is used (by freezing the output de-
;  multiplexer) to disable the output circuitry while the external digital-to-
;  analog converter is converting a new voltage leval and settling down after a
;  conversion.  A 1-bit indicator powering an LED is high whenever the input
;  music voltage (on the base channel only) quantizes to a root tone note (in
;  any octave) of the selected scale and is low otherwise.
;
;  The quantizing step is accomplished with look-up tables.  Each possible scale
;  has a look-up table hard coded into program memory.  Each table has an entry
;  for each possible digitized music voltage level, and is arranged to return
;  the proper quantized (standardized) voltage level value according to the
;  scale.  The look-up tables are distributed over the four pages of program
;  memory starting at a convenient address above the last program instruction
;  which is not a proper part of one of the look-up tables or the quantization
;  subroutine.  (The size of the rest of the program thus determines the maximum
;  number of look-up tables and thus the number of scales available for user
;  selection).
;
;
;
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
;  The analog-to-digital conversion is accomplished with the PIC's A/D module
;  which can convert analog voltages on each of the analog input lines (one for
;  music tone levels and the other for scale selection).  The program switches
;  from the music line to the scale selection line at a convenient point to
;  permit the user to update the selected scale.  (Multiplexing of the eight
;  music channels onto the music input line is accomplished by external chips
;  driven by a channel "address" controled by the PIC and placed on an address
;  bus common to the multiplexing and demultiplexing chips).  While the PIC's
;  A/D module produces a 10-bit digital result, the quantizer needs only eight,
;  and so, except for noise filtering purposes, it ignores the two least signi-
;  ficant bits.  Before doing so, however, it adds an appropriate constant to
;  the lowest two bits of the digitized channel value (and carried higher as
;  necessary) so that the 8-bit channel voltage value is rounded rather than
;  truncated from ten bits.  The input timing -- in particular the recovery time
;  after an A/D conversion and the time required to accurately acquire an analog
;  voltage level -- is measured by an input timer, in this case Timer0.
;
;  On the output side, the digital-to-analog conversion is carried out by an
;  external chip which receives its digital input by serial communication from
;  the PIC.  That external converter uses -- and the PIC supports -- the Serial
;  Peripheral Interface (SPI) protocol, so the serial communication is done by
;  the PIC's Master Synchronous Serial Port.  This module generates the clock
;  pulses which drive the synchronous serial transfer.  Other critical output
;  timing -- such as the period during which the output music channels are dis-
;  connected from the quantizer in order to permit change and settling of ana-
;  log output levels -- is controlled by a separate output timer so that input
;  and output processes can occur simulateously.  The PIC's Timer2 is used as
;  the output timer.  This timer can also provide any delay necessary to hold
;  the output channels to the D/A converter's output level for a minimum period.
;
;  In order to save time (and thus increase the frequency with which each music
;  channel is serviced), input and output processes occur simultaneously, and
;  the program's principal loop switches attention between each in order to op-
;  timize the overall timing.  One result of this arrangement is that the while
;  a given muliplexed music channel's input voltage level is being acquired,
;  digitized, and quantized, the _previous_ channel's quantized voltage (and re-
;  lated) information is being output.  Since the quantizer design uses a common
;  address bus for the input muliplexing chip and the output demultiplxing chip,
;  the wiring of one of the chips must be offset from the wiring of the other
;  chip by one pin.  In particular, the base input channel must be sampled when
;  the mutiplexer "address" is 7, and the same channel is output after the ad-
;  dress increments to 0.  Some of the program constants and initialized vari-
;  ables also take account of this output offset.
;
;  Some fundamental timing contraints arise on the input side.  It takes time
;  for analog voltage levels to stabilize on an input line and it takes time for
;  the analog-to-digital converter to produce a fully accurate digital result.
;  A few instructions must be executed between these delays, but this control
;  overhead can be absorbed within the hardware delays, so it need not add sub-
;  stantially to the overall looptime.  Because of the analog-to-digital conver-
;  ter's design, the acquisition time necessary to permit the analog voltage to
;  stabilize depends upon the output impedance of the input circuitry.  Since
;  this impedance will not exceed 2.2 KOhms, an aquisition time of 12.4 usec
;  will suffice.  At an oscillator frequency of 20 MHz, 18.4 usec are required
;  for the analog-to-digital conversion itself.  If the control overhead can be
;  fully absorbed within the hardward delays, the total looptime will approxi-
;  mate 30.8 usec (the sum of the acquisition and conversion delays) for single
;  music channel.  The output process also requires a critical delay of its own:
;  the output circuitry must be frozen while the quantized music tone's digital
;  value changes, is reconverted to an analog value, and settles down.  Within
;  this delay are two shorter hardware delays, in addition to the time it takes
;  to execute some of the otput and related control instructions.  First, two
;  output bytes must be serially transmitted to the external D/A converter.  At
;  a clock rate of 20 MHz, each byte takes 1.6 usec to complete.  Empirical
;  testing (with an oscilloscope) discloses a delay of close to 2 usec between
;  the transmission of each byte.  Second, the external D/A converter needs time
;  to slew and settle to a new voltage for each output channel.  Empirical test-
;  ing (with an oscilloscope) shows that, at least with the capcitances inherent
;  in a standard breadboard, 16 usec is necessary to avoid any trace of ramping
;  in the output voltages.  This long delay does slow operation, by ~ 2 usec,
;  beyond what the input processes minimally require.  Neverthelss, the program
;  is arranged to minimize this output delay in order to energize the ouput cir-
;  cuits for as long as possible and to interleve this delay with the input
;  hardware delays so as to minimize the total time necessary to service each
;  music channel.  The lower stray capcitances of a printed circuit board very
;  likely allow for a much shorter slew and settlre time.  But since the long
;  delay only increases the chennel service time by about 2 usec, and since the
;  the 2500 times per sec service rate of each channel is already much faster
;  than necessery (and since the output circuits have no trouble holding their
;  analog voltage while other channels are serviced and while the channel vol-
;  tage slews and settle), no effort was made to shorten the output slew and
;  settle time for the printed circuit hardware vrsion.
;
;  Most of the serial output for a music channel occurs while the next channel's
;  voltage is acquired on the music analog input line.  This includes all or
;  most of the delay necessary to permit the output voltages to change and to
;  settle.  The various hardware delays also provide time to check the mode se-
;  lection lines, to save the quantized music levels (for use in Hold mode), and
;  to service the RootTone indicator LED (and some other minor housekeeping as
;  well).
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
;  The RootTone indicator line is controlled by a subroutine which is called
;  when the basic music channel is being serviced (for output).  The subroutine
;  must essentially check to see whether the quantized music value is divisible
;  by 24 (the number of quartertones in an octave).  A faster version of the 
;  subroutine first tested whether the value is divisible by 8 and then, if so,
;  whether is is also divisible by 3 (using the fact that this test in binary is
;  equivalent to a simple divisible-by-11 test in decimal).  Although this sub-
;  routine is faster (both on average and in worst case performance) than a more
;  straightforwar subroutine, it require over forty instructions.  Since pro-
;  grame size is a priority (in order to leave room for the maximum number of
;  user selectable scales) and since the external D/A converter, as tested on a
;  breadboard, required a 16 usec slew and settle delay, the higher performance
;  of this subroutine has been sacrificed to a much shorter and more straight-
;  forward subroutine which merely subtracts 24 (the number of quartertones in
;  an octave) from the quantized tone until the result goes negative, when the
;  last-subtracted octave is added back in and the result is tested for zero.
;
;  The quantizer apparatus is subject to noise when the input voltage is close
;  to a threshhold between the eight-bit bins used by the quantizer.  A voltage
;  held near such a threshhold might fluctuate over time between adjacent quan-
;  tized values.  This results in audible noise (roughness, buzz) in the output.
;  To combat this, a voltage digitizing to a 10-bit digitization bin on a possi-
;  ble quantization boundary (i.e. on an 8-bit bin threshhold) is held to that
;  same 10-bit bin when the channel is next quantized if, but only if, the new
;  value crossed a quantization boundary by only one 10-bit bin.  This quite
;  simple noise filter effectively eliminates the boudary noise.
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

     list P=PIC16F886, F=INHX8M, B=10, C=110, N=45, ST=OFF, MM=OFF, R=DEC
     include "C:\Program Files\Microchip\MPASM Suite\P16F886.INC"
     __config _CONFIG1, _HS_OSC&_WDT_OFF&_PWRTE_ON&_BOR_OFF&_LVP_OFF&_CP_OFF&_DEBUG_ON
     errorlevel -302

;;;;;Equates;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;Input/Output Ports and Lines

;	Use PORTA for two analog input lines and digital shift line
;	  Line 0:  multiplexed music channels (8)
;	  Line 1:  user selection among preset scales
;	  Line 2:  line to place device in (high) and out (low) of Hold mode
;	  Line 4:  shift switch to select for addtional preset scales
;	  Line 5:  calibration switch to place device in (high) and out (low)
;		 of Calibration mode
	
INPUT	equ	PORTA		;Analog inputs (2 low-order lines)
TRISIN	equ	TRISA
HOLDMODE	equ	D'2'		;Hold mode sel. (high) line (desel=low)
SHIFTSW	equ	D'5'		;Shift switch on second highest bit line
CALIBSW	equ	D'4'		;Calibration mode swith on high bit line
;	  Program constants to select analog input for conversion
;	  Both refer to the low channel select bit in the ADCON0 register
SCALE	equ	CHS0		;Analog input line control, set this bit
LEVEL	equ	CHS0		;Analog input line control, clr this bit

;	Use PORTB for music channel mutiplexing output
;	and for scale selection indioator
;	  Lines 0-2:  3-bit channel indicator (multiplexers)
;	  Lines 3-7:  5-bit scale selection display (LEDs)
OUTCHAN	equ	PORTB		;Multiplexing address (3 low-order)
OUTSCALE	equ	PORTB		;Scale select display (5 high-order)
TRISOUT	equ	TRISB
CHANBITS	equ	B'00000111'	;Mask to isolate Channel bits
SCLBITS	equ	B'11111000'	;Mask to isolate Scale   bits

;	Use PORTC for serial output to the D/A converter
;	including the necessary external chip enable lines
;	and also for the root tone LED output line
;	  Line 0:  root tone indicator (LED)
;	  Line 3:  serial clock
;	  Line 4:  serial data input  (tied to Line 5)
;	  Line 5:  serial data output (to D/A converter)
;	  Line 6:  slave enable (active low)
;	  Line 7:  output demultiplexer enable (active high)
OUTSER	equ	PORTC		;Serial output for quantized note value
OUTROOT	equ	PORTC		;and output for root note indicator
TRISSER	equ	TRISC
ROOTLED	equ	D'0'		;Root tone LED on line 0
SCK	equ	D'3'		;Synchronous serial communication clock
SDI	equ	D'4'		;Serial data in
SDO	equ	D'5'		;Serial data out
SE	equ	D'6'		;Serial slave enable on line 6
OE	equ	D'7'		;Output demultiplxer enable on line 7

;Program Memory Locations

BASE	equ	H'100'		;Base address for look-up tables
SIZE	equ	H'100'		;Size of look-up table for each scale
JUMPBASE	equ	BASE-D'04'	;Address of 4-instruction jump routine
SCALETOT	equ	D'31'		;Total number of scales

HalfT	equ	BASE+(D'00'*SIZE)	;Half Tone
WholeT	equ	BASE+(D'01'*SIZE)	;Whole Tone
Major	equ	BASE+(D'02'*SIZE)	;Major
MajorPD	equ	BASE+(D'03'*SIZE)	;Major Pent Diatonic
HarmMin	equ	BASE+(D'04'*SIZE)	;Harmonic Minor
MinorAol	equ	BASE+(D'05'*SIZE)	;Minor/Aolian
MinorP	equ	BASE+(D'06'*SIZE)	;Minor Pentatonic
Blues	equ	BASE+(D'07'*SIZE)	;Blues
Dorian	equ	BASE+(D'08'*SIZE)	;Dorian
Lydian	equ	BASE+(D'09'*SIZE)	;Lydian
LydianD	equ	BASE+(D'10'*SIZE)	;Lydian Dominant
Phrygian	equ	BASE+(D'11'*SIZE)	;Phrygian
PhrygD	equ	BASE+(D'12'*SIZE)	;Phrygian Dominant
BalineseP	equ	BASE+(D'13'*SIZE)	;Balinese Pentatonic
Java	equ	BASE+(D'14'*SIZE)	;Java
Chinese	equ	BASE+(D'15'*SIZE)	;Chinese
Hindu	equ	BASE+(D'16'*SIZE)	;Hindu
HungMin	equ	BASE+(D'17'*SIZE)	;Hungarian Minor
Sus	equ	BASE+(D'18'*SIZE)	;Sustained
Dim	equ	BASE+(D'19'*SIZE)	;Diminished
Aug	equ	BASE+(D'20'*SIZE)	;Augmented
Seventh	equ	BASE+(D'21'*SIZE)	;Seventh
MinorSev	equ	BASE+(D'22'*SIZE)	;Minor Seventh
Thirds	equ	BASE+(D'23'*SIZE)	;Thirds
MinorThrd	equ	BASE+(D'24'*SIZE)	;Minor Thirds
Fourth	equ	BASE+(D'25'*SIZE)	;Fourths
EightT	equ	BASE+(D'26'*SIZE)	;Eight Tone
QuarterT	equ	BASE+(D'27'*SIZE)	;Quarter Tone
GreekLQT	equ	BASE+(D'28'*SIZE)	;Greek Lydian Quarter Tone
AolianQT	equ	BASE+(D'29'*SIZE)	;Aolian Quarter Tone
EqualQT	equ	BASE+(D'30'*SIZE)	;Equal Quarter Tone

;Data Memory Locations

BANK0RAM	equ	H'20'		;Start location for RAM variables

;Program Constants	

BASECHAN	equ	D'0'		;Base of eight music channels total
ACQDELAY	equ	D'196'		;12.4 usec voltage acquisition delay
OUTDELAY	equ	D'78'		;15.6 usec slew-and-settle delay
SCALEBAS	equ	BASE/SIZE		;Index   for first   scale table
SCALEDFT	equ	QuarterT/SIZE	;Index   for default scale table
INITVAL	equ	D'98'		;Initialization value for non-0 vars

;;;;;Variables;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

	cblock	BANK0RAM
	CALIBCH0			;Calibration value for each channel
	CALIBCH1			;(Pinning these arrays to RAM locations
	CALIBCH2			; evenly divisible by 8 allows for pos-
	CALIBCH3			; sible simplification of array indexing
	CALIBCH4			; code)
	CALIBCH5
	CALIBCH6
	CALIBCH7
	QUANTCH0			;Quantized value for each music channel
	QUANTCH1
	QUANTCH2
	QUANTCH3
	QUANTCH4
	QUANTCH5
	QUANTCH6
	QUANTCH7
	DIGLOCH0			;ADRESL value for each music channel
	DIGLOCH1
	DIGLOCH2
	DIGLOCH3
	DIGLOCH4
	DIGLOCH5
	DIGLOCH6
	DIGLOCH7
	DIGHICH0			;ADRESH value for each music channel
	DIGHICH1
	DIGHICH2
	DIGHICH3
	DIGHICH4
	DIGHICH5
	DIGHICH6
	DIGHICH7
	QUANTIZD			;Quantized value for most recent channel
	OLDSCALE			;Previosuly selected scale
	SCALETBL			;Index to table for selected scale
	CHANNEL			;Music channel being output (3 low bits)
	LOCOMP			;Composite of new & old lo A/D bytes
	OUTBYTE			;TX byte for serial out to D/A conv
	NOTE			;Working value   for RootTone check
	endc

;;;;;Vectors;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

	org	H'000'
	nop			;In-circuit debugger requires nops here
	nop

;	INITIALIZE
Init:	call	Initialz		;Execute initialization code
	goto	ModeMrg		;Start execution at CHANNEL increment

	org	H'004'
	goto	Init		;Interrupts are unused (jumped over)

;;;;;Macros;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;	None Used

;;;;;Main Program;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;	CHANNEL LOOP (basic program loop)
;	Repeatedly sample, digitize, and quantize voltages
;	on eight externally multiplexed music channels
;	Simultaneously output the quantized voltage level
;	for the previously sampled channel

;	Output -- Build high byte of control word for external D/A converter
GetLevel:	swapf	QUANTIZD,	W	;4 most sig bits of Q into low half
	andlw	B'00001111'	;Clear upper half for control bits
	iorlw	B'01010000'	;Insert control bits for external D/A
	movwf	OUTBYTE		;Save high byte for tx

;	Control -- Calculate and set new music channel
	movf	CHANNEL,	W	;Obtain channel number
	andlw	B'00000111'	;from three low bits of CHANNEL 
	movwf	FSR		;for use as mutiplexing address
	movf	OUTCHAN,	W	;Clear old multiplexing address
	andlw	B'11111000'	;from output port and
	iorwf	FSR,	W	;insert new multiplexing address

;	Control -- Disable output circuits to allow updating
	bcf	OUTSER,	OE	;Disconnect output lines before updating

;	Control -- Switch external multiplexers to new music channel
	movwf	OUTCHAN		;Update output port

;	Output -- Send high byte of control word to external D/A converter
	bcf	OUTSER,	SE	;Enable slave D/A converter (active low)
	bcf	PIR1,	SSPIF	;Clear interrupt flag
	movf	OUTBYTE,	W	;Load high byte for serial output
	movwf	SSPBUF		;Send data to shift register for output 

;	Output -- Build low bytes of control word for external D/A converter 
	swapf	QUANTIZD,	W	;4 Least sig bits of Q into high half
	andlw	B'11110000'	;pad 4 least sig bits with zeros
	movwf	OUTBYTE		;Save to send by serial tx

;	Output -- Wait to finish high byte tx
SerWaitH:	btfss	PIR1,	SSPIF	;Wait for serial transfer to finish
	goto	SerWaitH		;sending high byte
	movf	SSPBUF,	W	;Clear buffer for next send

;	Output -- Send low  byte of control word to external D/A converter
	bcf	PIR1,	SSPIF	;Clear interrupt flag
	movf	OUTBYTE,	W	;Load low  byte for serial tx
	movwf	SSPBUF		;Save to shift register for output

;	Output -- Save QUANTIZD in QUANTCHx array
	movlw	QUANTCH0		;Load base address from QUNATCHx array
	addwf	FSR,	F	;Add base addr. to channel index in FSR
	movf	QUANTIZD,	W	;Save QUANTIZD
	movwf	INDF		;to QUANTCHx array at channel index
	movlw	QUANTCH0		;Remove base address from value in FSR
	subwf	FSR,	F	;leaving only array index in FSR
	incf	FSR,	F	;Increment array index
	bcf	FSR,	3	;while preventing index overflow (< 8)

;	Output -- Wait to finish low byte tx
SerWaitL:	btfss	PIR1,	SSPIF	;Wait for serial transfer to finish
	goto	SerWaitL		;sending low byte
	bsf	OUTSER,	SE	;End transfer and commence D/A conv

;	Output -- Begin D/A converter settle delay
	bcf	PIR1,	TMR2IF	;Clear Timer2 flag
	bsf	T2CON,	TMR2ON	;Turn on Timer2

;	Input -- Wait for A/D converter to acquire voltage
AcqWait:	btfss	INTCON,	T0IF	;Wait to acquire full voltage
	goto	AcqWait		;after performing parallel tasks

;	Input -- Get analog voltage level and convert to ten-bit digital value
	bsf	ADCON0,	GO	;Begin A/D conversion of level

;	Output -- Clear serial buffer for future output
	bcf	SSPCON,	WCOL	;Ensure write collision flag is clear
	movf	SSPBUF,	W	;Clear old (irelevant xcieved byte)

;	Output -- Update RootTone indicator led bit
;		Determine whether output channel is basic music channel
	movf	CHANNEL,	W	;Test current music channel
	andlw	B'00000111'	;(absent exttraneous bits)
	xorlw	BASECHAN		;against basic music channel (w/ offset)
	btfsc	STATUS,	Z	;If on basic music channel 
	call	UpDate		;then update RootTone led

;	Control -- Mode Select:  test for special mode conditions
;		     Jump if selected, continue if not
	btfss	INPUT,	CALIBSW	;Check caibration mode select
	goto	Calib		;Change mode if clear
	btfsc	INPUT,	HOLDMODE	;Check hold mode select
	goto	Hold		;Change mode if set

;	Output -- Wait for D/A converter to settle
OutWait:	btfss	PIR1,	TMR2IF	;Wait for ouput voltage level to settle
	goto	OutWait
	bcf	T2CON,	TMR2ON	;Turn off Timer2

;	Output -- Enable analog output lines through external demultiplexer
	bsf	OUTSER,	OE	;Reconnect output lines after updating

;	Input -- Get A/D conversion result
;	         Ignore two least significant bits to give 256 8-bit bins
ConvWait:	btfsc	ADCON0,	GO	;Wait for conversion to finish
	goto	ConvWait

;	Input -- Begin acquisition delay (for analog voltage)
	movlw	ACQDELAY		;Set acquisition delay
	movwf	TMR0
	bcf	INTCON,	T0IF	;and clear clock flag

;	Input -- Noise Filter
;	Initialize QUANTIZD to noise filter value (i.e. previous channel val)
	movlw	QUANTCH0		;Load base address for music value array
	addwf	FSR,	F	;and add it to index pointer (=channel)
	movf	INDF,	W	;Load QUANTCHx value and save
	movwf	QUANTIZD		;as noise filter value for QUANTIZD

;	Create composite of new & old lo A/D bytes
;	Load new lo A/D byte for channel
Round:	bsf	STATUS,	RP0	;Select  RAM Bank 1 for ADRESL
	movlw	B'10000000'	;Offset input value to round rather than
	addwf	ADRESL,	W	;truncate 10-bit value to 8-bit value
	bcf	STATUS,	RP0	;Restore RAM Bank 0
	btfss	STATUS,	C	;If adjustment to lo A/D byte produced
	goto	Noise		;no carry,    then finish adjustment
	incf	ADRESH,	F	;a  carry,    then adjust hi A/D byte
	btfss	STATUS,	C	;If adjustment to hi A/D byte caused
	goto	Noise		;no overflow, then finish adjustment
	decf	ADRESH,	F	;an overflow, then readjust
Noise:	andlw	B'11000000'	;Clear extraneous lo A/D bits (in W)
	movwf	LOCOMP		;Store as high nibble of LOCOMP

;	Load old lo A/D byte for channel
	movlw	DIGLOCH0-QUANTCH0	;Adjust base addr for lo A/D byte array
	addwf	FSR,	F	;and add to ar. index pointer (=channel)
	swapf	INDF,	W	;Load previous load A/D byte for channel
	iorwf	LOCOMP,	F	;and create composite of new & old vals

;	Test for special noise conditions -- adjacent new & old hi A/D bytes
	movlw	DIGHICH0-DIGLOCH0	;Adjust base addr for hi A/D byte array
	addwf	FSR,	F	;and add to ar. index pointer (=channel)
	movf	INDF,	W	;Load previous hi A/D/ byte for channel
	subwf	ADRESH,	W	;Compare new and old hi A/D bytes
	addlw	D'1'		;If old byte exceeds new by 1 (diff=-1)
	btfsc	STATUS,	Z	;then jump to test whether lo bytes
	goto	NegTest		;are close enough for noise filtering
	sublw	D'2'		;If new byte exceeds old by 1 (diff=1-2)
	btfss	STATUS,	Z	;then proceed to test lo bytes
	goto	NewQuant		;Otherwise, abandon noise filtering

;	Test for special noise conditions -- lo bytes on hi byte boundary
;	If hi byte difference is +1, then check lo: new=H'00' & old=H'C0'
PosTest:	movf	LOCOMP,	W	;Check lo A/D value composite
	xorlw	H'0C'		;for new=0 & old=C
	btfsc	STATUS,	Z	;If so,
	goto	ModeMrg		;then skip updating QUANTIZD & A/D bytes
	goto	NewQuant		;else update all

;	If hi byte difference is -1, then check lo: new=H'0C' & old=H'00'
NegTest:	movf	LOCOMP,	W	;Check lo A/D value composite
	xorlw	H'C0'		;for new=C & old=0
	btfsc	STATUS,	Z	;If so,
	goto	ModeMrg		;then skip updating QUANTIZD & A/D bytes

;	Store channel A/D values for later noise filter testing
NewQuant:	movf	ADRESH,	W	;Load new A/D hi byte for channel
	movwf	INDF		;and save to hi byte array
	movlw	DIGLOCH0-DIGHICH0	;Adjust base address to l byte array
	addwf	FSR,	F	;and add to ar. index pointer (=channel)
	movf	LOCOMP,	W	;Load new-old lo byte composite
	andlw	B'11000000'	;and remove old value and stray bits
	movwf	INDF		;and save to lo byte array

;	Input -- Quantize voltage values to true tone values in selected scale 
Quantize:	call	SetLevel		;Quantize voltage level
	movwf	QUANTIZD		;Save quantized leval
	clrf	PCLATH		;Reset prog memory to Page0 (after jump)

;	Control -- Change music channel in order to continue
;		 Occasionally check to update user scale selection
ModeMrg:	incf	CHANNEL,	F	;Change music CHANNEL
	btfss	STATUS,	Z	;Time to recheck scale selection?
	goto	GetLevel		;no:  quantize next CHANNEL
				;yes: update scale and continue

;	SCALE LOOP (outer program loop)
;	User selects one of the preset scales

;	Change analog input line to SCALE selector
GetScale:	bsf	ADCON0,	SCALE	;Change to special analog input pin
	movlw	ACQDELAY		;Set acquisition delay
	movwf	TMR0
	bcf	INTCON,	T0IF	;and clear clock flag
	
SclWait:	btfss	INTCON,	T0IF	;Wait to acquire voltage
	goto	SclWait

;	Get user selected scale from SCALE input pin
	bsf	ADCON0,	GO	;Begin A/D conversion of scale
ScalPoll:	btfsc	ADCON0,	GO	;Wait for conversion to finish
	goto	ScalPoll

;	Restore default input pin to LEVEL
	bcf	ADCON0,	LEVEL	;Change to standard analog input pin

;	Update scale selection info
	call	SetScale

;	Return to CHANNEL LOOP
	goto	GetLevel		;Continue after updating scale

;	End of inner and outer main program loops

;	HOLD MODE
;	Output -- Wait for D/A converter to settle
Hold:	btfss	PIR1,	TMR2IF	;Wait for ouput voltage level to settle
	goto	Hold
	bcf	T2CON,	TMR2ON	;Turn off Timer2

;	Output -- Enable analog output lines through external demultiplexer
	bsf	OUTSER,	OE	;Reconnect output lines after updating

;	Input -- Wait for A/D conversion to finish
;	         Ignore result in favor of stored value
	btfsc	ADCON0,	GO	;Wait for conversion to finish
	goto	Hold

;	Input -- Begin acquisition delay (for analog voltage)
	movlw	ACQDELAY		;Set acquisition delay
	movwf	TMR0
	bcf	INTCON,	T0IF	;and clear clock flag

;	Input -- Get QUANTIZD from QUANTCHx array
	movlw	QUANTCH0		;Load base address for QUANTCHx array
	addwf	FSR,	F	;Add base addr. to index already in FSR
	movf	INDF,	W	;Retrive proper array element
	movwf	QUANTIZD		;and save to QUANTIZD
	movlw	QUANTCH0		;Remove base address from value in FSR
	subwf	FSR,	F	;leaving only array index in FSR

;	Control -- Return to main program loop
	goto	ModeMrg

;	End of Hold mode

;	CALIBRATION MODE
;	Output -- Wait for D/A converter to settle
Calib:	btfss	PIR1,	TMR2IF	;Wait for ouput voltage level to settle
	goto	Calib
	bcf	T2CON,	TMR2ON	;Turn off Timer2

;	Output -- Enable analog output lines through external demultiplexer
	bsf	OUTSER,	OE	;Reconnect output lines after updating

;	Input -- Wait for A/D conversion to finish
;	         Ignore result in favor of stored value
	btfsc	ADCON0,	GO	;Wait for conversion to finish
	goto	Calib

;	Input -- Begin acquisition delay (for analog voltage)
	movlw	ACQDELAY		;Set acquisition delay
	movwf	TMR0
	bcf	INTCON,	T0IF	;and clear clock flag

;	Input -- Get QUANTIZD from QUANTCHx array
	movlw	CALIBCH0		;Load base address for CALIBCHx array
	addwf	FSR,	F	;Add base addr. to index already in FSR
	movf	INDF,	W	;Retrive proper array element
	movwf	QUANTIZD		;and save to QUANTIZD
	movlw	CALIBCH0		;Remove base address from value in FSR
	subwf	FSR,	F	;leaving only array index in FSR

;	Control -- Return to main program loop
	goto	ModeMrg

;	End of Calibration mode

;	END OF MAIN PROGRAM

;;;;;Subroutines;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;Initializ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;  The program uses all three I/O ports (PORTA, PORTB, PORTC), two of the three
;  timers (Timer0 and Timer2), and two of the many specialized modules (A/D Con-
;  verter and Master Synchronous Serial Port).  They are initialized as follows:
;
;    PORTA = INPUT,              TRISIN
;      ANSEL      (RAM Bank 3)  AN0 and AN! analog, AN2 through AN7 digital
;                               init = B'00000011' w/ movlw & movwf
;      TRISIN     (RAM Bank 1)  All inputs, by POR default
;      INPUT      (RAM Bank 0)  Assigned by hardware 
;
;    PORTB = OUTCHAN = OUTSCALE, TRISOUT
;      ANSELH     (RAM Bank 3)  AN8 through AN15 digital,
;                               init = B'00000000' w/ clrf
;      TRISOUT    (RAM Bank 1)  All outputs, init = B'00000000' w/ clrf
;      OUTCHAN    (RAM Bank 0)  Assigned in program
;
;    PORTC = OUTSER  = OUTROOT,  TRISSER
;      TRISSER    (RAM Bank 1)  All outputs except Serial Data In line,
;                               init = B'00010000' w/ clrf & bsf TRISSER, SDI
;      OUTSER     (RAM Bank 0)  init = B'01000000', ROOTTONE LED off
;                               and external circuit selects inactive
;
;    Timer0
;      OPTION_REG (RAM Bank 1)  Init = B'11011111' fr POR default = B'11111111'
;                               w/ bcf OPTION_REG, T0CS to select internal clk
;      TMR0       (RAM Bank 0)  Assigned in program
;      INTCON     (RAM Bank 0)  All clear by POR default, clear interrupt flag
;
;    Timer2
;      PR2        (RAM Bank 1)  Init = OUTDELAY w/ movlw & movwf
;      TMR2       (RAM Bank 0)  Clear by POR default
;      T2CON      (RAM Bank 0)  Clear by POR cefault
;                               no pre- or post scaling & Timer2 not counting
;
;    A/D Converter
;      ANSEL      (RAM Bank 3)  Not implemented in PIC 16F876A
;      ANSELH     (RAM Bank 3)  Not implemented in PIC 16F876A
;      ADRESL     (RAM Bank 1)  Assigned by hardware
;      ADCON1     (RAM Bank 1)  Init = B'00000100' fr POR default = B'00000000'
;                               w/bsf ADCON1, PCFG2 to set 2 low order lines as
;                               analog inputs, all other line as digital inputs,
;                               also set digital format & select conv. clock 
;      ADRESH     (RAM Bank 0)  Assigned by hardware
;      ADCON0     (RAM Bank 0)  Init = B'10000001' w/ movlw & movwf
;                               to select conversion clock, select input ch = 0,
;                               also clear GO flag & enable converter module
;
;    MSSP (SPI)
;      SSPSTAT    (RAM Bank 1)  Init = B'01000000' fr POR default = B'00000000'
;                               to select sample point & clear buffer full flag
;                               also select clock edge for SPI mode = 0,0
;      SSPBUF     (RAM Bank 0)  Assigned in program
;      SSPCON     (RAM Bank 0)  Init = B'00100000' fr POR default = B'00000000'
;                               to select SPI master mode 0,0 & enable module
;                               also clear error flags
;
;  In addition, the following variables are read before they are assigned in the
;  program, so they are initialized here as follows:
;    CALIBCHx	each channel's (constant) calibration value
;    QUANTCHx	each channel's immediate past QUANTIZD value
;    DIGLOCHx	each channel's immediate past A/D conversion value (lo byte)
;    DIGHICHx	each channel's immediate past A/D conversion value (hi byte)
;    QUANTIZD	immediate past quantized music value
;    OLDSCALE	immediate past scale selection
;  (The following initialization procedure requires that all of the foregoing)
;  (variables occupy adjacent bytes in RAM: 8 bytes each for the DIGHICHx and)
;  (the DIGLOCHx arrays, and 1 byte each for OLDLO, OLDHI, QUANTIZED, and    )
;  (OLDSCALE                                                                 )
;    FSR		used a channel pointer in program
;    CHANNEL	used to count channels and determine when to update scale 
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;	INITIALIZE HARDWARE (I/O, Timer 0, Timer 2, A/D converter and MSSP)

;;;;;RAM Bank 3;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
Initialz:	bsf	STATUS,	RP0	;Select data RAM Bank 3
	bsf	STATUS,	RP1

;	Set up I/O hardware
	movlw	B'00000011'	;Set 2 low order input bits to analog
	movwf	ANSEL		;Set all other input bits set to digital
	clrf	ANSELH		;Set all other analog lines to digital

;	bcf	STATUS,	RP1	;Select data RAM Bank 1

;;;;;RAM Bank 1;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
	bcf	STATUS,	RP1	;Select data RAM Bank 1

;	Set up I/O hardware
	clrf	TRISOUT		;OUTCHAN=OUTSCALE is all outputs
	clrf	TRISSER		;OUTSER=OUTROOT   is all outputs
	bsf	TRISSER,	SDI	;except for SDI (serial data in) line

;	Set up Timer0
	bcf	OPTION_REG, T0CS	;Select internal clock for Timer0

;	Set up Timer2
	movlw	OUTDELAY		;Load output slew-and-settle delay
	movwf	PR2		;into Timer2 period register 

;	Set up A/D converter	;2 low-order lines analog, per ANSEL

;	Set up Master Sync Serial Port
	bsf	SSPSTAT,	CKE	;SPI master mode = 0,0

;;;;;;;;;;RAM Bank 0;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
	bcf	STATUS,	RP0	;Select data RAM BANK 0

;	Set up I/O hardware
	clrf	OUTSER		;Init RootTone LED off, outp. mux frozen
	bsf	OUTSER,	SE	;and deselect D/A converter

;	Set up Timer0		;Need not init: flag already clear

;	Set up Timer2		;Need not init: noscale & not counting

;	Set up A/D converter
	movlw	B'10000001'	;Ensble converter, clock = 1/32,
	movwf	ADCON0		;also analog channel = 0, not converting

;	Set up Master Sync Serial Port
	bsf	SSPCON,	SSPEN	;Enable MSSP; SPI master mode = 0,0

;	INITIALIZE VARIABLES
;	Init calibration array CALIBCHx
	movlw	CALIBCH5		;Load address of 5th CALIBCHx element
	movwf	FSR		;into array index pointer
	movlw	D'10'*D'24'	;Assign highest note value
	movwf	CALIBCH7		;to highest CALIBCHx element
	movlw	D'7' *D'24'	;Assign 7th octave RootTone value
	movwf	CALIBCH6		;to next highest CALIBCHx element
	movlw	D'5'*D'24'	;Assign correspondng octave RootTones
Ini0Loop:	movwf	INDF		;to lower CALIBCHx array elements
	decf	FSR,	F	;Adjust array index pointer to prev. el.
	addlw	D'0'-D'24'	;Calculate prev. octave RootTone value
	btfss	STATUS,	Z	;End loop before first CALIBCHx element
	goto	Ini0Loop		;otherwise continue initialization loop
	movwf	INDF		;Initialize CALIBCH0 to lowest note val.

;	Initialize other program variables:
;	dummy past A/D conversion values (both bytes) for each channel
;	dummy past raw A/D conversion values (not strictly necessary)
;	dummy past quantized value, and
;	dummy past scale select value (rounded A/D high byte)
;	(This procedure requires that all variables initialized by it occupy )
;	(adjacent bytes in RAM: 8 bytes each for DIGHICHx and DIGLOCHx, and 1)
;	(byte each for OLDLO, OLDHI,QUANTIZED, and OLDSCALE                  )
	movlw	D'20'		;Use NOTE for loop counter
	movwf	NOTE
	movlw	OLDSCALE		;Set initialization pointer
	movwf	FSR		;to last variable to be initialized
	movlw	INITVAL		;Load initialization 
Ini1Loop:	movwf	INDF		;Initialize adjacent variables
	decf	FSR,	F
	decfsz	NOTE,	F
	goto	Ini1Loop

;	Final initializations for program control
	clrf	FSR		;Set FSR to point to channel 0
	clrf	CHANNEL		;Initialize CHANNEL
	decf	CHANNEL,	F	;to increment to 0 at main prog start

	return

;;;;;SetScale;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;	Update scale selection variable and display output
;	Check whether scale selection has changed
;	Calculate new scale scelect value from A/D conversion (ADRESH, ADRESL)
SetScale:	movlw	B'11110000'	;Ignore lower two bits of digital value
	andwf	ADRESH,	F	;and then mask out four next lowest bits
	bcf	STATUS,	C	;Use carry bit to provide shift bit
	btfsc	INPUT,	SHIFTSW	;Adjust shift bit according to SHIFTSW
	bsf	STATUS,	C	;and then
	rrf	ADRESH,	F	;rotate it into digitized select value

;	Check for new scale select value
	movf	OLDSCALE,	W	;Compare scale select value w/ OLDSCALE
	xorwf	ADRESH,	W	;(compare adjusted ADRESH with OLDSCALE)
	btfsc	STATUS,	Z	;If no change (ADRESH = OLDSCALE),
	return			;then abandon update process

;	If selected scale has changed, then display new scale
;	and update SCALETBL to point to proper look-up table
	movf	ADRESH,	W	;Use new scale selection value
	movwf	OLDSCALE		;to update OLDSCALE and also
	movf	OUTSCALE,	W	;to display new scale selection
	andlw	B'00000111'	;Mask old scale display
	iorwf	ADRESH,	W	;Combine new scale selection
	movwf	OUTSCALE		;Update display

	bcf	STATUS,	C	;Clear carry bit for rotate instruction
	rrf	ADRESH,	F	;Obtain new SCALETBLE
	rrf	ADRESH,	F	;by calculating scale index
	rrf	ADRESH,	F
	movlw	SCALEBAS		;and adding it to first scale index
	addwf	ADRESH,	W
	movwf	SCALETBL		;Save at SCALETBLE for table look-up

	sublw	SCALETOT		;Check scale selection for overflow
	btfsc	STATUS,	C	;If scale selection was okay
	return			;then keep SCALETBL
	movlw	SCALEDFT		;else use default scale index
	movwf	SCALETBL		;Save at SCALETBLE for table look-up
	return

;;;;;UpDate;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;	Update RootTone indicator led
UpDate:	movf	QUANTIZD,	W	;Use NOTE to examine tone
	movwf	NOTE		;Initialize NOTE = QUANTIZD
	movlw	D'24'		;Load octave interval

RootLoop:	subwf	NOTE,	F	;Repeatedly subtract octave interval
	btfsc	STATUS,	C	;from NOTE until result goes negative
	goto	RootLoop		;(i.e. until carry bit is clear)

	addwf	NOTE,	F	;Add back last subtracted octave
	
	bcf	OUTROOT,	ROOTLED	;Adjust RootTone indicator LED line
	btfsc	STATUS,	Z	;(from last addwf, test for 0)
	bsf	OUTROOT,	ROOTLED	;as appropriate

	return			;and then return to calling program

;;;;;SetLevel;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;	Quantize measured (and digitized) voltage
	org	JUMPBASE		;Jump prep immediately before tables
SetLevel: movf	SCALETBL,	W	;Move SCALETBLE to PCLATH
	movwf	PCLATH		;in preparation for jump
	movf	ADRESH,	W	;Adjust program counter
	addwf	PCL,	F	;for appropriate jump

;Half Tone look-up table
	org	HalfT		;Half Tone look-up table
	retlw	(D'00'*D'24')+D'00'	;scale=00bin=000octave=00note=00
	retlw	(D'00'*D'24')+D'00'	;scale=00bin=001octave=00note=01
	retlw	(D'00'*D'24')+D'02'	;scale=00bin=002octave=00note=02
	retlw	(D'00'*D'24')+D'02'	;scale=00bin=003octave=00note=03
	retlw	(D'00'*D'24')+D'04'	;scale=00bin=004octave=00note=04
	retlw	(D'00'*D'24')+D'04'	;scale=00bin=005octave=00note=05
	retlw	(D'00'*D'24')+D'06'	;scale=00bin=006octave=00note=06
	retlw	(D'00'*D'24')+D'06'	;scale=00bin=007octave=00note=07
	retlw	(D'00'*D'24')+D'08'	;scale=00bin=008octave=00note=08
	retlw	(D'00'*D'24')+D'08'	;scale=00bin=009octave=00note=09
	retlw	(D'00'*D'24')+D'10'	;scale=00bin=010octave=00note=10
	retlw	(D'00'*D'24')+D'10'	;scale=00bin=011octave=00note=11
	retlw	(D'00'*D'24')+D'12'	;scale=00bin=012octave=00note=12
	retlw	(D'00'*D'24')+D'12'	;scale=00bin=013octave=00note=13
	retlw	(D'00'*D'24')+D'14'	;scale=00bin=014octave=00note=14
	retlw	(D'00'*D'24')+D'14'	;scale=00bin=015octave=00note=15
	retlw	(D'00'*D'24')+D'16'	;scale=00bin=016octave=00note=16
	retlw	(D'00'*D'24')+D'16'	;scale=00bin=017octave=00note=17
	retlw	(D'00'*D'24')+D'18'	;scale=00bin=018octave=00note=18
	retlw	(D'00'*D'24')+D'18'	;scale=00bin=019octave=00note=19
	retlw	(D'00'*D'24')+D'20'	;scale=00bin=020octave=00note=20
	retlw	(D'00'*D'24')+D'20'	;scale=00bin=021octave=00note=21
	retlw	(D'00'*D'24')+D'22'	;scale=00bin=022octave=00note=22
	retlw	(D'00'*D'24')+D'22'	;scale=00bin=023octave=00note=23
	retlw	(D'01'*D'24')+D'00'	;scale=00bin=024octave=01note=00
	retlw	(D'01'*D'24')+D'00'	;scale=00bin=025octave=01note=01
	retlw	(D'01'*D'24')+D'02'	;scale=00bin=026octave=01note=02
	retlw	(D'01'*D'24')+D'02'	;scale=00bin=027octave=01note=03
	retlw	(D'01'*D'24')+D'04'	;scale=00bin=028octave=01note=04
	retlw	(D'01'*D'24')+D'04'	;scale=00bin=029octave=01note=05
	retlw	(D'01'*D'24')+D'06'	;scale=00bin=030octave=01note=06
	retlw	(D'01'*D'24')+D'06'	;scale=00bin=031octave=01note=07
	retlw	(D'01'*D'24')+D'08'	;scale=00bin=032octave=01note=08
	retlw	(D'01'*D'24')+D'08'	;scale=00bin=033octave=01note=09
	retlw	(D'01'*D'24')+D'10'	;scale=00bin=034octave=01note=10
	retlw	(D'01'*D'24')+D'10'	;scale=00bin=035octave=01note=11
	retlw	(D'01'*D'24')+D'12'	;scale=00bin=036octave=01note=12
	retlw	(D'01'*D'24')+D'12'	;scale=00bin=037octave=01note=13
	retlw	(D'01'*D'24')+D'14'	;scale=00bin=038octave=01note=14
	retlw	(D'01'*D'24')+D'14'	;scale=00bin=039octave=01note=15
	retlw	(D'01'*D'24')+D'16'	;scale=00bin=040octave=01note=16
	retlw	(D'01'*D'24')+D'16'	;scale=00bin=041octave=01note=17
	retlw	(D'01'*D'24')+D'18'	;scale=00bin=042octave=01note=18
	retlw	(D'01'*D'24')+D'18'	;scale=00bin=043octave=01note=19
	retlw	(D'01'*D'24')+D'20'	;scale=00bin=044octave=01note=20
	retlw	(D'01'*D'24')+D'20'	;scale=00bin=045octave=01note=21
	retlw	(D'01'*D'24')+D'22'	;scale=00bin=046octave=01note=22
	retlw	(D'01'*D'24')+D'22'	;scale=00bin=047octave=01note=23
	retlw	(D'02'*D'24')+D'00'	;scale=00bin=048octave=02note=00
	retlw	(D'02'*D'24')+D'00'	;scale=00bin=049octave=02note=01
	retlw	(D'02'*D'24')+D'02'	;scale=00bin=050octave=02note=02
	retlw	(D'02'*D'24')+D'02'	;scale=00bin=051octave=02note=03
	retlw	(D'02'*D'24')+D'04'	;scale=00bin=052octave=02note=04
	retlw	(D'02'*D'24')+D'04'	;scale=00bin=053octave=02note=05
	retlw	(D'02'*D'24')+D'06'	;scale=00bin=054octave=02note=06
	retlw	(D'02'*D'24')+D'06'	;scale=00bin=055octave=02note=07
	retlw	(D'02'*D'24')+D'08'	;scale=00bin=056octave=02note=08
	retlw	(D'02'*D'24')+D'08'	;scale=00bin=057octave=02note=09
	retlw	(D'02'*D'24')+D'10'	;scale=00bin=058octave=02note=10
	retlw	(D'02'*D'24')+D'10'	;scale=00bin=059octave=02note=11
	retlw	(D'02'*D'24')+D'12'	;scale=00bin=060octave=02note=12
	retlw	(D'02'*D'24')+D'12'	;scale=00bin=061octave=02note=13
	retlw	(D'02'*D'24')+D'14'	;scale=00bin=062octave=02note=14
	retlw	(D'02'*D'24')+D'14'	;scale=00bin=063octave=02note=15
	retlw	(D'02'*D'24')+D'16'	;scale=00bin=064octave=02note=16
	retlw	(D'02'*D'24')+D'16'	;scale=00bin=065octave=02note=17
	retlw	(D'02'*D'24')+D'18'	;scale=00bin=066octave=02note=18
	retlw	(D'02'*D'24')+D'18'	;scale=00bin=067octave=02note=19
	retlw	(D'02'*D'24')+D'20'	;scale=00bin=068octave=02note=20
	retlw	(D'02'*D'24')+D'20'	;scale=00bin=069octave=02note=21
	retlw	(D'02'*D'24')+D'22'	;scale=00bin=070octave=02note=22
	retlw	(D'02'*D'24')+D'22'	;scale=00bin=071octave=02note=23
	retlw	(D'03'*D'24')+D'00'	;scale=00bin=072octave=03note=00
	retlw	(D'03'*D'24')+D'00'	;scale=00bin=073octave=03note=01
	retlw	(D'03'*D'24')+D'02'	;scale=00bin=074octave=03note=02
	retlw	(D'03'*D'24')+D'02'	;scale=00bin=075octave=03note=03
	retlw	(D'03'*D'24')+D'04'	;scale=00bin=076octave=03note=04
	retlw	(D'03'*D'24')+D'04'	;scale=00bin=077octave=03note=05
	retlw	(D'03'*D'24')+D'06'	;scale=00bin=078octave=03note=06
	retlw	(D'03'*D'24')+D'06'	;scale=00bin=079octave=03note=07
	retlw	(D'03'*D'24')+D'08'	;scale=00bin=080octave=03note=08
	retlw	(D'03'*D'24')+D'08'	;scale=00bin=081octave=03note=09
	retlw	(D'03'*D'24')+D'10'	;scale=00bin=082octave=03note=10
	retlw	(D'03'*D'24')+D'10'	;scale=00bin=083octave=03note=11
	retlw	(D'03'*D'24')+D'12'	;scale=00bin=084octave=03note=12
	retlw	(D'03'*D'24')+D'12'	;scale=00bin=085octave=03note=13
	retlw	(D'03'*D'24')+D'14'	;scale=00bin=086octave=03note=14
	retlw	(D'03'*D'24')+D'14'	;scale=00bin=087octave=03note=15
	retlw	(D'03'*D'24')+D'16'	;scale=00bin=088octave=03note=16
	retlw	(D'03'*D'24')+D'16'	;scale=00bin=089octave=03note=17
	retlw	(D'03'*D'24')+D'18'	;scale=00bin=090octave=03note=18
	retlw	(D'03'*D'24')+D'18'	;scale=00bin=091octave=03note=19
	retlw	(D'03'*D'24')+D'20'	;scale=00bin=092octave=03note=20
	retlw	(D'03'*D'24')+D'20'	;scale=00bin=093octave=03note=21
	retlw	(D'03'*D'24')+D'22'	;scale=00bin=094octave=03note=22
	retlw	(D'03'*D'24')+D'22'	;scale=00bin=095octave=03note=23
	retlw	(D'04'*D'24')+D'00'	;scale=00bin=096octave=04note=00
	retlw	(D'04'*D'24')+D'00'	;scale=00bin=097octave=04note=01
	retlw	(D'04'*D'24')+D'02'	;scale=00bin=098octave=04note=02
	retlw	(D'04'*D'24')+D'02'	;scale=00bin=099octave=04note=03
	retlw	(D'04'*D'24')+D'04'	;scale=00bin=100octave=04note=04
	retlw	(D'04'*D'24')+D'04'	;scale=00bin=101octave=04note=05
	retlw	(D'04'*D'24')+D'06'	;scale=00bin=102octave=04note=06
	retlw	(D'04'*D'24')+D'06'	;scale=00bin=103octave=04note=07
	retlw	(D'04'*D'24')+D'08'	;scale=00bin=104octave=04note=08
	retlw	(D'04'*D'24')+D'08'	;scale=00bin=105octave=04note=09
	retlw	(D'04'*D'24')+D'10'	;scale=00bin=106octave=04note=10
	retlw	(D'04'*D'24')+D'10'	;scale=00bin=107octave=04note=11
	retlw	(D'04'*D'24')+D'12'	;scale=00bin=108octave=04note=12
	retlw	(D'04'*D'24')+D'12'	;scale=00bin=109octave=04note=13
	retlw	(D'04'*D'24')+D'14'	;scale=00bin=110octave=04note=14
	retlw	(D'04'*D'24')+D'14'	;scale=00bin=111octave=04note=15
	retlw	(D'04'*D'24')+D'16'	;scale=00bin=112octave=04note=16
	retlw	(D'04'*D'24')+D'16'	;scale=00bin=113octave=04note=17
	retlw	(D'04'*D'24')+D'18'	;scale=00bin=114octave=04note=18
	retlw	(D'04'*D'24')+D'18'	;scale=00bin=115octave=04note=19
	retlw	(D'04'*D'24')+D'20'	;scale=00bin=116octave=04note=20
	retlw	(D'04'*D'24')+D'20'	;scale=00bin=117octave=04note=21
	retlw	(D'04'*D'24')+D'22'	;scale=00bin=118octave=04note=22
	retlw	(D'04'*D'24')+D'22'	;scale=00bin=119octave=04note=23
	retlw	(D'05'*D'24')+D'00'	;scale=00bin=120octave=05note=00
	retlw	(D'05'*D'24')+D'00'	;scale=00bin=121octave=05note=01
	retlw	(D'05'*D'24')+D'02'	;scale=00bin=122octave=05note=02
	retlw	(D'05'*D'24')+D'02'	;scale=00bin=123octave=05note=03
	retlw	(D'05'*D'24')+D'04'	;scale=00bin=124octave=05note=04
	retlw	(D'05'*D'24')+D'04'	;scale=00bin=125octave=05note=05
	retlw	(D'05'*D'24')+D'06'	;scale=00bin=126octave=05note=06
	retlw	(D'05'*D'24')+D'06'	;scale=00bin=127octave=05note=07
	retlw	(D'05'*D'24')+D'08'	;scale=00bin=128octave=05note=08
	retlw	(D'05'*D'24')+D'08'	;scale=00bin=129octave=05note=09
	retlw	(D'05'*D'24')+D'10'	;scale=00bin=130octave=05note=10
	retlw	(D'05'*D'24')+D'10'	;scale=00bin=131octave=05note=11
	retlw	(D'05'*D'24')+D'12'	;scale=00bin=132octave=05note=12
	retlw	(D'05'*D'24')+D'12'	;scale=00bin=133octave=05note=13
	retlw	(D'05'*D'24')+D'14'	;scale=00bin=134octave=05note=14
	retlw	(D'05'*D'24')+D'14'	;scale=00bin=135octave=05note=15
	retlw	(D'05'*D'24')+D'16'	;scale=00bin=136octave=05note=16
	retlw	(D'05'*D'24')+D'16'	;scale=00bin=137octave=05note=17
	retlw	(D'05'*D'24')+D'18'	;scale=00bin=138octave=05note=18
	retlw	(D'05'*D'24')+D'18'	;scale=00bin=139octave=05note=19
	retlw	(D'05'*D'24')+D'20'	;scale=00bin=140octave=05note=20
	retlw	(D'05'*D'24')+D'20'	;scale=00bin=141octave=05note=21
	retlw	(D'05'*D'24')+D'22'	;scale=00bin=142octave=05note=22
	retlw	(D'05'*D'24')+D'22'	;scale=00bin=143octave=05note=23
	retlw	(D'06'*D'24')+D'00'	;scale=00bin=144octave=06note=00
	retlw	(D'06'*D'24')+D'00'	;scale=00bin=145octave=06note=01
	retlw	(D'06'*D'24')+D'02'	;scale=00bin=146octave=06note=02
	retlw	(D'06'*D'24')+D'02'	;scale=00bin=147octave=06note=03
	retlw	(D'06'*D'24')+D'04'	;scale=00bin=148octave=06note=04
	retlw	(D'06'*D'24')+D'04'	;scale=00bin=149octave=06note=05
	retlw	(D'06'*D'24')+D'06'	;scale=00bin=150octave=06note=06
	retlw	(D'06'*D'24')+D'06'	;scale=00bin=151octave=06note=07
	retlw	(D'06'*D'24')+D'08'	;scale=00bin=152octave=06note=08
	retlw	(D'06'*D'24')+D'08'	;scale=00bin=153octave=06note=09
	retlw	(D'06'*D'24')+D'10'	;scale=00bin=154octave=06note=10
	retlw	(D'06'*D'24')+D'10'	;scale=00bin=155octave=06note=11
	retlw	(D'06'*D'24')+D'12'	;scale=00bin=156octave=06note=12
	retlw	(D'06'*D'24')+D'12'	;scale=00bin=157octave=06note=13
	retlw	(D'06'*D'24')+D'14'	;scale=00bin=158octave=06note=14
	retlw	(D'06'*D'24')+D'14'	;scale=00bin=159octave=06note=15
	retlw	(D'06'*D'24')+D'16'	;scale=00bin=160octave=06note=16
	retlw	(D'06'*D'24')+D'16'	;scale=00bin=161octave=06note=17
	retlw	(D'06'*D'24')+D'18'	;scale=00bin=162octave=06note=18
	retlw	(D'06'*D'24')+D'18'	;scale=00bin=163octave=06note=19
	retlw	(D'06'*D'24')+D'20'	;scale=00bin=164octave=06note=20
	retlw	(D'06'*D'24')+D'20'	;scale=00bin=165octave=06note=21
	retlw	(D'06'*D'24')+D'22'	;scale=00bin=166octave=06note=22
	retlw	(D'06'*D'24')+D'22'	;scale=00bin=167octave=06note=23
	retlw	(D'07'*D'24')+D'00'	;scale=00bin=168octave=07note=00
	retlw	(D'07'*D'24')+D'00'	;scale=00bin=169octave=07note=01
	retlw	(D'07'*D'24')+D'02'	;scale=00bin=170octave=07note=02
	retlw	(D'07'*D'24')+D'02'	;scale=00bin=171octave=07note=03
	retlw	(D'07'*D'24')+D'04'	;scale=00bin=172octave=07note=04
	retlw	(D'07'*D'24')+D'04'	;scale=00bin=173octave=07note=05
	retlw	(D'07'*D'24')+D'06'	;scale=00bin=174octave=07note=06
	retlw	(D'07'*D'24')+D'06'	;scale=00bin=175octave=07note=07
	retlw	(D'07'*D'24')+D'08'	;scale=00bin=176octave=07note=08
	retlw	(D'07'*D'24')+D'08'	;scale=00bin=177octave=07note=09
	retlw	(D'07'*D'24')+D'10'	;scale=00bin=178octave=07note=10
	retlw	(D'07'*D'24')+D'10'	;scale=00bin=179octave=07note=11
	retlw	(D'07'*D'24')+D'12'	;scale=00bin=180octave=07note=12
	retlw	(D'07'*D'24')+D'12'	;scale=00bin=181octave=07note=13
	retlw	(D'07'*D'24')+D'14'	;scale=00bin=182octave=07note=14
	retlw	(D'07'*D'24')+D'14'	;scale=00bin=183octave=07note=15
	retlw	(D'07'*D'24')+D'16'	;scale=00bin=184octave=07note=16
	retlw	(D'07'*D'24')+D'16'	;scale=00bin=185octave=07note=17
	retlw	(D'07'*D'24')+D'18'	;scale=00bin=186octave=07note=18
	retlw	(D'07'*D'24')+D'18'	;scale=00bin=187octave=07note=19
	retlw	(D'07'*D'24')+D'20'	;scale=00bin=188octave=07note=20
	retlw	(D'07'*D'24')+D'20'	;scale=00bin=189octave=07note=21
	retlw	(D'07'*D'24')+D'22'	;scale=00bin=190octave=07note=22
	retlw	(D'07'*D'24')+D'22'	;scale=00bin=191octave=07note=23
	retlw	(D'08'*D'24')+D'00'	;scale=00bin=192octave=08note=00
	retlw	(D'08'*D'24')+D'00'	;scale=00bin=193octave=08note=01
	retlw	(D'08'*D'24')+D'02'	;scale=00bin=194octave=08note=02
	retlw	(D'08'*D'24')+D'02'	;scale=00bin=195octave=08note=03
	retlw	(D'08'*D'24')+D'04'	;scale=00bin=196octave=08note=04
	retlw	(D'08'*D'24')+D'04'	;scale=00bin=197octave=08note=05
	retlw	(D'08'*D'24')+D'06'	;scale=00bin=198octave=08note=06
	retlw	(D'08'*D'24')+D'06'	;scale=00bin=199octave=08note=07
	retlw	(D'08'*D'24')+D'08'	;scale=00bin=200octave=08note=08
	retlw	(D'08'*D'24')+D'08'	;scale=00bin=201octave=08note=09
	retlw	(D'08'*D'24')+D'10'	;scale=00bin=202octave=08note=10
	retlw	(D'08'*D'24')+D'10'	;scale=00bin=203octave=08note=11
	retlw	(D'08'*D'24')+D'12'	;scale=00bin=204octave=08note=12
	retlw	(D'08'*D'24')+D'12'	;scale=00bin=205octave=08note=13
	retlw	(D'08'*D'24')+D'14'	;scale=00bin=206octave=08note=14
	retlw	(D'08'*D'24')+D'14'	;scale=00bin=207octave=08note=15
	retlw	(D'08'*D'24')+D'16'	;scale=00bin=208octave=08note=16
	retlw	(D'08'*D'24')+D'16'	;scale=00bin=209octave=08note=17
	retlw	(D'08'*D'24')+D'18'	;scale=00bin=210octave=08note=18
	retlw	(D'08'*D'24')+D'18'	;scale=00bin=211octave=08note=19
	retlw	(D'08'*D'24')+D'20'	;scale=00bin=212octave=08note=20
	retlw	(D'08'*D'24')+D'20'	;scale=00bin=213octave=08note=21
	retlw	(D'08'*D'24')+D'22'	;scale=00bin=214octave=08note=22
	retlw	(D'08'*D'24')+D'22'	;scale=00bin=215octave=08note=23
	retlw	(D'09'*D'24')+D'00'	;scale=00bin=216octave=09note=00
	retlw	(D'09'*D'24')+D'00'	;scale=00bin=217octave=09note=01
	retlw	(D'09'*D'24')+D'02'	;scale=00bin=218octave=09note=02
	retlw	(D'09'*D'24')+D'02'	;scale=00bin=219octave=09note=03
	retlw	(D'09'*D'24')+D'04'	;scale=00bin=220octave=09note=04
	retlw	(D'09'*D'24')+D'04'	;scale=00bin=221octave=09note=05
	retlw	(D'09'*D'24')+D'06'	;scale=00bin=222octave=09note=06
	retlw	(D'09'*D'24')+D'06'	;scale=00bin=223octave=09note=07
	retlw	(D'09'*D'24')+D'08'	;scale=00bin=224octave=09note=08
	retlw	(D'09'*D'24')+D'08'	;scale=00bin=225octave=09note=09
	retlw	(D'09'*D'24')+D'10'	;scale=00bin=226octave=09note=10
	retlw	(D'09'*D'24')+D'10'	;scale=00bin=227octave=09note=11
	retlw	(D'09'*D'24')+D'12'	;scale=00bin=228octave=09note=12
	retlw	(D'09'*D'24')+D'12'	;scale=00bin=229octave=09note=13
	retlw	(D'09'*D'24')+D'14'	;scale=00bin=230octave=09note=14
	retlw	(D'09'*D'24')+D'14'	;scale=00bin=231octave=09note=15
	retlw	(D'09'*D'24')+D'16'	;scale=00bin=232octave=09note=16
	retlw	(D'09'*D'24')+D'16'	;scale=00bin=233octave=09note=17
	retlw	(D'09'*D'24')+D'18'	;scale=00bin=234octave=09note=18
	retlw	(D'09'*D'24')+D'18'	;scale=00bin=235octave=09note=19
	retlw	(D'09'*D'24')+D'20'	;scale=00bin=236octave=09note=20
	retlw	(D'09'*D'24')+D'20'	;scale=00bin=237octave=09note=21
	retlw	(D'09'*D'24')+D'22'	;scale=00bin=238octave=09note=22
	retlw	(D'09'*D'24')+D'22'	;scale=00bin=239octave=09note=23
	retlw	(D'10'*D'24')+D'00'	;scale=00bin=240octave=10note=00
	retlw	(D'10'*D'24')+D'00'	;scale=00bin=241octave=10note=01
	retlw	(D'10'*D'24')+D'00'	;scale=00bin=242octave=10note=02
	retlw	(D'10'*D'24')+D'00'	;scale=00bin=243octave=10note=03
	retlw	(D'10'*D'24')+D'00'	;scale=00bin=244octave=10note=04
	retlw	(D'10'*D'24')+D'00'	;scale=00bin=245octave=10note=05
	retlw	(D'10'*D'24')+D'00'	;scale=00bin=246octave=10note=06
	retlw	(D'10'*D'24')+D'00'	;scale=00bin=247octave=10note=07
	retlw	(D'10'*D'24')+D'00'	;scale=00bin=248octave=10note=08
	retlw	(D'10'*D'24')+D'00'	;scale=00bin=249octave=10note=09
	retlw	(D'10'*D'24')+D'00'	;scale=00bin=250octave=10note=10
	retlw	(D'10'*D'24')+D'00'	;scale=00bin=251octave=10note=11
	retlw	(D'10'*D'24')+D'00'	;scale=00bin=252octave=10note=12
	retlw	(D'10'*D'24')+D'00'	;scale=00bin=253octave=10note=13
	retlw	(D'10'*D'24')+D'00'	;scale=00bin=254octave=10note=14
	retlw	(D'10'*D'24')+D'00'	;scale=00bin=255octave=10note=15

;Whole Tone look-up table
	org	WholeT		;Whole Tone look-up table
	retlw	(D'00'*D'24')+D'00'	;scale=01bin=000octave=00note=00
	retlw	(D'00'*D'24')+D'00'	;scale=01bin=001octave=00note=01
	retlw	(D'00'*D'24')+D'00'	;scale=01bin=002octave=00note=02
	retlw	(D'00'*D'24')+D'00'	;scale=01bin=003octave=00note=03
	retlw	(D'00'*D'24')+D'04'	;scale=01bin=004octave=00note=04
	retlw	(D'00'*D'24')+D'04'	;scale=01bin=005octave=00note=05
	retlw	(D'00'*D'24')+D'04'	;scale=01bin=006octave=00note=06
	retlw	(D'00'*D'24')+D'04'	;scale=01bin=007octave=00note=07
	retlw	(D'00'*D'24')+D'08'	;scale=01bin=008octave=00note=08
	retlw	(D'00'*D'24')+D'08'	;scale=01bin=009octave=00note=09
	retlw	(D'00'*D'24')+D'08'	;scale=01bin=010octave=00note=10
	retlw	(D'00'*D'24')+D'08'	;scale=01bin=011octave=00note=11
	retlw	(D'00'*D'24')+D'12'	;scale=01bin=012octave=00note=12
	retlw	(D'00'*D'24')+D'12'	;scale=01bin=013octave=00note=13
	retlw	(D'00'*D'24')+D'12'	;scale=01bin=014octave=00note=14
	retlw	(D'00'*D'24')+D'12'	;scale=01bin=015octave=00note=15
	retlw	(D'00'*D'24')+D'16'	;scale=01bin=016octave=00note=16
	retlw	(D'00'*D'24')+D'16'	;scale=01bin=017octave=00note=17
	retlw	(D'00'*D'24')+D'16'	;scale=01bin=018octave=00note=18
	retlw	(D'00'*D'24')+D'16'	;scale=01bin=019octave=00note=19
	retlw	(D'00'*D'24')+D'20'	;scale=01bin=020octave=00note=20
	retlw	(D'00'*D'24')+D'20'	;scale=01bin=021octave=00note=21
	retlw	(D'00'*D'24')+D'20'	;scale=01bin=022octave=00note=22
	retlw	(D'00'*D'24')+D'20'	;scale=01bin=023octave=00note=23
	retlw	(D'01'*D'24')+D'00'	;scale=01bin=024octave=01note=00
	retlw	(D'01'*D'24')+D'00'	;scale=01bin=025octave=01note=01
	retlw	(D'01'*D'24')+D'00'	;scale=01bin=026octave=01note=02
	retlw	(D'01'*D'24')+D'00'	;scale=01bin=027octave=01note=03
	retlw	(D'01'*D'24')+D'04'	;scale=01bin=028octave=01note=04
	retlw	(D'01'*D'24')+D'04'	;scale=01bin=029octave=01note=05
	retlw	(D'01'*D'24')+D'04'	;scale=01bin=030octave=01note=06
	retlw	(D'01'*D'24')+D'04'	;scale=01bin=031octave=01note=07
	retlw	(D'01'*D'24')+D'08'	;scale=01bin=032octave=01note=08
	retlw	(D'01'*D'24')+D'08'	;scale=01bin=033octave=01note=09
	retlw	(D'01'*D'24')+D'08'	;scale=01bin=034octave=01note=10
	retlw	(D'01'*D'24')+D'08'	;scale=01bin=035octave=01note=11
	retlw	(D'01'*D'24')+D'12'	;scale=01bin=036octave=01note=12
	retlw	(D'01'*D'24')+D'12'	;scale=01bin=037octave=01note=13
	retlw	(D'01'*D'24')+D'12'	;scale=01bin=038octave=01note=14
	retlw	(D'01'*D'24')+D'12'	;scale=01bin=039octave=01note=15
	retlw	(D'01'*D'24')+D'16'	;scale=01bin=040octave=01note=16
	retlw	(D'01'*D'24')+D'16'	;scale=01bin=041octave=01note=17
	retlw	(D'01'*D'24')+D'16'	;scale=01bin=042octave=01note=18
	retlw	(D'01'*D'24')+D'16'	;scale=01bin=043octave=01note=19
	retlw	(D'01'*D'24')+D'20'	;scale=01bin=044octave=01note=20
	retlw	(D'01'*D'24')+D'20'	;scale=01bin=045octave=01note=21
	retlw	(D'01'*D'24')+D'20'	;scale=01bin=046octave=01note=22
	retlw	(D'01'*D'24')+D'20'	;scale=01bin=047octave=01note=23
	retlw	(D'02'*D'24')+D'00'	;scale=01bin=048octave=02note=00
	retlw	(D'02'*D'24')+D'00'	;scale=01bin=049octave=02note=01
	retlw	(D'02'*D'24')+D'00'	;scale=01bin=050octave=02note=02
	retlw	(D'02'*D'24')+D'00'	;scale=01bin=051octave=02note=03
	retlw	(D'02'*D'24')+D'04'	;scale=01bin=052octave=02note=04
	retlw	(D'02'*D'24')+D'04'	;scale=01bin=053octave=02note=05
	retlw	(D'02'*D'24')+D'04'	;scale=01bin=054octave=02note=06
	retlw	(D'02'*D'24')+D'04'	;scale=01bin=055octave=02note=07
	retlw	(D'02'*D'24')+D'08'	;scale=01bin=056octave=02note=08
	retlw	(D'02'*D'24')+D'08'	;scale=01bin=057octave=02note=09
	retlw	(D'02'*D'24')+D'08'	;scale=01bin=058octave=02note=10
	retlw	(D'02'*D'24')+D'08'	;scale=01bin=059octave=02note=11
	retlw	(D'02'*D'24')+D'12'	;scale=01bin=060octave=02note=12
	retlw	(D'02'*D'24')+D'12'	;scale=01bin=061octave=02note=13
	retlw	(D'02'*D'24')+D'12'	;scale=01bin=062octave=02note=14
	retlw	(D'02'*D'24')+D'12'	;scale=01bin=063octave=02note=15
	retlw	(D'02'*D'24')+D'16'	;scale=01bin=064octave=02note=16
	retlw	(D'02'*D'24')+D'16'	;scale=01bin=065octave=02note=17
	retlw	(D'02'*D'24')+D'16'	;scale=01bin=066octave=02note=18
	retlw	(D'02'*D'24')+D'16'	;scale=01bin=067octave=02note=19
	retlw	(D'02'*D'24')+D'20'	;scale=01bin=068octave=02note=20
	retlw	(D'02'*D'24')+D'20'	;scale=01bin=069octave=02note=21
	retlw	(D'02'*D'24')+D'20'	;scale=01bin=070octave=02note=22
	retlw	(D'02'*D'24')+D'20'	;scale=01bin=071octave=02note=23
	retlw	(D'03'*D'24')+D'00'	;scale=01bin=072octave=03note=00
	retlw	(D'03'*D'24')+D'00'	;scale=01bin=073octave=03note=01
	retlw	(D'03'*D'24')+D'00'	;scale=01bin=074octave=03note=02
	retlw	(D'03'*D'24')+D'00'	;scale=01bin=075octave=03note=03
	retlw	(D'03'*D'24')+D'04'	;scale=01bin=076octave=03note=04
	retlw	(D'03'*D'24')+D'04'	;scale=01bin=077octave=03note=05
	retlw	(D'03'*D'24')+D'04'	;scale=01bin=078octave=03note=06
	retlw	(D'03'*D'24')+D'04'	;scale=01bin=079octave=03note=07
	retlw	(D'03'*D'24')+D'08'	;scale=01bin=080octave=03note=08
	retlw	(D'03'*D'24')+D'08'	;scale=01bin=081octave=03note=09
	retlw	(D'03'*D'24')+D'08'	;scale=01bin=082octave=03note=10
	retlw	(D'03'*D'24')+D'08'	;scale=01bin=083octave=03note=11
	retlw	(D'03'*D'24')+D'12'	;scale=01bin=084octave=03note=12
	retlw	(D'03'*D'24')+D'12'	;scale=01bin=085octave=03note=13
	retlw	(D'03'*D'24')+D'12'	;scale=01bin=086octave=03note=14
	retlw	(D'03'*D'24')+D'12'	;scale=01bin=087octave=03note=15
	retlw	(D'03'*D'24')+D'16'	;scale=01bin=088octave=03note=16
	retlw	(D'03'*D'24')+D'16'	;scale=01bin=089octave=03note=17
	retlw	(D'03'*D'24')+D'16'	;scale=01bin=090octave=03note=18
	retlw	(D'03'*D'24')+D'16'	;scale=01bin=091octave=03note=19
	retlw	(D'03'*D'24')+D'20'	;scale=01bin=092octave=03note=20
	retlw	(D'03'*D'24')+D'20'	;scale=01bin=093octave=03note=21
	retlw	(D'03'*D'24')+D'20'	;scale=01bin=094octave=03note=22
	retlw	(D'03'*D'24')+D'20'	;scale=01bin=095octave=03note=23
	retlw	(D'04'*D'24')+D'00'	;scale=01bin=096octave=04note=00
	retlw	(D'04'*D'24')+D'00'	;scale=01bin=097octave=04note=01
	retlw	(D'04'*D'24')+D'00'	;scale=01bin=098octave=04note=02
	retlw	(D'04'*D'24')+D'00'	;scale=01bin=099octave=04note=03
	retlw	(D'04'*D'24')+D'04'	;scale=01bin=100octave=04note=04
	retlw	(D'04'*D'24')+D'04'	;scale=01bin=101octave=04note=05
	retlw	(D'04'*D'24')+D'04'	;scale=01bin=102octave=04note=06
	retlw	(D'04'*D'24')+D'04'	;scale=01bin=103octave=04note=07
	retlw	(D'04'*D'24')+D'08'	;scale=01bin=104octave=04note=08
	retlw	(D'04'*D'24')+D'08'	;scale=01bin=105octave=04note=09
	retlw	(D'04'*D'24')+D'08'	;scale=01bin=106octave=04note=10
	retlw	(D'04'*D'24')+D'08'	;scale=01bin=107octave=04note=11
	retlw	(D'04'*D'24')+D'12'	;scale=01bin=108octave=04note=12
	retlw	(D'04'*D'24')+D'12'	;scale=01bin=109octave=04note=13
	retlw	(D'04'*D'24')+D'12'	;scale=01bin=110octave=04note=14
	retlw	(D'04'*D'24')+D'12'	;scale=01bin=111octave=04note=15
	retlw	(D'04'*D'24')+D'16'	;scale=01bin=112octave=04note=16
	retlw	(D'04'*D'24')+D'16'	;scale=01bin=113octave=04note=17
	retlw	(D'04'*D'24')+D'16'	;scale=01bin=114octave=04note=18
	retlw	(D'04'*D'24')+D'16'	;scale=01bin=115octave=04note=19
	retlw	(D'04'*D'24')+D'20'	;scale=01bin=116octave=04note=20
	retlw	(D'04'*D'24')+D'20'	;scale=01bin=117octave=04note=21
	retlw	(D'04'*D'24')+D'20'	;scale=01bin=118octave=04note=22
	retlw	(D'04'*D'24')+D'20'	;scale=01bin=119octave=04note=23
	retlw	(D'05'*D'24')+D'00'	;scale=01bin=120octave=05note=00
	retlw	(D'05'*D'24')+D'00'	;scale=01bin=121octave=05note=01
	retlw	(D'05'*D'24')+D'00'	;scale=01bin=122octave=05note=02
	retlw	(D'05'*D'24')+D'00'	;scale=01bin=123octave=05note=03
	retlw	(D'05'*D'24')+D'04'	;scale=01bin=124octave=05note=04
	retlw	(D'05'*D'24')+D'04'	;scale=01bin=125octave=05note=05
	retlw	(D'05'*D'24')+D'04'	;scale=01bin=126octave=05note=06
	retlw	(D'05'*D'24')+D'04'	;scale=01bin=127octave=05note=07
	retlw	(D'05'*D'24')+D'08'	;scale=01bin=128octave=05note=08
	retlw	(D'05'*D'24')+D'08'	;scale=01bin=129octave=05note=09
	retlw	(D'05'*D'24')+D'08'	;scale=01bin=130octave=05note=10
	retlw	(D'05'*D'24')+D'08'	;scale=01bin=131octave=05note=11
	retlw	(D'05'*D'24')+D'12'	;scale=01bin=132octave=05note=12
	retlw	(D'05'*D'24')+D'12'	;scale=01bin=133octave=05note=13
	retlw	(D'05'*D'24')+D'12'	;scale=01bin=134octave=05note=14
	retlw	(D'05'*D'24')+D'12'	;scale=01bin=135octave=05note=15
	retlw	(D'05'*D'24')+D'16'	;scale=01bin=136octave=05note=16
	retlw	(D'05'*D'24')+D'16'	;scale=01bin=137octave=05note=17
	retlw	(D'05'*D'24')+D'16'	;scale=01bin=138octave=05note=18
	retlw	(D'05'*D'24')+D'16'	;scale=01bin=139octave=05note=19
	retlw	(D'05'*D'24')+D'20'	;scale=01bin=140octave=05note=20
	retlw	(D'05'*D'24')+D'20'	;scale=01bin=141octave=05note=21
	retlw	(D'05'*D'24')+D'20'	;scale=01bin=142octave=05note=22
	retlw	(D'05'*D'24')+D'20'	;scale=01bin=143octave=05note=23
	retlw	(D'06'*D'24')+D'00'	;scale=01bin=144octave=06note=00
	retlw	(D'06'*D'24')+D'00'	;scale=01bin=145octave=06note=01
	retlw	(D'06'*D'24')+D'00'	;scale=01bin=146octave=06note=02
	retlw	(D'06'*D'24')+D'00'	;scale=01bin=147octave=06note=03
	retlw	(D'06'*D'24')+D'04'	;scale=01bin=148octave=06note=04
	retlw	(D'06'*D'24')+D'04'	;scale=01bin=149octave=06note=05
	retlw	(D'06'*D'24')+D'04'	;scale=01bin=150octave=06note=06
	retlw	(D'06'*D'24')+D'04'	;scale=01bin=151octave=06note=07
	retlw	(D'06'*D'24')+D'08'	;scale=01bin=152octave=06note=08
	retlw	(D'06'*D'24')+D'08'	;scale=01bin=153octave=06note=09
	retlw	(D'06'*D'24')+D'08'	;scale=01bin=154octave=06note=10
	retlw	(D'06'*D'24')+D'08'	;scale=01bin=155octave=06note=11
	retlw	(D'06'*D'24')+D'12'	;scale=01bin=156octave=06note=12
	retlw	(D'06'*D'24')+D'12'	;scale=01bin=157octave=06note=13
	retlw	(D'06'*D'24')+D'12'	;scale=01bin=158octave=06note=14
	retlw	(D'06'*D'24')+D'12'	;scale=01bin=159octave=06note=15
	retlw	(D'06'*D'24')+D'16'	;scale=01bin=160octave=06note=16
	retlw	(D'06'*D'24')+D'16'	;scale=01bin=161octave=06note=17
	retlw	(D'06'*D'24')+D'16'	;scale=01bin=162octave=06note=18
	retlw	(D'06'*D'24')+D'16'	;scale=01bin=163octave=06note=19
	retlw	(D'06'*D'24')+D'20'	;scale=01bin=164octave=06note=20
	retlw	(D'06'*D'24')+D'20'	;scale=01bin=165octave=06note=21
	retlw	(D'06'*D'24')+D'20'	;scale=01bin=166octave=06note=22
	retlw	(D'06'*D'24')+D'20'	;scale=01bin=167octave=06note=23
	retlw	(D'07'*D'24')+D'00'	;scale=01bin=168octave=07note=00
	retlw	(D'07'*D'24')+D'00'	;scale=01bin=169octave=07note=01
	retlw	(D'07'*D'24')+D'00'	;scale=01bin=170octave=07note=02
	retlw	(D'07'*D'24')+D'00'	;scale=01bin=171octave=07note=03
	retlw	(D'07'*D'24')+D'04'	;scale=01bin=172octave=07note=04
	retlw	(D'07'*D'24')+D'04'	;scale=01bin=173octave=07note=05
	retlw	(D'07'*D'24')+D'04'	;scale=01bin=174octave=07note=06
	retlw	(D'07'*D'24')+D'04'	;scale=01bin=175octave=07note=07
	retlw	(D'07'*D'24')+D'08'	;scale=01bin=176octave=07note=08
	retlw	(D'07'*D'24')+D'08'	;scale=01bin=177octave=07note=09
	retlw	(D'07'*D'24')+D'08'	;scale=01bin=178octave=07note=10
	retlw	(D'07'*D'24')+D'08'	;scale=01bin=179octave=07note=11
	retlw	(D'07'*D'24')+D'12'	;scale=01bin=180octave=07note=12
	retlw	(D'07'*D'24')+D'12'	;scale=01bin=181octave=07note=13
	retlw	(D'07'*D'24')+D'12'	;scale=01bin=182octave=07note=14
	retlw	(D'07'*D'24')+D'12'	;scale=01bin=183octave=07note=15
	retlw	(D'07'*D'24')+D'16'	;scale=01bin=184octave=07note=16
	retlw	(D'07'*D'24')+D'16'	;scale=01bin=185octave=07note=17
	retlw	(D'07'*D'24')+D'16'	;scale=01bin=186octave=07note=18
	retlw	(D'07'*D'24')+D'16'	;scale=01bin=187octave=07note=19
	retlw	(D'07'*D'24')+D'20'	;scale=01bin=188octave=07note=20
	retlw	(D'07'*D'24')+D'20'	;scale=01bin=189octave=07note=21
	retlw	(D'07'*D'24')+D'20'	;scale=01bin=190octave=07note=22
	retlw	(D'07'*D'24')+D'20'	;scale=01bin=191octave=07note=23
	retlw	(D'08'*D'24')+D'00'	;scale=01bin=192octave=08note=00
	retlw	(D'08'*D'24')+D'00'	;scale=01bin=193octave=08note=01
	retlw	(D'08'*D'24')+D'00'	;scale=01bin=194octave=08note=02
	retlw	(D'08'*D'24')+D'00'	;scale=01bin=195octave=08note=03
	retlw	(D'08'*D'24')+D'04'	;scale=01bin=196octave=08note=04
	retlw	(D'08'*D'24')+D'04'	;scale=01bin=197octave=08note=05
	retlw	(D'08'*D'24')+D'04'	;scale=01bin=198octave=08note=06
	retlw	(D'08'*D'24')+D'04'	;scale=01bin=199octave=08note=07
	retlw	(D'08'*D'24')+D'08'	;scale=01bin=200octave=08note=08
	retlw	(D'08'*D'24')+D'08'	;scale=01bin=201octave=08note=09
	retlw	(D'08'*D'24')+D'08'	;scale=01bin=202octave=08note=10
	retlw	(D'08'*D'24')+D'08'	;scale=01bin=203octave=08note=11
	retlw	(D'08'*D'24')+D'12'	;scale=01bin=204octave=08note=12
	retlw	(D'08'*D'24')+D'12'	;scale=01bin=205octave=08note=13
	retlw	(D'08'*D'24')+D'12'	;scale=01bin=206octave=08note=14
	retlw	(D'08'*D'24')+D'12'	;scale=01bin=207octave=08note=15
	retlw	(D'08'*D'24')+D'16'	;scale=01bin=208octave=08note=16
	retlw	(D'08'*D'24')+D'16'	;scale=01bin=209octave=08note=17
	retlw	(D'08'*D'24')+D'16'	;scale=01bin=210octave=08note=18
	retlw	(D'08'*D'24')+D'16'	;scale=01bin=211octave=08note=19
	retlw	(D'08'*D'24')+D'20'	;scale=01bin=212octave=08note=20
	retlw	(D'08'*D'24')+D'20'	;scale=01bin=213octave=08note=21
	retlw	(D'08'*D'24')+D'20'	;scale=01bin=214octave=08note=22
	retlw	(D'08'*D'24')+D'20'	;scale=01bin=215octave=08note=23
	retlw	(D'09'*D'24')+D'00'	;scale=01bin=216octave=09note=00
	retlw	(D'09'*D'24')+D'00'	;scale=01bin=217octave=09note=01
	retlw	(D'09'*D'24')+D'00'	;scale=01bin=218octave=09note=02
	retlw	(D'09'*D'24')+D'00'	;scale=01bin=219octave=09note=03
	retlw	(D'09'*D'24')+D'04'	;scale=01bin=220octave=09note=04
	retlw	(D'09'*D'24')+D'04'	;scale=01bin=221octave=09note=05
	retlw	(D'09'*D'24')+D'04'	;scale=01bin=222octave=09note=06
	retlw	(D'09'*D'24')+D'04'	;scale=01bin=223octave=09note=07
	retlw	(D'09'*D'24')+D'08'	;scale=01bin=224octave=09note=08
	retlw	(D'09'*D'24')+D'08'	;scale=01bin=225octave=09note=09
	retlw	(D'09'*D'24')+D'08'	;scale=01bin=226octave=09note=10
	retlw	(D'09'*D'24')+D'08'	;scale=01bin=227octave=09note=11
	retlw	(D'09'*D'24')+D'12'	;scale=01bin=228octave=09note=12
	retlw	(D'09'*D'24')+D'12'	;scale=01bin=229octave=09note=13
	retlw	(D'09'*D'24')+D'12'	;scale=01bin=230octave=09note=14
	retlw	(D'09'*D'24')+D'12'	;scale=01bin=231octave=09note=15
	retlw	(D'09'*D'24')+D'16'	;scale=01bin=232octave=09note=16
	retlw	(D'09'*D'24')+D'16'	;scale=01bin=233octave=09note=17
	retlw	(D'09'*D'24')+D'16'	;scale=01bin=234octave=09note=18
	retlw	(D'09'*D'24')+D'16'	;scale=01bin=235octave=09note=19
	retlw	(D'09'*D'24')+D'20'	;scale=01bin=236octave=09note=20
	retlw	(D'09'*D'24')+D'20'	;scale=01bin=237octave=09note=21
	retlw	(D'09'*D'24')+D'20'	;scale=01bin=238octave=09note=22
	retlw	(D'09'*D'24')+D'20'	;scale=01bin=239octave=09note=23
	retlw	(D'10'*D'24')+D'00'	;scale=01bin=240octave=10note=00
	retlw	(D'10'*D'24')+D'00'	;scale=01bin=241octave=10note=01
	retlw	(D'10'*D'24')+D'00'	;scale=01bin=242octave=10note=02
	retlw	(D'10'*D'24')+D'00'	;scale=01bin=243octave=10note=03
	retlw	(D'10'*D'24')+D'00'	;scale=01bin=244octave=10note=04
	retlw	(D'10'*D'24')+D'00'	;scale=01bin=245octave=10note=05
	retlw	(D'10'*D'24')+D'00'	;scale=01bin=246octave=10note=06
	retlw	(D'10'*D'24')+D'00'	;scale=01bin=247octave=10note=07
	retlw	(D'10'*D'24')+D'00'	;scale=01bin=248octave=10note=08
	retlw	(D'10'*D'24')+D'00'	;scale=01bin=249octave=10note=09
	retlw	(D'10'*D'24')+D'00'	;scale=01bin=250octave=10note=10
	retlw	(D'10'*D'24')+D'00'	;scale=01bin=251octave=10note=11
	retlw	(D'10'*D'24')+D'00'	;scale=01bin=252octave=10note=12
	retlw	(D'10'*D'24')+D'00'	;scale=01bin=253octave=10note=13
	retlw	(D'10'*D'24')+D'00'	;scale=01bin=254octave=10note=14
	retlw	(D'10'*D'24')+D'00'	;scale=01bin=255octave=10note=15

;	Major look-up table
	org	Major		;Major look-up table
	retlw	(D'00'*D'24')+D'00'	;scale=02bin=000octave=00note=00
	retlw	(D'00'*D'24')+D'00'	;scale=02bin=001octave=00note=01
	retlw	(D'00'*D'24')+D'00'	;scale=02bin=002octave=00note=02
	retlw	(D'00'*D'24')+D'00'	;scale=02bin=003octave=00note=03
	retlw	(D'00'*D'24')+D'04'	;scale=02bin=004octave=00note=04
	retlw	(D'00'*D'24')+D'04'	;scale=02bin=005octave=00note=05
	retlw	(D'00'*D'24')+D'04'	;scale=02bin=006octave=00note=06
	retlw	(D'00'*D'24')+D'04'	;scale=02bin=007octave=00note=07
	retlw	(D'00'*D'24')+D'08'	;scale=02bin=008octave=00note=08
	retlw	(D'00'*D'24')+D'08'	;scale=02bin=009octave=00note=09
	retlw	(D'00'*D'24')+D'10'	;scale=02bin=010octave=00note=10
	retlw	(D'00'*D'24')+D'10'	;scale=02bin=011octave=00note=11
	retlw	(D'00'*D'24')+D'10'	;scale=02bin=012octave=00note=12
	retlw	(D'00'*D'24')+D'10'	;scale=02bin=013octave=00note=13
	retlw	(D'00'*D'24')+D'14'	;scale=02bin=014octave=00note=14
	retlw	(D'00'*D'24')+D'14'	;scale=02bin=015octave=00note=15
	retlw	(D'00'*D'24')+D'14'	;scale=02bin=016octave=00note=16
	retlw	(D'00'*D'24')+D'14'	;scale=02bin=017octave=00note=17
	retlw	(D'00'*D'24')+D'18'	;scale=02bin=018octave=00note=18
	retlw	(D'00'*D'24')+D'18'	;scale=02bin=019octave=00note=19
	retlw	(D'00'*D'24')+D'18'	;scale=02bin=020octave=00note=20
	retlw	(D'00'*D'24')+D'18'	;scale=02bin=021octave=00note=21
	retlw	(D'00'*D'24')+D'22'	;scale=02bin=022octave=00note=22
	retlw	(D'00'*D'24')+D'22'	;scale=02bin=023octave=00note=23
	retlw	(D'01'*D'24')+D'00'	;scale=02bin=024octave=01note=00
	retlw	(D'01'*D'24')+D'00'	;scale=02bin=025octave=01note=01
	retlw	(D'01'*D'24')+D'00'	;scale=02bin=026octave=01note=02
	retlw	(D'01'*D'24')+D'00'	;scale=02bin=027octave=01note=03
	retlw	(D'01'*D'24')+D'04'	;scale=02bin=028octave=01note=04
	retlw	(D'01'*D'24')+D'04'	;scale=02bin=029octave=01note=05
	retlw	(D'01'*D'24')+D'04'	;scale=02bin=030octave=01note=06
	retlw	(D'01'*D'24')+D'04'	;scale=02bin=031octave=01note=07
	retlw	(D'01'*D'24')+D'08'	;scale=02bin=032octave=01note=08
	retlw	(D'01'*D'24')+D'08'	;scale=02bin=033octave=01note=09
	retlw	(D'01'*D'24')+D'10'	;scale=02bin=034octave=01note=10
	retlw	(D'01'*D'24')+D'10'	;scale=02bin=035octave=01note=11
	retlw	(D'01'*D'24')+D'10'	;scale=02bin=036octave=01note=12
	retlw	(D'01'*D'24')+D'10'	;scale=02bin=037octave=01note=13
	retlw	(D'01'*D'24')+D'14'	;scale=02bin=038octave=01note=14
	retlw	(D'01'*D'24')+D'14'	;scale=02bin=039octave=01note=15
	retlw	(D'01'*D'24')+D'14'	;scale=02bin=040octave=01note=16
	retlw	(D'01'*D'24')+D'14'	;scale=02bin=041octave=01note=17
	retlw	(D'01'*D'24')+D'18'	;scale=02bin=042octave=01note=18
	retlw	(D'01'*D'24')+D'18'	;scale=02bin=043octave=01note=19
	retlw	(D'01'*D'24')+D'18'	;scale=02bin=044octave=01note=20
	retlw	(D'01'*D'24')+D'18'	;scale=02bin=045octave=01note=21
	retlw	(D'01'*D'24')+D'22'	;scale=02bin=046octave=01note=22
	retlw	(D'01'*D'24')+D'22'	;scale=02bin=047octave=01note=23
	retlw	(D'02'*D'24')+D'00'	;scale=02bin=048octave=02note=00
	retlw	(D'02'*D'24')+D'00'	;scale=02bin=049octave=02note=01
	retlw	(D'02'*D'24')+D'00'	;scale=02bin=050octave=02note=02
	retlw	(D'02'*D'24')+D'00'	;scale=02bin=051octave=02note=03
	retlw	(D'02'*D'24')+D'04'	;scale=02bin=052octave=02note=04
	retlw	(D'02'*D'24')+D'04'	;scale=02bin=053octave=02note=05
	retlw	(D'02'*D'24')+D'04'	;scale=02bin=054octave=02note=06
	retlw	(D'02'*D'24')+D'04'	;scale=02bin=055octave=02note=07
	retlw	(D'02'*D'24')+D'08'	;scale=02bin=056octave=02note=08
	retlw	(D'02'*D'24')+D'08'	;scale=02bin=057octave=02note=09
	retlw	(D'02'*D'24')+D'10'	;scale=02bin=058octave=02note=10
	retlw	(D'02'*D'24')+D'10'	;scale=02bin=059octave=02note=11
	retlw	(D'02'*D'24')+D'10'	;scale=02bin=060octave=02note=12
	retlw	(D'02'*D'24')+D'10'	;scale=02bin=061octave=02note=13
	retlw	(D'02'*D'24')+D'14'	;scale=02bin=062octave=02note=14
	retlw	(D'02'*D'24')+D'14'	;scale=02bin=063octave=02note=15
	retlw	(D'02'*D'24')+D'14'	;scale=02bin=064octave=02note=16
	retlw	(D'02'*D'24')+D'14'	;scale=02bin=065octave=02note=17
	retlw	(D'02'*D'24')+D'18'	;scale=02bin=066octave=02note=18
	retlw	(D'02'*D'24')+D'18'	;scale=02bin=067octave=02note=19
	retlw	(D'02'*D'24')+D'18'	;scale=02bin=068octave=02note=20
	retlw	(D'02'*D'24')+D'18'	;scale=02bin=069octave=02note=21
	retlw	(D'02'*D'24')+D'22'	;scale=02bin=070octave=02note=22
	retlw	(D'02'*D'24')+D'22'	;scale=02bin=071octave=02note=23
	retlw	(D'03'*D'24')+D'00'	;scale=02bin=072octave=03note=00
	retlw	(D'03'*D'24')+D'00'	;scale=02bin=073octave=03note=01
	retlw	(D'03'*D'24')+D'00'	;scale=02bin=074octave=03note=02
	retlw	(D'03'*D'24')+D'00'	;scale=02bin=075octave=03note=03
	retlw	(D'03'*D'24')+D'04'	;scale=02bin=076octave=03note=04
	retlw	(D'03'*D'24')+D'04'	;scale=02bin=077octave=03note=05
	retlw	(D'03'*D'24')+D'04'	;scale=02bin=078octave=03note=06
	retlw	(D'03'*D'24')+D'04'	;scale=02bin=079octave=03note=07
	retlw	(D'03'*D'24')+D'08'	;scale=02bin=080octave=03note=08
	retlw	(D'03'*D'24')+D'08'	;scale=02bin=081octave=03note=09
	retlw	(D'03'*D'24')+D'10'	;scale=02bin=082octave=03note=10
	retlw	(D'03'*D'24')+D'10'	;scale=02bin=083octave=03note=11
	retlw	(D'03'*D'24')+D'10'	;scale=02bin=084octave=03note=12
	retlw	(D'03'*D'24')+D'10'	;scale=02bin=085octave=03note=13
	retlw	(D'03'*D'24')+D'14'	;scale=02bin=086octave=03note=14
	retlw	(D'03'*D'24')+D'14'	;scale=02bin=087octave=03note=15
	retlw	(D'03'*D'24')+D'14'	;scale=02bin=088octave=03note=16
	retlw	(D'03'*D'24')+D'14'	;scale=02bin=089octave=03note=17
	retlw	(D'03'*D'24')+D'18'	;scale=02bin=090octave=03note=18
	retlw	(D'03'*D'24')+D'18'	;scale=02bin=091octave=03note=19
	retlw	(D'03'*D'24')+D'18'	;scale=02bin=092octave=03note=20
	retlw	(D'03'*D'24')+D'18'	;scale=02bin=093octave=03note=21
	retlw	(D'03'*D'24')+D'22'	;scale=02bin=094octave=03note=22
	retlw	(D'03'*D'24')+D'22'	;scale=02bin=095octave=03note=23
	retlw	(D'04'*D'24')+D'00'	;scale=02bin=096octave=04note=00
	retlw	(D'04'*D'24')+D'00'	;scale=02bin=097octave=04note=01
	retlw	(D'04'*D'24')+D'00'	;scale=02bin=098octave=04note=02
	retlw	(D'04'*D'24')+D'00'	;scale=02bin=099octave=04note=03
	retlw	(D'04'*D'24')+D'04'	;scale=02bin=100octave=04note=04
	retlw	(D'04'*D'24')+D'04'	;scale=02bin=101octave=04note=05
	retlw	(D'04'*D'24')+D'04'	;scale=02bin=102octave=04note=06
	retlw	(D'04'*D'24')+D'04'	;scale=02bin=103octave=04note=07
	retlw	(D'04'*D'24')+D'08'	;scale=02bin=104octave=04note=08
	retlw	(D'04'*D'24')+D'08'	;scale=02bin=105octave=04note=09
	retlw	(D'04'*D'24')+D'10'	;scale=02bin=106octave=04note=10
	retlw	(D'04'*D'24')+D'10'	;scale=02bin=107octave=04note=11
	retlw	(D'04'*D'24')+D'10'	;scale=02bin=108octave=04note=12
	retlw	(D'04'*D'24')+D'10'	;scale=02bin=109octave=04note=13
	retlw	(D'04'*D'24')+D'14'	;scale=02bin=110octave=04note=14
	retlw	(D'04'*D'24')+D'14'	;scale=02bin=111octave=04note=15
	retlw	(D'04'*D'24')+D'14'	;scale=02bin=112octave=04note=16
	retlw	(D'04'*D'24')+D'14'	;scale=02bin=113octave=04note=17
	retlw	(D'04'*D'24')+D'18'	;scale=02bin=114octave=04note=18
	retlw	(D'04'*D'24')+D'18'	;scale=02bin=115octave=04note=19
	retlw	(D'04'*D'24')+D'18'	;scale=02bin=116octave=04note=20
	retlw	(D'04'*D'24')+D'18'	;scale=02bin=117octave=04note=21
	retlw	(D'04'*D'24')+D'22'	;scale=02bin=118octave=04note=22
	retlw	(D'04'*D'24')+D'22'	;scale=02bin=119octave=04note=23
	retlw	(D'05'*D'24')+D'00'	;scale=02bin=120octave=05note=00
	retlw	(D'05'*D'24')+D'00'	;scale=02bin=121octave=05note=01
	retlw	(D'05'*D'24')+D'00'	;scale=02bin=122octave=05note=02
	retlw	(D'05'*D'24')+D'00'	;scale=02bin=123octave=05note=03
	retlw	(D'05'*D'24')+D'04'	;scale=02bin=124octave=05note=04
	retlw	(D'05'*D'24')+D'04'	;scale=02bin=125octave=05note=05
	retlw	(D'05'*D'24')+D'04'	;scale=02bin=126octave=05note=06
	retlw	(D'05'*D'24')+D'04'	;scale=02bin=127octave=05note=07
	retlw	(D'05'*D'24')+D'08'	;scale=02bin=128octave=05note=08
	retlw	(D'05'*D'24')+D'08'	;scale=02bin=129octave=05note=09
	retlw	(D'05'*D'24')+D'10'	;scale=02bin=130octave=05note=10
	retlw	(D'05'*D'24')+D'10'	;scale=02bin=131octave=05note=11
	retlw	(D'05'*D'24')+D'10'	;scale=02bin=132octave=05note=12
	retlw	(D'05'*D'24')+D'10'	;scale=02bin=133octave=05note=13
	retlw	(D'05'*D'24')+D'14'	;scale=02bin=134octave=05note=14
	retlw	(D'05'*D'24')+D'14'	;scale=02bin=135octave=05note=15
	retlw	(D'05'*D'24')+D'14'	;scale=02bin=136octave=05note=16
	retlw	(D'05'*D'24')+D'14'	;scale=02bin=137octave=05note=17
	retlw	(D'05'*D'24')+D'18'	;scale=02bin=138octave=05note=18
	retlw	(D'05'*D'24')+D'18'	;scale=02bin=139octave=05note=19
	retlw	(D'05'*D'24')+D'18'	;scale=02bin=140octave=05note=20
	retlw	(D'05'*D'24')+D'18'	;scale=02bin=141octave=05note=21
	retlw	(D'05'*D'24')+D'22'	;scale=02bin=142octave=05note=22
	retlw	(D'05'*D'24')+D'22'	;scale=02bin=143octave=05note=23
	retlw	(D'06'*D'24')+D'00'	;scale=02bin=144octave=06note=00
	retlw	(D'06'*D'24')+D'00'	;scale=02bin=145octave=06note=01
	retlw	(D'06'*D'24')+D'00'	;scale=02bin=146octave=06note=02
	retlw	(D'06'*D'24')+D'00'	;scale=02bin=147octave=06note=03
	retlw	(D'06'*D'24')+D'04'	;scale=02bin=148octave=06note=04
	retlw	(D'06'*D'24')+D'04'	;scale=02bin=149octave=06note=05
	retlw	(D'06'*D'24')+D'04'	;scale=02bin=150octave=06note=06
	retlw	(D'06'*D'24')+D'04'	;scale=02bin=151octave=06note=07
	retlw	(D'06'*D'24')+D'08'	;scale=02bin=152octave=06note=08
	retlw	(D'06'*D'24')+D'08'	;scale=02bin=153octave=06note=09
	retlw	(D'06'*D'24')+D'10'	;scale=02bin=154octave=06note=10
	retlw	(D'06'*D'24')+D'10'	;scale=02bin=155octave=06note=11
	retlw	(D'06'*D'24')+D'10'	;scale=02bin=156octave=06note=12
	retlw	(D'06'*D'24')+D'10'	;scale=02bin=157octave=06note=13
	retlw	(D'06'*D'24')+D'14'	;scale=02bin=158octave=06note=14
	retlw	(D'06'*D'24')+D'14'	;scale=02bin=159octave=06note=15
	retlw	(D'06'*D'24')+D'14'	;scale=02bin=160octave=06note=16
	retlw	(D'06'*D'24')+D'14'	;scale=02bin=161octave=06note=17
	retlw	(D'06'*D'24')+D'18'	;scale=02bin=162octave=06note=18
	retlw	(D'06'*D'24')+D'18'	;scale=02bin=163octave=06note=19
	retlw	(D'06'*D'24')+D'18'	;scale=02bin=164octave=06note=20
	retlw	(D'06'*D'24')+D'18'	;scale=02bin=165octave=06note=21
	retlw	(D'06'*D'24')+D'22'	;scale=02bin=166octave=06note=22
	retlw	(D'06'*D'24')+D'22'	;scale=02bin=167octave=06note=23
	retlw	(D'07'*D'24')+D'00'	;scale=02bin=168octave=07note=00
	retlw	(D'07'*D'24')+D'00'	;scale=02bin=169octave=07note=01
	retlw	(D'07'*D'24')+D'00'	;scale=02bin=170octave=07note=02
	retlw	(D'07'*D'24')+D'00'	;scale=02bin=171octave=07note=03
	retlw	(D'07'*D'24')+D'04'	;scale=02bin=172octave=07note=04
	retlw	(D'07'*D'24')+D'04'	;scale=02bin=173octave=07note=05
	retlw	(D'07'*D'24')+D'04'	;scale=02bin=174octave=07note=06
	retlw	(D'07'*D'24')+D'04'	;scale=02bin=175octave=07note=07
	retlw	(D'07'*D'24')+D'08'	;scale=02bin=176octave=07note=08
	retlw	(D'07'*D'24')+D'08'	;scale=02bin=177octave=07note=09
	retlw	(D'07'*D'24')+D'10'	;scale=02bin=178octave=07note=10
	retlw	(D'07'*D'24')+D'10'	;scale=02bin=179octave=07note=11
	retlw	(D'07'*D'24')+D'10'	;scale=02bin=180octave=07note=12
	retlw	(D'07'*D'24')+D'10'	;scale=02bin=181octave=07note=13
	retlw	(D'07'*D'24')+D'14'	;scale=02bin=182octave=07note=14
	retlw	(D'07'*D'24')+D'14'	;scale=02bin=183octave=07note=15
	retlw	(D'07'*D'24')+D'14'	;scale=02bin=184octave=07note=16
	retlw	(D'07'*D'24')+D'14'	;scale=02bin=185octave=07note=17
	retlw	(D'07'*D'24')+D'18'	;scale=02bin=186octave=07note=18
	retlw	(D'07'*D'24')+D'18'	;scale=02bin=187octave=07note=19
	retlw	(D'07'*D'24')+D'18'	;scale=02bin=188octave=07note=20
	retlw	(D'07'*D'24')+D'18'	;scale=02bin=189octave=07note=21
	retlw	(D'07'*D'24')+D'22'	;scale=02bin=190octave=07note=22
	retlw	(D'07'*D'24')+D'22'	;scale=02bin=191octave=07note=23
	retlw	(D'08'*D'24')+D'00'	;scale=02bin=192octave=08note=00
	retlw	(D'08'*D'24')+D'00'	;scale=02bin=193octave=08note=01
	retlw	(D'08'*D'24')+D'00'	;scale=02bin=194octave=08note=02
	retlw	(D'08'*D'24')+D'00'	;scale=02bin=195octave=08note=03
	retlw	(D'08'*D'24')+D'04'	;scale=02bin=196octave=08note=04
	retlw	(D'08'*D'24')+D'04'	;scale=02bin=197octave=08note=05
	retlw	(D'08'*D'24')+D'04'	;scale=02bin=198octave=08note=06
	retlw	(D'08'*D'24')+D'04'	;scale=02bin=199octave=08note=07
	retlw	(D'08'*D'24')+D'08'	;scale=02bin=200octave=08note=08
	retlw	(D'08'*D'24')+D'08'	;scale=02bin=201octave=08note=09
	retlw	(D'08'*D'24')+D'10'	;scale=02bin=202octave=08note=10
	retlw	(D'08'*D'24')+D'10'	;scale=02bin=203octave=08note=11
	retlw	(D'08'*D'24')+D'10'	;scale=02bin=204octave=08note=12
	retlw	(D'08'*D'24')+D'10'	;scale=02bin=205octave=08note=13
	retlw	(D'08'*D'24')+D'14'	;scale=02bin=206octave=08note=14
	retlw	(D'08'*D'24')+D'14'	;scale=02bin=207octave=08note=15
	retlw	(D'08'*D'24')+D'14'	;scale=02bin=208octave=08note=16
	retlw	(D'08'*D'24')+D'14'	;scale=02bin=209octave=08note=17
	retlw	(D'08'*D'24')+D'18'	;scale=02bin=210octave=08note=18
	retlw	(D'08'*D'24')+D'18'	;scale=02bin=211octave=08note=19
	retlw	(D'08'*D'24')+D'18'	;scale=02bin=212octave=08note=20
	retlw	(D'08'*D'24')+D'18'	;scale=02bin=213octave=08note=21
	retlw	(D'08'*D'24')+D'22'	;scale=02bin=214octave=08note=22
	retlw	(D'08'*D'24')+D'22'	;scale=02bin=215octave=08note=23
	retlw	(D'09'*D'24')+D'00'	;scale=02bin=216octave=09note=00
	retlw	(D'09'*D'24')+D'00'	;scale=02bin=217octave=09note=01
	retlw	(D'09'*D'24')+D'00'	;scale=02bin=218octave=09note=02
	retlw	(D'09'*D'24')+D'00'	;scale=02bin=219octave=09note=03
	retlw	(D'09'*D'24')+D'04'	;scale=02bin=220octave=09note=04
	retlw	(D'09'*D'24')+D'04'	;scale=02bin=221octave=09note=05
	retlw	(D'09'*D'24')+D'04'	;scale=02bin=222octave=09note=06
	retlw	(D'09'*D'24')+D'04'	;scale=02bin=223octave=09note=07
	retlw	(D'09'*D'24')+D'08'	;scale=02bin=224octave=09note=08
	retlw	(D'09'*D'24')+D'08'	;scale=02bin=225octave=09note=09
	retlw	(D'09'*D'24')+D'10'	;scale=02bin=226octave=09note=10
	retlw	(D'09'*D'24')+D'10'	;scale=02bin=227octave=09note=11
	retlw	(D'09'*D'24')+D'10'	;scale=02bin=228octave=09note=12
	retlw	(D'09'*D'24')+D'10'	;scale=02bin=229octave=09note=13
	retlw	(D'09'*D'24')+D'14'	;scale=02bin=230octave=09note=14
	retlw	(D'09'*D'24')+D'14'	;scale=02bin=231octave=09note=15
	retlw	(D'09'*D'24')+D'14'	;scale=02bin=232octave=09note=16
	retlw	(D'09'*D'24')+D'14'	;scale=02bin=233octave=09note=17
	retlw	(D'09'*D'24')+D'18'	;scale=02bin=234octave=09note=18
	retlw	(D'09'*D'24')+D'18'	;scale=02bin=235octave=09note=19
	retlw	(D'09'*D'24')+D'18'	;scale=02bin=236octave=09note=20
	retlw	(D'09'*D'24')+D'18'	;scale=02bin=237octave=09note=21
	retlw	(D'09'*D'24')+D'22'	;scale=02bin=238octave=09note=22
	retlw	(D'09'*D'24')+D'22'	;scale=02bin=239octave=09note=23
	retlw	(D'10'*D'24')+D'00'	;scale=02bin=240octave=10note=00
	retlw	(D'10'*D'24')+D'00'	;scale=02bin=241octave=10note=01
	retlw	(D'10'*D'24')+D'00'	;scale=02bin=242octave=10note=02
	retlw	(D'10'*D'24')+D'00'	;scale=02bin=243octave=10note=03
	retlw	(D'10'*D'24')+D'00'	;scale=02bin=244octave=10note=04
	retlw	(D'10'*D'24')+D'00'	;scale=02bin=245octave=10note=05
	retlw	(D'10'*D'24')+D'00'	;scale=02bin=246octave=10note=06
	retlw	(D'10'*D'24')+D'00'	;scale=02bin=247octave=10note=07
	retlw	(D'10'*D'24')+D'00'	;scale=02bin=248octave=10note=08
	retlw	(D'10'*D'24')+D'00'	;scale=02bin=249octave=10note=09
	retlw	(D'10'*D'24')+D'00'	;scale=02bin=250octave=10note=10
	retlw	(D'10'*D'24')+D'00'	;scale=02bin=251octave=10note=11
	retlw	(D'10'*D'24')+D'00'	;scale=02bin=252octave=10note=12
	retlw	(D'10'*D'24')+D'00'	;scale=02bin=253octave=10note=13
	retlw	(D'10'*D'24')+D'00'	;scale=02bin=254octave=10note=14
	retlw	(D'10'*D'24')+D'00'	;scale=02bin=255octave=10note=15

;	Major Pent Diatonic look-up table
	org	MajorPD		;Major Pent Diatonic look-up table
	retlw	(D'00'*D'24')+D'00'	;scale=03bin=000octave=00note=00
	retlw	(D'00'*D'24')+D'00'	;scale=03bin=001octave=00note=01
	retlw	(D'00'*D'24')+D'00'	;scale=03bin=002octave=00note=02
	retlw	(D'00'*D'24')+D'00'	;scale=03bin=003octave=00note=03
	retlw	(D'00'*D'24')+D'04'	;scale=03bin=004octave=00note=04
	retlw	(D'00'*D'24')+D'04'	;scale=03bin=005octave=00note=05
	retlw	(D'00'*D'24')+D'04'	;scale=03bin=006octave=00note=06
	retlw	(D'00'*D'24')+D'04'	;scale=03bin=007octave=00note=07
	retlw	(D'00'*D'24')+D'08'	;scale=03bin=008octave=00note=08
	retlw	(D'00'*D'24')+D'08'	;scale=03bin=009octave=00note=09
	retlw	(D'00'*D'24')+D'08'	;scale=03bin=010octave=00note=10
	retlw	(D'00'*D'24')+D'08'	;scale=03bin=011octave=00note=11
	retlw	(D'00'*D'24')+D'08'	;scale=03bin=012octave=00note=12
	retlw	(D'00'*D'24')+D'08'	;scale=03bin=013octave=00note=13
	retlw	(D'00'*D'24')+D'14'	;scale=03bin=014octave=00note=14
	retlw	(D'00'*D'24')+D'14'	;scale=03bin=015octave=00note=15
	retlw	(D'00'*D'24')+D'14'	;scale=03bin=016octave=00note=16
	retlw	(D'00'*D'24')+D'14'	;scale=03bin=017octave=00note=17
	retlw	(D'00'*D'24')+D'18'	;scale=03bin=018octave=00note=18
	retlw	(D'00'*D'24')+D'18'	;scale=03bin=019octave=00note=19
	retlw	(D'00'*D'24')+D'18'	;scale=03bin=020octave=00note=20
	retlw	(D'00'*D'24')+D'18'	;scale=03bin=021octave=00note=21
	retlw	(D'00'*D'24')+D'18'	;scale=03bin=022octave=00note=22
	retlw	(D'00'*D'24')+D'18'	;scale=03bin=023octave=00note=23
	retlw	(D'01'*D'24')+D'00'	;scale=03bin=024octave=01note=00
	retlw	(D'01'*D'24')+D'00'	;scale=03bin=025octave=01note=01
	retlw	(D'01'*D'24')+D'00'	;scale=03bin=026octave=01note=02
	retlw	(D'01'*D'24')+D'00'	;scale=03bin=027octave=01note=03
	retlw	(D'01'*D'24')+D'04'	;scale=03bin=028octave=01note=04
	retlw	(D'01'*D'24')+D'04'	;scale=03bin=029octave=01note=05
	retlw	(D'01'*D'24')+D'04'	;scale=03bin=030octave=01note=06
	retlw	(D'01'*D'24')+D'04'	;scale=03bin=031octave=01note=07
	retlw	(D'01'*D'24')+D'08'	;scale=03bin=032octave=01note=08
	retlw	(D'01'*D'24')+D'08'	;scale=03bin=033octave=01note=09
	retlw	(D'01'*D'24')+D'08'	;scale=03bin=034octave=01note=10
	retlw	(D'01'*D'24')+D'08'	;scale=03bin=035octave=01note=11
	retlw	(D'01'*D'24')+D'08'	;scale=03bin=036octave=01note=12
	retlw	(D'01'*D'24')+D'08'	;scale=03bin=037octave=01note=13
	retlw	(D'01'*D'24')+D'14'	;scale=03bin=038octave=01note=14
	retlw	(D'01'*D'24')+D'14'	;scale=03bin=039octave=01note=15
	retlw	(D'01'*D'24')+D'14'	;scale=03bin=040octave=01note=16
	retlw	(D'01'*D'24')+D'14'	;scale=03bin=041octave=01note=17
	retlw	(D'01'*D'24')+D'18'	;scale=03bin=042octave=01note=18
	retlw	(D'01'*D'24')+D'18'	;scale=03bin=043octave=01note=19
	retlw	(D'01'*D'24')+D'18'	;scale=03bin=044octave=01note=20
	retlw	(D'01'*D'24')+D'18'	;scale=03bin=045octave=01note=21
	retlw	(D'01'*D'24')+D'18'	;scale=03bin=046octave=01note=22
	retlw	(D'01'*D'24')+D'18'	;scale=03bin=047octave=01note=23
	retlw	(D'02'*D'24')+D'00'	;scale=03bin=048octave=02note=00
	retlw	(D'02'*D'24')+D'00'	;scale=03bin=049octave=02note=01
	retlw	(D'02'*D'24')+D'00'	;scale=03bin=050octave=02note=02
	retlw	(D'02'*D'24')+D'00'	;scale=03bin=051octave=02note=03
	retlw	(D'02'*D'24')+D'04'	;scale=03bin=052octave=02note=04
	retlw	(D'02'*D'24')+D'04'	;scale=03bin=053octave=02note=05
	retlw	(D'02'*D'24')+D'04'	;scale=03bin=054octave=02note=06
	retlw	(D'02'*D'24')+D'04'	;scale=03bin=055octave=02note=07
	retlw	(D'02'*D'24')+D'08'	;scale=03bin=056octave=02note=08
	retlw	(D'02'*D'24')+D'08'	;scale=03bin=057octave=02note=09
	retlw	(D'02'*D'24')+D'08'	;scale=03bin=058octave=02note=10
	retlw	(D'02'*D'24')+D'08'	;scale=03bin=059octave=02note=11
	retlw	(D'02'*D'24')+D'08'	;scale=03bin=060octave=02note=12
	retlw	(D'02'*D'24')+D'08'	;scale=03bin=061octave=02note=13
	retlw	(D'02'*D'24')+D'14'	;scale=03bin=062octave=02note=14
	retlw	(D'02'*D'24')+D'14'	;scale=03bin=063octave=02note=15
	retlw	(D'02'*D'24')+D'14'	;scale=03bin=064octave=02note=16
	retlw	(D'02'*D'24')+D'14'	;scale=03bin=065octave=02note=17
	retlw	(D'02'*D'24')+D'18'	;scale=03bin=066octave=02note=18
	retlw	(D'02'*D'24')+D'18'	;scale=03bin=067octave=02note=19
	retlw	(D'02'*D'24')+D'18'	;scale=03bin=068octave=02note=20
	retlw	(D'02'*D'24')+D'18'	;scale=03bin=069octave=02note=21
	retlw	(D'02'*D'24')+D'18'	;scale=03bin=070octave=02note=22
	retlw	(D'02'*D'24')+D'18'	;scale=03bin=071octave=02note=23
	retlw	(D'03'*D'24')+D'00'	;scale=03bin=072octave=03note=00
	retlw	(D'03'*D'24')+D'00'	;scale=03bin=073octave=03note=01
	retlw	(D'03'*D'24')+D'00'	;scale=03bin=074octave=03note=02
	retlw	(D'03'*D'24')+D'00'	;scale=03bin=075octave=03note=03
	retlw	(D'03'*D'24')+D'04'	;scale=03bin=076octave=03note=04
	retlw	(D'03'*D'24')+D'04'	;scale=03bin=077octave=03note=05
	retlw	(D'03'*D'24')+D'04'	;scale=03bin=078octave=03note=06
	retlw	(D'03'*D'24')+D'04'	;scale=03bin=079octave=03note=07
	retlw	(D'03'*D'24')+D'08'	;scale=03bin=080octave=03note=08
	retlw	(D'03'*D'24')+D'08'	;scale=03bin=081octave=03note=09
	retlw	(D'03'*D'24')+D'08'	;scale=03bin=082octave=03note=10
	retlw	(D'03'*D'24')+D'08'	;scale=03bin=083octave=03note=11
	retlw	(D'03'*D'24')+D'08'	;scale=03bin=084octave=03note=12
	retlw	(D'03'*D'24')+D'08'	;scale=03bin=085octave=03note=13
	retlw	(D'03'*D'24')+D'14'	;scale=03bin=086octave=03note=14
	retlw	(D'03'*D'24')+D'14'	;scale=03bin=087octave=03note=15
	retlw	(D'03'*D'24')+D'14'	;scale=03bin=088octave=03note=16
	retlw	(D'03'*D'24')+D'14'	;scale=03bin=089octave=03note=17
	retlw	(D'03'*D'24')+D'18'	;scale=03bin=090octave=03note=18
	retlw	(D'03'*D'24')+D'18'	;scale=03bin=091octave=03note=19
	retlw	(D'03'*D'24')+D'18'	;scale=03bin=092octave=03note=20
	retlw	(D'03'*D'24')+D'18'	;scale=03bin=093octave=03note=21
	retlw	(D'03'*D'24')+D'18'	;scale=03bin=094octave=03note=22
	retlw	(D'03'*D'24')+D'18'	;scale=03bin=095octave=03note=23
	retlw	(D'04'*D'24')+D'00'	;scale=03bin=096octave=04note=00
	retlw	(D'04'*D'24')+D'00'	;scale=03bin=097octave=04note=01
	retlw	(D'04'*D'24')+D'00'	;scale=03bin=098octave=04note=02
	retlw	(D'04'*D'24')+D'00'	;scale=03bin=099octave=04note=03
	retlw	(D'04'*D'24')+D'04'	;scale=03bin=100octave=04note=04
	retlw	(D'04'*D'24')+D'04'	;scale=03bin=101octave=04note=05
	retlw	(D'04'*D'24')+D'04'	;scale=03bin=102octave=04note=06
	retlw	(D'04'*D'24')+D'04'	;scale=03bin=103octave=04note=07
	retlw	(D'04'*D'24')+D'08'	;scale=03bin=104octave=04note=08
	retlw	(D'04'*D'24')+D'08'	;scale=03bin=105octave=04note=09
	retlw	(D'04'*D'24')+D'08'	;scale=03bin=106octave=04note=10
	retlw	(D'04'*D'24')+D'08'	;scale=03bin=107octave=04note=11
	retlw	(D'04'*D'24')+D'08'	;scale=03bin=108octave=04note=12
	retlw	(D'04'*D'24')+D'08'	;scale=03bin=109octave=04note=13
	retlw	(D'04'*D'24')+D'14'	;scale=03bin=110octave=04note=14
	retlw	(D'04'*D'24')+D'14'	;scale=03bin=111octave=04note=15
	retlw	(D'04'*D'24')+D'14'	;scale=03bin=112octave=04note=16
	retlw	(D'04'*D'24')+D'14'	;scale=03bin=113octave=04note=17
	retlw	(D'04'*D'24')+D'18'	;scale=03bin=114octave=04note=18
	retlw	(D'04'*D'24')+D'18'	;scale=03bin=115octave=04note=19
	retlw	(D'04'*D'24')+D'18'	;scale=03bin=116octave=04note=20
	retlw	(D'04'*D'24')+D'18'	;scale=03bin=117octave=04note=21
	retlw	(D'04'*D'24')+D'18'	;scale=03bin=118octave=04note=22
	retlw	(D'04'*D'24')+D'18'	;scale=03bin=119octave=04note=23
	retlw	(D'05'*D'24')+D'00'	;scale=03bin=120octave=05note=00
	retlw	(D'05'*D'24')+D'00'	;scale=03bin=121octave=05note=01
	retlw	(D'05'*D'24')+D'00'	;scale=03bin=122octave=05note=02
	retlw	(D'05'*D'24')+D'00'	;scale=03bin=123octave=05note=03
	retlw	(D'05'*D'24')+D'04'	;scale=03bin=124octave=05note=04
	retlw	(D'05'*D'24')+D'04'	;scale=03bin=125octave=05note=05
	retlw	(D'05'*D'24')+D'04'	;scale=03bin=126octave=05note=06
	retlw	(D'05'*D'24')+D'04'	;scale=03bin=127octave=05note=07
	retlw	(D'05'*D'24')+D'08'	;scale=03bin=128octave=05note=08
	retlw	(D'05'*D'24')+D'08'	;scale=03bin=129octave=05note=09
	retlw	(D'05'*D'24')+D'08'	;scale=03bin=130octave=05note=10
	retlw	(D'05'*D'24')+D'08'	;scale=03bin=131octave=05note=11
	retlw	(D'05'*D'24')+D'08'	;scale=03bin=132octave=05note=12
	retlw	(D'05'*D'24')+D'08'	;scale=03bin=133octave=05note=13
	retlw	(D'05'*D'24')+D'14'	;scale=03bin=134octave=05note=14
	retlw	(D'05'*D'24')+D'14'	;scale=03bin=135octave=05note=15
	retlw	(D'05'*D'24')+D'14'	;scale=03bin=136octave=05note=16
	retlw	(D'05'*D'24')+D'14'	;scale=03bin=137octave=05note=17
	retlw	(D'05'*D'24')+D'18'	;scale=03bin=138octave=05note=18
	retlw	(D'05'*D'24')+D'18'	;scale=03bin=139octave=05note=19
	retlw	(D'05'*D'24')+D'18'	;scale=03bin=140octave=05note=20
	retlw	(D'05'*D'24')+D'18'	;scale=03bin=141octave=05note=21
	retlw	(D'05'*D'24')+D'18'	;scale=03bin=142octave=05note=22
	retlw	(D'05'*D'24')+D'18'	;scale=03bin=143octave=05note=23
	retlw	(D'06'*D'24')+D'00'	;scale=03bin=144octave=06note=00
	retlw	(D'06'*D'24')+D'00'	;scale=03bin=145octave=06note=01
	retlw	(D'06'*D'24')+D'00'	;scale=03bin=146octave=06note=02
	retlw	(D'06'*D'24')+D'00'	;scale=03bin=147octave=06note=03
	retlw	(D'06'*D'24')+D'04'	;scale=03bin=148octave=06note=04
	retlw	(D'06'*D'24')+D'04'	;scale=03bin=149octave=06note=05
	retlw	(D'06'*D'24')+D'04'	;scale=03bin=150octave=06note=06
	retlw	(D'06'*D'24')+D'04'	;scale=03bin=151octave=06note=07
	retlw	(D'06'*D'24')+D'08'	;scale=03bin=152octave=06note=08
	retlw	(D'06'*D'24')+D'08'	;scale=03bin=153octave=06note=09
	retlw	(D'06'*D'24')+D'08'	;scale=03bin=154octave=06note=10
	retlw	(D'06'*D'24')+D'08'	;scale=03bin=155octave=06note=11
	retlw	(D'06'*D'24')+D'08'	;scale=03bin=156octave=06note=12
	retlw	(D'06'*D'24')+D'08'	;scale=03bin=157octave=06note=13
	retlw	(D'06'*D'24')+D'14'	;scale=03bin=158octave=06note=14
	retlw	(D'06'*D'24')+D'14'	;scale=03bin=159octave=06note=15
	retlw	(D'06'*D'24')+D'14'	;scale=03bin=160octave=06note=16
	retlw	(D'06'*D'24')+D'14'	;scale=03bin=161octave=06note=17
	retlw	(D'06'*D'24')+D'18'	;scale=03bin=162octave=06note=18
	retlw	(D'06'*D'24')+D'18'	;scale=03bin=163octave=06note=19
	retlw	(D'06'*D'24')+D'18'	;scale=03bin=164octave=06note=20
	retlw	(D'06'*D'24')+D'18'	;scale=03bin=165octave=06note=21
	retlw	(D'06'*D'24')+D'18'	;scale=03bin=166octave=06note=22
	retlw	(D'06'*D'24')+D'18'	;scale=03bin=167octave=06note=23
	retlw	(D'07'*D'24')+D'00'	;scale=03bin=168octave=07note=00
	retlw	(D'07'*D'24')+D'00'	;scale=03bin=169octave=07note=01
	retlw	(D'07'*D'24')+D'00'	;scale=03bin=170octave=07note=02
	retlw	(D'07'*D'24')+D'00'	;scale=03bin=171octave=07note=03
	retlw	(D'07'*D'24')+D'04'	;scale=03bin=172octave=07note=04
	retlw	(D'07'*D'24')+D'04'	;scale=03bin=173octave=07note=05
	retlw	(D'07'*D'24')+D'04'	;scale=03bin=174octave=07note=06
	retlw	(D'07'*D'24')+D'04'	;scale=03bin=175octave=07note=07
	retlw	(D'07'*D'24')+D'08'	;scale=03bin=176octave=07note=08
	retlw	(D'07'*D'24')+D'08'	;scale=03bin=177octave=07note=09
	retlw	(D'07'*D'24')+D'08'	;scale=03bin=178octave=07note=10
	retlw	(D'07'*D'24')+D'08'	;scale=03bin=179octave=07note=11
	retlw	(D'07'*D'24')+D'08'	;scale=03bin=180octave=07note=12
	retlw	(D'07'*D'24')+D'08'	;scale=03bin=181octave=07note=13
	retlw	(D'07'*D'24')+D'14'	;scale=03bin=182octave=07note=14
	retlw	(D'07'*D'24')+D'14'	;scale=03bin=183octave=07note=15
	retlw	(D'07'*D'24')+D'14'	;scale=03bin=184octave=07note=16
	retlw	(D'07'*D'24')+D'14'	;scale=03bin=185octave=07note=17
	retlw	(D'07'*D'24')+D'18'	;scale=03bin=186octave=07note=18
	retlw	(D'07'*D'24')+D'18'	;scale=03bin=187octave=07note=19
	retlw	(D'07'*D'24')+D'18'	;scale=03bin=188octave=07note=20
	retlw	(D'07'*D'24')+D'18'	;scale=03bin=189octave=07note=21
	retlw	(D'07'*D'24')+D'18'	;scale=03bin=190octave=07note=22
	retlw	(D'07'*D'24')+D'18'	;scale=03bin=191octave=07note=23
	retlw	(D'08'*D'24')+D'00'	;scale=03bin=192octave=08note=00
	retlw	(D'08'*D'24')+D'00'	;scale=03bin=193octave=08note=01
	retlw	(D'08'*D'24')+D'00'	;scale=03bin=194octave=08note=02
	retlw	(D'08'*D'24')+D'00'	;scale=03bin=195octave=08note=03
	retlw	(D'08'*D'24')+D'04'	;scale=03bin=196octave=08note=04
	retlw	(D'08'*D'24')+D'04'	;scale=03bin=197octave=08note=05
	retlw	(D'08'*D'24')+D'04'	;scale=03bin=198octave=08note=06
	retlw	(D'08'*D'24')+D'04'	;scale=03bin=199octave=08note=07
	retlw	(D'08'*D'24')+D'08'	;scale=03bin=200octave=08note=08
	retlw	(D'08'*D'24')+D'08'	;scale=03bin=201octave=08note=09
	retlw	(D'08'*D'24')+D'08'	;scale=03bin=202octave=08note=10
	retlw	(D'08'*D'24')+D'08'	;scale=03bin=203octave=08note=11
	retlw	(D'08'*D'24')+D'08'	;scale=03bin=204octave=08note=12
	retlw	(D'08'*D'24')+D'08'	;scale=03bin=205octave=08note=13
	retlw	(D'08'*D'24')+D'14'	;scale=03bin=206octave=08note=14
	retlw	(D'08'*D'24')+D'14'	;scale=03bin=207octave=08note=15
	retlw	(D'08'*D'24')+D'14'	;scale=03bin=208octave=08note=16
	retlw	(D'08'*D'24')+D'14'	;scale=03bin=209octave=08note=17
	retlw	(D'08'*D'24')+D'18'	;scale=03bin=210octave=08note=18
	retlw	(D'08'*D'24')+D'18'	;scale=03bin=211octave=08note=19
	retlw	(D'08'*D'24')+D'18'	;scale=03bin=212octave=08note=20
	retlw	(D'08'*D'24')+D'18'	;scale=03bin=213octave=08note=21
	retlw	(D'08'*D'24')+D'18'	;scale=03bin=214octave=08note=22
	retlw	(D'08'*D'24')+D'18'	;scale=03bin=215octave=08note=23
	retlw	(D'09'*D'24')+D'00'	;scale=03bin=216octave=09note=00
	retlw	(D'09'*D'24')+D'00'	;scale=03bin=217octave=09note=01
	retlw	(D'09'*D'24')+D'00'	;scale=03bin=218octave=09note=02
	retlw	(D'09'*D'24')+D'00'	;scale=03bin=219octave=09note=03
	retlw	(D'09'*D'24')+D'04'	;scale=03bin=220octave=09note=04
	retlw	(D'09'*D'24')+D'04'	;scale=03bin=221octave=09note=05
	retlw	(D'09'*D'24')+D'04'	;scale=03bin=222octave=09note=06
	retlw	(D'09'*D'24')+D'04'	;scale=03bin=223octave=09note=07
	retlw	(D'09'*D'24')+D'08'	;scale=03bin=224octave=09note=08
	retlw	(D'09'*D'24')+D'08'	;scale=03bin=225octave=09note=09
	retlw	(D'09'*D'24')+D'08'	;scale=03bin=226octave=09note=10
	retlw	(D'09'*D'24')+D'08'	;scale=03bin=227octave=09note=11
	retlw	(D'09'*D'24')+D'08'	;scale=03bin=228octave=09note=12
	retlw	(D'09'*D'24')+D'08'	;scale=03bin=229octave=09note=13
	retlw	(D'09'*D'24')+D'14'	;scale=03bin=230octave=09note=14
	retlw	(D'09'*D'24')+D'14'	;scale=03bin=231octave=09note=15
	retlw	(D'09'*D'24')+D'14'	;scale=03bin=232octave=09note=16
	retlw	(D'09'*D'24')+D'14'	;scale=03bin=233octave=09note=17
	retlw	(D'09'*D'24')+D'18'	;scale=03bin=234octave=09note=18
	retlw	(D'09'*D'24')+D'18'	;scale=03bin=235octave=09note=19
	retlw	(D'09'*D'24')+D'18'	;scale=03bin=236octave=09note=20
	retlw	(D'09'*D'24')+D'18'	;scale=03bin=237octave=09note=21
	retlw	(D'09'*D'24')+D'18'	;scale=03bin=238octave=09note=22
	retlw	(D'09'*D'24')+D'18'	;scale=03bin=239octave=09note=23
	retlw	(D'10'*D'24')+D'00'	;scale=03bin=240octave=10note=00
	retlw	(D'10'*D'24')+D'00'	;scale=03bin=241octave=10note=01
	retlw	(D'10'*D'24')+D'00'	;scale=03bin=242octave=10note=02
	retlw	(D'10'*D'24')+D'00'	;scale=03bin=243octave=10note=03
	retlw	(D'10'*D'24')+D'00'	;scale=03bin=244octave=10note=04
	retlw	(D'10'*D'24')+D'00'	;scale=03bin=245octave=10note=05
	retlw	(D'10'*D'24')+D'00'	;scale=03bin=246octave=10note=06
	retlw	(D'10'*D'24')+D'00'	;scale=03bin=247octave=10note=07
	retlw	(D'10'*D'24')+D'00'	;scale=03bin=248octave=10note=08
	retlw	(D'10'*D'24')+D'00'	;scale=03bin=249octave=10note=09
	retlw	(D'10'*D'24')+D'00'	;scale=03bin=250octave=10note=10
	retlw	(D'10'*D'24')+D'00'	;scale=03bin=251octave=10note=11
	retlw	(D'10'*D'24')+D'00'	;scale=03bin=252octave=10note=12
	retlw	(D'10'*D'24')+D'00'	;scale=03bin=253octave=10note=13
	retlw	(D'10'*D'24')+D'00'	;scale=03bin=254octave=10note=14
	retlw	(D'10'*D'24')+D'00'	;scale=03bin=255octave=10note=15

;	Harmonic Minor look-up table
	org	HarmMin		;Harmonic Minor look-up table
	retlw	(D'00'*D'24')+D'00'	;scale=04bin=000octave=00note=00
	retlw	(D'00'*D'24')+D'00'	;scale=04bin=001octave=00note=01
	retlw	(D'00'*D'24')+D'00'	;scale=04bin=002octave=00note=02
	retlw	(D'00'*D'24')+D'00'	;scale=04bin=003octave=00note=03
	retlw	(D'00'*D'24')+D'04'	;scale=04bin=004octave=00note=04
	retlw	(D'00'*D'24')+D'04'	;scale=04bin=005octave=00note=05
	retlw	(D'00'*D'24')+D'06'	;scale=04bin=006octave=00note=06
	retlw	(D'00'*D'24')+D'06'	;scale=04bin=007octave=00note=07
	retlw	(D'00'*D'24')+D'06'	;scale=04bin=008octave=00note=08
	retlw	(D'00'*D'24')+D'06'	;scale=04bin=009octave=00note=09
	retlw	(D'00'*D'24')+D'10'	;scale=04bin=010octave=00note=10
	retlw	(D'00'*D'24')+D'10'	;scale=04bin=011octave=00note=11
	retlw	(D'00'*D'24')+D'10'	;scale=04bin=012octave=00note=12
	retlw	(D'00'*D'24')+D'10'	;scale=04bin=013octave=00note=13
	retlw	(D'00'*D'24')+D'14'	;scale=04bin=014octave=00note=14
	retlw	(D'00'*D'24')+D'14'	;scale=04bin=015octave=00note=15
	retlw	(D'00'*D'24')+D'16'	;scale=04bin=016octave=00note=16
	retlw	(D'00'*D'24')+D'16'	;scale=04bin=017octave=00note=17
	retlw	(D'00'*D'24')+D'16'	;scale=04bin=018octave=00note=18
	retlw	(D'00'*D'24')+D'16'	;scale=04bin=019octave=00note=19
	retlw	(D'00'*D'24')+D'16'	;scale=04bin=020octave=00note=20
	retlw	(D'00'*D'24')+D'16'	;scale=04bin=021octave=00note=21
	retlw	(D'00'*D'24')+D'22'	;scale=04bin=022octave=00note=22
	retlw	(D'00'*D'24')+D'22'	;scale=04bin=023octave=00note=23
	retlw	(D'01'*D'24')+D'00'	;scale=04bin=024octave=01note=00
	retlw	(D'01'*D'24')+D'00'	;scale=04bin=025octave=01note=01
	retlw	(D'01'*D'24')+D'00'	;scale=04bin=026octave=01note=02
	retlw	(D'01'*D'24')+D'00'	;scale=04bin=027octave=01note=03
	retlw	(D'01'*D'24')+D'04'	;scale=04bin=028octave=01note=04
	retlw	(D'01'*D'24')+D'04'	;scale=04bin=029octave=01note=05
	retlw	(D'01'*D'24')+D'06'	;scale=04bin=030octave=01note=06
	retlw	(D'01'*D'24')+D'06'	;scale=04bin=031octave=01note=07
	retlw	(D'01'*D'24')+D'06'	;scale=04bin=032octave=01note=08
	retlw	(D'01'*D'24')+D'06'	;scale=04bin=033octave=01note=09
	retlw	(D'01'*D'24')+D'10'	;scale=04bin=034octave=01note=10
	retlw	(D'01'*D'24')+D'10'	;scale=04bin=035octave=01note=11
	retlw	(D'01'*D'24')+D'10'	;scale=04bin=036octave=01note=12
	retlw	(D'01'*D'24')+D'10'	;scale=04bin=037octave=01note=13
	retlw	(D'01'*D'24')+D'14'	;scale=04bin=038octave=01note=14
	retlw	(D'01'*D'24')+D'14'	;scale=04bin=039octave=01note=15
	retlw	(D'01'*D'24')+D'16'	;scale=04bin=040octave=01note=16
	retlw	(D'01'*D'24')+D'16'	;scale=04bin=041octave=01note=17
	retlw	(D'01'*D'24')+D'16'	;scale=04bin=042octave=01note=18
	retlw	(D'01'*D'24')+D'16'	;scale=04bin=043octave=01note=19
	retlw	(D'01'*D'24')+D'16'	;scale=04bin=044octave=01note=20
	retlw	(D'01'*D'24')+D'16'	;scale=04bin=045octave=01note=21
	retlw	(D'01'*D'24')+D'22'	;scale=04bin=046octave=01note=22
	retlw	(D'01'*D'24')+D'22'	;scale=04bin=047octave=01note=23
	retlw	(D'02'*D'24')+D'00'	;scale=04bin=048octave=02note=00
	retlw	(D'02'*D'24')+D'00'	;scale=04bin=049octave=02note=01
	retlw	(D'02'*D'24')+D'00'	;scale=04bin=050octave=02note=02
	retlw	(D'02'*D'24')+D'00'	;scale=04bin=051octave=02note=03
	retlw	(D'02'*D'24')+D'04'	;scale=04bin=052octave=02note=04
	retlw	(D'02'*D'24')+D'04'	;scale=04bin=053octave=02note=05
	retlw	(D'02'*D'24')+D'06'	;scale=04bin=054octave=02note=06
	retlw	(D'02'*D'24')+D'06'	;scale=04bin=055octave=02note=07
	retlw	(D'02'*D'24')+D'06'	;scale=04bin=056octave=02note=08
	retlw	(D'02'*D'24')+D'06'	;scale=04bin=057octave=02note=09
	retlw	(D'02'*D'24')+D'10'	;scale=04bin=058octave=02note=10
	retlw	(D'02'*D'24')+D'10'	;scale=04bin=059octave=02note=11
	retlw	(D'02'*D'24')+D'10'	;scale=04bin=060octave=02note=12
	retlw	(D'02'*D'24')+D'10'	;scale=04bin=061octave=02note=13
	retlw	(D'02'*D'24')+D'14'	;scale=04bin=062octave=02note=14
	retlw	(D'02'*D'24')+D'14'	;scale=04bin=063octave=02note=15
	retlw	(D'02'*D'24')+D'16'	;scale=04bin=064octave=02note=16
	retlw	(D'02'*D'24')+D'16'	;scale=04bin=065octave=02note=17
	retlw	(D'02'*D'24')+D'16'	;scale=04bin=066octave=02note=18
	retlw	(D'02'*D'24')+D'16'	;scale=04bin=067octave=02note=19
	retlw	(D'02'*D'24')+D'16'	;scale=04bin=068octave=02note=20
	retlw	(D'02'*D'24')+D'16'	;scale=04bin=069octave=02note=21
	retlw	(D'02'*D'24')+D'22'	;scale=04bin=070octave=02note=22
	retlw	(D'02'*D'24')+D'22'	;scale=04bin=071octave=02note=23
	retlw	(D'03'*D'24')+D'00'	;scale=04bin=072octave=03note=00
	retlw	(D'03'*D'24')+D'00'	;scale=04bin=073octave=03note=01
	retlw	(D'03'*D'24')+D'00'	;scale=04bin=074octave=03note=02
	retlw	(D'03'*D'24')+D'00'	;scale=04bin=075octave=03note=03
	retlw	(D'03'*D'24')+D'04'	;scale=04bin=076octave=03note=04
	retlw	(D'03'*D'24')+D'04'	;scale=04bin=077octave=03note=05
	retlw	(D'03'*D'24')+D'06'	;scale=04bin=078octave=03note=06
	retlw	(D'03'*D'24')+D'06'	;scale=04bin=079octave=03note=07
	retlw	(D'03'*D'24')+D'06'	;scale=04bin=080octave=03note=08
	retlw	(D'03'*D'24')+D'06'	;scale=04bin=081octave=03note=09
	retlw	(D'03'*D'24')+D'10'	;scale=04bin=082octave=03note=10
	retlw	(D'03'*D'24')+D'10'	;scale=04bin=083octave=03note=11
	retlw	(D'03'*D'24')+D'10'	;scale=04bin=084octave=03note=12
	retlw	(D'03'*D'24')+D'10'	;scale=04bin=085octave=03note=13
	retlw	(D'03'*D'24')+D'14'	;scale=04bin=086octave=03note=14
	retlw	(D'03'*D'24')+D'14'	;scale=04bin=087octave=03note=15
	retlw	(D'03'*D'24')+D'16'	;scale=04bin=088octave=03note=16
	retlw	(D'03'*D'24')+D'16'	;scale=04bin=089octave=03note=17
	retlw	(D'03'*D'24')+D'16'	;scale=04bin=090octave=03note=18
	retlw	(D'03'*D'24')+D'16'	;scale=04bin=091octave=03note=19
	retlw	(D'03'*D'24')+D'16'	;scale=04bin=092octave=03note=20
	retlw	(D'03'*D'24')+D'16'	;scale=04bin=093octave=03note=21
	retlw	(D'03'*D'24')+D'22'	;scale=04bin=094octave=03note=22
	retlw	(D'03'*D'24')+D'22'	;scale=04bin=095octave=03note=23
	retlw	(D'04'*D'24')+D'00'	;scale=04bin=096octave=04note=00
	retlw	(D'04'*D'24')+D'00'	;scale=04bin=097octave=04note=01
	retlw	(D'04'*D'24')+D'00'	;scale=04bin=098octave=04note=02
	retlw	(D'04'*D'24')+D'00'	;scale=04bin=099octave=04note=03
	retlw	(D'04'*D'24')+D'04'	;scale=04bin=100octave=04note=04
	retlw	(D'04'*D'24')+D'04'	;scale=04bin=101octave=04note=05
	retlw	(D'04'*D'24')+D'06'	;scale=04bin=102octave=04note=06
	retlw	(D'04'*D'24')+D'06'	;scale=04bin=103octave=04note=07
	retlw	(D'04'*D'24')+D'06'	;scale=04bin=104octave=04note=08
	retlw	(D'04'*D'24')+D'06'	;scale=04bin=105octave=04note=09
	retlw	(D'04'*D'24')+D'10'	;scale=04bin=106octave=04note=10
	retlw	(D'04'*D'24')+D'10'	;scale=04bin=107octave=04note=11
	retlw	(D'04'*D'24')+D'10'	;scale=04bin=108octave=04note=12
	retlw	(D'04'*D'24')+D'10'	;scale=04bin=109octave=04note=13
	retlw	(D'04'*D'24')+D'14'	;scale=04bin=110octave=04note=14
	retlw	(D'04'*D'24')+D'14'	;scale=04bin=111octave=04note=15
	retlw	(D'04'*D'24')+D'16'	;scale=04bin=112octave=04note=16
	retlw	(D'04'*D'24')+D'16'	;scale=04bin=113octave=04note=17
	retlw	(D'04'*D'24')+D'16'	;scale=04bin=114octave=04note=18
	retlw	(D'04'*D'24')+D'16'	;scale=04bin=115octave=04note=19
	retlw	(D'04'*D'24')+D'16'	;scale=04bin=116octave=04note=20
	retlw	(D'04'*D'24')+D'16'	;scale=04bin=117octave=04note=21
	retlw	(D'04'*D'24')+D'22'	;scale=04bin=118octave=04note=22
	retlw	(D'04'*D'24')+D'22'	;scale=04bin=119octave=04note=23
	retlw	(D'05'*D'24')+D'00'	;scale=04bin=120octave=05note=00
	retlw	(D'05'*D'24')+D'00'	;scale=04bin=121octave=05note=01
	retlw	(D'05'*D'24')+D'00'	;scale=04bin=122octave=05note=02
	retlw	(D'05'*D'24')+D'00'	;scale=04bin=123octave=05note=03
	retlw	(D'05'*D'24')+D'04'	;scale=04bin=124octave=05note=04
	retlw	(D'05'*D'24')+D'04'	;scale=04bin=125octave=05note=05
	retlw	(D'05'*D'24')+D'06'	;scale=04bin=126octave=05note=06
	retlw	(D'05'*D'24')+D'06'	;scale=04bin=127octave=05note=07
	retlw	(D'05'*D'24')+D'06'	;scale=04bin=128octave=05note=08
	retlw	(D'05'*D'24')+D'06'	;scale=04bin=129octave=05note=09
	retlw	(D'05'*D'24')+D'10'	;scale=04bin=130octave=05note=10
	retlw	(D'05'*D'24')+D'10'	;scale=04bin=131octave=05note=11
	retlw	(D'05'*D'24')+D'10'	;scale=04bin=132octave=05note=12
	retlw	(D'05'*D'24')+D'10'	;scale=04bin=133octave=05note=13
	retlw	(D'05'*D'24')+D'14'	;scale=04bin=134octave=05note=14
	retlw	(D'05'*D'24')+D'14'	;scale=04bin=135octave=05note=15
	retlw	(D'05'*D'24')+D'16'	;scale=04bin=136octave=05note=16
	retlw	(D'05'*D'24')+D'16'	;scale=04bin=137octave=05note=17
	retlw	(D'05'*D'24')+D'16'	;scale=04bin=138octave=05note=18
	retlw	(D'05'*D'24')+D'16'	;scale=04bin=139octave=05note=19
	retlw	(D'05'*D'24')+D'16'	;scale=04bin=140octave=05note=20
	retlw	(D'05'*D'24')+D'16'	;scale=04bin=141octave=05note=21
	retlw	(D'05'*D'24')+D'22'	;scale=04bin=142octave=05note=22
	retlw	(D'05'*D'24')+D'22'	;scale=04bin=143octave=05note=23
	retlw	(D'06'*D'24')+D'00'	;scale=04bin=144octave=06note=00
	retlw	(D'06'*D'24')+D'00'	;scale=04bin=145octave=06note=01
	retlw	(D'06'*D'24')+D'00'	;scale=04bin=146octave=06note=02
	retlw	(D'06'*D'24')+D'00'	;scale=04bin=147octave=06note=03
	retlw	(D'06'*D'24')+D'04'	;scale=04bin=148octave=06note=04
	retlw	(D'06'*D'24')+D'04'	;scale=04bin=149octave=06note=05
	retlw	(D'06'*D'24')+D'06'	;scale=04bin=150octave=06note=06
	retlw	(D'06'*D'24')+D'06'	;scale=04bin=151octave=06note=07
	retlw	(D'06'*D'24')+D'06'	;scale=04bin=152octave=06note=08
	retlw	(D'06'*D'24')+D'06'	;scale=04bin=153octave=06note=09
	retlw	(D'06'*D'24')+D'10'	;scale=04bin=154octave=06note=10
	retlw	(D'06'*D'24')+D'10'	;scale=04bin=155octave=06note=11
	retlw	(D'06'*D'24')+D'10'	;scale=04bin=156octave=06note=12
	retlw	(D'06'*D'24')+D'10'	;scale=04bin=157octave=06note=13
	retlw	(D'06'*D'24')+D'14'	;scale=04bin=158octave=06note=14
	retlw	(D'06'*D'24')+D'14'	;scale=04bin=159octave=06note=15
	retlw	(D'06'*D'24')+D'16'	;scale=04bin=160octave=06note=16
	retlw	(D'06'*D'24')+D'16'	;scale=04bin=161octave=06note=17
	retlw	(D'06'*D'24')+D'16'	;scale=04bin=162octave=06note=18
	retlw	(D'06'*D'24')+D'16'	;scale=04bin=163octave=06note=19
	retlw	(D'06'*D'24')+D'16'	;scale=04bin=164octave=06note=20
	retlw	(D'06'*D'24')+D'16'	;scale=04bin=165octave=06note=21
	retlw	(D'06'*D'24')+D'22'	;scale=04bin=166octave=06note=22
	retlw	(D'06'*D'24')+D'22'	;scale=04bin=167octave=06note=23
	retlw	(D'07'*D'24')+D'00'	;scale=04bin=168octave=07note=00
	retlw	(D'07'*D'24')+D'00'	;scale=04bin=169octave=07note=01
	retlw	(D'07'*D'24')+D'00'	;scale=04bin=170octave=07note=02
	retlw	(D'07'*D'24')+D'00'	;scale=04bin=171octave=07note=03
	retlw	(D'07'*D'24')+D'04'	;scale=04bin=172octave=07note=04
	retlw	(D'07'*D'24')+D'04'	;scale=04bin=173octave=07note=05
	retlw	(D'07'*D'24')+D'06'	;scale=04bin=174octave=07note=06
	retlw	(D'07'*D'24')+D'06'	;scale=04bin=175octave=07note=07
	retlw	(D'07'*D'24')+D'06'	;scale=04bin=176octave=07note=08
	retlw	(D'07'*D'24')+D'06'	;scale=04bin=177octave=07note=09
	retlw	(D'07'*D'24')+D'10'	;scale=04bin=178octave=07note=10
	retlw	(D'07'*D'24')+D'10'	;scale=04bin=179octave=07note=11
	retlw	(D'07'*D'24')+D'10'	;scale=04bin=180octave=07note=12
	retlw	(D'07'*D'24')+D'10'	;scale=04bin=181octave=07note=13
	retlw	(D'07'*D'24')+D'14'	;scale=04bin=182octave=07note=14
	retlw	(D'07'*D'24')+D'14'	;scale=04bin=183octave=07note=15
	retlw	(D'07'*D'24')+D'16'	;scale=04bin=184octave=07note=16
	retlw	(D'07'*D'24')+D'16'	;scale=04bin=185octave=07note=17
	retlw	(D'07'*D'24')+D'16'	;scale=04bin=186octave=07note=18
	retlw	(D'07'*D'24')+D'16'	;scale=04bin=187octave=07note=19
	retlw	(D'07'*D'24')+D'16'	;scale=04bin=188octave=07note=20
	retlw	(D'07'*D'24')+D'16'	;scale=04bin=189octave=07note=21
	retlw	(D'07'*D'24')+D'22'	;scale=04bin=190octave=07note=22
	retlw	(D'07'*D'24')+D'22'	;scale=04bin=191octave=07note=23
	retlw	(D'08'*D'24')+D'00'	;scale=04bin=192octave=08note=00
	retlw	(D'08'*D'24')+D'00'	;scale=04bin=193octave=08note=01
	retlw	(D'08'*D'24')+D'00'	;scale=04bin=194octave=08note=02
	retlw	(D'08'*D'24')+D'00'	;scale=04bin=195octave=08note=03
	retlw	(D'08'*D'24')+D'04'	;scale=04bin=196octave=08note=04
	retlw	(D'08'*D'24')+D'04'	;scale=04bin=197octave=08note=05
	retlw	(D'08'*D'24')+D'06'	;scale=04bin=198octave=08note=06
	retlw	(D'08'*D'24')+D'06'	;scale=04bin=199octave=08note=07
	retlw	(D'08'*D'24')+D'06'	;scale=04bin=200octave=08note=08
	retlw	(D'08'*D'24')+D'06'	;scale=04bin=201octave=08note=09
	retlw	(D'08'*D'24')+D'10'	;scale=04bin=202octave=08note=10
	retlw	(D'08'*D'24')+D'10'	;scale=04bin=203octave=08note=11
	retlw	(D'08'*D'24')+D'10'	;scale=04bin=204octave=08note=12
	retlw	(D'08'*D'24')+D'10'	;scale=04bin=205octave=08note=13
	retlw	(D'08'*D'24')+D'14'	;scale=04bin=206octave=08note=14
	retlw	(D'08'*D'24')+D'14'	;scale=04bin=207octave=08note=15
	retlw	(D'08'*D'24')+D'16'	;scale=04bin=208octave=08note=16
	retlw	(D'08'*D'24')+D'16'	;scale=04bin=209octave=08note=17
	retlw	(D'08'*D'24')+D'16'	;scale=04bin=210octave=08note=18
	retlw	(D'08'*D'24')+D'16'	;scale=04bin=211octave=08note=19
	retlw	(D'08'*D'24')+D'16'	;scale=04bin=212octave=08note=20
	retlw	(D'08'*D'24')+D'16'	;scale=04bin=213octave=08note=21
	retlw	(D'08'*D'24')+D'22'	;scale=04bin=214octave=08note=22
	retlw	(D'08'*D'24')+D'22'	;scale=04bin=215octave=08note=23
	retlw	(D'09'*D'24')+D'00'	;scale=04bin=216octave=09note=00
	retlw	(D'09'*D'24')+D'00'	;scale=04bin=217octave=09note=01
	retlw	(D'09'*D'24')+D'00'	;scale=04bin=218octave=09note=02
	retlw	(D'09'*D'24')+D'00'	;scale=04bin=219octave=09note=03
	retlw	(D'09'*D'24')+D'04'	;scale=04bin=220octave=09note=04
	retlw	(D'09'*D'24')+D'04'	;scale=04bin=221octave=09note=05
	retlw	(D'09'*D'24')+D'06'	;scale=04bin=222octave=09note=06
	retlw	(D'09'*D'24')+D'06'	;scale=04bin=223octave=09note=07
	retlw	(D'09'*D'24')+D'06'	;scale=04bin=224octave=09note=08
	retlw	(D'09'*D'24')+D'06'	;scale=04bin=225octave=09note=09
	retlw	(D'09'*D'24')+D'10'	;scale=04bin=226octave=09note=10
	retlw	(D'09'*D'24')+D'10'	;scale=04bin=227octave=09note=11
	retlw	(D'09'*D'24')+D'10'	;scale=04bin=228octave=09note=12
	retlw	(D'09'*D'24')+D'10'	;scale=04bin=229octave=09note=13
	retlw	(D'09'*D'24')+D'14'	;scale=04bin=230octave=09note=14
	retlw	(D'09'*D'24')+D'14'	;scale=04bin=231octave=09note=15
	retlw	(D'09'*D'24')+D'16'	;scale=04bin=232octave=09note=16
	retlw	(D'09'*D'24')+D'16'	;scale=04bin=233octave=09note=17
	retlw	(D'09'*D'24')+D'16'	;scale=04bin=234octave=09note=18
	retlw	(D'09'*D'24')+D'16'	;scale=04bin=235octave=09note=19
	retlw	(D'09'*D'24')+D'16'	;scale=04bin=236octave=09note=20
	retlw	(D'09'*D'24')+D'16'	;scale=04bin=237octave=09note=21
	retlw	(D'09'*D'24')+D'22'	;scale=04bin=238octave=09note=22
	retlw	(D'09'*D'24')+D'22'	;scale=04bin=239octave=09note=23
	retlw	(D'10'*D'24')+D'00'	;scale=04bin=240octave=10note=00
	retlw	(D'10'*D'24')+D'00'	;scale=04bin=241octave=10note=01
	retlw	(D'10'*D'24')+D'00'	;scale=04bin=242octave=10note=02
	retlw	(D'10'*D'24')+D'00'	;scale=04bin=243octave=10note=03
	retlw	(D'10'*D'24')+D'00'	;scale=04bin=244octave=10note=04
	retlw	(D'10'*D'24')+D'00'	;scale=04bin=245octave=10note=05
	retlw	(D'10'*D'24')+D'00'	;scale=04bin=246octave=10note=06
	retlw	(D'10'*D'24')+D'00'	;scale=04bin=247octave=10note=07
	retlw	(D'10'*D'24')+D'00'	;scale=04bin=248octave=10note=08
	retlw	(D'10'*D'24')+D'00'	;scale=04bin=249octave=10note=09
	retlw	(D'10'*D'24')+D'00'	;scale=04bin=250octave=10note=10
	retlw	(D'10'*D'24')+D'00'	;scale=04bin=251octave=10note=11
	retlw	(D'10'*D'24')+D'00'	;scale=04bin=252octave=10note=12
	retlw	(D'10'*D'24')+D'00'	;scale=04bin=253octave=10note=13
	retlw	(D'10'*D'24')+D'00'	;scale=04bin=254octave=10note=14
	retlw	(D'10'*D'24')+D'00'	;scale=04bin=255octave=10note=15

;	Minor/Aolian look-up table
	org	MinorAol		;Minor/Aolian look-up table
	retlw	(D'00'*D'24')+D'00'	;scale=05bin=000octave=00note=00
	retlw	(D'00'*D'24')+D'00'	;scale=05bin=001octave=00note=01
	retlw	(D'00'*D'24')+D'00'	;scale=05bin=002octave=00note=02
	retlw	(D'00'*D'24')+D'00'	;scale=05bin=003octave=00note=03
	retlw	(D'00'*D'24')+D'04'	;scale=05bin=004octave=00note=04
	retlw	(D'00'*D'24')+D'04'	;scale=05bin=005octave=00note=05
	retlw	(D'00'*D'24')+D'06'	;scale=05bin=006octave=00note=06
	retlw	(D'00'*D'24')+D'06'	;scale=05bin=007octave=00note=07
	retlw	(D'00'*D'24')+D'06'	;scale=05bin=008octave=00note=08
	retlw	(D'00'*D'24')+D'06'	;scale=05bin=009octave=00note=09
	retlw	(D'00'*D'24')+D'10'	;scale=05bin=010octave=00note=10
	retlw	(D'00'*D'24')+D'10'	;scale=05bin=011octave=00note=11
	retlw	(D'00'*D'24')+D'10'	;scale=05bin=012octave=00note=12
	retlw	(D'00'*D'24')+D'10'	;scale=05bin=013octave=00note=13
	retlw	(D'00'*D'24')+D'14'	;scale=05bin=014octave=00note=14
	retlw	(D'00'*D'24')+D'14'	;scale=05bin=015octave=00note=15
	retlw	(D'00'*D'24')+D'16'	;scale=05bin=016octave=00note=16
	retlw	(D'00'*D'24')+D'16'	;scale=05bin=017octave=00note=17
	retlw	(D'00'*D'24')+D'16'	;scale=05bin=018octave=00note=18
	retlw	(D'00'*D'24')+D'16'	;scale=05bin=019octave=00note=19
	retlw	(D'00'*D'24')+D'20'	;scale=05bin=020octave=00note=20
	retlw	(D'00'*D'24')+D'20'	;scale=05bin=021octave=00note=21
	retlw	(D'00'*D'24')+D'20'	;scale=05bin=022octave=00note=22
	retlw	(D'00'*D'24')+D'20'	;scale=05bin=023octave=00note=23
	retlw	(D'01'*D'24')+D'00'	;scale=05bin=024octave=01note=00
	retlw	(D'01'*D'24')+D'00'	;scale=05bin=025octave=01note=01
	retlw	(D'01'*D'24')+D'00'	;scale=05bin=026octave=01note=02
	retlw	(D'01'*D'24')+D'00'	;scale=05bin=027octave=01note=03
	retlw	(D'01'*D'24')+D'04'	;scale=05bin=028octave=01note=04
	retlw	(D'01'*D'24')+D'04'	;scale=05bin=029octave=01note=05
	retlw	(D'01'*D'24')+D'06'	;scale=05bin=030octave=01note=06
	retlw	(D'01'*D'24')+D'06'	;scale=05bin=031octave=01note=07
	retlw	(D'01'*D'24')+D'06'	;scale=05bin=032octave=01note=08
	retlw	(D'01'*D'24')+D'06'	;scale=05bin=033octave=01note=09
	retlw	(D'01'*D'24')+D'10'	;scale=05bin=034octave=01note=10
	retlw	(D'01'*D'24')+D'10'	;scale=05bin=035octave=01note=11
	retlw	(D'01'*D'24')+D'10'	;scale=05bin=036octave=01note=12
	retlw	(D'01'*D'24')+D'10'	;scale=05bin=037octave=01note=13
	retlw	(D'01'*D'24')+D'14'	;scale=05bin=038octave=01note=14
	retlw	(D'01'*D'24')+D'14'	;scale=05bin=039octave=01note=15
	retlw	(D'01'*D'24')+D'16'	;scale=05bin=040octave=01note=16
	retlw	(D'01'*D'24')+D'16'	;scale=05bin=041octave=01note=17
	retlw	(D'01'*D'24')+D'16'	;scale=05bin=042octave=01note=18
	retlw	(D'01'*D'24')+D'16'	;scale=05bin=043octave=01note=19
	retlw	(D'01'*D'24')+D'20'	;scale=05bin=044octave=01note=20
	retlw	(D'01'*D'24')+D'20'	;scale=05bin=045octave=01note=21
	retlw	(D'01'*D'24')+D'20'	;scale=05bin=046octave=01note=22
	retlw	(D'01'*D'24')+D'20'	;scale=05bin=047octave=01note=23
	retlw	(D'02'*D'24')+D'00'	;scale=05bin=048octave=02note=00
	retlw	(D'02'*D'24')+D'00'	;scale=05bin=049octave=02note=01
	retlw	(D'02'*D'24')+D'00'	;scale=05bin=050octave=02note=02
	retlw	(D'02'*D'24')+D'00'	;scale=05bin=051octave=02note=03
	retlw	(D'02'*D'24')+D'04'	;scale=05bin=052octave=02note=04
	retlw	(D'02'*D'24')+D'04'	;scale=05bin=053octave=02note=05
	retlw	(D'02'*D'24')+D'06'	;scale=05bin=054octave=02note=06
	retlw	(D'02'*D'24')+D'06'	;scale=05bin=055octave=02note=07
	retlw	(D'02'*D'24')+D'06'	;scale=05bin=056octave=02note=08
	retlw	(D'02'*D'24')+D'06'	;scale=05bin=057octave=02note=09
	retlw	(D'02'*D'24')+D'10'	;scale=05bin=058octave=02note=10
	retlw	(D'02'*D'24')+D'10'	;scale=05bin=059octave=02note=11
	retlw	(D'02'*D'24')+D'10'	;scale=05bin=060octave=02note=12
	retlw	(D'02'*D'24')+D'10'	;scale=05bin=061octave=02note=13
	retlw	(D'02'*D'24')+D'14'	;scale=05bin=062octave=02note=14
	retlw	(D'02'*D'24')+D'14'	;scale=05bin=063octave=02note=15
	retlw	(D'02'*D'24')+D'16'	;scale=05bin=064octave=02note=16
	retlw	(D'02'*D'24')+D'16'	;scale=05bin=065octave=02note=17
	retlw	(D'02'*D'24')+D'16'	;scale=05bin=066octave=02note=18
	retlw	(D'02'*D'24')+D'16'	;scale=05bin=067octave=02note=19
	retlw	(D'02'*D'24')+D'20'	;scale=05bin=068octave=02note=20
	retlw	(D'02'*D'24')+D'20'	;scale=05bin=069octave=02note=21
	retlw	(D'02'*D'24')+D'20'	;scale=05bin=070octave=02note=22
	retlw	(D'02'*D'24')+D'20'	;scale=05bin=071octave=02note=23
	retlw	(D'03'*D'24')+D'00'	;scale=05bin=072octave=03note=00
	retlw	(D'03'*D'24')+D'00'	;scale=05bin=073octave=03note=01
	retlw	(D'03'*D'24')+D'00'	;scale=05bin=074octave=03note=02
	retlw	(D'03'*D'24')+D'00'	;scale=05bin=075octave=03note=03
	retlw	(D'03'*D'24')+D'04'	;scale=05bin=076octave=03note=04
	retlw	(D'03'*D'24')+D'04'	;scale=05bin=077octave=03note=05
	retlw	(D'03'*D'24')+D'06'	;scale=05bin=078octave=03note=06
	retlw	(D'03'*D'24')+D'06'	;scale=05bin=079octave=03note=07
	retlw	(D'03'*D'24')+D'06'	;scale=05bin=080octave=03note=08
	retlw	(D'03'*D'24')+D'06'	;scale=05bin=081octave=03note=09
	retlw	(D'03'*D'24')+D'10'	;scale=05bin=082octave=03note=10
	retlw	(D'03'*D'24')+D'10'	;scale=05bin=083octave=03note=11
	retlw	(D'03'*D'24')+D'10'	;scale=05bin=084octave=03note=12
	retlw	(D'03'*D'24')+D'10'	;scale=05bin=085octave=03note=13
	retlw	(D'03'*D'24')+D'14'	;scale=05bin=086octave=03note=14
	retlw	(D'03'*D'24')+D'14'	;scale=05bin=087octave=03note=15
	retlw	(D'03'*D'24')+D'16'	;scale=05bin=088octave=03note=16
	retlw	(D'03'*D'24')+D'16'	;scale=05bin=089octave=03note=17
	retlw	(D'03'*D'24')+D'16'	;scale=05bin=090octave=03note=18
	retlw	(D'03'*D'24')+D'16'	;scale=05bin=091octave=03note=19
	retlw	(D'03'*D'24')+D'20'	;scale=05bin=092octave=03note=20
	retlw	(D'03'*D'24')+D'20'	;scale=05bin=093octave=03note=21
	retlw	(D'03'*D'24')+D'20'	;scale=05bin=094octave=03note=22
	retlw	(D'03'*D'24')+D'20'	;scale=05bin=095octave=03note=23
	retlw	(D'04'*D'24')+D'00'	;scale=05bin=096octave=04note=00
	retlw	(D'04'*D'24')+D'00'	;scale=05bin=097octave=04note=01
	retlw	(D'04'*D'24')+D'00'	;scale=05bin=098octave=04note=02
	retlw	(D'04'*D'24')+D'00'	;scale=05bin=099octave=04note=03
	retlw	(D'04'*D'24')+D'04'	;scale=05bin=100octave=04note=04
	retlw	(D'04'*D'24')+D'04'	;scale=05bin=101octave=04note=05
	retlw	(D'04'*D'24')+D'06'	;scale=05bin=102octave=04note=06
	retlw	(D'04'*D'24')+D'06'	;scale=05bin=103octave=04note=07
	retlw	(D'04'*D'24')+D'06'	;scale=05bin=104octave=04note=08
	retlw	(D'04'*D'24')+D'06'	;scale=05bin=105octave=04note=09
	retlw	(D'04'*D'24')+D'10'	;scale=05bin=106octave=04note=10
	retlw	(D'04'*D'24')+D'10'	;scale=05bin=107octave=04note=11
	retlw	(D'04'*D'24')+D'10'	;scale=05bin=108octave=04note=12
	retlw	(D'04'*D'24')+D'10'	;scale=05bin=109octave=04note=13
	retlw	(D'04'*D'24')+D'14'	;scale=05bin=110octave=04note=14
	retlw	(D'04'*D'24')+D'14'	;scale=05bin=111octave=04note=15
	retlw	(D'04'*D'24')+D'16'	;scale=05bin=112octave=04note=16
	retlw	(D'04'*D'24')+D'16'	;scale=05bin=113octave=04note=17
	retlw	(D'04'*D'24')+D'16'	;scale=05bin=114octave=04note=18
	retlw	(D'04'*D'24')+D'16'	;scale=05bin=115octave=04note=19
	retlw	(D'04'*D'24')+D'20'	;scale=05bin=116octave=04note=20
	retlw	(D'04'*D'24')+D'20'	;scale=05bin=117octave=04note=21
	retlw	(D'04'*D'24')+D'20'	;scale=05bin=118octave=04note=22
	retlw	(D'04'*D'24')+D'20'	;scale=05bin=119octave=04note=23
	retlw	(D'05'*D'24')+D'00'	;scale=05bin=120octave=05note=00
	retlw	(D'05'*D'24')+D'00'	;scale=05bin=121octave=05note=01
	retlw	(D'05'*D'24')+D'00'	;scale=05bin=122octave=05note=02
	retlw	(D'05'*D'24')+D'00'	;scale=05bin=123octave=05note=03
	retlw	(D'05'*D'24')+D'04'	;scale=05bin=124octave=05note=04
	retlw	(D'05'*D'24')+D'04'	;scale=05bin=125octave=05note=05
	retlw	(D'05'*D'24')+D'06'	;scale=05bin=126octave=05note=06
	retlw	(D'05'*D'24')+D'06'	;scale=05bin=127octave=05note=07
	retlw	(D'05'*D'24')+D'06'	;scale=05bin=128octave=05note=08
	retlw	(D'05'*D'24')+D'06'	;scale=05bin=129octave=05note=09
	retlw	(D'05'*D'24')+D'10'	;scale=05bin=130octave=05note=10
	retlw	(D'05'*D'24')+D'10'	;scale=05bin=131octave=05note=11
	retlw	(D'05'*D'24')+D'10'	;scale=05bin=132octave=05note=12
	retlw	(D'05'*D'24')+D'10'	;scale=05bin=133octave=05note=13
	retlw	(D'05'*D'24')+D'14'	;scale=05bin=134octave=05note=14
	retlw	(D'05'*D'24')+D'14'	;scale=05bin=135octave=05note=15
	retlw	(D'05'*D'24')+D'16'	;scale=05bin=136octave=05note=16
	retlw	(D'05'*D'24')+D'16'	;scale=05bin=137octave=05note=17
	retlw	(D'05'*D'24')+D'16'	;scale=05bin=138octave=05note=18
	retlw	(D'05'*D'24')+D'16'	;scale=05bin=139octave=05note=19
	retlw	(D'05'*D'24')+D'20'	;scale=05bin=140octave=05note=20
	retlw	(D'05'*D'24')+D'20'	;scale=05bin=141octave=05note=21
	retlw	(D'05'*D'24')+D'20'	;scale=05bin=142octave=05note=22
	retlw	(D'05'*D'24')+D'20'	;scale=05bin=143octave=05note=23
	retlw	(D'06'*D'24')+D'00'	;scale=05bin=144octave=06note=00
	retlw	(D'06'*D'24')+D'00'	;scale=05bin=145octave=06note=01
	retlw	(D'06'*D'24')+D'00'	;scale=05bin=146octave=06note=02
	retlw	(D'06'*D'24')+D'00'	;scale=05bin=147octave=06note=03
	retlw	(D'06'*D'24')+D'04'	;scale=05bin=148octave=06note=04
	retlw	(D'06'*D'24')+D'04'	;scale=05bin=149octave=06note=05
	retlw	(D'06'*D'24')+D'06'	;scale=05bin=150octave=06note=06
	retlw	(D'06'*D'24')+D'06'	;scale=05bin=151octave=06note=07
	retlw	(D'06'*D'24')+D'06'	;scale=05bin=152octave=06note=08
	retlw	(D'06'*D'24')+D'06'	;scale=05bin=153octave=06note=09
	retlw	(D'06'*D'24')+D'10'	;scale=05bin=154octave=06note=10
	retlw	(D'06'*D'24')+D'10'	;scale=05bin=155octave=06note=11
	retlw	(D'06'*D'24')+D'10'	;scale=05bin=156octave=06note=12
	retlw	(D'06'*D'24')+D'10'	;scale=05bin=157octave=06note=13
	retlw	(D'06'*D'24')+D'14'	;scale=05bin=158octave=06note=14
	retlw	(D'06'*D'24')+D'14'	;scale=05bin=159octave=06note=15
	retlw	(D'06'*D'24')+D'16'	;scale=05bin=160octave=06note=16
	retlw	(D'06'*D'24')+D'16'	;scale=05bin=161octave=06note=17
	retlw	(D'06'*D'24')+D'16'	;scale=05bin=162octave=06note=18
	retlw	(D'06'*D'24')+D'16'	;scale=05bin=163octave=06note=19
	retlw	(D'06'*D'24')+D'20'	;scale=05bin=164octave=06note=20
	retlw	(D'06'*D'24')+D'20'	;scale=05bin=165octave=06note=21
	retlw	(D'06'*D'24')+D'20'	;scale=05bin=166octave=06note=22
	retlw	(D'06'*D'24')+D'20'	;scale=05bin=167octave=06note=23
	retlw	(D'07'*D'24')+D'00'	;scale=05bin=168octave=07note=00
	retlw	(D'07'*D'24')+D'00'	;scale=05bin=169octave=07note=01
	retlw	(D'07'*D'24')+D'00'	;scale=05bin=170octave=07note=02
	retlw	(D'07'*D'24')+D'00'	;scale=05bin=171octave=07note=03
	retlw	(D'07'*D'24')+D'04'	;scale=05bin=172octave=07note=04
	retlw	(D'07'*D'24')+D'04'	;scale=05bin=173octave=07note=05
	retlw	(D'07'*D'24')+D'06'	;scale=05bin=174octave=07note=06
	retlw	(D'07'*D'24')+D'06'	;scale=05bin=175octave=07note=07
	retlw	(D'07'*D'24')+D'06'	;scale=05bin=176octave=07note=08
	retlw	(D'07'*D'24')+D'06'	;scale=05bin=177octave=07note=09
	retlw	(D'07'*D'24')+D'10'	;scale=05bin=178octave=07note=10
	retlw	(D'07'*D'24')+D'10'	;scale=05bin=179octave=07note=11
	retlw	(D'07'*D'24')+D'10'	;scale=05bin=180octave=07note=12
	retlw	(D'07'*D'24')+D'10'	;scale=05bin=181octave=07note=13
	retlw	(D'07'*D'24')+D'14'	;scale=05bin=182octave=07note=14
	retlw	(D'07'*D'24')+D'14'	;scale=05bin=183octave=07note=15
	retlw	(D'07'*D'24')+D'16'	;scale=05bin=184octave=07note=16
	retlw	(D'07'*D'24')+D'16'	;scale=05bin=185octave=07note=17
	retlw	(D'07'*D'24')+D'16'	;scale=05bin=186octave=07note=18
	retlw	(D'07'*D'24')+D'16'	;scale=05bin=187octave=07note=19
	retlw	(D'07'*D'24')+D'20'	;scale=05bin=188octave=07note=20
	retlw	(D'07'*D'24')+D'20'	;scale=05bin=189octave=07note=21
	retlw	(D'07'*D'24')+D'20'	;scale=05bin=190octave=07note=22
	retlw	(D'07'*D'24')+D'20'	;scale=05bin=191octave=07note=23
	retlw	(D'08'*D'24')+D'00'	;scale=05bin=192octave=08note=00
	retlw	(D'08'*D'24')+D'00'	;scale=05bin=193octave=08note=01
	retlw	(D'08'*D'24')+D'00'	;scale=05bin=194octave=08note=02
	retlw	(D'08'*D'24')+D'00'	;scale=05bin=195octave=08note=03
	retlw	(D'08'*D'24')+D'04'	;scale=05bin=196octave=08note=04
	retlw	(D'08'*D'24')+D'04'	;scale=05bin=197octave=08note=05
	retlw	(D'08'*D'24')+D'06'	;scale=05bin=198octave=08note=06
	retlw	(D'08'*D'24')+D'06'	;scale=05bin=199octave=08note=07
	retlw	(D'08'*D'24')+D'06'	;scale=05bin=200octave=08note=08
	retlw	(D'08'*D'24')+D'06'	;scale=05bin=201octave=08note=09
	retlw	(D'08'*D'24')+D'10'	;scale=05bin=202octave=08note=10
	retlw	(D'08'*D'24')+D'10'	;scale=05bin=203octave=08note=11
	retlw	(D'08'*D'24')+D'10'	;scale=05bin=204octave=08note=12
	retlw	(D'08'*D'24')+D'10'	;scale=05bin=205octave=08note=13
	retlw	(D'08'*D'24')+D'14'	;scale=05bin=206octave=08note=14
	retlw	(D'08'*D'24')+D'14'	;scale=05bin=207octave=08note=15
	retlw	(D'08'*D'24')+D'16'	;scale=05bin=208octave=08note=16
	retlw	(D'08'*D'24')+D'16'	;scale=05bin=209octave=08note=17
	retlw	(D'08'*D'24')+D'16'	;scale=05bin=210octave=08note=18
	retlw	(D'08'*D'24')+D'16'	;scale=05bin=211octave=08note=19
	retlw	(D'08'*D'24')+D'20'	;scale=05bin=212octave=08note=20
	retlw	(D'08'*D'24')+D'20'	;scale=05bin=213octave=08note=21
	retlw	(D'08'*D'24')+D'20'	;scale=05bin=214octave=08note=22
	retlw	(D'08'*D'24')+D'20'	;scale=05bin=215octave=08note=23
	retlw	(D'09'*D'24')+D'00'	;scale=05bin=216octave=09note=00
	retlw	(D'09'*D'24')+D'00'	;scale=05bin=217octave=09note=01
	retlw	(D'09'*D'24')+D'00'	;scale=05bin=218octave=09note=02
	retlw	(D'09'*D'24')+D'00'	;scale=05bin=219octave=09note=03
	retlw	(D'09'*D'24')+D'04'	;scale=05bin=220octave=09note=04
	retlw	(D'09'*D'24')+D'04'	;scale=05bin=221octave=09note=05
	retlw	(D'09'*D'24')+D'06'	;scale=05bin=222octave=09note=06
	retlw	(D'09'*D'24')+D'06'	;scale=05bin=223octave=09note=07
	retlw	(D'09'*D'24')+D'06'	;scale=05bin=224octave=09note=08
	retlw	(D'09'*D'24')+D'06'	;scale=05bin=225octave=09note=09
	retlw	(D'09'*D'24')+D'10'	;scale=05bin=226octave=09note=10
	retlw	(D'09'*D'24')+D'10'	;scale=05bin=227octave=09note=11
	retlw	(D'09'*D'24')+D'10'	;scale=05bin=228octave=09note=12
	retlw	(D'09'*D'24')+D'10'	;scale=05bin=229octave=09note=13
	retlw	(D'09'*D'24')+D'14'	;scale=05bin=230octave=09note=14
	retlw	(D'09'*D'24')+D'14'	;scale=05bin=231octave=09note=15
	retlw	(D'09'*D'24')+D'16'	;scale=05bin=232octave=09note=16
	retlw	(D'09'*D'24')+D'16'	;scale=05bin=233octave=09note=17
	retlw	(D'09'*D'24')+D'16'	;scale=05bin=234octave=09note=18
	retlw	(D'09'*D'24')+D'16'	;scale=05bin=235octave=09note=19
	retlw	(D'09'*D'24')+D'20'	;scale=05bin=236octave=09note=20
	retlw	(D'09'*D'24')+D'20'	;scale=05bin=237octave=09note=21
	retlw	(D'09'*D'24')+D'20'	;scale=05bin=238octave=09note=22
	retlw	(D'09'*D'24')+D'20'	;scale=05bin=239octave=09note=23
	retlw	(D'10'*D'24')+D'00'	;scale=05bin=240octave=10note=00
	retlw	(D'10'*D'24')+D'00'	;scale=05bin=241octave=10note=01
	retlw	(D'10'*D'24')+D'00'	;scale=05bin=242octave=10note=02
	retlw	(D'10'*D'24')+D'00'	;scale=05bin=243octave=10note=03
	retlw	(D'10'*D'24')+D'00'	;scale=05bin=244octave=10note=04
	retlw	(D'10'*D'24')+D'00'	;scale=05bin=245octave=10note=05
	retlw	(D'10'*D'24')+D'00'	;scale=05bin=246octave=10note=06
	retlw	(D'10'*D'24')+D'00'	;scale=05bin=247octave=10note=07
	retlw	(D'10'*D'24')+D'00'	;scale=05bin=248octave=10note=08
	retlw	(D'10'*D'24')+D'00'	;scale=05bin=249octave=10note=09
	retlw	(D'10'*D'24')+D'00'	;scale=05bin=250octave=10note=10
	retlw	(D'10'*D'24')+D'00'	;scale=05bin=251octave=10note=11
	retlw	(D'10'*D'24')+D'00'	;scale=05bin=252octave=10note=12
	retlw	(D'10'*D'24')+D'00'	;scale=05bin=253octave=10note=13
	retlw	(D'10'*D'24')+D'00'	;scale=05bin=254octave=10note=14
	retlw	(D'10'*D'24')+D'00'	;scale=05bin=255octave=10note=15

;	Minor Pentatonic look-up table
	org	MinorP		;Minor Pentatonic look-up table
	retlw	(D'00'*D'24')+D'00'	;scale=06bin=000octave=00note=00
	retlw	(D'00'*D'24')+D'00'	;scale=06bin=001octave=00note=01
	retlw	(D'00'*D'24')+D'00'	;scale=06bin=002octave=00note=02
	retlw	(D'00'*D'24')+D'00'	;scale=06bin=003octave=00note=03
	retlw	(D'00'*D'24')+D'00'	;scale=06bin=004octave=00note=04
	retlw	(D'00'*D'24')+D'00'	;scale=06bin=005octave=00note=05
	retlw	(D'00'*D'24')+D'06'	;scale=06bin=006octave=00note=06
	retlw	(D'00'*D'24')+D'06'	;scale=06bin=007octave=00note=07
	retlw	(D'00'*D'24')+D'06'	;scale=06bin=008octave=00note=08
	retlw	(D'00'*D'24')+D'06'	;scale=06bin=009octave=00note=09
	retlw	(D'00'*D'24')+D'10'	;scale=06bin=010octave=00note=10
	retlw	(D'00'*D'24')+D'10'	;scale=06bin=011octave=00note=11
	retlw	(D'00'*D'24')+D'10'	;scale=06bin=012octave=00note=12
	retlw	(D'00'*D'24')+D'10'	;scale=06bin=013octave=00note=13
	retlw	(D'00'*D'24')+D'14'	;scale=06bin=014octave=00note=14
	retlw	(D'00'*D'24')+D'14'	;scale=06bin=015octave=00note=15
	retlw	(D'00'*D'24')+D'14'	;scale=06bin=016octave=00note=16
	retlw	(D'00'*D'24')+D'14'	;scale=06bin=017octave=00note=17
	retlw	(D'00'*D'24')+D'14'	;scale=06bin=018octave=00note=18
	retlw	(D'00'*D'24')+D'14'	;scale=06bin=019octave=00note=19
	retlw	(D'00'*D'24')+D'20'	;scale=06bin=020octave=00note=20
	retlw	(D'00'*D'24')+D'20'	;scale=06bin=021octave=00note=21
	retlw	(D'00'*D'24')+D'20'	;scale=06bin=022octave=00note=22
	retlw	(D'00'*D'24')+D'20'	;scale=06bin=023octave=00note=23
	retlw	(D'01'*D'24')+D'00'	;scale=06bin=024octave=01note=00
	retlw	(D'01'*D'24')+D'00'	;scale=06bin=025octave=01note=01
	retlw	(D'01'*D'24')+D'00'	;scale=06bin=026octave=01note=02
	retlw	(D'01'*D'24')+D'00'	;scale=06bin=027octave=01note=03
	retlw	(D'01'*D'24')+D'00'	;scale=06bin=028octave=01note=04
	retlw	(D'01'*D'24')+D'00'	;scale=06bin=029octave=01note=05
	retlw	(D'01'*D'24')+D'06'	;scale=06bin=030octave=01note=06
	retlw	(D'01'*D'24')+D'06'	;scale=06bin=031octave=01note=07
	retlw	(D'01'*D'24')+D'06'	;scale=06bin=032octave=01note=08
	retlw	(D'01'*D'24')+D'06'	;scale=06bin=033octave=01note=09
	retlw	(D'01'*D'24')+D'10'	;scale=06bin=034octave=01note=10
	retlw	(D'01'*D'24')+D'10'	;scale=06bin=035octave=01note=11
	retlw	(D'01'*D'24')+D'10'	;scale=06bin=036octave=01note=12
	retlw	(D'01'*D'24')+D'10'	;scale=06bin=037octave=01note=13
	retlw	(D'01'*D'24')+D'14'	;scale=06bin=038octave=01note=14
	retlw	(D'01'*D'24')+D'14'	;scale=06bin=039octave=01note=15
	retlw	(D'01'*D'24')+D'14'	;scale=06bin=040octave=01note=16
	retlw	(D'01'*D'24')+D'14'	;scale=06bin=041octave=01note=17
	retlw	(D'01'*D'24')+D'14'	;scale=06bin=042octave=01note=18
	retlw	(D'01'*D'24')+D'14'	;scale=06bin=043octave=01note=19
	retlw	(D'01'*D'24')+D'20'	;scale=06bin=044octave=01note=20
	retlw	(D'01'*D'24')+D'20'	;scale=06bin=045octave=01note=21
	retlw	(D'01'*D'24')+D'20'	;scale=06bin=046octave=01note=22
	retlw	(D'01'*D'24')+D'20'	;scale=06bin=047octave=01note=23
	retlw	(D'02'*D'24')+D'00'	;scale=06bin=048octave=02note=00
	retlw	(D'02'*D'24')+D'00'	;scale=06bin=049octave=02note=01
	retlw	(D'02'*D'24')+D'00'	;scale=06bin=050octave=02note=02
	retlw	(D'02'*D'24')+D'00'	;scale=06bin=051octave=02note=03
	retlw	(D'02'*D'24')+D'00'	;scale=06bin=052octave=02note=04
	retlw	(D'02'*D'24')+D'00'	;scale=06bin=053octave=02note=05
	retlw	(D'02'*D'24')+D'06'	;scale=06bin=054octave=02note=06
	retlw	(D'02'*D'24')+D'06'	;scale=06bin=055octave=02note=07
	retlw	(D'02'*D'24')+D'06'	;scale=06bin=056octave=02note=08
	retlw	(D'02'*D'24')+D'06'	;scale=06bin=057octave=02note=09
	retlw	(D'02'*D'24')+D'10'	;scale=06bin=058octave=02note=10
	retlw	(D'02'*D'24')+D'10'	;scale=06bin=059octave=02note=11
	retlw	(D'02'*D'24')+D'10'	;scale=06bin=060octave=02note=12
	retlw	(D'02'*D'24')+D'10'	;scale=06bin=061octave=02note=13
	retlw	(D'02'*D'24')+D'14'	;scale=06bin=062octave=02note=14
	retlw	(D'02'*D'24')+D'14'	;scale=06bin=063octave=02note=15
	retlw	(D'02'*D'24')+D'14'	;scale=06bin=064octave=02note=16
	retlw	(D'02'*D'24')+D'14'	;scale=06bin=065octave=02note=17
	retlw	(D'02'*D'24')+D'14'	;scale=06bin=066octave=02note=18
	retlw	(D'02'*D'24')+D'14'	;scale=06bin=067octave=02note=19
	retlw	(D'02'*D'24')+D'20'	;scale=06bin=068octave=02note=20
	retlw	(D'02'*D'24')+D'20'	;scale=06bin=069octave=02note=21
	retlw	(D'02'*D'24')+D'20'	;scale=06bin=070octave=02note=22
	retlw	(D'02'*D'24')+D'20'	;scale=06bin=071octave=02note=23
	retlw	(D'03'*D'24')+D'00'	;scale=06bin=072octave=03note=00
	retlw	(D'03'*D'24')+D'00'	;scale=06bin=073octave=03note=01
	retlw	(D'03'*D'24')+D'00'	;scale=06bin=074octave=03note=02
	retlw	(D'03'*D'24')+D'00'	;scale=06bin=075octave=03note=03
	retlw	(D'03'*D'24')+D'00'	;scale=06bin=076octave=03note=04
	retlw	(D'03'*D'24')+D'00'	;scale=06bin=077octave=03note=05
	retlw	(D'03'*D'24')+D'06'	;scale=06bin=078octave=03note=06
	retlw	(D'03'*D'24')+D'06'	;scale=06bin=079octave=03note=07
	retlw	(D'03'*D'24')+D'06'	;scale=06bin=080octave=03note=08
	retlw	(D'03'*D'24')+D'06'	;scale=06bin=081octave=03note=09
	retlw	(D'03'*D'24')+D'10'	;scale=06bin=082octave=03note=10
	retlw	(D'03'*D'24')+D'10'	;scale=06bin=083octave=03note=11
	retlw	(D'03'*D'24')+D'10'	;scale=06bin=084octave=03note=12
	retlw	(D'03'*D'24')+D'10'	;scale=06bin=085octave=03note=13
	retlw	(D'03'*D'24')+D'14'	;scale=06bin=086octave=03note=14
	retlw	(D'03'*D'24')+D'14'	;scale=06bin=087octave=03note=15
	retlw	(D'03'*D'24')+D'14'	;scale=06bin=088octave=03note=16
	retlw	(D'03'*D'24')+D'14'	;scale=06bin=089octave=03note=17
	retlw	(D'03'*D'24')+D'14'	;scale=06bin=090octave=03note=18
	retlw	(D'03'*D'24')+D'14'	;scale=06bin=091octave=03note=19
	retlw	(D'03'*D'24')+D'20'	;scale=06bin=092octave=03note=20
	retlw	(D'03'*D'24')+D'20'	;scale=06bin=093octave=03note=21
	retlw	(D'03'*D'24')+D'20'	;scale=06bin=094octave=03note=22
	retlw	(D'03'*D'24')+D'20'	;scale=06bin=095octave=03note=23
	retlw	(D'04'*D'24')+D'00'	;scale=06bin=096octave=04note=00
	retlw	(D'04'*D'24')+D'00'	;scale=06bin=097octave=04note=01
	retlw	(D'04'*D'24')+D'00'	;scale=06bin=098octave=04note=02
	retlw	(D'04'*D'24')+D'00'	;scale=06bin=099octave=04note=03
	retlw	(D'04'*D'24')+D'00'	;scale=06bin=100octave=04note=04
	retlw	(D'04'*D'24')+D'00'	;scale=06bin=101octave=04note=05
	retlw	(D'04'*D'24')+D'06'	;scale=06bin=102octave=04note=06
	retlw	(D'04'*D'24')+D'06'	;scale=06bin=103octave=04note=07
	retlw	(D'04'*D'24')+D'06'	;scale=06bin=104octave=04note=08
	retlw	(D'04'*D'24')+D'06'	;scale=06bin=105octave=04note=09
	retlw	(D'04'*D'24')+D'10'	;scale=06bin=106octave=04note=10
	retlw	(D'04'*D'24')+D'10'	;scale=06bin=107octave=04note=11
	retlw	(D'04'*D'24')+D'10'	;scale=06bin=108octave=04note=12
	retlw	(D'04'*D'24')+D'10'	;scale=06bin=109octave=04note=13
	retlw	(D'04'*D'24')+D'14'	;scale=06bin=110octave=04note=14
	retlw	(D'04'*D'24')+D'14'	;scale=06bin=111octave=04note=15
	retlw	(D'04'*D'24')+D'14'	;scale=06bin=112octave=04note=16
	retlw	(D'04'*D'24')+D'14'	;scale=06bin=113octave=04note=17
	retlw	(D'04'*D'24')+D'14'	;scale=06bin=114octave=04note=18
	retlw	(D'04'*D'24')+D'14'	;scale=06bin=115octave=04note=19
	retlw	(D'04'*D'24')+D'20'	;scale=06bin=116octave=04note=20
	retlw	(D'04'*D'24')+D'20'	;scale=06bin=117octave=04note=21
	retlw	(D'04'*D'24')+D'20'	;scale=06bin=118octave=04note=22
	retlw	(D'04'*D'24')+D'20'	;scale=06bin=119octave=04note=23
	retlw	(D'05'*D'24')+D'00'	;scale=06bin=120octave=05note=00
	retlw	(D'05'*D'24')+D'00'	;scale=06bin=121octave=05note=01
	retlw	(D'05'*D'24')+D'00'	;scale=06bin=122octave=05note=02
	retlw	(D'05'*D'24')+D'00'	;scale=06bin=123octave=05note=03
	retlw	(D'05'*D'24')+D'00'	;scale=06bin=124octave=05note=04
	retlw	(D'05'*D'24')+D'00'	;scale=06bin=125octave=05note=05
	retlw	(D'05'*D'24')+D'06'	;scale=06bin=126octave=05note=06
	retlw	(D'05'*D'24')+D'06'	;scale=06bin=127octave=05note=07
	retlw	(D'05'*D'24')+D'06'	;scale=06bin=128octave=05note=08
	retlw	(D'05'*D'24')+D'06'	;scale=06bin=129octave=05note=09
	retlw	(D'05'*D'24')+D'10'	;scale=06bin=130octave=05note=10
	retlw	(D'05'*D'24')+D'10'	;scale=06bin=131octave=05note=11
	retlw	(D'05'*D'24')+D'10'	;scale=06bin=132octave=05note=12
	retlw	(D'05'*D'24')+D'10'	;scale=06bin=133octave=05note=13
	retlw	(D'05'*D'24')+D'14'	;scale=06bin=134octave=05note=14
	retlw	(D'05'*D'24')+D'14'	;scale=06bin=135octave=05note=15
	retlw	(D'05'*D'24')+D'14'	;scale=06bin=136octave=05note=16
	retlw	(D'05'*D'24')+D'14'	;scale=06bin=137octave=05note=17
	retlw	(D'05'*D'24')+D'14'	;scale=06bin=138octave=05note=18
	retlw	(D'05'*D'24')+D'14'	;scale=06bin=139octave=05note=19
	retlw	(D'05'*D'24')+D'20'	;scale=06bin=140octave=05note=20
	retlw	(D'05'*D'24')+D'20'	;scale=06bin=141octave=05note=21
	retlw	(D'05'*D'24')+D'20'	;scale=06bin=142octave=05note=22
	retlw	(D'05'*D'24')+D'20'	;scale=06bin=143octave=05note=23
	retlw	(D'06'*D'24')+D'00'	;scale=06bin=144octave=06note=00
	retlw	(D'06'*D'24')+D'00'	;scale=06bin=145octave=06note=01
	retlw	(D'06'*D'24')+D'00'	;scale=06bin=146octave=06note=02
	retlw	(D'06'*D'24')+D'00'	;scale=06bin=147octave=06note=03
	retlw	(D'06'*D'24')+D'00'	;scale=06bin=148octave=06note=04
	retlw	(D'06'*D'24')+D'00'	;scale=06bin=149octave=06note=05
	retlw	(D'06'*D'24')+D'06'	;scale=06bin=150octave=06note=06
	retlw	(D'06'*D'24')+D'06'	;scale=06bin=151octave=06note=07
	retlw	(D'06'*D'24')+D'06'	;scale=06bin=152octave=06note=08
	retlw	(D'06'*D'24')+D'06'	;scale=06bin=153octave=06note=09
	retlw	(D'06'*D'24')+D'10'	;scale=06bin=154octave=06note=10
	retlw	(D'06'*D'24')+D'10'	;scale=06bin=155octave=06note=11
	retlw	(D'06'*D'24')+D'10'	;scale=06bin=156octave=06note=12
	retlw	(D'06'*D'24')+D'10'	;scale=06bin=157octave=06note=13
	retlw	(D'06'*D'24')+D'14'	;scale=06bin=158octave=06note=14
	retlw	(D'06'*D'24')+D'14'	;scale=06bin=159octave=06note=15
	retlw	(D'06'*D'24')+D'14'	;scale=06bin=160octave=06note=16
	retlw	(D'06'*D'24')+D'14'	;scale=06bin=161octave=06note=17
	retlw	(D'06'*D'24')+D'14'	;scale=06bin=162octave=06note=18
	retlw	(D'06'*D'24')+D'14'	;scale=06bin=163octave=06note=19
	retlw	(D'06'*D'24')+D'20'	;scale=06bin=164octave=06note=20
	retlw	(D'06'*D'24')+D'20'	;scale=06bin=165octave=06note=21
	retlw	(D'06'*D'24')+D'20'	;scale=06bin=166octave=06note=22
	retlw	(D'06'*D'24')+D'20'	;scale=06bin=167octave=06note=23
	retlw	(D'07'*D'24')+D'00'	;scale=06bin=168octave=07note=00
	retlw	(D'07'*D'24')+D'00'	;scale=06bin=169octave=07note=01
	retlw	(D'07'*D'24')+D'00'	;scale=06bin=170octave=07note=02
	retlw	(D'07'*D'24')+D'00'	;scale=06bin=171octave=07note=03
	retlw	(D'07'*D'24')+D'00'	;scale=06bin=172octave=07note=04
	retlw	(D'07'*D'24')+D'00'	;scale=06bin=173octave=07note=05
	retlw	(D'07'*D'24')+D'06'	;scale=06bin=174octave=07note=06
	retlw	(D'07'*D'24')+D'06'	;scale=06bin=175octave=07note=07
	retlw	(D'07'*D'24')+D'06'	;scale=06bin=176octave=07note=08
	retlw	(D'07'*D'24')+D'06'	;scale=06bin=177octave=07note=09
	retlw	(D'07'*D'24')+D'10'	;scale=06bin=178octave=07note=10
	retlw	(D'07'*D'24')+D'10'	;scale=06bin=179octave=07note=11
	retlw	(D'07'*D'24')+D'10'	;scale=06bin=180octave=07note=12
	retlw	(D'07'*D'24')+D'10'	;scale=06bin=181octave=07note=13
	retlw	(D'07'*D'24')+D'14'	;scale=06bin=182octave=07note=14
	retlw	(D'07'*D'24')+D'14'	;scale=06bin=183octave=07note=15
	retlw	(D'07'*D'24')+D'14'	;scale=06bin=184octave=07note=16
	retlw	(D'07'*D'24')+D'14'	;scale=06bin=185octave=07note=17
	retlw	(D'07'*D'24')+D'14'	;scale=06bin=186octave=07note=18
	retlw	(D'07'*D'24')+D'14'	;scale=06bin=187octave=07note=19
	retlw	(D'07'*D'24')+D'20'	;scale=06bin=188octave=07note=20
	retlw	(D'07'*D'24')+D'20'	;scale=06bin=189octave=07note=21
	retlw	(D'07'*D'24')+D'20'	;scale=06bin=190octave=07note=22
	retlw	(D'07'*D'24')+D'20'	;scale=06bin=191octave=07note=23
	retlw	(D'08'*D'24')+D'00'	;scale=06bin=192octave=08note=00
	retlw	(D'08'*D'24')+D'00'	;scale=06bin=193octave=08note=01
	retlw	(D'08'*D'24')+D'00'	;scale=06bin=194octave=08note=02
	retlw	(D'08'*D'24')+D'00'	;scale=06bin=195octave=08note=03
	retlw	(D'08'*D'24')+D'00'	;scale=06bin=196octave=08note=04
	retlw	(D'08'*D'24')+D'00'	;scale=06bin=197octave=08note=05
	retlw	(D'08'*D'24')+D'06'	;scale=06bin=198octave=08note=06
	retlw	(D'08'*D'24')+D'06'	;scale=06bin=199octave=08note=07
	retlw	(D'08'*D'24')+D'06'	;scale=06bin=200octave=08note=08
	retlw	(D'08'*D'24')+D'06'	;scale=06bin=201octave=08note=09
	retlw	(D'08'*D'24')+D'10'	;scale=06bin=202octave=08note=10
	retlw	(D'08'*D'24')+D'10'	;scale=06bin=203octave=08note=11
	retlw	(D'08'*D'24')+D'10'	;scale=06bin=204octave=08note=12
	retlw	(D'08'*D'24')+D'10'	;scale=06bin=205octave=08note=13
	retlw	(D'08'*D'24')+D'14'	;scale=06bin=206octave=08note=14
	retlw	(D'08'*D'24')+D'14'	;scale=06bin=207octave=08note=15
	retlw	(D'08'*D'24')+D'14'	;scale=06bin=208octave=08note=16
	retlw	(D'08'*D'24')+D'14'	;scale=06bin=209octave=08note=17
	retlw	(D'08'*D'24')+D'14'	;scale=06bin=210octave=08note=18
	retlw	(D'08'*D'24')+D'14'	;scale=06bin=211octave=08note=19
	retlw	(D'08'*D'24')+D'20'	;scale=06bin=212octave=08note=20
	retlw	(D'08'*D'24')+D'20'	;scale=06bin=213octave=08note=21
	retlw	(D'08'*D'24')+D'20'	;scale=06bin=214octave=08note=22
	retlw	(D'08'*D'24')+D'20'	;scale=06bin=215octave=08note=23
	retlw	(D'09'*D'24')+D'00'	;scale=06bin=216octave=09note=00
	retlw	(D'09'*D'24')+D'00'	;scale=06bin=217octave=09note=01
	retlw	(D'09'*D'24')+D'00'	;scale=06bin=218octave=09note=02
	retlw	(D'09'*D'24')+D'00'	;scale=06bin=219octave=09note=03
	retlw	(D'09'*D'24')+D'00'	;scale=06bin=220octave=09note=04
	retlw	(D'09'*D'24')+D'00'	;scale=06bin=221octave=09note=05
	retlw	(D'09'*D'24')+D'06'	;scale=06bin=222octave=09note=06
	retlw	(D'09'*D'24')+D'06'	;scale=06bin=223octave=09note=07
	retlw	(D'09'*D'24')+D'06'	;scale=06bin=224octave=09note=08
	retlw	(D'09'*D'24')+D'06'	;scale=06bin=225octave=09note=09
	retlw	(D'09'*D'24')+D'10'	;scale=06bin=226octave=09note=10
	retlw	(D'09'*D'24')+D'10'	;scale=06bin=227octave=09note=11
	retlw	(D'09'*D'24')+D'10'	;scale=06bin=228octave=09note=12
	retlw	(D'09'*D'24')+D'10'	;scale=06bin=229octave=09note=13
	retlw	(D'09'*D'24')+D'14'	;scale=06bin=230octave=09note=14
	retlw	(D'09'*D'24')+D'14'	;scale=06bin=231octave=09note=15
	retlw	(D'09'*D'24')+D'14'	;scale=06bin=232octave=09note=16
	retlw	(D'09'*D'24')+D'14'	;scale=06bin=233octave=09note=17
	retlw	(D'09'*D'24')+D'14'	;scale=06bin=234octave=09note=18
	retlw	(D'09'*D'24')+D'14'	;scale=06bin=235octave=09note=19
	retlw	(D'09'*D'24')+D'20'	;scale=06bin=236octave=09note=20
	retlw	(D'09'*D'24')+D'20'	;scale=06bin=237octave=09note=21
	retlw	(D'09'*D'24')+D'20'	;scale=06bin=238octave=09note=22
	retlw	(D'09'*D'24')+D'20'	;scale=06bin=239octave=09note=23
	retlw	(D'10'*D'24')+D'00'	;scale=06bin=240octave=10note=00
	retlw	(D'10'*D'24')+D'00'	;scale=06bin=241octave=10note=01
	retlw	(D'10'*D'24')+D'00'	;scale=06bin=242octave=10note=02
	retlw	(D'10'*D'24')+D'00'	;scale=06bin=243octave=10note=03
	retlw	(D'10'*D'24')+D'00'	;scale=06bin=244octave=10note=04
	retlw	(D'10'*D'24')+D'00'	;scale=06bin=245octave=10note=05
	retlw	(D'10'*D'24')+D'00'	;scale=06bin=246octave=10note=06
	retlw	(D'10'*D'24')+D'00'	;scale=06bin=247octave=10note=07
	retlw	(D'10'*D'24')+D'00'	;scale=06bin=248octave=10note=08
	retlw	(D'10'*D'24')+D'00'	;scale=06bin=249octave=10note=09
	retlw	(D'10'*D'24')+D'00'	;scale=06bin=250octave=10note=10
	retlw	(D'10'*D'24')+D'00'	;scale=06bin=251octave=10note=11
	retlw	(D'10'*D'24')+D'00'	;scale=06bin=252octave=10note=12
	retlw	(D'10'*D'24')+D'00'	;scale=06bin=253octave=10note=13
	retlw	(D'10'*D'24')+D'00'	;scale=06bin=254octave=10note=14
	retlw	(D'10'*D'24')+D'00'	;scale=06bin=255octave=10note=15

;	Blues look-up table
	org	Blues		;Blues look-up table
	retlw	(D'00'*D'24')+D'00'	;scale=07bin=000octave=00note=00
	retlw	(D'00'*D'24')+D'00'	;scale=07bin=001octave=00note=01
	retlw	(D'00'*D'24')+D'00'	;scale=07bin=002octave=00note=02
	retlw	(D'00'*D'24')+D'00'	;scale=07bin=003octave=00note=03
	retlw	(D'00'*D'24')+D'00'	;scale=07bin=004octave=00note=04
	retlw	(D'00'*D'24')+D'00'	;scale=07bin=005octave=00note=05
	retlw	(D'00'*D'24')+D'06'	;scale=07bin=006octave=00note=06
	retlw	(D'00'*D'24')+D'06'	;scale=07bin=007octave=00note=07
	retlw	(D'00'*D'24')+D'06'	;scale=07bin=008octave=00note=08
	retlw	(D'00'*D'24')+D'06'	;scale=07bin=009octave=00note=09
	retlw	(D'00'*D'24')+D'10'	;scale=07bin=010octave=00note=10
	retlw	(D'00'*D'24')+D'10'	;scale=07bin=011octave=00note=11
	retlw	(D'00'*D'24')+D'12'	;scale=07bin=012octave=00note=12
	retlw	(D'00'*D'24')+D'12'	;scale=07bin=013octave=00note=13
	retlw	(D'00'*D'24')+D'14'	;scale=07bin=014octave=00note=14
	retlw	(D'00'*D'24')+D'14'	;scale=07bin=015octave=00note=15
	retlw	(D'00'*D'24')+D'14'	;scale=07bin=016octave=00note=16
	retlw	(D'00'*D'24')+D'14'	;scale=07bin=017octave=00note=17
	retlw	(D'00'*D'24')+D'14'	;scale=07bin=018octave=00note=18
	retlw	(D'00'*D'24')+D'14'	;scale=07bin=019octave=00note=19
	retlw	(D'00'*D'24')+D'20'	;scale=07bin=020octave=00note=20
	retlw	(D'00'*D'24')+D'20'	;scale=07bin=021octave=00note=21
	retlw	(D'00'*D'24')+D'20'	;scale=07bin=022octave=00note=22
	retlw	(D'00'*D'24')+D'20'	;scale=07bin=023octave=00note=23
	retlw	(D'01'*D'24')+D'00'	;scale=07bin=024octave=01note=00
	retlw	(D'01'*D'24')+D'00'	;scale=07bin=025octave=01note=01
	retlw	(D'01'*D'24')+D'00'	;scale=07bin=026octave=01note=02
	retlw	(D'01'*D'24')+D'00'	;scale=07bin=027octave=01note=03
	retlw	(D'01'*D'24')+D'00'	;scale=07bin=028octave=01note=04
	retlw	(D'01'*D'24')+D'00'	;scale=07bin=029octave=01note=05
	retlw	(D'01'*D'24')+D'06'	;scale=07bin=030octave=01note=06
	retlw	(D'01'*D'24')+D'06'	;scale=07bin=031octave=01note=07
	retlw	(D'01'*D'24')+D'06'	;scale=07bin=032octave=01note=08
	retlw	(D'01'*D'24')+D'06'	;scale=07bin=033octave=01note=09
	retlw	(D'01'*D'24')+D'10'	;scale=07bin=034octave=01note=10
	retlw	(D'01'*D'24')+D'10'	;scale=07bin=035octave=01note=11
	retlw	(D'01'*D'24')+D'12'	;scale=07bin=036octave=01note=12
	retlw	(D'01'*D'24')+D'12'	;scale=07bin=037octave=01note=13
	retlw	(D'01'*D'24')+D'14'	;scale=07bin=038octave=01note=14
	retlw	(D'01'*D'24')+D'14'	;scale=07bin=039octave=01note=15
	retlw	(D'01'*D'24')+D'14'	;scale=07bin=040octave=01note=16
	retlw	(D'01'*D'24')+D'14'	;scale=07bin=041octave=01note=17
	retlw	(D'01'*D'24')+D'14'	;scale=07bin=042octave=01note=18
	retlw	(D'01'*D'24')+D'14'	;scale=07bin=043octave=01note=19
	retlw	(D'01'*D'24')+D'20'	;scale=07bin=044octave=01note=20
	retlw	(D'01'*D'24')+D'20'	;scale=07bin=045octave=01note=21
	retlw	(D'01'*D'24')+D'20'	;scale=07bin=046octave=01note=22
	retlw	(D'01'*D'24')+D'20'	;scale=07bin=047octave=01note=23
	retlw	(D'02'*D'24')+D'00'	;scale=07bin=048octave=02note=00
	retlw	(D'02'*D'24')+D'00'	;scale=07bin=049octave=02note=01
	retlw	(D'02'*D'24')+D'00'	;scale=07bin=050octave=02note=02
	retlw	(D'02'*D'24')+D'00'	;scale=07bin=051octave=02note=03
	retlw	(D'02'*D'24')+D'00'	;scale=07bin=052octave=02note=04
	retlw	(D'02'*D'24')+D'00'	;scale=07bin=053octave=02note=05
	retlw	(D'02'*D'24')+D'06'	;scale=07bin=054octave=02note=06
	retlw	(D'02'*D'24')+D'06'	;scale=07bin=055octave=02note=07
	retlw	(D'02'*D'24')+D'06'	;scale=07bin=056octave=02note=08
	retlw	(D'02'*D'24')+D'06'	;scale=07bin=057octave=02note=09
	retlw	(D'02'*D'24')+D'10'	;scale=07bin=058octave=02note=10
	retlw	(D'02'*D'24')+D'10'	;scale=07bin=059octave=02note=11
	retlw	(D'02'*D'24')+D'12'	;scale=07bin=060octave=02note=12
	retlw	(D'02'*D'24')+D'12'	;scale=07bin=061octave=02note=13
	retlw	(D'02'*D'24')+D'14'	;scale=07bin=062octave=02note=14
	retlw	(D'02'*D'24')+D'14'	;scale=07bin=063octave=02note=15
	retlw	(D'02'*D'24')+D'14'	;scale=07bin=064octave=02note=16
	retlw	(D'02'*D'24')+D'14'	;scale=07bin=065octave=02note=17
	retlw	(D'02'*D'24')+D'14'	;scale=07bin=066octave=02note=18
	retlw	(D'02'*D'24')+D'14'	;scale=07bin=067octave=02note=19
	retlw	(D'02'*D'24')+D'20'	;scale=07bin=068octave=02note=20
	retlw	(D'02'*D'24')+D'20'	;scale=07bin=069octave=02note=21
	retlw	(D'02'*D'24')+D'20'	;scale=07bin=070octave=02note=22
	retlw	(D'02'*D'24')+D'20'	;scale=07bin=071octave=02note=23
	retlw	(D'03'*D'24')+D'00'	;scale=07bin=072octave=03note=00
	retlw	(D'03'*D'24')+D'00'	;scale=07bin=073octave=03note=01
	retlw	(D'03'*D'24')+D'00'	;scale=07bin=074octave=03note=02
	retlw	(D'03'*D'24')+D'00'	;scale=07bin=075octave=03note=03
	retlw	(D'03'*D'24')+D'00'	;scale=07bin=076octave=03note=04
	retlw	(D'03'*D'24')+D'00'	;scale=07bin=077octave=03note=05
	retlw	(D'03'*D'24')+D'06'	;scale=07bin=078octave=03note=06
	retlw	(D'03'*D'24')+D'06'	;scale=07bin=079octave=03note=07
	retlw	(D'03'*D'24')+D'06'	;scale=07bin=080octave=03note=08
	retlw	(D'03'*D'24')+D'06'	;scale=07bin=081octave=03note=09
	retlw	(D'03'*D'24')+D'10'	;scale=07bin=082octave=03note=10
	retlw	(D'03'*D'24')+D'10'	;scale=07bin=083octave=03note=11
	retlw	(D'03'*D'24')+D'12'	;scale=07bin=084octave=03note=12
	retlw	(D'03'*D'24')+D'12'	;scale=07bin=085octave=03note=13
	retlw	(D'03'*D'24')+D'14'	;scale=07bin=086octave=03note=14
	retlw	(D'03'*D'24')+D'14'	;scale=07bin=087octave=03note=15
	retlw	(D'03'*D'24')+D'14'	;scale=07bin=088octave=03note=16
	retlw	(D'03'*D'24')+D'14'	;scale=07bin=089octave=03note=17
	retlw	(D'03'*D'24')+D'14'	;scale=07bin=090octave=03note=18
	retlw	(D'03'*D'24')+D'14'	;scale=07bin=091octave=03note=19
	retlw	(D'03'*D'24')+D'20'	;scale=07bin=092octave=03note=20
	retlw	(D'03'*D'24')+D'20'	;scale=07bin=093octave=03note=21
	retlw	(D'03'*D'24')+D'20'	;scale=07bin=094octave=03note=22
	retlw	(D'03'*D'24')+D'20'	;scale=07bin=095octave=03note=23
	retlw	(D'04'*D'24')+D'00'	;scale=07bin=096octave=04note=00
	retlw	(D'04'*D'24')+D'00'	;scale=07bin=097octave=04note=01
	retlw	(D'04'*D'24')+D'00'	;scale=07bin=098octave=04note=02
	retlw	(D'04'*D'24')+D'00'	;scale=07bin=099octave=04note=03
	retlw	(D'04'*D'24')+D'00'	;scale=07bin=100octave=04note=04
	retlw	(D'04'*D'24')+D'00'	;scale=07bin=101octave=04note=05
	retlw	(D'04'*D'24')+D'06'	;scale=07bin=102octave=04note=06
	retlw	(D'04'*D'24')+D'06'	;scale=07bin=103octave=04note=07
	retlw	(D'04'*D'24')+D'06'	;scale=07bin=104octave=04note=08
	retlw	(D'04'*D'24')+D'06'	;scale=07bin=105octave=04note=09
	retlw	(D'04'*D'24')+D'10'	;scale=07bin=106octave=04note=10
	retlw	(D'04'*D'24')+D'10'	;scale=07bin=107octave=04note=11
	retlw	(D'04'*D'24')+D'12'	;scale=07bin=108octave=04note=12
	retlw	(D'04'*D'24')+D'12'	;scale=07bin=109octave=04note=13
	retlw	(D'04'*D'24')+D'14'	;scale=07bin=110octave=04note=14
	retlw	(D'04'*D'24')+D'14'	;scale=07bin=111octave=04note=15
	retlw	(D'04'*D'24')+D'14'	;scale=07bin=112octave=04note=16
	retlw	(D'04'*D'24')+D'14'	;scale=07bin=113octave=04note=17
	retlw	(D'04'*D'24')+D'14'	;scale=07bin=114octave=04note=18
	retlw	(D'04'*D'24')+D'14'	;scale=07bin=115octave=04note=19
	retlw	(D'04'*D'24')+D'20'	;scale=07bin=116octave=04note=20
	retlw	(D'04'*D'24')+D'20'	;scale=07bin=117octave=04note=21
	retlw	(D'04'*D'24')+D'20'	;scale=07bin=118octave=04note=22
	retlw	(D'04'*D'24')+D'20'	;scale=07bin=119octave=04note=23
	retlw	(D'05'*D'24')+D'00'	;scale=07bin=120octave=05note=00
	retlw	(D'05'*D'24')+D'00'	;scale=07bin=121octave=05note=01
	retlw	(D'05'*D'24')+D'00'	;scale=07bin=122octave=05note=02
	retlw	(D'05'*D'24')+D'00'	;scale=07bin=123octave=05note=03
	retlw	(D'05'*D'24')+D'00'	;scale=07bin=124octave=05note=04
	retlw	(D'05'*D'24')+D'00'	;scale=07bin=125octave=05note=05
	retlw	(D'05'*D'24')+D'06'	;scale=07bin=126octave=05note=06
	retlw	(D'05'*D'24')+D'06'	;scale=07bin=127octave=05note=07
	retlw	(D'05'*D'24')+D'06'	;scale=07bin=128octave=05note=08
	retlw	(D'05'*D'24')+D'06'	;scale=07bin=129octave=05note=09
	retlw	(D'05'*D'24')+D'10'	;scale=07bin=130octave=05note=10
	retlw	(D'05'*D'24')+D'10'	;scale=07bin=131octave=05note=11
	retlw	(D'05'*D'24')+D'12'	;scale=07bin=132octave=05note=12
	retlw	(D'05'*D'24')+D'12'	;scale=07bin=133octave=05note=13
	retlw	(D'05'*D'24')+D'14'	;scale=07bin=134octave=05note=14
	retlw	(D'05'*D'24')+D'14'	;scale=07bin=135octave=05note=15
	retlw	(D'05'*D'24')+D'14'	;scale=07bin=136octave=05note=16
	retlw	(D'05'*D'24')+D'14'	;scale=07bin=137octave=05note=17
	retlw	(D'05'*D'24')+D'14'	;scale=07bin=138octave=05note=18
	retlw	(D'05'*D'24')+D'14'	;scale=07bin=139octave=05note=19
	retlw	(D'05'*D'24')+D'20'	;scale=07bin=140octave=05note=20
	retlw	(D'05'*D'24')+D'20'	;scale=07bin=141octave=05note=21
	retlw	(D'05'*D'24')+D'20'	;scale=07bin=142octave=05note=22
	retlw	(D'05'*D'24')+D'20'	;scale=07bin=143octave=05note=23
	retlw	(D'06'*D'24')+D'00'	;scale=07bin=144octave=06note=00
	retlw	(D'06'*D'24')+D'00'	;scale=07bin=145octave=06note=01
	retlw	(D'06'*D'24')+D'00'	;scale=07bin=146octave=06note=02
	retlw	(D'06'*D'24')+D'00'	;scale=07bin=147octave=06note=03
	retlw	(D'06'*D'24')+D'00'	;scale=07bin=148octave=06note=04
	retlw	(D'06'*D'24')+D'00'	;scale=07bin=149octave=06note=05
	retlw	(D'06'*D'24')+D'06'	;scale=07bin=150octave=06note=06
	retlw	(D'06'*D'24')+D'06'	;scale=07bin=151octave=06note=07
	retlw	(D'06'*D'24')+D'06'	;scale=07bin=152octave=06note=08
	retlw	(D'06'*D'24')+D'06'	;scale=07bin=153octave=06note=09
	retlw	(D'06'*D'24')+D'10'	;scale=07bin=154octave=06note=10
	retlw	(D'06'*D'24')+D'10'	;scale=07bin=155octave=06note=11
	retlw	(D'06'*D'24')+D'12'	;scale=07bin=156octave=06note=12
	retlw	(D'06'*D'24')+D'12'	;scale=07bin=157octave=06note=13
	retlw	(D'06'*D'24')+D'14'	;scale=07bin=158octave=06note=14
	retlw	(D'06'*D'24')+D'14'	;scale=07bin=159octave=06note=15
	retlw	(D'06'*D'24')+D'14'	;scale=07bin=160octave=06note=16
	retlw	(D'06'*D'24')+D'14'	;scale=07bin=161octave=06note=17
	retlw	(D'06'*D'24')+D'14'	;scale=07bin=162octave=06note=18
	retlw	(D'06'*D'24')+D'14'	;scale=07bin=163octave=06note=19
	retlw	(D'06'*D'24')+D'20'	;scale=07bin=164octave=06note=20
	retlw	(D'06'*D'24')+D'20'	;scale=07bin=165octave=06note=21
	retlw	(D'06'*D'24')+D'20'	;scale=07bin=166octave=06note=22
	retlw	(D'06'*D'24')+D'20'	;scale=07bin=167octave=06note=23
	retlw	(D'07'*D'24')+D'00'	;scale=07bin=168octave=07note=00
	retlw	(D'07'*D'24')+D'00'	;scale=07bin=169octave=07note=01
	retlw	(D'07'*D'24')+D'00'	;scale=07bin=170octave=07note=02
	retlw	(D'07'*D'24')+D'00'	;scale=07bin=171octave=07note=03
	retlw	(D'07'*D'24')+D'00'	;scale=07bin=172octave=07note=04
	retlw	(D'07'*D'24')+D'00'	;scale=07bin=173octave=07note=05
	retlw	(D'07'*D'24')+D'06'	;scale=07bin=174octave=07note=06
	retlw	(D'07'*D'24')+D'06'	;scale=07bin=175octave=07note=07
	retlw	(D'07'*D'24')+D'06'	;scale=07bin=176octave=07note=08
	retlw	(D'07'*D'24')+D'06'	;scale=07bin=177octave=07note=09
	retlw	(D'07'*D'24')+D'10'	;scale=07bin=178octave=07note=10
	retlw	(D'07'*D'24')+D'10'	;scale=07bin=179octave=07note=11
	retlw	(D'07'*D'24')+D'12'	;scale=07bin=180octave=07note=12
	retlw	(D'07'*D'24')+D'12'	;scale=07bin=181octave=07note=13
	retlw	(D'07'*D'24')+D'14'	;scale=07bin=182octave=07note=14
	retlw	(D'07'*D'24')+D'14'	;scale=07bin=183octave=07note=15
	retlw	(D'07'*D'24')+D'14'	;scale=07bin=184octave=07note=16
	retlw	(D'07'*D'24')+D'14'	;scale=07bin=185octave=07note=17
	retlw	(D'07'*D'24')+D'14'	;scale=07bin=186octave=07note=18
	retlw	(D'07'*D'24')+D'14'	;scale=07bin=187octave=07note=19
	retlw	(D'07'*D'24')+D'20'	;scale=07bin=188octave=07note=20
	retlw	(D'07'*D'24')+D'20'	;scale=07bin=189octave=07note=21
	retlw	(D'07'*D'24')+D'20'	;scale=07bin=190octave=07note=22
	retlw	(D'07'*D'24')+D'20'	;scale=07bin=191octave=07note=23
	retlw	(D'08'*D'24')+D'00'	;scale=07bin=192octave=08note=00
	retlw	(D'08'*D'24')+D'00'	;scale=07bin=193octave=08note=01
	retlw	(D'08'*D'24')+D'00'	;scale=07bin=194octave=08note=02
	retlw	(D'08'*D'24')+D'00'	;scale=07bin=195octave=08note=03
	retlw	(D'08'*D'24')+D'00'	;scale=07bin=196octave=08note=04
	retlw	(D'08'*D'24')+D'00'	;scale=07bin=197octave=08note=05
	retlw	(D'08'*D'24')+D'06'	;scale=07bin=198octave=08note=06
	retlw	(D'08'*D'24')+D'06'	;scale=07bin=199octave=08note=07
	retlw	(D'08'*D'24')+D'06'	;scale=07bin=200octave=08note=08
	retlw	(D'08'*D'24')+D'06'	;scale=07bin=201octave=08note=09
	retlw	(D'08'*D'24')+D'10'	;scale=07bin=202octave=08note=10
	retlw	(D'08'*D'24')+D'10'	;scale=07bin=203octave=08note=11
	retlw	(D'08'*D'24')+D'12'	;scale=07bin=204octave=08note=12
	retlw	(D'08'*D'24')+D'12'	;scale=07bin=205octave=08note=13
	retlw	(D'08'*D'24')+D'14'	;scale=07bin=206octave=08note=14
	retlw	(D'08'*D'24')+D'14'	;scale=07bin=207octave=08note=15
	retlw	(D'08'*D'24')+D'14'	;scale=07bin=208octave=08note=16
	retlw	(D'08'*D'24')+D'14'	;scale=07bin=209octave=08note=17
	retlw	(D'08'*D'24')+D'14'	;scale=07bin=210octave=08note=18
	retlw	(D'08'*D'24')+D'14'	;scale=07bin=211octave=08note=19
	retlw	(D'08'*D'24')+D'20'	;scale=07bin=212octave=08note=20
	retlw	(D'08'*D'24')+D'20'	;scale=07bin=213octave=08note=21
	retlw	(D'08'*D'24')+D'20'	;scale=07bin=214octave=08note=22
	retlw	(D'08'*D'24')+D'20'	;scale=07bin=215octave=08note=23
	retlw	(D'09'*D'24')+D'00'	;scale=07bin=216octave=09note=00
	retlw	(D'09'*D'24')+D'00'	;scale=07bin=217octave=09note=01
	retlw	(D'09'*D'24')+D'00'	;scale=07bin=218octave=09note=02
	retlw	(D'09'*D'24')+D'00'	;scale=07bin=219octave=09note=03
	retlw	(D'09'*D'24')+D'00'	;scale=07bin=220octave=09note=04
	retlw	(D'09'*D'24')+D'00'	;scale=07bin=221octave=09note=05
	retlw	(D'09'*D'24')+D'06'	;scale=07bin=222octave=09note=06
	retlw	(D'09'*D'24')+D'06'	;scale=07bin=223octave=09note=07
	retlw	(D'09'*D'24')+D'06'	;scale=07bin=224octave=09note=08
	retlw	(D'09'*D'24')+D'06'	;scale=07bin=225octave=09note=09
	retlw	(D'09'*D'24')+D'10'	;scale=07bin=226octave=09note=10
	retlw	(D'09'*D'24')+D'10'	;scale=07bin=227octave=09note=11
	retlw	(D'09'*D'24')+D'12'	;scale=07bin=228octave=09note=12
	retlw	(D'09'*D'24')+D'12'	;scale=07bin=229octave=09note=13
	retlw	(D'09'*D'24')+D'14'	;scale=07bin=230octave=09note=14
	retlw	(D'09'*D'24')+D'14'	;scale=07bin=231octave=09note=15
	retlw	(D'09'*D'24')+D'14'	;scale=07bin=232octave=09note=16
	retlw	(D'09'*D'24')+D'14'	;scale=07bin=233octave=09note=17
	retlw	(D'09'*D'24')+D'14'	;scale=07bin=234octave=09note=18
	retlw	(D'09'*D'24')+D'14'	;scale=07bin=235octave=09note=19
	retlw	(D'09'*D'24')+D'20'	;scale=07bin=236octave=09note=20
	retlw	(D'09'*D'24')+D'20'	;scale=07bin=237octave=09note=21
	retlw	(D'09'*D'24')+D'20'	;scale=07bin=238octave=09note=22
	retlw	(D'09'*D'24')+D'20'	;scale=07bin=239octave=09note=23
	retlw	(D'10'*D'24')+D'00'	;scale=07bin=240octave=10note=00
	retlw	(D'10'*D'24')+D'00'	;scale=07bin=241octave=10note=01
	retlw	(D'10'*D'24')+D'00'	;scale=07bin=242octave=10note=02
	retlw	(D'10'*D'24')+D'00'	;scale=07bin=243octave=10note=03
	retlw	(D'10'*D'24')+D'00'	;scale=07bin=244octave=10note=04
	retlw	(D'10'*D'24')+D'00'	;scale=07bin=245octave=10note=05
	retlw	(D'10'*D'24')+D'00'	;scale=07bin=246octave=10note=06
	retlw	(D'10'*D'24')+D'00'	;scale=07bin=247octave=10note=07
	retlw	(D'10'*D'24')+D'00'	;scale=07bin=248octave=10note=08
	retlw	(D'10'*D'24')+D'00'	;scale=07bin=249octave=10note=09
	retlw	(D'10'*D'24')+D'00'	;scale=07bin=250octave=10note=10
	retlw	(D'10'*D'24')+D'00'	;scale=07bin=251octave=10note=11
	retlw	(D'10'*D'24')+D'00'	;scale=07bin=252octave=10note=12
	retlw	(D'10'*D'24')+D'00'	;scale=07bin=253octave=10note=13
	retlw	(D'10'*D'24')+D'00'	;scale=07bin=254octave=10note=14
	retlw	(D'10'*D'24')+D'00'	;scale=07bin=255octave=10note=15

;	Dorian look-up table
	org	Dorian		;Dorian look-up table
	retlw	(D'00'*D'24')+D'00'	;scale=08bin=000octave=00note=00
	retlw	(D'00'*D'24')+D'00'	;scale=08bin=001octave=00note=01
	retlw	(D'00'*D'24')+D'00'	;scale=08bin=002octave=00note=02
	retlw	(D'00'*D'24')+D'00'	;scale=08bin=003octave=00note=03
	retlw	(D'00'*D'24')+D'04'	;scale=08bin=004octave=00note=04
	retlw	(D'00'*D'24')+D'04'	;scale=08bin=005octave=00note=05
	retlw	(D'00'*D'24')+D'06'	;scale=08bin=006octave=00note=06
	retlw	(D'00'*D'24')+D'06'	;scale=08bin=007octave=00note=07
	retlw	(D'00'*D'24')+D'06'	;scale=08bin=008octave=00note=08
	retlw	(D'00'*D'24')+D'06'	;scale=08bin=009octave=00note=09
	retlw	(D'00'*D'24')+D'10'	;scale=08bin=010octave=00note=10
	retlw	(D'00'*D'24')+D'10'	;scale=08bin=011octave=00note=11
	retlw	(D'00'*D'24')+D'10'	;scale=08bin=012octave=00note=12
	retlw	(D'00'*D'24')+D'10'	;scale=08bin=013octave=00note=13
	retlw	(D'00'*D'24')+D'14'	;scale=08bin=014octave=00note=14
	retlw	(D'00'*D'24')+D'14'	;scale=08bin=015octave=00note=15
	retlw	(D'00'*D'24')+D'14'	;scale=08bin=016octave=00note=16
	retlw	(D'00'*D'24')+D'14'	;scale=08bin=017octave=00note=17
	retlw	(D'00'*D'24')+D'18'	;scale=08bin=018octave=00note=18
	retlw	(D'00'*D'24')+D'18'	;scale=08bin=019octave=00note=19
	retlw	(D'00'*D'24')+D'20'	;scale=08bin=020octave=00note=20
	retlw	(D'00'*D'24')+D'20'	;scale=08bin=021octave=00note=21
	retlw	(D'00'*D'24')+D'20'	;scale=08bin=022octave=00note=22
	retlw	(D'00'*D'24')+D'20'	;scale=08bin=023octave=00note=23
	retlw	(D'01'*D'24')+D'00'	;scale=08bin=024octave=01note=00
	retlw	(D'01'*D'24')+D'00'	;scale=08bin=025octave=01note=01
	retlw	(D'01'*D'24')+D'00'	;scale=08bin=026octave=01note=02
	retlw	(D'01'*D'24')+D'00'	;scale=08bin=027octave=01note=03
	retlw	(D'01'*D'24')+D'04'	;scale=08bin=028octave=01note=04
	retlw	(D'01'*D'24')+D'04'	;scale=08bin=029octave=01note=05
	retlw	(D'01'*D'24')+D'06'	;scale=08bin=030octave=01note=06
	retlw	(D'01'*D'24')+D'06'	;scale=08bin=031octave=01note=07
	retlw	(D'01'*D'24')+D'06'	;scale=08bin=032octave=01note=08
	retlw	(D'01'*D'24')+D'06'	;scale=08bin=033octave=01note=09
	retlw	(D'01'*D'24')+D'10'	;scale=08bin=034octave=01note=10
	retlw	(D'01'*D'24')+D'10'	;scale=08bin=035octave=01note=11
	retlw	(D'01'*D'24')+D'10'	;scale=08bin=036octave=01note=12
	retlw	(D'01'*D'24')+D'10'	;scale=08bin=037octave=01note=13
	retlw	(D'01'*D'24')+D'14'	;scale=08bin=038octave=01note=14
	retlw	(D'01'*D'24')+D'14'	;scale=08bin=039octave=01note=15
	retlw	(D'01'*D'24')+D'14'	;scale=08bin=040octave=01note=16
	retlw	(D'01'*D'24')+D'14'	;scale=08bin=041octave=01note=17
	retlw	(D'01'*D'24')+D'18'	;scale=08bin=042octave=01note=18
	retlw	(D'01'*D'24')+D'18'	;scale=08bin=043octave=01note=19
	retlw	(D'01'*D'24')+D'20'	;scale=08bin=044octave=01note=20
	retlw	(D'01'*D'24')+D'20'	;scale=08bin=045octave=01note=21
	retlw	(D'01'*D'24')+D'20'	;scale=08bin=046octave=01note=22
	retlw	(D'01'*D'24')+D'20'	;scale=08bin=047octave=01note=23
	retlw	(D'02'*D'24')+D'00'	;scale=08bin=048octave=02note=00
	retlw	(D'02'*D'24')+D'00'	;scale=08bin=049octave=02note=01
	retlw	(D'02'*D'24')+D'00'	;scale=08bin=050octave=02note=02
	retlw	(D'02'*D'24')+D'00'	;scale=08bin=051octave=02note=03
	retlw	(D'02'*D'24')+D'04'	;scale=08bin=052octave=02note=04
	retlw	(D'02'*D'24')+D'04'	;scale=08bin=053octave=02note=05
	retlw	(D'02'*D'24')+D'06'	;scale=08bin=054octave=02note=06
	retlw	(D'02'*D'24')+D'06'	;scale=08bin=055octave=02note=07
	retlw	(D'02'*D'24')+D'06'	;scale=08bin=056octave=02note=08
	retlw	(D'02'*D'24')+D'06'	;scale=08bin=057octave=02note=09
	retlw	(D'02'*D'24')+D'10'	;scale=08bin=058octave=02note=10
	retlw	(D'02'*D'24')+D'10'	;scale=08bin=059octave=02note=11
	retlw	(D'02'*D'24')+D'10'	;scale=08bin=060octave=02note=12
	retlw	(D'02'*D'24')+D'10'	;scale=08bin=061octave=02note=13
	retlw	(D'02'*D'24')+D'14'	;scale=08bin=062octave=02note=14
	retlw	(D'02'*D'24')+D'14'	;scale=08bin=063octave=02note=15
	retlw	(D'02'*D'24')+D'14'	;scale=08bin=064octave=02note=16
	retlw	(D'02'*D'24')+D'14'	;scale=08bin=065octave=02note=17
	retlw	(D'02'*D'24')+D'18'	;scale=08bin=066octave=02note=18
	retlw	(D'02'*D'24')+D'18'	;scale=08bin=067octave=02note=19
	retlw	(D'02'*D'24')+D'20'	;scale=08bin=068octave=02note=20
	retlw	(D'02'*D'24')+D'20'	;scale=08bin=069octave=02note=21
	retlw	(D'02'*D'24')+D'20'	;scale=08bin=070octave=02note=22
	retlw	(D'02'*D'24')+D'20'	;scale=08bin=071octave=02note=23
	retlw	(D'03'*D'24')+D'00'	;scale=08bin=072octave=03note=00
	retlw	(D'03'*D'24')+D'00'	;scale=08bin=073octave=03note=01
	retlw	(D'03'*D'24')+D'00'	;scale=08bin=074octave=03note=02
	retlw	(D'03'*D'24')+D'00'	;scale=08bin=075octave=03note=03
	retlw	(D'03'*D'24')+D'04'	;scale=08bin=076octave=03note=04
	retlw	(D'03'*D'24')+D'04'	;scale=08bin=077octave=03note=05
	retlw	(D'03'*D'24')+D'06'	;scale=08bin=078octave=03note=06
	retlw	(D'03'*D'24')+D'06'	;scale=08bin=079octave=03note=07
	retlw	(D'03'*D'24')+D'06'	;scale=08bin=080octave=03note=08
	retlw	(D'03'*D'24')+D'06'	;scale=08bin=081octave=03note=09
	retlw	(D'03'*D'24')+D'10'	;scale=08bin=082octave=03note=10
	retlw	(D'03'*D'24')+D'10'	;scale=08bin=083octave=03note=11
	retlw	(D'03'*D'24')+D'10'	;scale=08bin=084octave=03note=12
	retlw	(D'03'*D'24')+D'10'	;scale=08bin=085octave=03note=13
	retlw	(D'03'*D'24')+D'14'	;scale=08bin=086octave=03note=14
	retlw	(D'03'*D'24')+D'14'	;scale=08bin=087octave=03note=15
	retlw	(D'03'*D'24')+D'14'	;scale=08bin=088octave=03note=16
	retlw	(D'03'*D'24')+D'14'	;scale=08bin=089octave=03note=17
	retlw	(D'03'*D'24')+D'18'	;scale=08bin=090octave=03note=18
	retlw	(D'03'*D'24')+D'18'	;scale=08bin=091octave=03note=19
	retlw	(D'03'*D'24')+D'20'	;scale=08bin=092octave=03note=20
	retlw	(D'03'*D'24')+D'20'	;scale=08bin=093octave=03note=21
	retlw	(D'03'*D'24')+D'20'	;scale=08bin=094octave=03note=22
	retlw	(D'03'*D'24')+D'20'	;scale=08bin=095octave=03note=23
	retlw	(D'04'*D'24')+D'00'	;scale=08bin=096octave=04note=00
	retlw	(D'04'*D'24')+D'00'	;scale=08bin=097octave=04note=01
	retlw	(D'04'*D'24')+D'00'	;scale=08bin=098octave=04note=02
	retlw	(D'04'*D'24')+D'00'	;scale=08bin=099octave=04note=03
	retlw	(D'04'*D'24')+D'04'	;scale=08bin=100octave=04note=04
	retlw	(D'04'*D'24')+D'04'	;scale=08bin=101octave=04note=05
	retlw	(D'04'*D'24')+D'06'	;scale=08bin=102octave=04note=06
	retlw	(D'04'*D'24')+D'06'	;scale=08bin=103octave=04note=07
	retlw	(D'04'*D'24')+D'06'	;scale=08bin=104octave=04note=08
	retlw	(D'04'*D'24')+D'06'	;scale=08bin=105octave=04note=09
	retlw	(D'04'*D'24')+D'10'	;scale=08bin=106octave=04note=10
	retlw	(D'04'*D'24')+D'10'	;scale=08bin=107octave=04note=11
	retlw	(D'04'*D'24')+D'10'	;scale=08bin=108octave=04note=12
	retlw	(D'04'*D'24')+D'10'	;scale=08bin=109octave=04note=13
	retlw	(D'04'*D'24')+D'14'	;scale=08bin=110octave=04note=14
	retlw	(D'04'*D'24')+D'14'	;scale=08bin=111octave=04note=15
	retlw	(D'04'*D'24')+D'14'	;scale=08bin=112octave=04note=16
	retlw	(D'04'*D'24')+D'14'	;scale=08bin=113octave=04note=17
	retlw	(D'04'*D'24')+D'18'	;scale=08bin=114octave=04note=18
	retlw	(D'04'*D'24')+D'18'	;scale=08bin=115octave=04note=19
	retlw	(D'04'*D'24')+D'20'	;scale=08bin=116octave=04note=20
	retlw	(D'04'*D'24')+D'20'	;scale=08bin=117octave=04note=21
	retlw	(D'04'*D'24')+D'20'	;scale=08bin=118octave=04note=22
	retlw	(D'04'*D'24')+D'20'	;scale=08bin=119octave=04note=23
	retlw	(D'05'*D'24')+D'00'	;scale=08bin=120octave=05note=00
	retlw	(D'05'*D'24')+D'00'	;scale=08bin=121octave=05note=01
	retlw	(D'05'*D'24')+D'00'	;scale=08bin=122octave=05note=02
	retlw	(D'05'*D'24')+D'00'	;scale=08bin=123octave=05note=03
	retlw	(D'05'*D'24')+D'04'	;scale=08bin=124octave=05note=04
	retlw	(D'05'*D'24')+D'04'	;scale=08bin=125octave=05note=05
	retlw	(D'05'*D'24')+D'06'	;scale=08bin=126octave=05note=06
	retlw	(D'05'*D'24')+D'06'	;scale=08bin=127octave=05note=07
	retlw	(D'05'*D'24')+D'06'	;scale=08bin=128octave=05note=08
	retlw	(D'05'*D'24')+D'06'	;scale=08bin=129octave=05note=09
	retlw	(D'05'*D'24')+D'10'	;scale=08bin=130octave=05note=10
	retlw	(D'05'*D'24')+D'10'	;scale=08bin=131octave=05note=11
	retlw	(D'05'*D'24')+D'10'	;scale=08bin=132octave=05note=12
	retlw	(D'05'*D'24')+D'10'	;scale=08bin=133octave=05note=13
	retlw	(D'05'*D'24')+D'14'	;scale=08bin=134octave=05note=14
	retlw	(D'05'*D'24')+D'14'	;scale=08bin=135octave=05note=15
	retlw	(D'05'*D'24')+D'14'	;scale=08bin=136octave=05note=16
	retlw	(D'05'*D'24')+D'14'	;scale=08bin=137octave=05note=17
	retlw	(D'05'*D'24')+D'18'	;scale=08bin=138octave=05note=18
	retlw	(D'05'*D'24')+D'18'	;scale=08bin=139octave=05note=19
	retlw	(D'05'*D'24')+D'20'	;scale=08bin=140octave=05note=20
	retlw	(D'05'*D'24')+D'20'	;scale=08bin=141octave=05note=21
	retlw	(D'05'*D'24')+D'20'	;scale=08bin=142octave=05note=22
	retlw	(D'05'*D'24')+D'20'	;scale=08bin=143octave=05note=23
	retlw	(D'06'*D'24')+D'00'	;scale=08bin=144octave=06note=00
	retlw	(D'06'*D'24')+D'00'	;scale=08bin=145octave=06note=01
	retlw	(D'06'*D'24')+D'00'	;scale=08bin=146octave=06note=02
	retlw	(D'06'*D'24')+D'00'	;scale=08bin=147octave=06note=03
	retlw	(D'06'*D'24')+D'04'	;scale=08bin=148octave=06note=04
	retlw	(D'06'*D'24')+D'04'	;scale=08bin=149octave=06note=05
	retlw	(D'06'*D'24')+D'06'	;scale=08bin=150octave=06note=06
	retlw	(D'06'*D'24')+D'06'	;scale=08bin=151octave=06note=07
	retlw	(D'06'*D'24')+D'06'	;scale=08bin=152octave=06note=08
	retlw	(D'06'*D'24')+D'06'	;scale=08bin=153octave=06note=09
	retlw	(D'06'*D'24')+D'10'	;scale=08bin=154octave=06note=10
	retlw	(D'06'*D'24')+D'10'	;scale=08bin=155octave=06note=11
	retlw	(D'06'*D'24')+D'10'	;scale=08bin=156octave=06note=12
	retlw	(D'06'*D'24')+D'10'	;scale=08bin=157octave=06note=13
	retlw	(D'06'*D'24')+D'14'	;scale=08bin=158octave=06note=14
	retlw	(D'06'*D'24')+D'14'	;scale=08bin=159octave=06note=15
	retlw	(D'06'*D'24')+D'14'	;scale=08bin=160octave=06note=16
	retlw	(D'06'*D'24')+D'14'	;scale=08bin=161octave=06note=17
	retlw	(D'06'*D'24')+D'18'	;scale=08bin=162octave=06note=18
	retlw	(D'06'*D'24')+D'18'	;scale=08bin=163octave=06note=19
	retlw	(D'06'*D'24')+D'20'	;scale=08bin=164octave=06note=20
	retlw	(D'06'*D'24')+D'20'	;scale=08bin=165octave=06note=21
	retlw	(D'06'*D'24')+D'20'	;scale=08bin=166octave=06note=22
	retlw	(D'06'*D'24')+D'20'	;scale=08bin=167octave=06note=23
	retlw	(D'07'*D'24')+D'00'	;scale=08bin=168octave=07note=00
	retlw	(D'07'*D'24')+D'00'	;scale=08bin=169octave=07note=01
	retlw	(D'07'*D'24')+D'00'	;scale=08bin=170octave=07note=02
	retlw	(D'07'*D'24')+D'00'	;scale=08bin=171octave=07note=03
	retlw	(D'07'*D'24')+D'04'	;scale=08bin=172octave=07note=04
	retlw	(D'07'*D'24')+D'04'	;scale=08bin=173octave=07note=05
	retlw	(D'07'*D'24')+D'06'	;scale=08bin=174octave=07note=06
	retlw	(D'07'*D'24')+D'06'	;scale=08bin=175octave=07note=07
	retlw	(D'07'*D'24')+D'06'	;scale=08bin=176octave=07note=08
	retlw	(D'07'*D'24')+D'06'	;scale=08bin=177octave=07note=09
	retlw	(D'07'*D'24')+D'10'	;scale=08bin=178octave=07note=10
	retlw	(D'07'*D'24')+D'10'	;scale=08bin=179octave=07note=11
	retlw	(D'07'*D'24')+D'10'	;scale=08bin=180octave=07note=12
	retlw	(D'07'*D'24')+D'10'	;scale=08bin=181octave=07note=13
	retlw	(D'07'*D'24')+D'14'	;scale=08bin=182octave=07note=14
	retlw	(D'07'*D'24')+D'14'	;scale=08bin=183octave=07note=15
	retlw	(D'07'*D'24')+D'14'	;scale=08bin=184octave=07note=16
	retlw	(D'07'*D'24')+D'14'	;scale=08bin=185octave=07note=17
	retlw	(D'07'*D'24')+D'18'	;scale=08bin=186octave=07note=18
	retlw	(D'07'*D'24')+D'18'	;scale=08bin=187octave=07note=19
	retlw	(D'07'*D'24')+D'20'	;scale=08bin=188octave=07note=20
	retlw	(D'07'*D'24')+D'20'	;scale=08bin=189octave=07note=21
	retlw	(D'07'*D'24')+D'20'	;scale=08bin=190octave=07note=22
	retlw	(D'07'*D'24')+D'20'	;scale=08bin=191octave=07note=23
	retlw	(D'08'*D'24')+D'00'	;scale=08bin=192octave=08note=00
	retlw	(D'08'*D'24')+D'00'	;scale=08bin=193octave=08note=01
	retlw	(D'08'*D'24')+D'00'	;scale=08bin=194octave=08note=02
	retlw	(D'08'*D'24')+D'00'	;scale=08bin=195octave=08note=03
	retlw	(D'08'*D'24')+D'04'	;scale=08bin=196octave=08note=04
	retlw	(D'08'*D'24')+D'04'	;scale=08bin=197octave=08note=05
	retlw	(D'08'*D'24')+D'06'	;scale=08bin=198octave=08note=06
	retlw	(D'08'*D'24')+D'06'	;scale=08bin=199octave=08note=07
	retlw	(D'08'*D'24')+D'06'	;scale=08bin=200octave=08note=08
	retlw	(D'08'*D'24')+D'06'	;scale=08bin=201octave=08note=09
	retlw	(D'08'*D'24')+D'10'	;scale=08bin=202octave=08note=10
	retlw	(D'08'*D'24')+D'10'	;scale=08bin=203octave=08note=11
	retlw	(D'08'*D'24')+D'10'	;scale=08bin=204octave=08note=12
	retlw	(D'08'*D'24')+D'10'	;scale=08bin=205octave=08note=13
	retlw	(D'08'*D'24')+D'14'	;scale=08bin=206octave=08note=14
	retlw	(D'08'*D'24')+D'14'	;scale=08bin=207octave=08note=15
	retlw	(D'08'*D'24')+D'14'	;scale=08bin=208octave=08note=16
	retlw	(D'08'*D'24')+D'14'	;scale=08bin=209octave=08note=17
	retlw	(D'08'*D'24')+D'18'	;scale=08bin=210octave=08note=18
	retlw	(D'08'*D'24')+D'18'	;scale=08bin=211octave=08note=19
	retlw	(D'08'*D'24')+D'20'	;scale=08bin=212octave=08note=20
	retlw	(D'08'*D'24')+D'20'	;scale=08bin=213octave=08note=21
	retlw	(D'08'*D'24')+D'20'	;scale=08bin=214octave=08note=22
	retlw	(D'08'*D'24')+D'20'	;scale=08bin=215octave=08note=23
	retlw	(D'09'*D'24')+D'00'	;scale=08bin=216octave=09note=00
	retlw	(D'09'*D'24')+D'00'	;scale=08bin=217octave=09note=01
	retlw	(D'09'*D'24')+D'00'	;scale=08bin=218octave=09note=02
	retlw	(D'09'*D'24')+D'00'	;scale=08bin=219octave=09note=03
	retlw	(D'09'*D'24')+D'04'	;scale=08bin=220octave=09note=04
	retlw	(D'09'*D'24')+D'04'	;scale=08bin=221octave=09note=05
	retlw	(D'09'*D'24')+D'06'	;scale=08bin=222octave=09note=06
	retlw	(D'09'*D'24')+D'06'	;scale=08bin=223octave=09note=07
	retlw	(D'09'*D'24')+D'06'	;scale=08bin=224octave=09note=08
	retlw	(D'09'*D'24')+D'06'	;scale=08bin=225octave=09note=09
	retlw	(D'09'*D'24')+D'10'	;scale=08bin=226octave=09note=10
	retlw	(D'09'*D'24')+D'10'	;scale=08bin=227octave=09note=11
	retlw	(D'09'*D'24')+D'10'	;scale=08bin=228octave=09note=12
	retlw	(D'09'*D'24')+D'10'	;scale=08bin=229octave=09note=13
	retlw	(D'09'*D'24')+D'14'	;scale=08bin=230octave=09note=14
	retlw	(D'09'*D'24')+D'14'	;scale=08bin=231octave=09note=15
	retlw	(D'09'*D'24')+D'14'	;scale=08bin=232octave=09note=16
	retlw	(D'09'*D'24')+D'14'	;scale=08bin=233octave=09note=17
	retlw	(D'09'*D'24')+D'18'	;scale=08bin=234octave=09note=18
	retlw	(D'09'*D'24')+D'18'	;scale=08bin=235octave=09note=19
	retlw	(D'09'*D'24')+D'20'	;scale=08bin=236octave=09note=20
	retlw	(D'09'*D'24')+D'20'	;scale=08bin=237octave=09note=21
	retlw	(D'09'*D'24')+D'20'	;scale=08bin=238octave=09note=22
	retlw	(D'09'*D'24')+D'20'	;scale=08bin=239octave=09note=23
	retlw	(D'10'*D'24')+D'00'	;scale=08bin=240octave=10note=00
	retlw	(D'10'*D'24')+D'00'	;scale=08bin=241octave=10note=01
	retlw	(D'10'*D'24')+D'00'	;scale=08bin=242octave=10note=02
	retlw	(D'10'*D'24')+D'00'	;scale=08bin=243octave=10note=03
	retlw	(D'10'*D'24')+D'00'	;scale=08bin=244octave=10note=04
	retlw	(D'10'*D'24')+D'00'	;scale=08bin=245octave=10note=05
	retlw	(D'10'*D'24')+D'00'	;scale=08bin=246octave=10note=06
	retlw	(D'10'*D'24')+D'00'	;scale=08bin=247octave=10note=07
	retlw	(D'10'*D'24')+D'00'	;scale=08bin=248octave=10note=08
	retlw	(D'10'*D'24')+D'00'	;scale=08bin=249octave=10note=09
	retlw	(D'10'*D'24')+D'00'	;scale=08bin=250octave=10note=10
	retlw	(D'10'*D'24')+D'00'	;scale=08bin=251octave=10note=11
	retlw	(D'10'*D'24')+D'00'	;scale=08bin=252octave=10note=12
	retlw	(D'10'*D'24')+D'00'	;scale=08bin=253octave=10note=13
	retlw	(D'10'*D'24')+D'00'	;scale=08bin=254octave=10note=14
	retlw	(D'10'*D'24')+D'00'	;scale=08bin=255octave=10note=15

;	Lydian look-up table
	org	Lydian		;Lydian look-up table
	retlw	(D'00'*D'24')+D'00'	;scale=09bin=000octave=00note=00
	retlw	(D'00'*D'24')+D'00'	;scale=09bin=001octave=00note=01
	retlw	(D'00'*D'24')+D'00'	;scale=09bin=002octave=00note=02
	retlw	(D'00'*D'24')+D'00'	;scale=09bin=003octave=00note=03
	retlw	(D'00'*D'24')+D'04'	;scale=09bin=004octave=00note=04
	retlw	(D'00'*D'24')+D'04'	;scale=09bin=005octave=00note=05
	retlw	(D'00'*D'24')+D'04'	;scale=09bin=006octave=00note=06
	retlw	(D'00'*D'24')+D'04'	;scale=09bin=007octave=00note=07
	retlw	(D'00'*D'24')+D'08'	;scale=09bin=008octave=00note=08
	retlw	(D'00'*D'24')+D'08'	;scale=09bin=009octave=00note=09
	retlw	(D'00'*D'24')+D'08'	;scale=09bin=010octave=00note=10
	retlw	(D'00'*D'24')+D'08'	;scale=09bin=011octave=00note=11
	retlw	(D'00'*D'24')+D'12'	;scale=09bin=012octave=00note=12
	retlw	(D'00'*D'24')+D'12'	;scale=09bin=013octave=00note=13
	retlw	(D'00'*D'24')+D'14'	;scale=09bin=014octave=00note=14
	retlw	(D'00'*D'24')+D'14'	;scale=09bin=015octave=00note=15
	retlw	(D'00'*D'24')+D'14'	;scale=09bin=016octave=00note=16
	retlw	(D'00'*D'24')+D'14'	;scale=09bin=017octave=00note=17
	retlw	(D'00'*D'24')+D'18'	;scale=09bin=018octave=00note=18
	retlw	(D'00'*D'24')+D'18'	;scale=09bin=019octave=00note=19
	retlw	(D'00'*D'24')+D'18'	;scale=09bin=020octave=00note=20
	retlw	(D'00'*D'24')+D'18'	;scale=09bin=021octave=00note=21
	retlw	(D'00'*D'24')+D'22'	;scale=09bin=022octave=00note=22
	retlw	(D'00'*D'24')+D'22'	;scale=09bin=023octave=00note=23
	retlw	(D'01'*D'24')+D'00'	;scale=09bin=024octave=01note=00
	retlw	(D'01'*D'24')+D'00'	;scale=09bin=025octave=01note=01
	retlw	(D'01'*D'24')+D'00'	;scale=09bin=026octave=01note=02
	retlw	(D'01'*D'24')+D'00'	;scale=09bin=027octave=01note=03
	retlw	(D'01'*D'24')+D'04'	;scale=09bin=028octave=01note=04
	retlw	(D'01'*D'24')+D'04'	;scale=09bin=029octave=01note=05
	retlw	(D'01'*D'24')+D'04'	;scale=09bin=030octave=01note=06
	retlw	(D'01'*D'24')+D'04'	;scale=09bin=031octave=01note=07
	retlw	(D'01'*D'24')+D'08'	;scale=09bin=032octave=01note=08
	retlw	(D'01'*D'24')+D'08'	;scale=09bin=033octave=01note=09
	retlw	(D'01'*D'24')+D'08'	;scale=09bin=034octave=01note=10
	retlw	(D'01'*D'24')+D'08'	;scale=09bin=035octave=01note=11
	retlw	(D'01'*D'24')+D'12'	;scale=09bin=036octave=01note=12
	retlw	(D'01'*D'24')+D'12'	;scale=09bin=037octave=01note=13
	retlw	(D'01'*D'24')+D'14'	;scale=09bin=038octave=01note=14
	retlw	(D'01'*D'24')+D'14'	;scale=09bin=039octave=01note=15
	retlw	(D'01'*D'24')+D'14'	;scale=09bin=040octave=01note=16
	retlw	(D'01'*D'24')+D'14'	;scale=09bin=041octave=01note=17
	retlw	(D'01'*D'24')+D'18'	;scale=09bin=042octave=01note=18
	retlw	(D'01'*D'24')+D'18'	;scale=09bin=043octave=01note=19
	retlw	(D'01'*D'24')+D'18'	;scale=09bin=044octave=01note=20
	retlw	(D'01'*D'24')+D'18'	;scale=09bin=045octave=01note=21
	retlw	(D'01'*D'24')+D'22'	;scale=09bin=046octave=01note=22
	retlw	(D'01'*D'24')+D'22'	;scale=09bin=047octave=01note=23
	retlw	(D'02'*D'24')+D'00'	;scale=09bin=048octave=02note=00
	retlw	(D'02'*D'24')+D'00'	;scale=09bin=049octave=02note=01
	retlw	(D'02'*D'24')+D'00'	;scale=09bin=050octave=02note=02
	retlw	(D'02'*D'24')+D'00'	;scale=09bin=051octave=02note=03
	retlw	(D'02'*D'24')+D'04'	;scale=09bin=052octave=02note=04
	retlw	(D'02'*D'24')+D'04'	;scale=09bin=053octave=02note=05
	retlw	(D'02'*D'24')+D'04'	;scale=09bin=054octave=02note=06
	retlw	(D'02'*D'24')+D'04'	;scale=09bin=055octave=02note=07
	retlw	(D'02'*D'24')+D'08'	;scale=09bin=056octave=02note=08
	retlw	(D'02'*D'24')+D'08'	;scale=09bin=057octave=02note=09
	retlw	(D'02'*D'24')+D'08'	;scale=09bin=058octave=02note=10
	retlw	(D'02'*D'24')+D'08'	;scale=09bin=059octave=02note=11
	retlw	(D'02'*D'24')+D'12'	;scale=09bin=060octave=02note=12
	retlw	(D'02'*D'24')+D'12'	;scale=09bin=061octave=02note=13
	retlw	(D'02'*D'24')+D'14'	;scale=09bin=062octave=02note=14
	retlw	(D'02'*D'24')+D'14'	;scale=09bin=063octave=02note=15
	retlw	(D'02'*D'24')+D'14'	;scale=09bin=064octave=02note=16
	retlw	(D'02'*D'24')+D'14'	;scale=09bin=065octave=02note=17
	retlw	(D'02'*D'24')+D'18'	;scale=09bin=066octave=02note=18
	retlw	(D'02'*D'24')+D'18'	;scale=09bin=067octave=02note=19
	retlw	(D'02'*D'24')+D'18'	;scale=09bin=068octave=02note=20
	retlw	(D'02'*D'24')+D'18'	;scale=09bin=069octave=02note=21
	retlw	(D'02'*D'24')+D'22'	;scale=09bin=070octave=02note=22
	retlw	(D'02'*D'24')+D'22'	;scale=09bin=071octave=02note=23
	retlw	(D'03'*D'24')+D'00'	;scale=09bin=072octave=03note=00
	retlw	(D'03'*D'24')+D'00'	;scale=09bin=073octave=03note=01
	retlw	(D'03'*D'24')+D'00'	;scale=09bin=074octave=03note=02
	retlw	(D'03'*D'24')+D'00'	;scale=09bin=075octave=03note=03
	retlw	(D'03'*D'24')+D'04'	;scale=09bin=076octave=03note=04
	retlw	(D'03'*D'24')+D'04'	;scale=09bin=077octave=03note=05
	retlw	(D'03'*D'24')+D'04'	;scale=09bin=078octave=03note=06
	retlw	(D'03'*D'24')+D'04'	;scale=09bin=079octave=03note=07
	retlw	(D'03'*D'24')+D'08'	;scale=09bin=080octave=03note=08
	retlw	(D'03'*D'24')+D'08'	;scale=09bin=081octave=03note=09
	retlw	(D'03'*D'24')+D'08'	;scale=09bin=082octave=03note=10
	retlw	(D'03'*D'24')+D'08'	;scale=09bin=083octave=03note=11
	retlw	(D'03'*D'24')+D'12'	;scale=09bin=084octave=03note=12
	retlw	(D'03'*D'24')+D'12'	;scale=09bin=085octave=03note=13
	retlw	(D'03'*D'24')+D'14'	;scale=09bin=086octave=03note=14
	retlw	(D'03'*D'24')+D'14'	;scale=09bin=087octave=03note=15
	retlw	(D'03'*D'24')+D'14'	;scale=09bin=088octave=03note=16
	retlw	(D'03'*D'24')+D'14'	;scale=09bin=089octave=03note=17
	retlw	(D'03'*D'24')+D'18'	;scale=09bin=090octave=03note=18
	retlw	(D'03'*D'24')+D'18'	;scale=09bin=091octave=03note=19
	retlw	(D'03'*D'24')+D'18'	;scale=09bin=092octave=03note=20
	retlw	(D'03'*D'24')+D'18'	;scale=09bin=093octave=03note=21
	retlw	(D'03'*D'24')+D'22'	;scale=09bin=094octave=03note=22
	retlw	(D'03'*D'24')+D'22'	;scale=09bin=095octave=03note=23
	retlw	(D'04'*D'24')+D'00'	;scale=09bin=096octave=04note=00
	retlw	(D'04'*D'24')+D'00'	;scale=09bin=097octave=04note=01
	retlw	(D'04'*D'24')+D'00'	;scale=09bin=098octave=04note=02
	retlw	(D'04'*D'24')+D'00'	;scale=09bin=099octave=04note=03
	retlw	(D'04'*D'24')+D'04'	;scale=09bin=100octave=04note=04
	retlw	(D'04'*D'24')+D'04'	;scale=09bin=101octave=04note=05
	retlw	(D'04'*D'24')+D'04'	;scale=09bin=102octave=04note=06
	retlw	(D'04'*D'24')+D'04'	;scale=09bin=103octave=04note=07
	retlw	(D'04'*D'24')+D'08'	;scale=09bin=104octave=04note=08
	retlw	(D'04'*D'24')+D'08'	;scale=09bin=105octave=04note=09
	retlw	(D'04'*D'24')+D'08'	;scale=09bin=106octave=04note=10
	retlw	(D'04'*D'24')+D'08'	;scale=09bin=107octave=04note=11
	retlw	(D'04'*D'24')+D'12'	;scale=09bin=108octave=04note=12
	retlw	(D'04'*D'24')+D'12'	;scale=09bin=109octave=04note=13
	retlw	(D'04'*D'24')+D'14'	;scale=09bin=110octave=04note=14
	retlw	(D'04'*D'24')+D'14'	;scale=09bin=111octave=04note=15
	retlw	(D'04'*D'24')+D'14'	;scale=09bin=112octave=04note=16
	retlw	(D'04'*D'24')+D'14'	;scale=09bin=113octave=04note=17
	retlw	(D'04'*D'24')+D'18'	;scale=09bin=114octave=04note=18
	retlw	(D'04'*D'24')+D'18'	;scale=09bin=115octave=04note=19
	retlw	(D'04'*D'24')+D'18'	;scale=09bin=116octave=04note=20
	retlw	(D'04'*D'24')+D'18'	;scale=09bin=117octave=04note=21
	retlw	(D'04'*D'24')+D'22'	;scale=09bin=118octave=04note=22
	retlw	(D'04'*D'24')+D'22'	;scale=09bin=119octave=04note=23
	retlw	(D'05'*D'24')+D'00'	;scale=09bin=120octave=05note=00
	retlw	(D'05'*D'24')+D'00'	;scale=09bin=121octave=05note=01
	retlw	(D'05'*D'24')+D'00'	;scale=09bin=122octave=05note=02
	retlw	(D'05'*D'24')+D'00'	;scale=09bin=123octave=05note=03
	retlw	(D'05'*D'24')+D'04'	;scale=09bin=124octave=05note=04
	retlw	(D'05'*D'24')+D'04'	;scale=09bin=125octave=05note=05
	retlw	(D'05'*D'24')+D'04'	;scale=09bin=126octave=05note=06
	retlw	(D'05'*D'24')+D'04'	;scale=09bin=127octave=05note=07
	retlw	(D'05'*D'24')+D'08'	;scale=09bin=128octave=05note=08
	retlw	(D'05'*D'24')+D'08'	;scale=09bin=129octave=05note=09
	retlw	(D'05'*D'24')+D'08'	;scale=09bin=130octave=05note=10
	retlw	(D'05'*D'24')+D'08'	;scale=09bin=131octave=05note=11
	retlw	(D'05'*D'24')+D'12'	;scale=09bin=132octave=05note=12
	retlw	(D'05'*D'24')+D'12'	;scale=09bin=133octave=05note=13
	retlw	(D'05'*D'24')+D'14'	;scale=09bin=134octave=05note=14
	retlw	(D'05'*D'24')+D'14'	;scale=09bin=135octave=05note=15
	retlw	(D'05'*D'24')+D'14'	;scale=09bin=136octave=05note=16
	retlw	(D'05'*D'24')+D'14'	;scale=09bin=137octave=05note=17
	retlw	(D'05'*D'24')+D'18'	;scale=09bin=138octave=05note=18
	retlw	(D'05'*D'24')+D'18'	;scale=09bin=139octave=05note=19
	retlw	(D'05'*D'24')+D'18'	;scale=09bin=140octave=05note=20
	retlw	(D'05'*D'24')+D'18'	;scale=09bin=141octave=05note=21
	retlw	(D'05'*D'24')+D'22'	;scale=09bin=142octave=05note=22
	retlw	(D'05'*D'24')+D'22'	;scale=09bin=143octave=05note=23
	retlw	(D'06'*D'24')+D'00'	;scale=09bin=144octave=06note=00
	retlw	(D'06'*D'24')+D'00'	;scale=09bin=145octave=06note=01
	retlw	(D'06'*D'24')+D'00'	;scale=09bin=146octave=06note=02
	retlw	(D'06'*D'24')+D'00'	;scale=09bin=147octave=06note=03
	retlw	(D'06'*D'24')+D'04'	;scale=09bin=148octave=06note=04
	retlw	(D'06'*D'24')+D'04'	;scale=09bin=149octave=06note=05
	retlw	(D'06'*D'24')+D'04'	;scale=09bin=150octave=06note=06
	retlw	(D'06'*D'24')+D'04'	;scale=09bin=151octave=06note=07
	retlw	(D'06'*D'24')+D'08'	;scale=09bin=152octave=06note=08
	retlw	(D'06'*D'24')+D'08'	;scale=09bin=153octave=06note=09
	retlw	(D'06'*D'24')+D'08'	;scale=09bin=154octave=06note=10
	retlw	(D'06'*D'24')+D'08'	;scale=09bin=155octave=06note=11
	retlw	(D'06'*D'24')+D'12'	;scale=09bin=156octave=06note=12
	retlw	(D'06'*D'24')+D'12'	;scale=09bin=157octave=06note=13
	retlw	(D'06'*D'24')+D'14'	;scale=09bin=158octave=06note=14
	retlw	(D'06'*D'24')+D'14'	;scale=09bin=159octave=06note=15
	retlw	(D'06'*D'24')+D'14'	;scale=09bin=160octave=06note=16
	retlw	(D'06'*D'24')+D'14'	;scale=09bin=161octave=06note=17
	retlw	(D'06'*D'24')+D'18'	;scale=09bin=162octave=06note=18
	retlw	(D'06'*D'24')+D'18'	;scale=09bin=163octave=06note=19
	retlw	(D'06'*D'24')+D'18'	;scale=09bin=164octave=06note=20
	retlw	(D'06'*D'24')+D'18'	;scale=09bin=165octave=06note=21
	retlw	(D'06'*D'24')+D'22'	;scale=09bin=166octave=06note=22
	retlw	(D'06'*D'24')+D'22'	;scale=09bin=167octave=06note=23
	retlw	(D'07'*D'24')+D'00'	;scale=09bin=168octave=07note=00
	retlw	(D'07'*D'24')+D'00'	;scale=09bin=169octave=07note=01
	retlw	(D'07'*D'24')+D'00'	;scale=09bin=170octave=07note=02
	retlw	(D'07'*D'24')+D'00'	;scale=09bin=171octave=07note=03
	retlw	(D'07'*D'24')+D'04'	;scale=09bin=172octave=07note=04
	retlw	(D'07'*D'24')+D'04'	;scale=09bin=173octave=07note=05
	retlw	(D'07'*D'24')+D'04'	;scale=09bin=174octave=07note=06
	retlw	(D'07'*D'24')+D'04'	;scale=09bin=175octave=07note=07
	retlw	(D'07'*D'24')+D'08'	;scale=09bin=176octave=07note=08
	retlw	(D'07'*D'24')+D'08'	;scale=09bin=177octave=07note=09
	retlw	(D'07'*D'24')+D'08'	;scale=09bin=178octave=07note=10
	retlw	(D'07'*D'24')+D'08'	;scale=09bin=179octave=07note=11
	retlw	(D'07'*D'24')+D'12'	;scale=09bin=180octave=07note=12
	retlw	(D'07'*D'24')+D'12'	;scale=09bin=181octave=07note=13
	retlw	(D'07'*D'24')+D'14'	;scale=09bin=182octave=07note=14
	retlw	(D'07'*D'24')+D'14'	;scale=09bin=183octave=07note=15
	retlw	(D'07'*D'24')+D'14'	;scale=09bin=184octave=07note=16
	retlw	(D'07'*D'24')+D'14'	;scale=09bin=185octave=07note=17
	retlw	(D'07'*D'24')+D'18'	;scale=09bin=186octave=07note=18
	retlw	(D'07'*D'24')+D'18'	;scale=09bin=187octave=07note=19
	retlw	(D'07'*D'24')+D'18'	;scale=09bin=188octave=07note=20
	retlw	(D'07'*D'24')+D'18'	;scale=09bin=189octave=07note=21
	retlw	(D'07'*D'24')+D'22'	;scale=09bin=190octave=07note=22
	retlw	(D'07'*D'24')+D'22'	;scale=09bin=191octave=07note=23
	retlw	(D'08'*D'24')+D'00'	;scale=09bin=192octave=08note=00
	retlw	(D'08'*D'24')+D'00'	;scale=09bin=193octave=08note=01
	retlw	(D'08'*D'24')+D'00'	;scale=09bin=194octave=08note=02
	retlw	(D'08'*D'24')+D'00'	;scale=09bin=195octave=08note=03
	retlw	(D'08'*D'24')+D'04'	;scale=09bin=196octave=08note=04
	retlw	(D'08'*D'24')+D'04'	;scale=09bin=197octave=08note=05
	retlw	(D'08'*D'24')+D'04'	;scale=09bin=198octave=08note=06
	retlw	(D'08'*D'24')+D'04'	;scale=09bin=199octave=08note=07
	retlw	(D'08'*D'24')+D'08'	;scale=09bin=200octave=08note=08
	retlw	(D'08'*D'24')+D'08'	;scale=09bin=201octave=08note=09
	retlw	(D'08'*D'24')+D'08'	;scale=09bin=202octave=08note=10
	retlw	(D'08'*D'24')+D'08'	;scale=09bin=203octave=08note=11
	retlw	(D'08'*D'24')+D'12'	;scale=09bin=204octave=08note=12
	retlw	(D'08'*D'24')+D'12'	;scale=09bin=205octave=08note=13
	retlw	(D'08'*D'24')+D'14'	;scale=09bin=206octave=08note=14
	retlw	(D'08'*D'24')+D'14'	;scale=09bin=207octave=08note=15
	retlw	(D'08'*D'24')+D'14'	;scale=09bin=208octave=08note=16
	retlw	(D'08'*D'24')+D'14'	;scale=09bin=209octave=08note=17
	retlw	(D'08'*D'24')+D'18'	;scale=09bin=210octave=08note=18
	retlw	(D'08'*D'24')+D'18'	;scale=09bin=211octave=08note=19
	retlw	(D'08'*D'24')+D'18'	;scale=09bin=212octave=08note=20
	retlw	(D'08'*D'24')+D'18'	;scale=09bin=213octave=08note=21
	retlw	(D'08'*D'24')+D'22'	;scale=09bin=214octave=08note=22
	retlw	(D'08'*D'24')+D'22'	;scale=09bin=215octave=08note=23
	retlw	(D'09'*D'24')+D'00'	;scale=09bin=216octave=09note=00
	retlw	(D'09'*D'24')+D'00'	;scale=09bin=217octave=09note=01
	retlw	(D'09'*D'24')+D'00'	;scale=09bin=218octave=09note=02
	retlw	(D'09'*D'24')+D'00'	;scale=09bin=219octave=09note=03
	retlw	(D'09'*D'24')+D'04'	;scale=09bin=220octave=09note=04
	retlw	(D'09'*D'24')+D'04'	;scale=09bin=221octave=09note=05
	retlw	(D'09'*D'24')+D'04'	;scale=09bin=222octave=09note=06
	retlw	(D'09'*D'24')+D'04'	;scale=09bin=223octave=09note=07
	retlw	(D'09'*D'24')+D'08'	;scale=09bin=224octave=09note=08
	retlw	(D'09'*D'24')+D'08'	;scale=09bin=225octave=09note=09
	retlw	(D'09'*D'24')+D'08'	;scale=09bin=226octave=09note=10
	retlw	(D'09'*D'24')+D'08'	;scale=09bin=227octave=09note=11
	retlw	(D'09'*D'24')+D'12'	;scale=09bin=228octave=09note=12
	retlw	(D'09'*D'24')+D'12'	;scale=09bin=229octave=09note=13
	retlw	(D'09'*D'24')+D'14'	;scale=09bin=230octave=09note=14
	retlw	(D'09'*D'24')+D'14'	;scale=09bin=231octave=09note=15
	retlw	(D'09'*D'24')+D'14'	;scale=09bin=232octave=09note=16
	retlw	(D'09'*D'24')+D'14'	;scale=09bin=233octave=09note=17
	retlw	(D'09'*D'24')+D'18'	;scale=09bin=234octave=09note=18
	retlw	(D'09'*D'24')+D'18'	;scale=09bin=235octave=09note=19
	retlw	(D'09'*D'24')+D'18'	;scale=09bin=236octave=09note=20
	retlw	(D'09'*D'24')+D'18'	;scale=09bin=237octave=09note=21
	retlw	(D'09'*D'24')+D'22'	;scale=09bin=238octave=09note=22
	retlw	(D'09'*D'24')+D'22'	;scale=09bin=239octave=09note=23
	retlw	(D'10'*D'24')+D'00'	;scale=09bin=240octave=10note=00
	retlw	(D'10'*D'24')+D'00'	;scale=09bin=241octave=10note=01
	retlw	(D'10'*D'24')+D'00'	;scale=09bin=242octave=10note=02
	retlw	(D'10'*D'24')+D'00'	;scale=09bin=243octave=10note=03
	retlw	(D'10'*D'24')+D'00'	;scale=09bin=244octave=10note=04
	retlw	(D'10'*D'24')+D'00'	;scale=09bin=245octave=10note=05
	retlw	(D'10'*D'24')+D'00'	;scale=09bin=246octave=10note=06
	retlw	(D'10'*D'24')+D'00'	;scale=09bin=247octave=10note=07
	retlw	(D'10'*D'24')+D'00'	;scale=09bin=248octave=10note=08
	retlw	(D'10'*D'24')+D'00'	;scale=09bin=249octave=10note=09
	retlw	(D'10'*D'24')+D'00'	;scale=09bin=250octave=10note=10
	retlw	(D'10'*D'24')+D'00'	;scale=09bin=251octave=10note=11
	retlw	(D'10'*D'24')+D'00'	;scale=09bin=252octave=10note=12
	retlw	(D'10'*D'24')+D'00'	;scale=09bin=253octave=10note=13
	retlw	(D'10'*D'24')+D'00'	;scale=09bin=254octave=10note=14
	retlw	(D'10'*D'24')+D'00'	;scale=09bin=255octave=10note=15

;	Lydian Dominant look-up table
	org	LydianD		;Lydian Dominant look-up table
	retlw	(D'00'*D'24')+D'00'	;scale=10bin=000octave=00note=00
	retlw	(D'00'*D'24')+D'00'	;scale=10bin=001octave=00note=01
	retlw	(D'00'*D'24')+D'00'	;scale=10bin=002octave=00note=02
	retlw	(D'00'*D'24')+D'00'	;scale=10bin=003octave=00note=03
	retlw	(D'00'*D'24')+D'04'	;scale=10bin=004octave=00note=04
	retlw	(D'00'*D'24')+D'04'	;scale=10bin=005octave=00note=05
	retlw	(D'00'*D'24')+D'04'	;scale=10bin=006octave=00note=06
	retlw	(D'00'*D'24')+D'04'	;scale=10bin=007octave=00note=07
	retlw	(D'00'*D'24')+D'08'	;scale=10bin=008octave=00note=08
	retlw	(D'00'*D'24')+D'08'	;scale=10bin=009octave=00note=09
	retlw	(D'00'*D'24')+D'08'	;scale=10bin=010octave=00note=10
	retlw	(D'00'*D'24')+D'08'	;scale=10bin=011octave=00note=11
	retlw	(D'00'*D'24')+D'12'	;scale=10bin=012octave=00note=12
	retlw	(D'00'*D'24')+D'12'	;scale=10bin=013octave=00note=13
	retlw	(D'00'*D'24')+D'14'	;scale=10bin=014octave=00note=14
	retlw	(D'00'*D'24')+D'14'	;scale=10bin=015octave=00note=15
	retlw	(D'00'*D'24')+D'14'	;scale=10bin=016octave=00note=16
	retlw	(D'00'*D'24')+D'14'	;scale=10bin=017octave=00note=17
	retlw	(D'00'*D'24')+D'18'	;scale=10bin=018octave=00note=18
	retlw	(D'00'*D'24')+D'18'	;scale=10bin=019octave=00note=19
	retlw	(D'00'*D'24')+D'20'	;scale=10bin=020octave=00note=20
	retlw	(D'00'*D'24')+D'20'	;scale=10bin=021octave=00note=21
	retlw	(D'00'*D'24')+D'20'	;scale=10bin=022octave=00note=22
	retlw	(D'00'*D'24')+D'20'	;scale=10bin=023octave=00note=23
	retlw	(D'01'*D'24')+D'00'	;scale=10bin=024octave=01note=00
	retlw	(D'01'*D'24')+D'00'	;scale=10bin=025octave=01note=01
	retlw	(D'01'*D'24')+D'00'	;scale=10bin=026octave=01note=02
	retlw	(D'01'*D'24')+D'00'	;scale=10bin=027octave=01note=03
	retlw	(D'01'*D'24')+D'04'	;scale=10bin=028octave=01note=04
	retlw	(D'01'*D'24')+D'04'	;scale=10bin=029octave=01note=05
	retlw	(D'01'*D'24')+D'04'	;scale=10bin=030octave=01note=06
	retlw	(D'01'*D'24')+D'04'	;scale=10bin=031octave=01note=07
	retlw	(D'01'*D'24')+D'08'	;scale=10bin=032octave=01note=08
	retlw	(D'01'*D'24')+D'08'	;scale=10bin=033octave=01note=09
	retlw	(D'01'*D'24')+D'08'	;scale=10bin=034octave=01note=10
	retlw	(D'01'*D'24')+D'08'	;scale=10bin=035octave=01note=11
	retlw	(D'01'*D'24')+D'12'	;scale=10bin=036octave=01note=12
	retlw	(D'01'*D'24')+D'12'	;scale=10bin=037octave=01note=13
	retlw	(D'01'*D'24')+D'14'	;scale=10bin=038octave=01note=14
	retlw	(D'01'*D'24')+D'14'	;scale=10bin=039octave=01note=15
	retlw	(D'01'*D'24')+D'14'	;scale=10bin=040octave=01note=16
	retlw	(D'01'*D'24')+D'14'	;scale=10bin=041octave=01note=17
	retlw	(D'01'*D'24')+D'18'	;scale=10bin=042octave=01note=18
	retlw	(D'01'*D'24')+D'18'	;scale=10bin=043octave=01note=19
	retlw	(D'01'*D'24')+D'20'	;scale=10bin=044octave=01note=20
	retlw	(D'01'*D'24')+D'20'	;scale=10bin=045octave=01note=21
	retlw	(D'01'*D'24')+D'20'	;scale=10bin=046octave=01note=22
	retlw	(D'01'*D'24')+D'20'	;scale=10bin=047octave=01note=23
	retlw	(D'02'*D'24')+D'00'	;scale=10bin=048octave=02note=00
	retlw	(D'02'*D'24')+D'00'	;scale=10bin=049octave=02note=01
	retlw	(D'02'*D'24')+D'00'	;scale=10bin=050octave=02note=02
	retlw	(D'02'*D'24')+D'00'	;scale=10bin=051octave=02note=03
	retlw	(D'02'*D'24')+D'04'	;scale=10bin=052octave=02note=04
	retlw	(D'02'*D'24')+D'04'	;scale=10bin=053octave=02note=05
	retlw	(D'02'*D'24')+D'04'	;scale=10bin=054octave=02note=06
	retlw	(D'02'*D'24')+D'04'	;scale=10bin=055octave=02note=07
	retlw	(D'02'*D'24')+D'08'	;scale=10bin=056octave=02note=08
	retlw	(D'02'*D'24')+D'08'	;scale=10bin=057octave=02note=09
	retlw	(D'02'*D'24')+D'08'	;scale=10bin=058octave=02note=10
	retlw	(D'02'*D'24')+D'08'	;scale=10bin=059octave=02note=11
	retlw	(D'02'*D'24')+D'12'	;scale=10bin=060octave=02note=12
	retlw	(D'02'*D'24')+D'12'	;scale=10bin=061octave=02note=13
	retlw	(D'02'*D'24')+D'14'	;scale=10bin=062octave=02note=14
	retlw	(D'02'*D'24')+D'14'	;scale=10bin=063octave=02note=15
	retlw	(D'02'*D'24')+D'14'	;scale=10bin=064octave=02note=16
	retlw	(D'02'*D'24')+D'14'	;scale=10bin=065octave=02note=17
	retlw	(D'02'*D'24')+D'18'	;scale=10bin=066octave=02note=18
	retlw	(D'02'*D'24')+D'18'	;scale=10bin=067octave=02note=19
	retlw	(D'02'*D'24')+D'20'	;scale=10bin=068octave=02note=20
	retlw	(D'02'*D'24')+D'20'	;scale=10bin=069octave=02note=21
	retlw	(D'02'*D'24')+D'20'	;scale=10bin=070octave=02note=22
	retlw	(D'02'*D'24')+D'20'	;scale=10bin=071octave=02note=23
	retlw	(D'03'*D'24')+D'00'	;scale=10bin=072octave=03note=00
	retlw	(D'03'*D'24')+D'00'	;scale=10bin=073octave=03note=01
	retlw	(D'03'*D'24')+D'00'	;scale=10bin=074octave=03note=02
	retlw	(D'03'*D'24')+D'00'	;scale=10bin=075octave=03note=03
	retlw	(D'03'*D'24')+D'04'	;scale=10bin=076octave=03note=04
	retlw	(D'03'*D'24')+D'04'	;scale=10bin=077octave=03note=05
	retlw	(D'03'*D'24')+D'04'	;scale=10bin=078octave=03note=06
	retlw	(D'03'*D'24')+D'04'	;scale=10bin=079octave=03note=07
	retlw	(D'03'*D'24')+D'08'	;scale=10bin=080octave=03note=08
	retlw	(D'03'*D'24')+D'08'	;scale=10bin=081octave=03note=09
	retlw	(D'03'*D'24')+D'08'	;scale=10bin=082octave=03note=10
	retlw	(D'03'*D'24')+D'08'	;scale=10bin=083octave=03note=11
	retlw	(D'03'*D'24')+D'12'	;scale=10bin=084octave=03note=12
	retlw	(D'03'*D'24')+D'12'	;scale=10bin=085octave=03note=13
	retlw	(D'03'*D'24')+D'14'	;scale=10bin=086octave=03note=14
	retlw	(D'03'*D'24')+D'14'	;scale=10bin=087octave=03note=15
	retlw	(D'03'*D'24')+D'14'	;scale=10bin=088octave=03note=16
	retlw	(D'03'*D'24')+D'14'	;scale=10bin=089octave=03note=17
	retlw	(D'03'*D'24')+D'18'	;scale=10bin=090octave=03note=18
	retlw	(D'03'*D'24')+D'18'	;scale=10bin=091octave=03note=19
	retlw	(D'03'*D'24')+D'20'	;scale=10bin=092octave=03note=20
	retlw	(D'03'*D'24')+D'20'	;scale=10bin=093octave=03note=21
	retlw	(D'03'*D'24')+D'20'	;scale=10bin=094octave=03note=22
	retlw	(D'03'*D'24')+D'20'	;scale=10bin=095octave=03note=23
	retlw	(D'04'*D'24')+D'00'	;scale=10bin=096octave=04note=00
	retlw	(D'04'*D'24')+D'00'	;scale=10bin=097octave=04note=01
	retlw	(D'04'*D'24')+D'00'	;scale=10bin=098octave=04note=02
	retlw	(D'04'*D'24')+D'00'	;scale=10bin=099octave=04note=03
	retlw	(D'04'*D'24')+D'04'	;scale=10bin=100octave=04note=04
	retlw	(D'04'*D'24')+D'04'	;scale=10bin=101octave=04note=05
	retlw	(D'04'*D'24')+D'04'	;scale=10bin=102octave=04note=06
	retlw	(D'04'*D'24')+D'04'	;scale=10bin=103octave=04note=07
	retlw	(D'04'*D'24')+D'08'	;scale=10bin=104octave=04note=08
	retlw	(D'04'*D'24')+D'08'	;scale=10bin=105octave=04note=09
	retlw	(D'04'*D'24')+D'08'	;scale=10bin=106octave=04note=10
	retlw	(D'04'*D'24')+D'08'	;scale=10bin=107octave=04note=11
	retlw	(D'04'*D'24')+D'12'	;scale=10bin=108octave=04note=12
	retlw	(D'04'*D'24')+D'12'	;scale=10bin=109octave=04note=13
	retlw	(D'04'*D'24')+D'14'	;scale=10bin=110octave=04note=14
	retlw	(D'04'*D'24')+D'14'	;scale=10bin=111octave=04note=15
	retlw	(D'04'*D'24')+D'14'	;scale=10bin=112octave=04note=16
	retlw	(D'04'*D'24')+D'14'	;scale=10bin=113octave=04note=17
	retlw	(D'04'*D'24')+D'18'	;scale=10bin=114octave=04note=18
	retlw	(D'04'*D'24')+D'18'	;scale=10bin=115octave=04note=19
	retlw	(D'04'*D'24')+D'20'	;scale=10bin=116octave=04note=20
	retlw	(D'04'*D'24')+D'20'	;scale=10bin=117octave=04note=21
	retlw	(D'04'*D'24')+D'20'	;scale=10bin=118octave=04note=22
	retlw	(D'04'*D'24')+D'20'	;scale=10bin=119octave=04note=23
	retlw	(D'05'*D'24')+D'00'	;scale=10bin=120octave=05note=00
	retlw	(D'05'*D'24')+D'00'	;scale=10bin=121octave=05note=01
	retlw	(D'05'*D'24')+D'00'	;scale=10bin=122octave=05note=02
	retlw	(D'05'*D'24')+D'00'	;scale=10bin=123octave=05note=03
	retlw	(D'05'*D'24')+D'04'	;scale=10bin=124octave=05note=04
	retlw	(D'05'*D'24')+D'04'	;scale=10bin=125octave=05note=05
	retlw	(D'05'*D'24')+D'04'	;scale=10bin=126octave=05note=06
	retlw	(D'05'*D'24')+D'04'	;scale=10bin=127octave=05note=07
	retlw	(D'05'*D'24')+D'08'	;scale=10bin=128octave=05note=08
	retlw	(D'05'*D'24')+D'08'	;scale=10bin=129octave=05note=09
	retlw	(D'05'*D'24')+D'08'	;scale=10bin=130octave=05note=10
	retlw	(D'05'*D'24')+D'08'	;scale=10bin=131octave=05note=11
	retlw	(D'05'*D'24')+D'12'	;scale=10bin=132octave=05note=12
	retlw	(D'05'*D'24')+D'12'	;scale=10bin=133octave=05note=13
	retlw	(D'05'*D'24')+D'14'	;scale=10bin=134octave=05note=14
	retlw	(D'05'*D'24')+D'14'	;scale=10bin=135octave=05note=15
	retlw	(D'05'*D'24')+D'14'	;scale=10bin=136octave=05note=16
	retlw	(D'05'*D'24')+D'14'	;scale=10bin=137octave=05note=17
	retlw	(D'05'*D'24')+D'18'	;scale=10bin=138octave=05note=18
	retlw	(D'05'*D'24')+D'18'	;scale=10bin=139octave=05note=19
	retlw	(D'05'*D'24')+D'20'	;scale=10bin=140octave=05note=20
	retlw	(D'05'*D'24')+D'20'	;scale=10bin=141octave=05note=21
	retlw	(D'05'*D'24')+D'20'	;scale=10bin=142octave=05note=22
	retlw	(D'05'*D'24')+D'20'	;scale=10bin=143octave=05note=23
	retlw	(D'06'*D'24')+D'00'	;scale=10bin=144octave=06note=00
	retlw	(D'06'*D'24')+D'00'	;scale=10bin=145octave=06note=01
	retlw	(D'06'*D'24')+D'00'	;scale=10bin=146octave=06note=02
	retlw	(D'06'*D'24')+D'00'	;scale=10bin=147octave=06note=03
	retlw	(D'06'*D'24')+D'04'	;scale=10bin=148octave=06note=04
	retlw	(D'06'*D'24')+D'04'	;scale=10bin=149octave=06note=05
	retlw	(D'06'*D'24')+D'04'	;scale=10bin=150octave=06note=06
	retlw	(D'06'*D'24')+D'04'	;scale=10bin=151octave=06note=07
	retlw	(D'06'*D'24')+D'08'	;scale=10bin=152octave=06note=08
	retlw	(D'06'*D'24')+D'08'	;scale=10bin=153octave=06note=09
	retlw	(D'06'*D'24')+D'08'	;scale=10bin=154octave=06note=10
	retlw	(D'06'*D'24')+D'08'	;scale=10bin=155octave=06note=11
	retlw	(D'06'*D'24')+D'12'	;scale=10bin=156octave=06note=12
	retlw	(D'06'*D'24')+D'12'	;scale=10bin=157octave=06note=13
	retlw	(D'06'*D'24')+D'14'	;scale=10bin=158octave=06note=14
	retlw	(D'06'*D'24')+D'14'	;scale=10bin=159octave=06note=15
	retlw	(D'06'*D'24')+D'14'	;scale=10bin=160octave=06note=16
	retlw	(D'06'*D'24')+D'14'	;scale=10bin=161octave=06note=17
	retlw	(D'06'*D'24')+D'18'	;scale=10bin=162octave=06note=18
	retlw	(D'06'*D'24')+D'18'	;scale=10bin=163octave=06note=19
	retlw	(D'06'*D'24')+D'20'	;scale=10bin=164octave=06note=20
	retlw	(D'06'*D'24')+D'20'	;scale=10bin=165octave=06note=21
	retlw	(D'06'*D'24')+D'20'	;scale=10bin=166octave=06note=22
	retlw	(D'06'*D'24')+D'20'	;scale=10bin=167octave=06note=23
	retlw	(D'07'*D'24')+D'00'	;scale=10bin=168octave=07note=00
	retlw	(D'07'*D'24')+D'00'	;scale=10bin=169octave=07note=01
	retlw	(D'07'*D'24')+D'00'	;scale=10bin=170octave=07note=02
	retlw	(D'07'*D'24')+D'00'	;scale=10bin=171octave=07note=03
	retlw	(D'07'*D'24')+D'04'	;scale=10bin=172octave=07note=04
	retlw	(D'07'*D'24')+D'04'	;scale=10bin=173octave=07note=05
	retlw	(D'07'*D'24')+D'04'	;scale=10bin=174octave=07note=06
	retlw	(D'07'*D'24')+D'04'	;scale=10bin=175octave=07note=07
	retlw	(D'07'*D'24')+D'08'	;scale=10bin=176octave=07note=08
	retlw	(D'07'*D'24')+D'08'	;scale=10bin=177octave=07note=09
	retlw	(D'07'*D'24')+D'08'	;scale=10bin=178octave=07note=10
	retlw	(D'07'*D'24')+D'08'	;scale=10bin=179octave=07note=11
	retlw	(D'07'*D'24')+D'12'	;scale=10bin=180octave=07note=12
	retlw	(D'07'*D'24')+D'12'	;scale=10bin=181octave=07note=13
	retlw	(D'07'*D'24')+D'14'	;scale=10bin=182octave=07note=14
	retlw	(D'07'*D'24')+D'14'	;scale=10bin=183octave=07note=15
	retlw	(D'07'*D'24')+D'14'	;scale=10bin=184octave=07note=16
	retlw	(D'07'*D'24')+D'14'	;scale=10bin=185octave=07note=17
	retlw	(D'07'*D'24')+D'18'	;scale=10bin=186octave=07note=18
	retlw	(D'07'*D'24')+D'18'	;scale=10bin=187octave=07note=19
	retlw	(D'07'*D'24')+D'20'	;scale=10bin=188octave=07note=20
	retlw	(D'07'*D'24')+D'20'	;scale=10bin=189octave=07note=21
	retlw	(D'07'*D'24')+D'20'	;scale=10bin=190octave=07note=22
	retlw	(D'07'*D'24')+D'20'	;scale=10bin=191octave=07note=23
	retlw	(D'08'*D'24')+D'00'	;scale=10bin=192octave=08note=00
	retlw	(D'08'*D'24')+D'00'	;scale=10bin=193octave=08note=01
	retlw	(D'08'*D'24')+D'00'	;scale=10bin=194octave=08note=02
	retlw	(D'08'*D'24')+D'00'	;scale=10bin=195octave=08note=03
	retlw	(D'08'*D'24')+D'04'	;scale=10bin=196octave=08note=04
	retlw	(D'08'*D'24')+D'04'	;scale=10bin=197octave=08note=05
	retlw	(D'08'*D'24')+D'04'	;scale=10bin=198octave=08note=06
	retlw	(D'08'*D'24')+D'04'	;scale=10bin=199octave=08note=07
	retlw	(D'08'*D'24')+D'08'	;scale=10bin=200octave=08note=08
	retlw	(D'08'*D'24')+D'08'	;scale=10bin=201octave=08note=09
	retlw	(D'08'*D'24')+D'08'	;scale=10bin=202octave=08note=10
	retlw	(D'08'*D'24')+D'08'	;scale=10bin=203octave=08note=11
	retlw	(D'08'*D'24')+D'12'	;scale=10bin=204octave=08note=12
	retlw	(D'08'*D'24')+D'12'	;scale=10bin=205octave=08note=13
	retlw	(D'08'*D'24')+D'14'	;scale=10bin=206octave=08note=14
	retlw	(D'08'*D'24')+D'14'	;scale=10bin=207octave=08note=15
	retlw	(D'08'*D'24')+D'14'	;scale=10bin=208octave=08note=16
	retlw	(D'08'*D'24')+D'14'	;scale=10bin=209octave=08note=17
	retlw	(D'08'*D'24')+D'18'	;scale=10bin=210octave=08note=18
	retlw	(D'08'*D'24')+D'18'	;scale=10bin=211octave=08note=19
	retlw	(D'08'*D'24')+D'20'	;scale=10bin=212octave=08note=20
	retlw	(D'08'*D'24')+D'20'	;scale=10bin=213octave=08note=21
	retlw	(D'08'*D'24')+D'20'	;scale=10bin=214octave=08note=22
	retlw	(D'08'*D'24')+D'20'	;scale=10bin=215octave=08note=23
	retlw	(D'09'*D'24')+D'00'	;scale=10bin=216octave=09note=00
	retlw	(D'09'*D'24')+D'00'	;scale=10bin=217octave=09note=01
	retlw	(D'09'*D'24')+D'00'	;scale=10bin=218octave=09note=02
	retlw	(D'09'*D'24')+D'00'	;scale=10bin=219octave=09note=03
	retlw	(D'09'*D'24')+D'04'	;scale=10bin=220octave=09note=04
	retlw	(D'09'*D'24')+D'04'	;scale=10bin=221octave=09note=05
	retlw	(D'09'*D'24')+D'04'	;scale=10bin=222octave=09note=06
	retlw	(D'09'*D'24')+D'04'	;scale=10bin=223octave=09note=07
	retlw	(D'09'*D'24')+D'08'	;scale=10bin=224octave=09note=08
	retlw	(D'09'*D'24')+D'08'	;scale=10bin=225octave=09note=09
	retlw	(D'09'*D'24')+D'08'	;scale=10bin=226octave=09note=10
	retlw	(D'09'*D'24')+D'08'	;scale=10bin=227octave=09note=11
	retlw	(D'09'*D'24')+D'12'	;scale=10bin=228octave=09note=12
	retlw	(D'09'*D'24')+D'12'	;scale=10bin=229octave=09note=13
	retlw	(D'09'*D'24')+D'14'	;scale=10bin=230octave=09note=14
	retlw	(D'09'*D'24')+D'14'	;scale=10bin=231octave=09note=15
	retlw	(D'09'*D'24')+D'14'	;scale=10bin=232octave=09note=16
	retlw	(D'09'*D'24')+D'14'	;scale=10bin=233octave=09note=17
	retlw	(D'09'*D'24')+D'18'	;scale=10bin=234octave=09note=18
	retlw	(D'09'*D'24')+D'18'	;scale=10bin=235octave=09note=19
	retlw	(D'09'*D'24')+D'20'	;scale=10bin=236octave=09note=20
	retlw	(D'09'*D'24')+D'20'	;scale=10bin=237octave=09note=21
	retlw	(D'09'*D'24')+D'20'	;scale=10bin=238octave=09note=22
	retlw	(D'09'*D'24')+D'20'	;scale=10bin=239octave=09note=23
	retlw	(D'10'*D'24')+D'00'	;scale=10bin=240octave=10note=00
	retlw	(D'10'*D'24')+D'00'	;scale=10bin=241octave=10note=01
	retlw	(D'10'*D'24')+D'00'	;scale=10bin=242octave=10note=02
	retlw	(D'10'*D'24')+D'00'	;scale=10bin=243octave=10note=03
	retlw	(D'10'*D'24')+D'00'	;scale=10bin=244octave=10note=04
	retlw	(D'10'*D'24')+D'00'	;scale=10bin=245octave=10note=05
	retlw	(D'10'*D'24')+D'00'	;scale=10bin=246octave=10note=06
	retlw	(D'10'*D'24')+D'00'	;scale=10bin=247octave=10note=07
	retlw	(D'10'*D'24')+D'00'	;scale=10bin=248octave=10note=08
	retlw	(D'10'*D'24')+D'00'	;scale=10bin=249octave=10note=09
	retlw	(D'10'*D'24')+D'00'	;scale=10bin=250octave=10note=10
	retlw	(D'10'*D'24')+D'00'	;scale=10bin=251octave=10note=11
	retlw	(D'10'*D'24')+D'00'	;scale=10bin=252octave=10note=12
	retlw	(D'10'*D'24')+D'00'	;scale=10bin=253octave=10note=13
	retlw	(D'10'*D'24')+D'00'	;scale=10bin=254octave=10note=14
	retlw	(D'10'*D'24')+D'00'	;scale=10bin=255octave=10note=15

;	Phrygian look-up table
	org	Phrygian		;Phrygian look-up table
	retlw	(D'00'*D'24')+D'00'	;scale=11bin=000octave=00note=00
	retlw	(D'00'*D'24')+D'00'	;scale=11bin=001octave=00note=01
	retlw	(D'00'*D'24')+D'02'	;scale=11bin=002octave=00note=02
	retlw	(D'00'*D'24')+D'02'	;scale=11bin=003octave=00note=03
	retlw	(D'00'*D'24')+D'02'	;scale=11bin=004octave=00note=04
	retlw	(D'00'*D'24')+D'02'	;scale=11bin=005octave=00note=05
	retlw	(D'00'*D'24')+D'06'	;scale=11bin=006octave=00note=06
	retlw	(D'00'*D'24')+D'06'	;scale=11bin=007octave=00note=07
	retlw	(D'00'*D'24')+D'06'	;scale=11bin=008octave=00note=08
	retlw	(D'00'*D'24')+D'06'	;scale=11bin=009octave=00note=09
	retlw	(D'00'*D'24')+D'10'	;scale=11bin=010octave=00note=10
	retlw	(D'00'*D'24')+D'10'	;scale=11bin=011octave=00note=11
	retlw	(D'00'*D'24')+D'10'	;scale=11bin=012octave=00note=12
	retlw	(D'00'*D'24')+D'10'	;scale=11bin=013octave=00note=13
	retlw	(D'00'*D'24')+D'14'	;scale=11bin=014octave=00note=14
	retlw	(D'00'*D'24')+D'14'	;scale=11bin=015octave=00note=15
	retlw	(D'00'*D'24')+D'16'	;scale=11bin=016octave=00note=16
	retlw	(D'00'*D'24')+D'16'	;scale=11bin=017octave=00note=17
	retlw	(D'00'*D'24')+D'16'	;scale=11bin=018octave=00note=18
	retlw	(D'00'*D'24')+D'16'	;scale=11bin=019octave=00note=19
	retlw	(D'00'*D'24')+D'20'	;scale=11bin=020octave=00note=20
	retlw	(D'00'*D'24')+D'20'	;scale=11bin=021octave=00note=21
	retlw	(D'00'*D'24')+D'20'	;scale=11bin=022octave=00note=22
	retlw	(D'00'*D'24')+D'20'	;scale=11bin=023octave=00note=23
	retlw	(D'01'*D'24')+D'00'	;scale=11bin=024octave=01note=00
	retlw	(D'01'*D'24')+D'00'	;scale=11bin=025octave=01note=01
	retlw	(D'01'*D'24')+D'02'	;scale=11bin=026octave=01note=02
	retlw	(D'01'*D'24')+D'02'	;scale=11bin=027octave=01note=03
	retlw	(D'01'*D'24')+D'02'	;scale=11bin=028octave=01note=04
	retlw	(D'01'*D'24')+D'02'	;scale=11bin=029octave=01note=05
	retlw	(D'01'*D'24')+D'06'	;scale=11bin=030octave=01note=06
	retlw	(D'01'*D'24')+D'06'	;scale=11bin=031octave=01note=07
	retlw	(D'01'*D'24')+D'06'	;scale=11bin=032octave=01note=08
	retlw	(D'01'*D'24')+D'06'	;scale=11bin=033octave=01note=09
	retlw	(D'01'*D'24')+D'10'	;scale=11bin=034octave=01note=10
	retlw	(D'01'*D'24')+D'10'	;scale=11bin=035octave=01note=11
	retlw	(D'01'*D'24')+D'10'	;scale=11bin=036octave=01note=12
	retlw	(D'01'*D'24')+D'10'	;scale=11bin=037octave=01note=13
	retlw	(D'01'*D'24')+D'14'	;scale=11bin=038octave=01note=14
	retlw	(D'01'*D'24')+D'14'	;scale=11bin=039octave=01note=15
	retlw	(D'01'*D'24')+D'16'	;scale=11bin=040octave=01note=16
	retlw	(D'01'*D'24')+D'16'	;scale=11bin=041octave=01note=17
	retlw	(D'01'*D'24')+D'16'	;scale=11bin=042octave=01note=18
	retlw	(D'01'*D'24')+D'16'	;scale=11bin=043octave=01note=19
	retlw	(D'01'*D'24')+D'20'	;scale=11bin=044octave=01note=20
	retlw	(D'01'*D'24')+D'20'	;scale=11bin=045octave=01note=21
	retlw	(D'01'*D'24')+D'20'	;scale=11bin=046octave=01note=22
	retlw	(D'01'*D'24')+D'20'	;scale=11bin=047octave=01note=23
	retlw	(D'02'*D'24')+D'00'	;scale=11bin=048octave=02note=00
	retlw	(D'02'*D'24')+D'00'	;scale=11bin=049octave=02note=01
	retlw	(D'02'*D'24')+D'02'	;scale=11bin=050octave=02note=02
	retlw	(D'02'*D'24')+D'02'	;scale=11bin=051octave=02note=03
	retlw	(D'02'*D'24')+D'02'	;scale=11bin=052octave=02note=04
	retlw	(D'02'*D'24')+D'02'	;scale=11bin=053octave=02note=05
	retlw	(D'02'*D'24')+D'06'	;scale=11bin=054octave=02note=06
	retlw	(D'02'*D'24')+D'06'	;scale=11bin=055octave=02note=07
	retlw	(D'02'*D'24')+D'06'	;scale=11bin=056octave=02note=08
	retlw	(D'02'*D'24')+D'06'	;scale=11bin=057octave=02note=09
	retlw	(D'02'*D'24')+D'10'	;scale=11bin=058octave=02note=10
	retlw	(D'02'*D'24')+D'10'	;scale=11bin=059octave=02note=11
	retlw	(D'02'*D'24')+D'10'	;scale=11bin=060octave=02note=12
	retlw	(D'02'*D'24')+D'10'	;scale=11bin=061octave=02note=13
	retlw	(D'02'*D'24')+D'14'	;scale=11bin=062octave=02note=14
	retlw	(D'02'*D'24')+D'14'	;scale=11bin=063octave=02note=15
	retlw	(D'02'*D'24')+D'16'	;scale=11bin=064octave=02note=16
	retlw	(D'02'*D'24')+D'16'	;scale=11bin=065octave=02note=17
	retlw	(D'02'*D'24')+D'16'	;scale=11bin=066octave=02note=18
	retlw	(D'02'*D'24')+D'16'	;scale=11bin=067octave=02note=19
	retlw	(D'02'*D'24')+D'20'	;scale=11bin=068octave=02note=20
	retlw	(D'02'*D'24')+D'20'	;scale=11bin=069octave=02note=21
	retlw	(D'02'*D'24')+D'20'	;scale=11bin=070octave=02note=22
	retlw	(D'02'*D'24')+D'20'	;scale=11bin=071octave=02note=23
	retlw	(D'03'*D'24')+D'00'	;scale=11bin=072octave=03note=00
	retlw	(D'03'*D'24')+D'00'	;scale=11bin=073octave=03note=01
	retlw	(D'03'*D'24')+D'02'	;scale=11bin=074octave=03note=02
	retlw	(D'03'*D'24')+D'02'	;scale=11bin=075octave=03note=03
	retlw	(D'03'*D'24')+D'02'	;scale=11bin=076octave=03note=04
	retlw	(D'03'*D'24')+D'02'	;scale=11bin=077octave=03note=05
	retlw	(D'03'*D'24')+D'06'	;scale=11bin=078octave=03note=06
	retlw	(D'03'*D'24')+D'06'	;scale=11bin=079octave=03note=07
	retlw	(D'03'*D'24')+D'06'	;scale=11bin=080octave=03note=08
	retlw	(D'03'*D'24')+D'06'	;scale=11bin=081octave=03note=09
	retlw	(D'03'*D'24')+D'10'	;scale=11bin=082octave=03note=10
	retlw	(D'03'*D'24')+D'10'	;scale=11bin=083octave=03note=11
	retlw	(D'03'*D'24')+D'10'	;scale=11bin=084octave=03note=12
	retlw	(D'03'*D'24')+D'10'	;scale=11bin=085octave=03note=13
	retlw	(D'03'*D'24')+D'14'	;scale=11bin=086octave=03note=14
	retlw	(D'03'*D'24')+D'14'	;scale=11bin=087octave=03note=15
	retlw	(D'03'*D'24')+D'16'	;scale=11bin=088octave=03note=16
	retlw	(D'03'*D'24')+D'16'	;scale=11bin=089octave=03note=17
	retlw	(D'03'*D'24')+D'16'	;scale=11bin=090octave=03note=18
	retlw	(D'03'*D'24')+D'16'	;scale=11bin=091octave=03note=19
	retlw	(D'03'*D'24')+D'20'	;scale=11bin=092octave=03note=20
	retlw	(D'03'*D'24')+D'20'	;scale=11bin=093octave=03note=21
	retlw	(D'03'*D'24')+D'20'	;scale=11bin=094octave=03note=22
	retlw	(D'03'*D'24')+D'20'	;scale=11bin=095octave=03note=23
	retlw	(D'04'*D'24')+D'00'	;scale=11bin=096octave=04note=00
	retlw	(D'04'*D'24')+D'00'	;scale=11bin=097octave=04note=01
	retlw	(D'04'*D'24')+D'02'	;scale=11bin=098octave=04note=02
	retlw	(D'04'*D'24')+D'02'	;scale=11bin=099octave=04note=03
	retlw	(D'04'*D'24')+D'02'	;scale=11bin=100octave=04note=04
	retlw	(D'04'*D'24')+D'02'	;scale=11bin=101octave=04note=05
	retlw	(D'04'*D'24')+D'06'	;scale=11bin=102octave=04note=06
	retlw	(D'04'*D'24')+D'06'	;scale=11bin=103octave=04note=07
	retlw	(D'04'*D'24')+D'06'	;scale=11bin=104octave=04note=08
	retlw	(D'04'*D'24')+D'06'	;scale=11bin=105octave=04note=09
	retlw	(D'04'*D'24')+D'10'	;scale=11bin=106octave=04note=10
	retlw	(D'04'*D'24')+D'10'	;scale=11bin=107octave=04note=11
	retlw	(D'04'*D'24')+D'10'	;scale=11bin=108octave=04note=12
	retlw	(D'04'*D'24')+D'10'	;scale=11bin=109octave=04note=13
	retlw	(D'04'*D'24')+D'14'	;scale=11bin=110octave=04note=14
	retlw	(D'04'*D'24')+D'14'	;scale=11bin=111octave=04note=15
	retlw	(D'04'*D'24')+D'16'	;scale=11bin=112octave=04note=16
	retlw	(D'04'*D'24')+D'16'	;scale=11bin=113octave=04note=17
	retlw	(D'04'*D'24')+D'16'	;scale=11bin=114octave=04note=18
	retlw	(D'04'*D'24')+D'16'	;scale=11bin=115octave=04note=19
	retlw	(D'04'*D'24')+D'20'	;scale=11bin=116octave=04note=20
	retlw	(D'04'*D'24')+D'20'	;scale=11bin=117octave=04note=21
	retlw	(D'04'*D'24')+D'20'	;scale=11bin=118octave=04note=22
	retlw	(D'04'*D'24')+D'20'	;scale=11bin=119octave=04note=23
	retlw	(D'05'*D'24')+D'00'	;scale=11bin=120octave=05note=00
	retlw	(D'05'*D'24')+D'00'	;scale=11bin=121octave=05note=01
	retlw	(D'05'*D'24')+D'02'	;scale=11bin=122octave=05note=02
	retlw	(D'05'*D'24')+D'02'	;scale=11bin=123octave=05note=03
	retlw	(D'05'*D'24')+D'02'	;scale=11bin=124octave=05note=04
	retlw	(D'05'*D'24')+D'02'	;scale=11bin=125octave=05note=05
	retlw	(D'05'*D'24')+D'06'	;scale=11bin=126octave=05note=06
	retlw	(D'05'*D'24')+D'06'	;scale=11bin=127octave=05note=07
	retlw	(D'05'*D'24')+D'06'	;scale=11bin=128octave=05note=08
	retlw	(D'05'*D'24')+D'06'	;scale=11bin=129octave=05note=09
	retlw	(D'05'*D'24')+D'10'	;scale=11bin=130octave=05note=10
	retlw	(D'05'*D'24')+D'10'	;scale=11bin=131octave=05note=11
	retlw	(D'05'*D'24')+D'10'	;scale=11bin=132octave=05note=12
	retlw	(D'05'*D'24')+D'10'	;scale=11bin=133octave=05note=13
	retlw	(D'05'*D'24')+D'14'	;scale=11bin=134octave=05note=14
	retlw	(D'05'*D'24')+D'14'	;scale=11bin=135octave=05note=15
	retlw	(D'05'*D'24')+D'16'	;scale=11bin=136octave=05note=16
	retlw	(D'05'*D'24')+D'16'	;scale=11bin=137octave=05note=17
	retlw	(D'05'*D'24')+D'16'	;scale=11bin=138octave=05note=18
	retlw	(D'05'*D'24')+D'16'	;scale=11bin=139octave=05note=19
	retlw	(D'05'*D'24')+D'20'	;scale=11bin=140octave=05note=20
	retlw	(D'05'*D'24')+D'20'	;scale=11bin=141octave=05note=21
	retlw	(D'05'*D'24')+D'20'	;scale=11bin=142octave=05note=22
	retlw	(D'05'*D'24')+D'20'	;scale=11bin=143octave=05note=23
	retlw	(D'06'*D'24')+D'00'	;scale=11bin=144octave=06note=00
	retlw	(D'06'*D'24')+D'00'	;scale=11bin=145octave=06note=01
	retlw	(D'06'*D'24')+D'02'	;scale=11bin=146octave=06note=02
	retlw	(D'06'*D'24')+D'02'	;scale=11bin=147octave=06note=03
	retlw	(D'06'*D'24')+D'02'	;scale=11bin=148octave=06note=04
	retlw	(D'06'*D'24')+D'02'	;scale=11bin=149octave=06note=05
	retlw	(D'06'*D'24')+D'06'	;scale=11bin=150octave=06note=06
	retlw	(D'06'*D'24')+D'06'	;scale=11bin=151octave=06note=07
	retlw	(D'06'*D'24')+D'06'	;scale=11bin=152octave=06note=08
	retlw	(D'06'*D'24')+D'06'	;scale=11bin=153octave=06note=09
	retlw	(D'06'*D'24')+D'10'	;scale=11bin=154octave=06note=10
	retlw	(D'06'*D'24')+D'10'	;scale=11bin=155octave=06note=11
	retlw	(D'06'*D'24')+D'10'	;scale=11bin=156octave=06note=12
	retlw	(D'06'*D'24')+D'10'	;scale=11bin=157octave=06note=13
	retlw	(D'06'*D'24')+D'14'	;scale=11bin=158octave=06note=14
	retlw	(D'06'*D'24')+D'14'	;scale=11bin=159octave=06note=15
	retlw	(D'06'*D'24')+D'16'	;scale=11bin=160octave=06note=16
	retlw	(D'06'*D'24')+D'16'	;scale=11bin=161octave=06note=17
	retlw	(D'06'*D'24')+D'16'	;scale=11bin=162octave=06note=18
	retlw	(D'06'*D'24')+D'16'	;scale=11bin=163octave=06note=19
	retlw	(D'06'*D'24')+D'20'	;scale=11bin=164octave=06note=20
	retlw	(D'06'*D'24')+D'20'	;scale=11bin=165octave=06note=21
	retlw	(D'06'*D'24')+D'20'	;scale=11bin=166octave=06note=22
	retlw	(D'06'*D'24')+D'20'	;scale=11bin=167octave=06note=23
	retlw	(D'07'*D'24')+D'00'	;scale=11bin=168octave=07note=00
	retlw	(D'07'*D'24')+D'00'	;scale=11bin=169octave=07note=01
	retlw	(D'07'*D'24')+D'02'	;scale=11bin=170octave=07note=02
	retlw	(D'07'*D'24')+D'02'	;scale=11bin=171octave=07note=03
	retlw	(D'07'*D'24')+D'02'	;scale=11bin=172octave=07note=04
	retlw	(D'07'*D'24')+D'02'	;scale=11bin=173octave=07note=05
	retlw	(D'07'*D'24')+D'06'	;scale=11bin=174octave=07note=06
	retlw	(D'07'*D'24')+D'06'	;scale=11bin=175octave=07note=07
	retlw	(D'07'*D'24')+D'06'	;scale=11bin=176octave=07note=08
	retlw	(D'07'*D'24')+D'06'	;scale=11bin=177octave=07note=09
	retlw	(D'07'*D'24')+D'10'	;scale=11bin=178octave=07note=10
	retlw	(D'07'*D'24')+D'10'	;scale=11bin=179octave=07note=11
	retlw	(D'07'*D'24')+D'10'	;scale=11bin=180octave=07note=12
	retlw	(D'07'*D'24')+D'10'	;scale=11bin=181octave=07note=13
	retlw	(D'07'*D'24')+D'14'	;scale=11bin=182octave=07note=14
	retlw	(D'07'*D'24')+D'14'	;scale=11bin=183octave=07note=15
	retlw	(D'07'*D'24')+D'16'	;scale=11bin=184octave=07note=16
	retlw	(D'07'*D'24')+D'16'	;scale=11bin=185octave=07note=17
	retlw	(D'07'*D'24')+D'16'	;scale=11bin=186octave=07note=18
	retlw	(D'07'*D'24')+D'16'	;scale=11bin=187octave=07note=19
	retlw	(D'07'*D'24')+D'20'	;scale=11bin=188octave=07note=20
	retlw	(D'07'*D'24')+D'20'	;scale=11bin=189octave=07note=21
	retlw	(D'07'*D'24')+D'20'	;scale=11bin=190octave=07note=22
	retlw	(D'07'*D'24')+D'20'	;scale=11bin=191octave=07note=23
	retlw	(D'08'*D'24')+D'00'	;scale=11bin=192octave=08note=00
	retlw	(D'08'*D'24')+D'00'	;scale=11bin=193octave=08note=01
	retlw	(D'08'*D'24')+D'02'	;scale=11bin=194octave=08note=02
	retlw	(D'08'*D'24')+D'02'	;scale=11bin=195octave=08note=03
	retlw	(D'08'*D'24')+D'02'	;scale=11bin=196octave=08note=04
	retlw	(D'08'*D'24')+D'02'	;scale=11bin=197octave=08note=05
	retlw	(D'08'*D'24')+D'06'	;scale=11bin=198octave=08note=06
	retlw	(D'08'*D'24')+D'06'	;scale=11bin=199octave=08note=07
	retlw	(D'08'*D'24')+D'06'	;scale=11bin=200octave=08note=08
	retlw	(D'08'*D'24')+D'06'	;scale=11bin=201octave=08note=09
	retlw	(D'08'*D'24')+D'10'	;scale=11bin=202octave=08note=10
	retlw	(D'08'*D'24')+D'10'	;scale=11bin=203octave=08note=11
	retlw	(D'08'*D'24')+D'10'	;scale=11bin=204octave=08note=12
	retlw	(D'08'*D'24')+D'10'	;scale=11bin=205octave=08note=13
	retlw	(D'08'*D'24')+D'14'	;scale=11bin=206octave=08note=14
	retlw	(D'08'*D'24')+D'14'	;scale=11bin=207octave=08note=15
	retlw	(D'08'*D'24')+D'16'	;scale=11bin=208octave=08note=16
	retlw	(D'08'*D'24')+D'16'	;scale=11bin=209octave=08note=17
	retlw	(D'08'*D'24')+D'16'	;scale=11bin=210octave=08note=18
	retlw	(D'08'*D'24')+D'16'	;scale=11bin=211octave=08note=19
	retlw	(D'08'*D'24')+D'20'	;scale=11bin=212octave=08note=20
	retlw	(D'08'*D'24')+D'20'	;scale=11bin=213octave=08note=21
	retlw	(D'08'*D'24')+D'20'	;scale=11bin=214octave=08note=22
	retlw	(D'08'*D'24')+D'20'	;scale=11bin=215octave=08note=23
	retlw	(D'09'*D'24')+D'00'	;scale=11bin=216octave=09note=00
	retlw	(D'09'*D'24')+D'00'	;scale=11bin=217octave=09note=01
	retlw	(D'09'*D'24')+D'02'	;scale=11bin=218octave=09note=02
	retlw	(D'09'*D'24')+D'02'	;scale=11bin=219octave=09note=03
	retlw	(D'09'*D'24')+D'02'	;scale=11bin=220octave=09note=04
	retlw	(D'09'*D'24')+D'02'	;scale=11bin=221octave=09note=05
	retlw	(D'09'*D'24')+D'06'	;scale=11bin=222octave=09note=06
	retlw	(D'09'*D'24')+D'06'	;scale=11bin=223octave=09note=07
	retlw	(D'09'*D'24')+D'06'	;scale=11bin=224octave=09note=08
	retlw	(D'09'*D'24')+D'06'	;scale=11bin=225octave=09note=09
	retlw	(D'09'*D'24')+D'10'	;scale=11bin=226octave=09note=10
	retlw	(D'09'*D'24')+D'10'	;scale=11bin=227octave=09note=11
	retlw	(D'09'*D'24')+D'10'	;scale=11bin=228octave=09note=12
	retlw	(D'09'*D'24')+D'10'	;scale=11bin=229octave=09note=13
	retlw	(D'09'*D'24')+D'14'	;scale=11bin=230octave=09note=14
	retlw	(D'09'*D'24')+D'14'	;scale=11bin=231octave=09note=15
	retlw	(D'09'*D'24')+D'16'	;scale=11bin=232octave=09note=16
	retlw	(D'09'*D'24')+D'16'	;scale=11bin=233octave=09note=17
	retlw	(D'09'*D'24')+D'16'	;scale=11bin=234octave=09note=18
	retlw	(D'09'*D'24')+D'16'	;scale=11bin=235octave=09note=19
	retlw	(D'09'*D'24')+D'20'	;scale=11bin=236octave=09note=20
	retlw	(D'09'*D'24')+D'20'	;scale=11bin=237octave=09note=21
	retlw	(D'09'*D'24')+D'20'	;scale=11bin=238octave=09note=22
	retlw	(D'09'*D'24')+D'20'	;scale=11bin=239octave=09note=23
	retlw	(D'10'*D'24')+D'00'	;scale=11bin=240octave=10note=00
	retlw	(D'10'*D'24')+D'00'	;scale=11bin=241octave=10note=01
	retlw	(D'10'*D'24')+D'00'	;scale=11bin=242octave=10note=02
	retlw	(D'10'*D'24')+D'00'	;scale=11bin=243octave=10note=03
	retlw	(D'10'*D'24')+D'00'	;scale=11bin=244octave=10note=04
	retlw	(D'10'*D'24')+D'00'	;scale=11bin=245octave=10note=05
	retlw	(D'10'*D'24')+D'00'	;scale=11bin=246octave=10note=06
	retlw	(D'10'*D'24')+D'00'	;scale=11bin=247octave=10note=07
	retlw	(D'10'*D'24')+D'00'	;scale=11bin=248octave=10note=08
	retlw	(D'10'*D'24')+D'00'	;scale=11bin=249octave=10note=09
	retlw	(D'10'*D'24')+D'00'	;scale=11bin=250octave=10note=10
	retlw	(D'10'*D'24')+D'00'	;scale=11bin=251octave=10note=11
	retlw	(D'10'*D'24')+D'00'	;scale=11bin=252octave=10note=12
	retlw	(D'10'*D'24')+D'00'	;scale=11bin=253octave=10note=13
	retlw	(D'10'*D'24')+D'00'	;scale=11bin=254octave=10note=14
	retlw	(D'10'*D'24')+D'00'	;scale=11bin=255octave=10note=15

;	Phrygian Dominant look-up table
	org	PhrygD		;Phrygian Dominant look-up table
	retlw	(D'00'*D'24')+D'00'	;scale=12bin=000octave=00note=00
	retlw	(D'00'*D'24')+D'00'	;scale=12bin=001octave=00note=01
	retlw	(D'00'*D'24')+D'02'	;scale=12bin=002octave=00note=02
	retlw	(D'00'*D'24')+D'02'	;scale=12bin=003octave=00note=03
	retlw	(D'00'*D'24')+D'02'	;scale=12bin=004octave=00note=04
	retlw	(D'00'*D'24')+D'02'	;scale=12bin=005octave=00note=05
	retlw	(D'00'*D'24')+D'02'	;scale=12bin=006octave=00note=06
	retlw	(D'00'*D'24')+D'02'	;scale=12bin=007octave=00note=07
	retlw	(D'00'*D'24')+D'08'	;scale=12bin=008octave=00note=08
	retlw	(D'00'*D'24')+D'08'	;scale=12bin=009octave=00note=09
	retlw	(D'00'*D'24')+D'10'	;scale=12bin=010octave=00note=10
	retlw	(D'00'*D'24')+D'10'	;scale=12bin=011octave=00note=11
	retlw	(D'00'*D'24')+D'10'	;scale=12bin=012octave=00note=12
	retlw	(D'00'*D'24')+D'10'	;scale=12bin=013octave=00note=13
	retlw	(D'00'*D'24')+D'14'	;scale=12bin=014octave=00note=14
	retlw	(D'00'*D'24')+D'14'	;scale=12bin=015octave=00note=15
	retlw	(D'00'*D'24')+D'16'	;scale=12bin=016octave=00note=16
	retlw	(D'00'*D'24')+D'16'	;scale=12bin=017octave=00note=17
	retlw	(D'00'*D'24')+D'16'	;scale=12bin=018octave=00note=18
	retlw	(D'00'*D'24')+D'16'	;scale=12bin=019octave=00note=19
	retlw	(D'00'*D'24')+D'20'	;scale=12bin=020octave=00note=20
	retlw	(D'00'*D'24')+D'20'	;scale=12bin=021octave=00note=21
	retlw	(D'00'*D'24')+D'20'	;scale=12bin=022octave=00note=22
	retlw	(D'00'*D'24')+D'20'	;scale=12bin=023octave=00note=23
	retlw	(D'01'*D'24')+D'00'	;scale=12bin=024octave=01note=00
	retlw	(D'01'*D'24')+D'00'	;scale=12bin=025octave=01note=01
	retlw	(D'01'*D'24')+D'02'	;scale=12bin=026octave=01note=02
	retlw	(D'01'*D'24')+D'02'	;scale=12bin=027octave=01note=03
	retlw	(D'01'*D'24')+D'02'	;scale=12bin=028octave=01note=04
	retlw	(D'01'*D'24')+D'02'	;scale=12bin=029octave=01note=05
	retlw	(D'01'*D'24')+D'02'	;scale=12bin=030octave=01note=06
	retlw	(D'01'*D'24')+D'02'	;scale=12bin=031octave=01note=07
	retlw	(D'01'*D'24')+D'08'	;scale=12bin=032octave=01note=08
	retlw	(D'01'*D'24')+D'08'	;scale=12bin=033octave=01note=09
	retlw	(D'01'*D'24')+D'10'	;scale=12bin=034octave=01note=10
	retlw	(D'01'*D'24')+D'10'	;scale=12bin=035octave=01note=11
	retlw	(D'01'*D'24')+D'10'	;scale=12bin=036octave=01note=12
	retlw	(D'01'*D'24')+D'10'	;scale=12bin=037octave=01note=13
	retlw	(D'01'*D'24')+D'14'	;scale=12bin=038octave=01note=14
	retlw	(D'01'*D'24')+D'14'	;scale=12bin=039octave=01note=15
	retlw	(D'01'*D'24')+D'16'	;scale=12bin=040octave=01note=16
	retlw	(D'01'*D'24')+D'16'	;scale=12bin=041octave=01note=17
	retlw	(D'01'*D'24')+D'16'	;scale=12bin=042octave=01note=18
	retlw	(D'01'*D'24')+D'16'	;scale=12bin=043octave=01note=19
	retlw	(D'01'*D'24')+D'20'	;scale=12bin=044octave=01note=20
	retlw	(D'01'*D'24')+D'20'	;scale=12bin=045octave=01note=21
	retlw	(D'01'*D'24')+D'20'	;scale=12bin=046octave=01note=22
	retlw	(D'01'*D'24')+D'20'	;scale=12bin=047octave=01note=23
	retlw	(D'02'*D'24')+D'00'	;scale=12bin=048octave=02note=00
	retlw	(D'02'*D'24')+D'00'	;scale=12bin=049octave=02note=01
	retlw	(D'02'*D'24')+D'02'	;scale=12bin=050octave=02note=02
	retlw	(D'02'*D'24')+D'02'	;scale=12bin=051octave=02note=03
	retlw	(D'02'*D'24')+D'02'	;scale=12bin=052octave=02note=04
	retlw	(D'02'*D'24')+D'02'	;scale=12bin=053octave=02note=05
	retlw	(D'02'*D'24')+D'02'	;scale=12bin=054octave=02note=06
	retlw	(D'02'*D'24')+D'02'	;scale=12bin=055octave=02note=07
	retlw	(D'02'*D'24')+D'08'	;scale=12bin=056octave=02note=08
	retlw	(D'02'*D'24')+D'08'	;scale=12bin=057octave=02note=09
	retlw	(D'02'*D'24')+D'10'	;scale=12bin=058octave=02note=10
	retlw	(D'02'*D'24')+D'10'	;scale=12bin=059octave=02note=11
	retlw	(D'02'*D'24')+D'10'	;scale=12bin=060octave=02note=12
	retlw	(D'02'*D'24')+D'10'	;scale=12bin=061octave=02note=13
	retlw	(D'02'*D'24')+D'14'	;scale=12bin=062octave=02note=14
	retlw	(D'02'*D'24')+D'14'	;scale=12bin=063octave=02note=15
	retlw	(D'02'*D'24')+D'16'	;scale=12bin=064octave=02note=16
	retlw	(D'02'*D'24')+D'16'	;scale=12bin=065octave=02note=17
	retlw	(D'02'*D'24')+D'16'	;scale=12bin=066octave=02note=18
	retlw	(D'02'*D'24')+D'16'	;scale=12bin=067octave=02note=19
	retlw	(D'02'*D'24')+D'20'	;scale=12bin=068octave=02note=20
	retlw	(D'02'*D'24')+D'20'	;scale=12bin=069octave=02note=21
	retlw	(D'02'*D'24')+D'20'	;scale=12bin=070octave=02note=22
	retlw	(D'02'*D'24')+D'20'	;scale=12bin=071octave=02note=23
	retlw	(D'03'*D'24')+D'00'	;scale=12bin=072octave=03note=00
	retlw	(D'03'*D'24')+D'00'	;scale=12bin=073octave=03note=01
	retlw	(D'03'*D'24')+D'02'	;scale=12bin=074octave=03note=02
	retlw	(D'03'*D'24')+D'02'	;scale=12bin=075octave=03note=03
	retlw	(D'03'*D'24')+D'02'	;scale=12bin=076octave=03note=04
	retlw	(D'03'*D'24')+D'02'	;scale=12bin=077octave=03note=05
	retlw	(D'03'*D'24')+D'02'	;scale=12bin=078octave=03note=06
	retlw	(D'03'*D'24')+D'02'	;scale=12bin=079octave=03note=07
	retlw	(D'03'*D'24')+D'08'	;scale=12bin=080octave=03note=08
	retlw	(D'03'*D'24')+D'08'	;scale=12bin=081octave=03note=09
	retlw	(D'03'*D'24')+D'10'	;scale=12bin=082octave=03note=10
	retlw	(D'03'*D'24')+D'10'	;scale=12bin=083octave=03note=11
	retlw	(D'03'*D'24')+D'10'	;scale=12bin=084octave=03note=12
	retlw	(D'03'*D'24')+D'10'	;scale=12bin=085octave=03note=13
	retlw	(D'03'*D'24')+D'14'	;scale=12bin=086octave=03note=14
	retlw	(D'03'*D'24')+D'14'	;scale=12bin=087octave=03note=15
	retlw	(D'03'*D'24')+D'16'	;scale=12bin=088octave=03note=16
	retlw	(D'03'*D'24')+D'16'	;scale=12bin=089octave=03note=17
	retlw	(D'03'*D'24')+D'16'	;scale=12bin=090octave=03note=18
	retlw	(D'03'*D'24')+D'16'	;scale=12bin=091octave=03note=19
	retlw	(D'03'*D'24')+D'20'	;scale=12bin=092octave=03note=20
	retlw	(D'03'*D'24')+D'20'	;scale=12bin=093octave=03note=21
	retlw	(D'03'*D'24')+D'20'	;scale=12bin=094octave=03note=22
	retlw	(D'03'*D'24')+D'20'	;scale=12bin=095octave=03note=23
	retlw	(D'04'*D'24')+D'00'	;scale=12bin=096octave=04note=00
	retlw	(D'04'*D'24')+D'00'	;scale=12bin=097octave=04note=01
	retlw	(D'04'*D'24')+D'02'	;scale=12bin=098octave=04note=02
	retlw	(D'04'*D'24')+D'02'	;scale=12bin=099octave=04note=03
	retlw	(D'04'*D'24')+D'02'	;scale=12bin=100octave=04note=04
	retlw	(D'04'*D'24')+D'02'	;scale=12bin=101octave=04note=05
	retlw	(D'04'*D'24')+D'02'	;scale=12bin=102octave=04note=06
	retlw	(D'04'*D'24')+D'02'	;scale=12bin=103octave=04note=07
	retlw	(D'04'*D'24')+D'08'	;scale=12bin=104octave=04note=08
	retlw	(D'04'*D'24')+D'08'	;scale=12bin=105octave=04note=09
	retlw	(D'04'*D'24')+D'10'	;scale=12bin=106octave=04note=10
	retlw	(D'04'*D'24')+D'10'	;scale=12bin=107octave=04note=11
	retlw	(D'04'*D'24')+D'10'	;scale=12bin=108octave=04note=12
	retlw	(D'04'*D'24')+D'10'	;scale=12bin=109octave=04note=13
	retlw	(D'04'*D'24')+D'14'	;scale=12bin=110octave=04note=14
	retlw	(D'04'*D'24')+D'14'	;scale=12bin=111octave=04note=15
	retlw	(D'04'*D'24')+D'16'	;scale=12bin=112octave=04note=16
	retlw	(D'04'*D'24')+D'16'	;scale=12bin=113octave=04note=17
	retlw	(D'04'*D'24')+D'16'	;scale=12bin=114octave=04note=18
	retlw	(D'04'*D'24')+D'16'	;scale=12bin=115octave=04note=19
	retlw	(D'04'*D'24')+D'20'	;scale=12bin=116octave=04note=20
	retlw	(D'04'*D'24')+D'20'	;scale=12bin=117octave=04note=21
	retlw	(D'04'*D'24')+D'20'	;scale=12bin=118octave=04note=22
	retlw	(D'04'*D'24')+D'20'	;scale=12bin=119octave=04note=23
	retlw	(D'05'*D'24')+D'00'	;scale=12bin=120octave=05note=00
	retlw	(D'05'*D'24')+D'00'	;scale=12bin=121octave=05note=01
	retlw	(D'05'*D'24')+D'02'	;scale=12bin=122octave=05note=02
	retlw	(D'05'*D'24')+D'02'	;scale=12bin=123octave=05note=03
	retlw	(D'05'*D'24')+D'02'	;scale=12bin=124octave=05note=04
	retlw	(D'05'*D'24')+D'02'	;scale=12bin=125octave=05note=05
	retlw	(D'05'*D'24')+D'02'	;scale=12bin=126octave=05note=06
	retlw	(D'05'*D'24')+D'02'	;scale=12bin=127octave=05note=07
	retlw	(D'05'*D'24')+D'08'	;scale=12bin=128octave=05note=08
	retlw	(D'05'*D'24')+D'08'	;scale=12bin=129octave=05note=09
	retlw	(D'05'*D'24')+D'10'	;scale=12bin=130octave=05note=10
	retlw	(D'05'*D'24')+D'10'	;scale=12bin=131octave=05note=11
	retlw	(D'05'*D'24')+D'10'	;scale=12bin=132octave=05note=12
	retlw	(D'05'*D'24')+D'10'	;scale=12bin=133octave=05note=13
	retlw	(D'05'*D'24')+D'14'	;scale=12bin=134octave=05note=14
	retlw	(D'05'*D'24')+D'14'	;scale=12bin=135octave=05note=15
	retlw	(D'05'*D'24')+D'16'	;scale=12bin=136octave=05note=16
	retlw	(D'05'*D'24')+D'16'	;scale=12bin=137octave=05note=17
	retlw	(D'05'*D'24')+D'16'	;scale=12bin=138octave=05note=18
	retlw	(D'05'*D'24')+D'16'	;scale=12bin=139octave=05note=19
	retlw	(D'05'*D'24')+D'20'	;scale=12bin=140octave=05note=20
	retlw	(D'05'*D'24')+D'20'	;scale=12bin=141octave=05note=21
	retlw	(D'05'*D'24')+D'20'	;scale=12bin=142octave=05note=22
	retlw	(D'05'*D'24')+D'20'	;scale=12bin=143octave=05note=23
	retlw	(D'06'*D'24')+D'00'	;scale=12bin=144octave=06note=00
	retlw	(D'06'*D'24')+D'00'	;scale=12bin=145octave=06note=01
	retlw	(D'06'*D'24')+D'02'	;scale=12bin=146octave=06note=02
	retlw	(D'06'*D'24')+D'02'	;scale=12bin=147octave=06note=03
	retlw	(D'06'*D'24')+D'02'	;scale=12bin=148octave=06note=04
	retlw	(D'06'*D'24')+D'02'	;scale=12bin=149octave=06note=05
	retlw	(D'06'*D'24')+D'02'	;scale=12bin=150octave=06note=06
	retlw	(D'06'*D'24')+D'02'	;scale=12bin=151octave=06note=07
	retlw	(D'06'*D'24')+D'08'	;scale=12bin=152octave=06note=08
	retlw	(D'06'*D'24')+D'08'	;scale=12bin=153octave=06note=09
	retlw	(D'06'*D'24')+D'10'	;scale=12bin=154octave=06note=10
	retlw	(D'06'*D'24')+D'10'	;scale=12bin=155octave=06note=11
	retlw	(D'06'*D'24')+D'10'	;scale=12bin=156octave=06note=12
	retlw	(D'06'*D'24')+D'10'	;scale=12bin=157octave=06note=13
	retlw	(D'06'*D'24')+D'14'	;scale=12bin=158octave=06note=14
	retlw	(D'06'*D'24')+D'14'	;scale=12bin=159octave=06note=15
	retlw	(D'06'*D'24')+D'16'	;scale=12bin=160octave=06note=16
	retlw	(D'06'*D'24')+D'16'	;scale=12bin=161octave=06note=17
	retlw	(D'06'*D'24')+D'16'	;scale=12bin=162octave=06note=18
	retlw	(D'06'*D'24')+D'16'	;scale=12bin=163octave=06note=19
	retlw	(D'06'*D'24')+D'20'	;scale=12bin=164octave=06note=20
	retlw	(D'06'*D'24')+D'20'	;scale=12bin=165octave=06note=21
	retlw	(D'06'*D'24')+D'20'	;scale=12bin=166octave=06note=22
	retlw	(D'06'*D'24')+D'20'	;scale=12bin=167octave=06note=23
	retlw	(D'07'*D'24')+D'00'	;scale=12bin=168octave=07note=00
	retlw	(D'07'*D'24')+D'00'	;scale=12bin=169octave=07note=01
	retlw	(D'07'*D'24')+D'02'	;scale=12bin=170octave=07note=02
	retlw	(D'07'*D'24')+D'02'	;scale=12bin=171octave=07note=03
	retlw	(D'07'*D'24')+D'02'	;scale=12bin=172octave=07note=04
	retlw	(D'07'*D'24')+D'02'	;scale=12bin=173octave=07note=05
	retlw	(D'07'*D'24')+D'02'	;scale=12bin=174octave=07note=06
	retlw	(D'07'*D'24')+D'02'	;scale=12bin=175octave=07note=07
	retlw	(D'07'*D'24')+D'08'	;scale=12bin=176octave=07note=08
	retlw	(D'07'*D'24')+D'08'	;scale=12bin=177octave=07note=09
	retlw	(D'07'*D'24')+D'10'	;scale=12bin=178octave=07note=10
	retlw	(D'07'*D'24')+D'10'	;scale=12bin=179octave=07note=11
	retlw	(D'07'*D'24')+D'10'	;scale=12bin=180octave=07note=12
	retlw	(D'07'*D'24')+D'10'	;scale=12bin=181octave=07note=13
	retlw	(D'07'*D'24')+D'14'	;scale=12bin=182octave=07note=14
	retlw	(D'07'*D'24')+D'14'	;scale=12bin=183octave=07note=15
	retlw	(D'07'*D'24')+D'16'	;scale=12bin=184octave=07note=16
	retlw	(D'07'*D'24')+D'16'	;scale=12bin=185octave=07note=17
	retlw	(D'07'*D'24')+D'16'	;scale=12bin=186octave=07note=18
	retlw	(D'07'*D'24')+D'16'	;scale=12bin=187octave=07note=19
	retlw	(D'07'*D'24')+D'20'	;scale=12bin=188octave=07note=20
	retlw	(D'07'*D'24')+D'20'	;scale=12bin=189octave=07note=21
	retlw	(D'07'*D'24')+D'20'	;scale=12bin=190octave=07note=22
	retlw	(D'07'*D'24')+D'20'	;scale=12bin=191octave=07note=23
	retlw	(D'08'*D'24')+D'00'	;scale=12bin=192octave=08note=00
	retlw	(D'08'*D'24')+D'00'	;scale=12bin=193octave=08note=01
	retlw	(D'08'*D'24')+D'02'	;scale=12bin=194octave=08note=02
	retlw	(D'08'*D'24')+D'02'	;scale=12bin=195octave=08note=03
	retlw	(D'08'*D'24')+D'02'	;scale=12bin=196octave=08note=04
	retlw	(D'08'*D'24')+D'02'	;scale=12bin=197octave=08note=05
	retlw	(D'08'*D'24')+D'02'	;scale=12bin=198octave=08note=06
	retlw	(D'08'*D'24')+D'02'	;scale=12bin=199octave=08note=07
	retlw	(D'08'*D'24')+D'08'	;scale=12bin=200octave=08note=08
	retlw	(D'08'*D'24')+D'08'	;scale=12bin=201octave=08note=09
	retlw	(D'08'*D'24')+D'10'	;scale=12bin=202octave=08note=10
	retlw	(D'08'*D'24')+D'10'	;scale=12bin=203octave=08note=11
	retlw	(D'08'*D'24')+D'10'	;scale=12bin=204octave=08note=12
	retlw	(D'08'*D'24')+D'10'	;scale=12bin=205octave=08note=13
	retlw	(D'08'*D'24')+D'14'	;scale=12bin=206octave=08note=14
	retlw	(D'08'*D'24')+D'14'	;scale=12bin=207octave=08note=15
	retlw	(D'08'*D'24')+D'16'	;scale=12bin=208octave=08note=16
	retlw	(D'08'*D'24')+D'16'	;scale=12bin=209octave=08note=17
	retlw	(D'08'*D'24')+D'16'	;scale=12bin=210octave=08note=18
	retlw	(D'08'*D'24')+D'16'	;scale=12bin=211octave=08note=19
	retlw	(D'08'*D'24')+D'20'	;scale=12bin=212octave=08note=20
	retlw	(D'08'*D'24')+D'20'	;scale=12bin=213octave=08note=21
	retlw	(D'08'*D'24')+D'20'	;scale=12bin=214octave=08note=22
	retlw	(D'08'*D'24')+D'20'	;scale=12bin=215octave=08note=23
	retlw	(D'09'*D'24')+D'00'	;scale=12bin=216octave=09note=00
	retlw	(D'09'*D'24')+D'00'	;scale=12bin=217octave=09note=01
	retlw	(D'09'*D'24')+D'02'	;scale=12bin=218octave=09note=02
	retlw	(D'09'*D'24')+D'02'	;scale=12bin=219octave=09note=03
	retlw	(D'09'*D'24')+D'02'	;scale=12bin=220octave=09note=04
	retlw	(D'09'*D'24')+D'02'	;scale=12bin=221octave=09note=05
	retlw	(D'09'*D'24')+D'02'	;scale=12bin=222octave=09note=06
	retlw	(D'09'*D'24')+D'02'	;scale=12bin=223octave=09note=07
	retlw	(D'09'*D'24')+D'08'	;scale=12bin=224octave=09note=08
	retlw	(D'09'*D'24')+D'08'	;scale=12bin=225octave=09note=09
	retlw	(D'09'*D'24')+D'10'	;scale=12bin=226octave=09note=10
	retlw	(D'09'*D'24')+D'10'	;scale=12bin=227octave=09note=11
	retlw	(D'09'*D'24')+D'10'	;scale=12bin=228octave=09note=12
	retlw	(D'09'*D'24')+D'10'	;scale=12bin=229octave=09note=13
	retlw	(D'09'*D'24')+D'14'	;scale=12bin=230octave=09note=14
	retlw	(D'09'*D'24')+D'14'	;scale=12bin=231octave=09note=15
	retlw	(D'09'*D'24')+D'16'	;scale=12bin=232octave=09note=16
	retlw	(D'09'*D'24')+D'16'	;scale=12bin=233octave=09note=17
	retlw	(D'09'*D'24')+D'16'	;scale=12bin=234octave=09note=18
	retlw	(D'09'*D'24')+D'16'	;scale=12bin=235octave=09note=19
	retlw	(D'09'*D'24')+D'20'	;scale=12bin=236octave=09note=20
	retlw	(D'09'*D'24')+D'20'	;scale=12bin=237octave=09note=21
	retlw	(D'09'*D'24')+D'20'	;scale=12bin=238octave=09note=22
	retlw	(D'09'*D'24')+D'20'	;scale=12bin=239octave=09note=23
	retlw	(D'10'*D'24')+D'00'	;scale=12bin=240octave=10note=00
	retlw	(D'10'*D'24')+D'00'	;scale=12bin=241octave=10note=01
	retlw	(D'10'*D'24')+D'00'	;scale=12bin=242octave=10note=02
	retlw	(D'10'*D'24')+D'00'	;scale=12bin=243octave=10note=03
	retlw	(D'10'*D'24')+D'00'	;scale=12bin=244octave=10note=04
	retlw	(D'10'*D'24')+D'00'	;scale=12bin=245octave=10note=05
	retlw	(D'10'*D'24')+D'00'	;scale=12bin=246octave=10note=06
	retlw	(D'10'*D'24')+D'00'	;scale=12bin=247octave=10note=07
	retlw	(D'10'*D'24')+D'00'	;scale=12bin=248octave=10note=08
	retlw	(D'10'*D'24')+D'00'	;scale=12bin=249octave=10note=09
	retlw	(D'10'*D'24')+D'00'	;scale=12bin=250octave=10note=10
	retlw	(D'10'*D'24')+D'00'	;scale=12bin=251octave=10note=11
	retlw	(D'10'*D'24')+D'00'	;scale=12bin=252octave=10note=12
	retlw	(D'10'*D'24')+D'00'	;scale=12bin=253octave=10note=13
	retlw	(D'10'*D'24')+D'00'	;scale=12bin=254octave=10note=14
	retlw	(D'10'*D'24')+D'00'	;scale=12bin=255octave=10note=15

;	Balinese Pent look-up table
	org	BalineseP		;Balinese Pent look-up table
	retlw	(D'00'*D'24')+D'00'	;scale=13bin=000octave=00note=00
	retlw	(D'00'*D'24')+D'00'	;scale=13bin=001octave=00note=01
	retlw	(D'00'*D'24')+D'02'	;scale=13bin=002octave=00note=02
	retlw	(D'00'*D'24')+D'02'	;scale=13bin=003octave=00note=03
	retlw	(D'00'*D'24')+D'02'	;scale=13bin=004octave=00note=04
	retlw	(D'00'*D'24')+D'02'	;scale=13bin=005octave=00note=05
	retlw	(D'00'*D'24')+D'06'	;scale=13bin=006octave=00note=06
	retlw	(D'00'*D'24')+D'06'	;scale=13bin=007octave=00note=07
	retlw	(D'00'*D'24')+D'06'	;scale=13bin=008octave=00note=08
	retlw	(D'00'*D'24')+D'06'	;scale=13bin=009octave=00note=09
	retlw	(D'00'*D'24')+D'06'	;scale=13bin=010octave=00note=10
	retlw	(D'00'*D'24')+D'06'	;scale=13bin=011octave=00note=11
	retlw	(D'00'*D'24')+D'06'	;scale=13bin=012octave=00note=12
	retlw	(D'00'*D'24')+D'06'	;scale=13bin=013octave=00note=13
	retlw	(D'00'*D'24')+D'14'	;scale=13bin=014octave=00note=14
	retlw	(D'00'*D'24')+D'14'	;scale=13bin=015octave=00note=15
	retlw	(D'00'*D'24')+D'16'	;scale=13bin=016octave=00note=16
	retlw	(D'00'*D'24')+D'16'	;scale=13bin=017octave=00note=17
	retlw	(D'00'*D'24')+D'16'	;scale=13bin=018octave=00note=18
	retlw	(D'00'*D'24')+D'16'	;scale=13bin=019octave=00note=19
	retlw	(D'00'*D'24')+D'16'	;scale=13bin=020octave=00note=20
	retlw	(D'00'*D'24')+D'16'	;scale=13bin=021octave=00note=21
	retlw	(D'00'*D'24')+D'16'	;scale=13bin=022octave=00note=22
	retlw	(D'00'*D'24')+D'16'	;scale=13bin=023octave=00note=23
	retlw	(D'01'*D'24')+D'00'	;scale=13bin=024octave=01note=00
	retlw	(D'01'*D'24')+D'00'	;scale=13bin=025octave=01note=01
	retlw	(D'01'*D'24')+D'02'	;scale=13bin=026octave=01note=02
	retlw	(D'01'*D'24')+D'02'	;scale=13bin=027octave=01note=03
	retlw	(D'01'*D'24')+D'02'	;scale=13bin=028octave=01note=04
	retlw	(D'01'*D'24')+D'02'	;scale=13bin=029octave=01note=05
	retlw	(D'01'*D'24')+D'06'	;scale=13bin=030octave=01note=06
	retlw	(D'01'*D'24')+D'06'	;scale=13bin=031octave=01note=07
	retlw	(D'01'*D'24')+D'06'	;scale=13bin=032octave=01note=08
	retlw	(D'01'*D'24')+D'06'	;scale=13bin=033octave=01note=09
	retlw	(D'01'*D'24')+D'06'	;scale=13bin=034octave=01note=10
	retlw	(D'01'*D'24')+D'06'	;scale=13bin=035octave=01note=11
	retlw	(D'01'*D'24')+D'06'	;scale=13bin=036octave=01note=12
	retlw	(D'01'*D'24')+D'06'	;scale=13bin=037octave=01note=13
	retlw	(D'01'*D'24')+D'14'	;scale=13bin=038octave=01note=14
	retlw	(D'01'*D'24')+D'14'	;scale=13bin=039octave=01note=15
	retlw	(D'01'*D'24')+D'16'	;scale=13bin=040octave=01note=16
	retlw	(D'01'*D'24')+D'16'	;scale=13bin=041octave=01note=17
	retlw	(D'01'*D'24')+D'16'	;scale=13bin=042octave=01note=18
	retlw	(D'01'*D'24')+D'16'	;scale=13bin=043octave=01note=19
	retlw	(D'01'*D'24')+D'16'	;scale=13bin=044octave=01note=20
	retlw	(D'01'*D'24')+D'16'	;scale=13bin=045octave=01note=21
	retlw	(D'01'*D'24')+D'16'	;scale=13bin=046octave=01note=22
	retlw	(D'01'*D'24')+D'16'	;scale=13bin=047octave=01note=23
	retlw	(D'02'*D'24')+D'00'	;scale=13bin=048octave=02note=00
	retlw	(D'02'*D'24')+D'00'	;scale=13bin=049octave=02note=01
	retlw	(D'02'*D'24')+D'02'	;scale=13bin=050octave=02note=02
	retlw	(D'02'*D'24')+D'02'	;scale=13bin=051octave=02note=03
	retlw	(D'02'*D'24')+D'02'	;scale=13bin=052octave=02note=04
	retlw	(D'02'*D'24')+D'02'	;scale=13bin=053octave=02note=05
	retlw	(D'02'*D'24')+D'06'	;scale=13bin=054octave=02note=06
	retlw	(D'02'*D'24')+D'06'	;scale=13bin=055octave=02note=07
	retlw	(D'02'*D'24')+D'06'	;scale=13bin=056octave=02note=08
	retlw	(D'02'*D'24')+D'06'	;scale=13bin=057octave=02note=09
	retlw	(D'02'*D'24')+D'06'	;scale=13bin=058octave=02note=10
	retlw	(D'02'*D'24')+D'06'	;scale=13bin=059octave=02note=11
	retlw	(D'02'*D'24')+D'06'	;scale=13bin=060octave=02note=12
	retlw	(D'02'*D'24')+D'06'	;scale=13bin=061octave=02note=13
	retlw	(D'02'*D'24')+D'14'	;scale=13bin=062octave=02note=14
	retlw	(D'02'*D'24')+D'14'	;scale=13bin=063octave=02note=15
	retlw	(D'02'*D'24')+D'16'	;scale=13bin=064octave=02note=16
	retlw	(D'02'*D'24')+D'16'	;scale=13bin=065octave=02note=17
	retlw	(D'02'*D'24')+D'16'	;scale=13bin=066octave=02note=18
	retlw	(D'02'*D'24')+D'16'	;scale=13bin=067octave=02note=19
	retlw	(D'02'*D'24')+D'16'	;scale=13bin=068octave=02note=20
	retlw	(D'02'*D'24')+D'16'	;scale=13bin=069octave=02note=21
	retlw	(D'02'*D'24')+D'16'	;scale=13bin=070octave=02note=22
	retlw	(D'02'*D'24')+D'16'	;scale=13bin=071octave=02note=23
	retlw	(D'03'*D'24')+D'00'	;scale=13bin=072octave=03note=00
	retlw	(D'03'*D'24')+D'00'	;scale=13bin=073octave=03note=01
	retlw	(D'03'*D'24')+D'02'	;scale=13bin=074octave=03note=02
	retlw	(D'03'*D'24')+D'02'	;scale=13bin=075octave=03note=03
	retlw	(D'03'*D'24')+D'02'	;scale=13bin=076octave=03note=04
	retlw	(D'03'*D'24')+D'02'	;scale=13bin=077octave=03note=05
	retlw	(D'03'*D'24')+D'06'	;scale=13bin=078octave=03note=06
	retlw	(D'03'*D'24')+D'06'	;scale=13bin=079octave=03note=07
	retlw	(D'03'*D'24')+D'06'	;scale=13bin=080octave=03note=08
	retlw	(D'03'*D'24')+D'06'	;scale=13bin=081octave=03note=09
	retlw	(D'03'*D'24')+D'06'	;scale=13bin=082octave=03note=10
	retlw	(D'03'*D'24')+D'06'	;scale=13bin=083octave=03note=11
	retlw	(D'03'*D'24')+D'06'	;scale=13bin=084octave=03note=12
	retlw	(D'03'*D'24')+D'06'	;scale=13bin=085octave=03note=13
	retlw	(D'03'*D'24')+D'14'	;scale=13bin=086octave=03note=14
	retlw	(D'03'*D'24')+D'14'	;scale=13bin=087octave=03note=15
	retlw	(D'03'*D'24')+D'16'	;scale=13bin=088octave=03note=16
	retlw	(D'03'*D'24')+D'16'	;scale=13bin=089octave=03note=17
	retlw	(D'03'*D'24')+D'16'	;scale=13bin=090octave=03note=18
	retlw	(D'03'*D'24')+D'16'	;scale=13bin=091octave=03note=19
	retlw	(D'03'*D'24')+D'16'	;scale=13bin=092octave=03note=20
	retlw	(D'03'*D'24')+D'16'	;scale=13bin=093octave=03note=21
	retlw	(D'03'*D'24')+D'16'	;scale=13bin=094octave=03note=22
	retlw	(D'03'*D'24')+D'16'	;scale=13bin=095octave=03note=23
	retlw	(D'04'*D'24')+D'00'	;scale=13bin=096octave=04note=00
	retlw	(D'04'*D'24')+D'00'	;scale=13bin=097octave=04note=01
	retlw	(D'04'*D'24')+D'02'	;scale=13bin=098octave=04note=02
	retlw	(D'04'*D'24')+D'02'	;scale=13bin=099octave=04note=03
	retlw	(D'04'*D'24')+D'02'	;scale=13bin=100octave=04note=04
	retlw	(D'04'*D'24')+D'02'	;scale=13bin=101octave=04note=05
	retlw	(D'04'*D'24')+D'06'	;scale=13bin=102octave=04note=06
	retlw	(D'04'*D'24')+D'06'	;scale=13bin=103octave=04note=07
	retlw	(D'04'*D'24')+D'06'	;scale=13bin=104octave=04note=08
	retlw	(D'04'*D'24')+D'06'	;scale=13bin=105octave=04note=09
	retlw	(D'04'*D'24')+D'06'	;scale=13bin=106octave=04note=10
	retlw	(D'04'*D'24')+D'06'	;scale=13bin=107octave=04note=11
	retlw	(D'04'*D'24')+D'06'	;scale=13bin=108octave=04note=12
	retlw	(D'04'*D'24')+D'06'	;scale=13bin=109octave=04note=13
	retlw	(D'04'*D'24')+D'14'	;scale=13bin=110octave=04note=14
	retlw	(D'04'*D'24')+D'14'	;scale=13bin=111octave=04note=15
	retlw	(D'04'*D'24')+D'16'	;scale=13bin=112octave=04note=16
	retlw	(D'04'*D'24')+D'16'	;scale=13bin=113octave=04note=17
	retlw	(D'04'*D'24')+D'16'	;scale=13bin=114octave=04note=18
	retlw	(D'04'*D'24')+D'16'	;scale=13bin=115octave=04note=19
	retlw	(D'04'*D'24')+D'16'	;scale=13bin=116octave=04note=20
	retlw	(D'04'*D'24')+D'16'	;scale=13bin=117octave=04note=21
	retlw	(D'04'*D'24')+D'16'	;scale=13bin=118octave=04note=22
	retlw	(D'04'*D'24')+D'16'	;scale=13bin=119octave=04note=23
	retlw	(D'05'*D'24')+D'00'	;scale=13bin=120octave=05note=00
	retlw	(D'05'*D'24')+D'00'	;scale=13bin=121octave=05note=01
	retlw	(D'05'*D'24')+D'02'	;scale=13bin=122octave=05note=02
	retlw	(D'05'*D'24')+D'02'	;scale=13bin=123octave=05note=03
	retlw	(D'05'*D'24')+D'02'	;scale=13bin=124octave=05note=04
	retlw	(D'05'*D'24')+D'02'	;scale=13bin=125octave=05note=05
	retlw	(D'05'*D'24')+D'06'	;scale=13bin=126octave=05note=06
	retlw	(D'05'*D'24')+D'06'	;scale=13bin=127octave=05note=07
	retlw	(D'05'*D'24')+D'06'	;scale=13bin=128octave=05note=08
	retlw	(D'05'*D'24')+D'06'	;scale=13bin=129octave=05note=09
	retlw	(D'05'*D'24')+D'06'	;scale=13bin=130octave=05note=10
	retlw	(D'05'*D'24')+D'06'	;scale=13bin=131octave=05note=11
	retlw	(D'05'*D'24')+D'06'	;scale=13bin=132octave=05note=12
	retlw	(D'05'*D'24')+D'06'	;scale=13bin=133octave=05note=13
	retlw	(D'05'*D'24')+D'14'	;scale=13bin=134octave=05note=14
	retlw	(D'05'*D'24')+D'14'	;scale=13bin=135octave=05note=15
	retlw	(D'05'*D'24')+D'16'	;scale=13bin=136octave=05note=16
	retlw	(D'05'*D'24')+D'16'	;scale=13bin=137octave=05note=17
	retlw	(D'05'*D'24')+D'16'	;scale=13bin=138octave=05note=18
	retlw	(D'05'*D'24')+D'16'	;scale=13bin=139octave=05note=19
	retlw	(D'05'*D'24')+D'16'	;scale=13bin=140octave=05note=20
	retlw	(D'05'*D'24')+D'16'	;scale=13bin=141octave=05note=21
	retlw	(D'05'*D'24')+D'16'	;scale=13bin=142octave=05note=22
	retlw	(D'05'*D'24')+D'16'	;scale=13bin=143octave=05note=23
	retlw	(D'06'*D'24')+D'00'	;scale=13bin=144octave=06note=00
	retlw	(D'06'*D'24')+D'00'	;scale=13bin=145octave=06note=01
	retlw	(D'06'*D'24')+D'02'	;scale=13bin=146octave=06note=02
	retlw	(D'06'*D'24')+D'02'	;scale=13bin=147octave=06note=03
	retlw	(D'06'*D'24')+D'02'	;scale=13bin=148octave=06note=04
	retlw	(D'06'*D'24')+D'02'	;scale=13bin=149octave=06note=05
	retlw	(D'06'*D'24')+D'06'	;scale=13bin=150octave=06note=06
	retlw	(D'06'*D'24')+D'06'	;scale=13bin=151octave=06note=07
	retlw	(D'06'*D'24')+D'06'	;scale=13bin=152octave=06note=08
	retlw	(D'06'*D'24')+D'06'	;scale=13bin=153octave=06note=09
	retlw	(D'06'*D'24')+D'06'	;scale=13bin=154octave=06note=10
	retlw	(D'06'*D'24')+D'06'	;scale=13bin=155octave=06note=11
	retlw	(D'06'*D'24')+D'06'	;scale=13bin=156octave=06note=12
	retlw	(D'06'*D'24')+D'06'	;scale=13bin=157octave=06note=13
	retlw	(D'06'*D'24')+D'14'	;scale=13bin=158octave=06note=14
	retlw	(D'06'*D'24')+D'14'	;scale=13bin=159octave=06note=15
	retlw	(D'06'*D'24')+D'16'	;scale=13bin=160octave=06note=16
	retlw	(D'06'*D'24')+D'16'	;scale=13bin=161octave=06note=17
	retlw	(D'06'*D'24')+D'16'	;scale=13bin=162octave=06note=18
	retlw	(D'06'*D'24')+D'16'	;scale=13bin=163octave=06note=19
	retlw	(D'06'*D'24')+D'16'	;scale=13bin=164octave=06note=20
	retlw	(D'06'*D'24')+D'16'	;scale=13bin=165octave=06note=21
	retlw	(D'06'*D'24')+D'16'	;scale=13bin=166octave=06note=22
	retlw	(D'06'*D'24')+D'16'	;scale=13bin=167octave=06note=23
	retlw	(D'07'*D'24')+D'00'	;scale=13bin=168octave=07note=00
	retlw	(D'07'*D'24')+D'00'	;scale=13bin=169octave=07note=01
	retlw	(D'07'*D'24')+D'02'	;scale=13bin=170octave=07note=02
	retlw	(D'07'*D'24')+D'02'	;scale=13bin=171octave=07note=03
	retlw	(D'07'*D'24')+D'02'	;scale=13bin=172octave=07note=04
	retlw	(D'07'*D'24')+D'02'	;scale=13bin=173octave=07note=05
	retlw	(D'07'*D'24')+D'06'	;scale=13bin=174octave=07note=06
	retlw	(D'07'*D'24')+D'06'	;scale=13bin=175octave=07note=07
	retlw	(D'07'*D'24')+D'06'	;scale=13bin=176octave=07note=08
	retlw	(D'07'*D'24')+D'06'	;scale=13bin=177octave=07note=09
	retlw	(D'07'*D'24')+D'06'	;scale=13bin=178octave=07note=10
	retlw	(D'07'*D'24')+D'06'	;scale=13bin=179octave=07note=11
	retlw	(D'07'*D'24')+D'06'	;scale=13bin=180octave=07note=12
	retlw	(D'07'*D'24')+D'06'	;scale=13bin=181octave=07note=13
	retlw	(D'07'*D'24')+D'14'	;scale=13bin=182octave=07note=14
	retlw	(D'07'*D'24')+D'14'	;scale=13bin=183octave=07note=15
	retlw	(D'07'*D'24')+D'16'	;scale=13bin=184octave=07note=16
	retlw	(D'07'*D'24')+D'16'	;scale=13bin=185octave=07note=17
	retlw	(D'07'*D'24')+D'16'	;scale=13bin=186octave=07note=18
	retlw	(D'07'*D'24')+D'16'	;scale=13bin=187octave=07note=19
	retlw	(D'07'*D'24')+D'16'	;scale=13bin=188octave=07note=20
	retlw	(D'07'*D'24')+D'16'	;scale=13bin=189octave=07note=21
	retlw	(D'07'*D'24')+D'16'	;scale=13bin=190octave=07note=22
	retlw	(D'07'*D'24')+D'16'	;scale=13bin=191octave=07note=23
	retlw	(D'08'*D'24')+D'00'	;scale=13bin=192octave=08note=00
	retlw	(D'08'*D'24')+D'00'	;scale=13bin=193octave=08note=01
	retlw	(D'08'*D'24')+D'02'	;scale=13bin=194octave=08note=02
	retlw	(D'08'*D'24')+D'02'	;scale=13bin=195octave=08note=03
	retlw	(D'08'*D'24')+D'02'	;scale=13bin=196octave=08note=04
	retlw	(D'08'*D'24')+D'02'	;scale=13bin=197octave=08note=05
	retlw	(D'08'*D'24')+D'06'	;scale=13bin=198octave=08note=06
	retlw	(D'08'*D'24')+D'06'	;scale=13bin=199octave=08note=07
	retlw	(D'08'*D'24')+D'06'	;scale=13bin=200octave=08note=08
	retlw	(D'08'*D'24')+D'06'	;scale=13bin=201octave=08note=09
	retlw	(D'08'*D'24')+D'06'	;scale=13bin=202octave=08note=10
	retlw	(D'08'*D'24')+D'06'	;scale=13bin=203octave=08note=11
	retlw	(D'08'*D'24')+D'06'	;scale=13bin=204octave=08note=12
	retlw	(D'08'*D'24')+D'06'	;scale=13bin=205octave=08note=13
	retlw	(D'08'*D'24')+D'14'	;scale=13bin=206octave=08note=14
	retlw	(D'08'*D'24')+D'14'	;scale=13bin=207octave=08note=15
	retlw	(D'08'*D'24')+D'16'	;scale=13bin=208octave=08note=16
	retlw	(D'08'*D'24')+D'16'	;scale=13bin=209octave=08note=17
	retlw	(D'08'*D'24')+D'16'	;scale=13bin=210octave=08note=18
	retlw	(D'08'*D'24')+D'16'	;scale=13bin=211octave=08note=19
	retlw	(D'08'*D'24')+D'16'	;scale=13bin=212octave=08note=20
	retlw	(D'08'*D'24')+D'16'	;scale=13bin=213octave=08note=21
	retlw	(D'08'*D'24')+D'16'	;scale=13bin=214octave=08note=22
	retlw	(D'08'*D'24')+D'16'	;scale=13bin=215octave=08note=23
	retlw	(D'09'*D'24')+D'00'	;scale=13bin=216octave=09note=00
	retlw	(D'09'*D'24')+D'00'	;scale=13bin=217octave=09note=01
	retlw	(D'09'*D'24')+D'02'	;scale=13bin=218octave=09note=02
	retlw	(D'09'*D'24')+D'02'	;scale=13bin=219octave=09note=03
	retlw	(D'09'*D'24')+D'02'	;scale=13bin=220octave=09note=04
	retlw	(D'09'*D'24')+D'02'	;scale=13bin=221octave=09note=05
	retlw	(D'09'*D'24')+D'06'	;scale=13bin=222octave=09note=06
	retlw	(D'09'*D'24')+D'06'	;scale=13bin=223octave=09note=07
	retlw	(D'09'*D'24')+D'06'	;scale=13bin=224octave=09note=08
	retlw	(D'09'*D'24')+D'06'	;scale=13bin=225octave=09note=09
	retlw	(D'09'*D'24')+D'06'	;scale=13bin=226octave=09note=10
	retlw	(D'09'*D'24')+D'06'	;scale=13bin=227octave=09note=11
	retlw	(D'09'*D'24')+D'06'	;scale=13bin=228octave=09note=12
	retlw	(D'09'*D'24')+D'06'	;scale=13bin=229octave=09note=13
	retlw	(D'09'*D'24')+D'14'	;scale=13bin=230octave=09note=14
	retlw	(D'09'*D'24')+D'14'	;scale=13bin=231octave=09note=15
	retlw	(D'09'*D'24')+D'16'	;scale=13bin=232octave=09note=16
	retlw	(D'09'*D'24')+D'16'	;scale=13bin=233octave=09note=17
	retlw	(D'09'*D'24')+D'16'	;scale=13bin=234octave=09note=18
	retlw	(D'09'*D'24')+D'16'	;scale=13bin=235octave=09note=19
	retlw	(D'09'*D'24')+D'16'	;scale=13bin=236octave=09note=20
	retlw	(D'09'*D'24')+D'16'	;scale=13bin=237octave=09note=21
	retlw	(D'09'*D'24')+D'16'	;scale=13bin=238octave=09note=22
	retlw	(D'09'*D'24')+D'16'	;scale=13bin=239octave=09note=23
	retlw	(D'10'*D'24')+D'00'	;scale=13bin=240octave=10note=00
	retlw	(D'10'*D'24')+D'00'	;scale=13bin=241octave=10note=01
	retlw	(D'10'*D'24')+D'00'	;scale=13bin=242octave=10note=02
	retlw	(D'10'*D'24')+D'00'	;scale=13bin=243octave=10note=03
	retlw	(D'10'*D'24')+D'00'	;scale=13bin=244octave=10note=04
	retlw	(D'10'*D'24')+D'00'	;scale=13bin=245octave=10note=05
	retlw	(D'10'*D'24')+D'00'	;scale=13bin=246octave=10note=06
	retlw	(D'10'*D'24')+D'00'	;scale=13bin=247octave=10note=07
	retlw	(D'10'*D'24')+D'00'	;scale=13bin=248octave=10note=08
	retlw	(D'10'*D'24')+D'00'	;scale=13bin=249octave=10note=09
	retlw	(D'10'*D'24')+D'00'	;scale=13bin=250octave=10note=10
	retlw	(D'10'*D'24')+D'00'	;scale=13bin=251octave=10note=11
	retlw	(D'10'*D'24')+D'00'	;scale=13bin=252octave=10note=12
	retlw	(D'10'*D'24')+D'00'	;scale=13bin=253octave=10note=13
	retlw	(D'10'*D'24')+D'00'	;scale=13bin=254octave=10note=14
	retlw	(D'10'*D'24')+D'00'	;scale=13bin=255octave=10note=15

;	Java look-up table
	org	Java		;Java look-up table
	retlw	(D'00'*D'24')+D'00'	;scale=14bin=000octave=00note=00
	retlw	(D'00'*D'24')+D'00'	;scale=14bin=001octave=00note=01
	retlw	(D'00'*D'24')+D'02'	;scale=14bin=002octave=00note=02
	retlw	(D'00'*D'24')+D'02'	;scale=14bin=003octave=00note=03
	retlw	(D'00'*D'24')+D'02'	;scale=14bin=004octave=00note=04
	retlw	(D'00'*D'24')+D'02'	;scale=14bin=005octave=00note=05
	retlw	(D'00'*D'24')+D'06'	;scale=14bin=006octave=00note=06
	retlw	(D'00'*D'24')+D'06'	;scale=14bin=007octave=00note=07
	retlw	(D'00'*D'24')+D'06'	;scale=14bin=008octave=00note=08
	retlw	(D'00'*D'24')+D'06'	;scale=14bin=009octave=00note=09
	retlw	(D'00'*D'24')+D'10'	;scale=14bin=010octave=00note=10
	retlw	(D'00'*D'24')+D'10'	;scale=14bin=011octave=00note=11
	retlw	(D'00'*D'24')+D'10'	;scale=14bin=012octave=00note=12
	retlw	(D'00'*D'24')+D'10'	;scale=14bin=013octave=00note=13
	retlw	(D'00'*D'24')+D'14'	;scale=14bin=014octave=00note=14
	retlw	(D'00'*D'24')+D'14'	;scale=14bin=015octave=00note=15
	retlw	(D'00'*D'24')+D'14'	;scale=14bin=016octave=00note=16
	retlw	(D'00'*D'24')+D'14'	;scale=14bin=017octave=00note=17
	retlw	(D'00'*D'24')+D'18'	;scale=14bin=018octave=00note=18
	retlw	(D'00'*D'24')+D'18'	;scale=14bin=019octave=00note=19
	retlw	(D'00'*D'24')+D'20'	;scale=14bin=020octave=00note=20
	retlw	(D'00'*D'24')+D'20'	;scale=14bin=021octave=00note=21
	retlw	(D'00'*D'24')+D'20'	;scale=14bin=022octave=00note=22
	retlw	(D'00'*D'24')+D'20'	;scale=14bin=023octave=00note=23
	retlw	(D'01'*D'24')+D'00'	;scale=14bin=024octave=01note=00
	retlw	(D'01'*D'24')+D'00'	;scale=14bin=025octave=01note=01
	retlw	(D'01'*D'24')+D'02'	;scale=14bin=026octave=01note=02
	retlw	(D'01'*D'24')+D'02'	;scale=14bin=027octave=01note=03
	retlw	(D'01'*D'24')+D'02'	;scale=14bin=028octave=01note=04
	retlw	(D'01'*D'24')+D'02'	;scale=14bin=029octave=01note=05
	retlw	(D'01'*D'24')+D'06'	;scale=14bin=030octave=01note=06
	retlw	(D'01'*D'24')+D'06'	;scale=14bin=031octave=01note=07
	retlw	(D'01'*D'24')+D'06'	;scale=14bin=032octave=01note=08
	retlw	(D'01'*D'24')+D'06'	;scale=14bin=033octave=01note=09
	retlw	(D'01'*D'24')+D'10'	;scale=14bin=034octave=01note=10
	retlw	(D'01'*D'24')+D'10'	;scale=14bin=035octave=01note=11
	retlw	(D'01'*D'24')+D'10'	;scale=14bin=036octave=01note=12
	retlw	(D'01'*D'24')+D'10'	;scale=14bin=037octave=01note=13
	retlw	(D'01'*D'24')+D'14'	;scale=14bin=038octave=01note=14
	retlw	(D'01'*D'24')+D'14'	;scale=14bin=039octave=01note=15
	retlw	(D'01'*D'24')+D'14'	;scale=14bin=040octave=01note=16
	retlw	(D'01'*D'24')+D'14'	;scale=14bin=041octave=01note=17
	retlw	(D'01'*D'24')+D'18'	;scale=14bin=042octave=01note=18
	retlw	(D'01'*D'24')+D'18'	;scale=14bin=043octave=01note=19
	retlw	(D'01'*D'24')+D'20'	;scale=14bin=044octave=01note=20
	retlw	(D'01'*D'24')+D'20'	;scale=14bin=045octave=01note=21
	retlw	(D'01'*D'24')+D'20'	;scale=14bin=046octave=01note=22
	retlw	(D'01'*D'24')+D'20'	;scale=14bin=047octave=01note=23
	retlw	(D'02'*D'24')+D'00'	;scale=14bin=048octave=02note=00
	retlw	(D'02'*D'24')+D'00'	;scale=14bin=049octave=02note=01
	retlw	(D'02'*D'24')+D'02'	;scale=14bin=050octave=02note=02
	retlw	(D'02'*D'24')+D'02'	;scale=14bin=051octave=02note=03
	retlw	(D'02'*D'24')+D'02'	;scale=14bin=052octave=02note=04
	retlw	(D'02'*D'24')+D'02'	;scale=14bin=053octave=02note=05
	retlw	(D'02'*D'24')+D'06'	;scale=14bin=054octave=02note=06
	retlw	(D'02'*D'24')+D'06'	;scale=14bin=055octave=02note=07
	retlw	(D'02'*D'24')+D'06'	;scale=14bin=056octave=02note=08
	retlw	(D'02'*D'24')+D'06'	;scale=14bin=057octave=02note=09
	retlw	(D'02'*D'24')+D'10'	;scale=14bin=058octave=02note=10
	retlw	(D'02'*D'24')+D'10'	;scale=14bin=059octave=02note=11
	retlw	(D'02'*D'24')+D'10'	;scale=14bin=060octave=02note=12
	retlw	(D'02'*D'24')+D'10'	;scale=14bin=061octave=02note=13
	retlw	(D'02'*D'24')+D'14'	;scale=14bin=062octave=02note=14
	retlw	(D'02'*D'24')+D'14'	;scale=14bin=063octave=02note=15
	retlw	(D'02'*D'24')+D'14'	;scale=14bin=064octave=02note=16
	retlw	(D'02'*D'24')+D'14'	;scale=14bin=065octave=02note=17
	retlw	(D'02'*D'24')+D'18'	;scale=14bin=066octave=02note=18
	retlw	(D'02'*D'24')+D'18'	;scale=14bin=067octave=02note=19
	retlw	(D'02'*D'24')+D'20'	;scale=14bin=068octave=02note=20
	retlw	(D'02'*D'24')+D'20'	;scale=14bin=069octave=02note=21
	retlw	(D'02'*D'24')+D'20'	;scale=14bin=070octave=02note=22
	retlw	(D'02'*D'24')+D'20'	;scale=14bin=071octave=02note=23
	retlw	(D'03'*D'24')+D'00'	;scale=14bin=072octave=03note=00
	retlw	(D'03'*D'24')+D'00'	;scale=14bin=073octave=03note=01
	retlw	(D'03'*D'24')+D'02'	;scale=14bin=074octave=03note=02
	retlw	(D'03'*D'24')+D'02'	;scale=14bin=075octave=03note=03
	retlw	(D'03'*D'24')+D'02'	;scale=14bin=076octave=03note=04
	retlw	(D'03'*D'24')+D'02'	;scale=14bin=077octave=03note=05
	retlw	(D'03'*D'24')+D'06'	;scale=14bin=078octave=03note=06
	retlw	(D'03'*D'24')+D'06'	;scale=14bin=079octave=03note=07
	retlw	(D'03'*D'24')+D'06'	;scale=14bin=080octave=03note=08
	retlw	(D'03'*D'24')+D'06'	;scale=14bin=081octave=03note=09
	retlw	(D'03'*D'24')+D'10'	;scale=14bin=082octave=03note=10
	retlw	(D'03'*D'24')+D'10'	;scale=14bin=083octave=03note=11
	retlw	(D'03'*D'24')+D'10'	;scale=14bin=084octave=03note=12
	retlw	(D'03'*D'24')+D'10'	;scale=14bin=085octave=03note=13
	retlw	(D'03'*D'24')+D'14'	;scale=14bin=086octave=03note=14
	retlw	(D'03'*D'24')+D'14'	;scale=14bin=087octave=03note=15
	retlw	(D'03'*D'24')+D'14'	;scale=14bin=088octave=03note=16
	retlw	(D'03'*D'24')+D'14'	;scale=14bin=089octave=03note=17
	retlw	(D'03'*D'24')+D'18'	;scale=14bin=090octave=03note=18
	retlw	(D'03'*D'24')+D'18'	;scale=14bin=091octave=03note=19
	retlw	(D'03'*D'24')+D'20'	;scale=14bin=092octave=03note=20
	retlw	(D'03'*D'24')+D'20'	;scale=14bin=093octave=03note=21
	retlw	(D'03'*D'24')+D'20'	;scale=14bin=094octave=03note=22
	retlw	(D'03'*D'24')+D'20'	;scale=14bin=095octave=03note=23
	retlw	(D'04'*D'24')+D'00'	;scale=14bin=096octave=04note=00
	retlw	(D'04'*D'24')+D'00'	;scale=14bin=097octave=04note=01
	retlw	(D'04'*D'24')+D'02'	;scale=14bin=098octave=04note=02
	retlw	(D'04'*D'24')+D'02'	;scale=14bin=099octave=04note=03
	retlw	(D'04'*D'24')+D'02'	;scale=14bin=100octave=04note=04
	retlw	(D'04'*D'24')+D'02'	;scale=14bin=101octave=04note=05
	retlw	(D'04'*D'24')+D'06'	;scale=14bin=102octave=04note=06
	retlw	(D'04'*D'24')+D'06'	;scale=14bin=103octave=04note=07
	retlw	(D'04'*D'24')+D'06'	;scale=14bin=104octave=04note=08
	retlw	(D'04'*D'24')+D'06'	;scale=14bin=105octave=04note=09
	retlw	(D'04'*D'24')+D'10'	;scale=14bin=106octave=04note=10
	retlw	(D'04'*D'24')+D'10'	;scale=14bin=107octave=04note=11
	retlw	(D'04'*D'24')+D'10'	;scale=14bin=108octave=04note=12
	retlw	(D'04'*D'24')+D'10'	;scale=14bin=109octave=04note=13
	retlw	(D'04'*D'24')+D'14'	;scale=14bin=110octave=04note=14
	retlw	(D'04'*D'24')+D'14'	;scale=14bin=111octave=04note=15
	retlw	(D'04'*D'24')+D'14'	;scale=14bin=112octave=04note=16
	retlw	(D'04'*D'24')+D'14'	;scale=14bin=113octave=04note=17
	retlw	(D'04'*D'24')+D'18'	;scale=14bin=114octave=04note=18
	retlw	(D'04'*D'24')+D'18'	;scale=14bin=115octave=04note=19
	retlw	(D'04'*D'24')+D'20'	;scale=14bin=116octave=04note=20
	retlw	(D'04'*D'24')+D'20'	;scale=14bin=117octave=04note=21
	retlw	(D'04'*D'24')+D'20'	;scale=14bin=118octave=04note=22
	retlw	(D'04'*D'24')+D'20'	;scale=14bin=119octave=04note=23
	retlw	(D'05'*D'24')+D'00'	;scale=14bin=120octave=05note=00
	retlw	(D'05'*D'24')+D'00'	;scale=14bin=121octave=05note=01
	retlw	(D'05'*D'24')+D'02'	;scale=14bin=122octave=05note=02
	retlw	(D'05'*D'24')+D'02'	;scale=14bin=123octave=05note=03
	retlw	(D'05'*D'24')+D'02'	;scale=14bin=124octave=05note=04
	retlw	(D'05'*D'24')+D'02'	;scale=14bin=125octave=05note=05
	retlw	(D'05'*D'24')+D'06'	;scale=14bin=126octave=05note=06
	retlw	(D'05'*D'24')+D'06'	;scale=14bin=127octave=05note=07
	retlw	(D'05'*D'24')+D'06'	;scale=14bin=128octave=05note=08
	retlw	(D'05'*D'24')+D'06'	;scale=14bin=129octave=05note=09
	retlw	(D'05'*D'24')+D'10'	;scale=14bin=130octave=05note=10
	retlw	(D'05'*D'24')+D'10'	;scale=14bin=131octave=05note=11
	retlw	(D'05'*D'24')+D'10'	;scale=14bin=132octave=05note=12
	retlw	(D'05'*D'24')+D'10'	;scale=14bin=133octave=05note=13
	retlw	(D'05'*D'24')+D'14'	;scale=14bin=134octave=05note=14
	retlw	(D'05'*D'24')+D'14'	;scale=14bin=135octave=05note=15
	retlw	(D'05'*D'24')+D'14'	;scale=14bin=136octave=05note=16
	retlw	(D'05'*D'24')+D'14'	;scale=14bin=137octave=05note=17
	retlw	(D'05'*D'24')+D'18'	;scale=14bin=138octave=05note=18
	retlw	(D'05'*D'24')+D'18'	;scale=14bin=139octave=05note=19
	retlw	(D'05'*D'24')+D'20'	;scale=14bin=140octave=05note=20
	retlw	(D'05'*D'24')+D'20'	;scale=14bin=141octave=05note=21
	retlw	(D'05'*D'24')+D'20'	;scale=14bin=142octave=05note=22
	retlw	(D'05'*D'24')+D'20'	;scale=14bin=143octave=05note=23
	retlw	(D'06'*D'24')+D'00'	;scale=14bin=144octave=06note=00
	retlw	(D'06'*D'24')+D'00'	;scale=14bin=145octave=06note=01
	retlw	(D'06'*D'24')+D'02'	;scale=14bin=146octave=06note=02
	retlw	(D'06'*D'24')+D'02'	;scale=14bin=147octave=06note=03
	retlw	(D'06'*D'24')+D'02'	;scale=14bin=148octave=06note=04
	retlw	(D'06'*D'24')+D'02'	;scale=14bin=149octave=06note=05
	retlw	(D'06'*D'24')+D'06'	;scale=14bin=150octave=06note=06
	retlw	(D'06'*D'24')+D'06'	;scale=14bin=151octave=06note=07
	retlw	(D'06'*D'24')+D'06'	;scale=14bin=152octave=06note=08
	retlw	(D'06'*D'24')+D'06'	;scale=14bin=153octave=06note=09
	retlw	(D'06'*D'24')+D'10'	;scale=14bin=154octave=06note=10
	retlw	(D'06'*D'24')+D'10'	;scale=14bin=155octave=06note=11
	retlw	(D'06'*D'24')+D'10'	;scale=14bin=156octave=06note=12
	retlw	(D'06'*D'24')+D'10'	;scale=14bin=157octave=06note=13
	retlw	(D'06'*D'24')+D'14'	;scale=14bin=158octave=06note=14
	retlw	(D'06'*D'24')+D'14'	;scale=14bin=159octave=06note=15
	retlw	(D'06'*D'24')+D'14'	;scale=14bin=160octave=06note=16
	retlw	(D'06'*D'24')+D'14'	;scale=14bin=161octave=06note=17
	retlw	(D'06'*D'24')+D'18'	;scale=14bin=162octave=06note=18
	retlw	(D'06'*D'24')+D'18'	;scale=14bin=163octave=06note=19
	retlw	(D'06'*D'24')+D'20'	;scale=14bin=164octave=06note=20
	retlw	(D'06'*D'24')+D'20'	;scale=14bin=165octave=06note=21
	retlw	(D'06'*D'24')+D'20'	;scale=14bin=166octave=06note=22
	retlw	(D'06'*D'24')+D'20'	;scale=14bin=167octave=06note=23
	retlw	(D'07'*D'24')+D'00'	;scale=14bin=168octave=07note=00
	retlw	(D'07'*D'24')+D'00'	;scale=14bin=169octave=07note=01
	retlw	(D'07'*D'24')+D'02'	;scale=14bin=170octave=07note=02
	retlw	(D'07'*D'24')+D'02'	;scale=14bin=171octave=07note=03
	retlw	(D'07'*D'24')+D'02'	;scale=14bin=172octave=07note=04
	retlw	(D'07'*D'24')+D'02'	;scale=14bin=173octave=07note=05
	retlw	(D'07'*D'24')+D'06'	;scale=14bin=174octave=07note=06
	retlw	(D'07'*D'24')+D'06'	;scale=14bin=175octave=07note=07
	retlw	(D'07'*D'24')+D'06'	;scale=14bin=176octave=07note=08
	retlw	(D'07'*D'24')+D'06'	;scale=14bin=177octave=07note=09
	retlw	(D'07'*D'24')+D'10'	;scale=14bin=178octave=07note=10
	retlw	(D'07'*D'24')+D'10'	;scale=14bin=179octave=07note=11
	retlw	(D'07'*D'24')+D'10'	;scale=14bin=180octave=07note=12
	retlw	(D'07'*D'24')+D'10'	;scale=14bin=181octave=07note=13
	retlw	(D'07'*D'24')+D'14'	;scale=14bin=182octave=07note=14
	retlw	(D'07'*D'24')+D'14'	;scale=14bin=183octave=07note=15
	retlw	(D'07'*D'24')+D'14'	;scale=14bin=184octave=07note=16
	retlw	(D'07'*D'24')+D'14'	;scale=14bin=185octave=07note=17
	retlw	(D'07'*D'24')+D'18'	;scale=14bin=186octave=07note=18
	retlw	(D'07'*D'24')+D'18'	;scale=14bin=187octave=07note=19
	retlw	(D'07'*D'24')+D'20'	;scale=14bin=188octave=07note=20
	retlw	(D'07'*D'24')+D'20'	;scale=14bin=189octave=07note=21
	retlw	(D'07'*D'24')+D'20'	;scale=14bin=190octave=07note=22
	retlw	(D'07'*D'24')+D'20'	;scale=14bin=191octave=07note=23
	retlw	(D'08'*D'24')+D'00'	;scale=14bin=192octave=08note=00
	retlw	(D'08'*D'24')+D'00'	;scale=14bin=193octave=08note=01
	retlw	(D'08'*D'24')+D'02'	;scale=14bin=194octave=08note=02
	retlw	(D'08'*D'24')+D'02'	;scale=14bin=195octave=08note=03
	retlw	(D'08'*D'24')+D'02'	;scale=14bin=196octave=08note=04
	retlw	(D'08'*D'24')+D'02'	;scale=14bin=197octave=08note=05
	retlw	(D'08'*D'24')+D'06'	;scale=14bin=198octave=08note=06
	retlw	(D'08'*D'24')+D'06'	;scale=14bin=199octave=08note=07
	retlw	(D'08'*D'24')+D'06'	;scale=14bin=200octave=08note=08
	retlw	(D'08'*D'24')+D'06'	;scale=14bin=201octave=08note=09
	retlw	(D'08'*D'24')+D'10'	;scale=14bin=202octave=08note=10
	retlw	(D'08'*D'24')+D'10'	;scale=14bin=203octave=08note=11
	retlw	(D'08'*D'24')+D'10'	;scale=14bin=204octave=08note=12
	retlw	(D'08'*D'24')+D'10'	;scale=14bin=205octave=08note=13
	retlw	(D'08'*D'24')+D'14'	;scale=14bin=206octave=08note=14
	retlw	(D'08'*D'24')+D'14'	;scale=14bin=207octave=08note=15
	retlw	(D'08'*D'24')+D'14'	;scale=14bin=208octave=08note=16
	retlw	(D'08'*D'24')+D'14'	;scale=14bin=209octave=08note=17
	retlw	(D'08'*D'24')+D'18'	;scale=14bin=210octave=08note=18
	retlw	(D'08'*D'24')+D'18'	;scale=14bin=211octave=08note=19
	retlw	(D'08'*D'24')+D'20'	;scale=14bin=212octave=08note=20
	retlw	(D'08'*D'24')+D'20'	;scale=14bin=213octave=08note=21
	retlw	(D'08'*D'24')+D'20'	;scale=14bin=214octave=08note=22
	retlw	(D'08'*D'24')+D'20'	;scale=14bin=215octave=08note=23
	retlw	(D'09'*D'24')+D'00'	;scale=14bin=216octave=09note=00
	retlw	(D'09'*D'24')+D'00'	;scale=14bin=217octave=09note=01
	retlw	(D'09'*D'24')+D'02'	;scale=14bin=218octave=09note=02
	retlw	(D'09'*D'24')+D'02'	;scale=14bin=219octave=09note=03
	retlw	(D'09'*D'24')+D'02'	;scale=14bin=220octave=09note=04
	retlw	(D'09'*D'24')+D'02'	;scale=14bin=221octave=09note=05
	retlw	(D'09'*D'24')+D'06'	;scale=14bin=222octave=09note=06
	retlw	(D'09'*D'24')+D'06'	;scale=14bin=223octave=09note=07
	retlw	(D'09'*D'24')+D'06'	;scale=14bin=224octave=09note=08
	retlw	(D'09'*D'24')+D'06'	;scale=14bin=225octave=09note=09
	retlw	(D'09'*D'24')+D'10'	;scale=14bin=226octave=09note=10
	retlw	(D'09'*D'24')+D'10'	;scale=14bin=227octave=09note=11
	retlw	(D'09'*D'24')+D'10'	;scale=14bin=228octave=09note=12
	retlw	(D'09'*D'24')+D'10'	;scale=14bin=229octave=09note=13
	retlw	(D'09'*D'24')+D'14'	;scale=14bin=230octave=09note=14
	retlw	(D'09'*D'24')+D'14'	;scale=14bin=231octave=09note=15
	retlw	(D'09'*D'24')+D'14'	;scale=14bin=232octave=09note=16
	retlw	(D'09'*D'24')+D'14'	;scale=14bin=233octave=09note=17
	retlw	(D'09'*D'24')+D'18'	;scale=14bin=234octave=09note=18
	retlw	(D'09'*D'24')+D'18'	;scale=14bin=235octave=09note=19
	retlw	(D'09'*D'24')+D'20'	;scale=14bin=236octave=09note=20
	retlw	(D'09'*D'24')+D'20'	;scale=14bin=237octave=09note=21
	retlw	(D'09'*D'24')+D'20'	;scale=14bin=238octave=09note=22
	retlw	(D'09'*D'24')+D'20'	;scale=14bin=239octave=09note=23
	retlw	(D'10'*D'24')+D'00'	;scale=14bin=240octave=10note=00
	retlw	(D'10'*D'24')+D'00'	;scale=14bin=241octave=10note=01
	retlw	(D'10'*D'24')+D'00'	;scale=14bin=242octave=10note=02
	retlw	(D'10'*D'24')+D'00'	;scale=14bin=243octave=10note=03
	retlw	(D'10'*D'24')+D'00'	;scale=14bin=244octave=10note=04
	retlw	(D'10'*D'24')+D'00'	;scale=14bin=245octave=10note=05
	retlw	(D'10'*D'24')+D'00'	;scale=14bin=246octave=10note=06
	retlw	(D'10'*D'24')+D'00'	;scale=14bin=247octave=10note=07
	retlw	(D'10'*D'24')+D'00'	;scale=14bin=248octave=10note=08
	retlw	(D'10'*D'24')+D'00'	;scale=14bin=249octave=10note=09
	retlw	(D'10'*D'24')+D'00'	;scale=14bin=250octave=10note=10
	retlw	(D'10'*D'24')+D'00'	;scale=14bin=251octave=10note=11
	retlw	(D'10'*D'24')+D'00'	;scale=14bin=252octave=10note=12
	retlw	(D'10'*D'24')+D'00'	;scale=14bin=253octave=10note=13
	retlw	(D'10'*D'24')+D'00'	;scale=14bin=254octave=10note=14
	retlw	(D'10'*D'24')+D'00'	;scale=14bin=255octave=10note=15

;	Chinese look-up table
	org	Chinese		;Chinese Pent look-up table
	retlw	(D'00'*D'24')+D'00'	;scale=15bin=000octave=00note=00
	retlw	(D'00'*D'24')+D'00'	;scale=15bin=001octave=00note=01
	retlw	(D'00'*D'24')+D'00'	;scale=15bin=002octave=00note=02
	retlw	(D'00'*D'24')+D'00'	;scale=15bin=003octave=00note=03
	retlw	(D'00'*D'24')+D'00'	;scale=15bin=004octave=00note=04
	retlw	(D'00'*D'24')+D'00'	;scale=15bin=005octave=00note=05
	retlw	(D'00'*D'24')+D'00'	;scale=15bin=006octave=00note=06
	retlw	(D'00'*D'24')+D'00'	;scale=15bin=007octave=00note=07
	retlw	(D'00'*D'24')+D'08'	;scale=15bin=008octave=00note=08
	retlw	(D'00'*D'24')+D'08'	;scale=15bin=009octave=00note=09
	retlw	(D'00'*D'24')+D'08'	;scale=15bin=010octave=00note=10
	retlw	(D'00'*D'24')+D'08'	;scale=15bin=011octave=00note=11
	retlw	(D'00'*D'24')+D'12'	;scale=15bin=012octave=00note=12
	retlw	(D'00'*D'24')+D'12'	;scale=15bin=013octave=00note=13
	retlw	(D'00'*D'24')+D'14'	;scale=15bin=014octave=00note=14
	retlw	(D'00'*D'24')+D'14'	;scale=15bin=015octave=00note=15
	retlw	(D'00'*D'24')+D'14'	;scale=15bin=016octave=00note=16
	retlw	(D'00'*D'24')+D'14'	;scale=15bin=017octave=00note=17
	retlw	(D'00'*D'24')+D'14'	;scale=15bin=018octave=00note=18
	retlw	(D'00'*D'24')+D'14'	;scale=15bin=019octave=00note=19
	retlw	(D'00'*D'24')+D'14'	;scale=15bin=020octave=00note=20
	retlw	(D'00'*D'24')+D'14'	;scale=15bin=021octave=00note=21
	retlw	(D'00'*D'24')+D'22'	;scale=15bin=022octave=00note=22
	retlw	(D'00'*D'24')+D'22'	;scale=15bin=023octave=00note=23
	retlw	(D'01'*D'24')+D'00'	;scale=15bin=024octave=01note=00
	retlw	(D'01'*D'24')+D'00'	;scale=15bin=025octave=01note=01
	retlw	(D'01'*D'24')+D'00'	;scale=15bin=026octave=01note=02
	retlw	(D'01'*D'24')+D'00'	;scale=15bin=027octave=01note=03
	retlw	(D'01'*D'24')+D'00'	;scale=15bin=028octave=01note=04
	retlw	(D'01'*D'24')+D'00'	;scale=15bin=029octave=01note=05
	retlw	(D'01'*D'24')+D'00'	;scale=15bin=030octave=01note=06
	retlw	(D'01'*D'24')+D'00'	;scale=15bin=031octave=01note=07
	retlw	(D'01'*D'24')+D'08'	;scale=15bin=032octave=01note=08
	retlw	(D'01'*D'24')+D'08'	;scale=15bin=033octave=01note=09
	retlw	(D'01'*D'24')+D'08'	;scale=15bin=034octave=01note=10
	retlw	(D'01'*D'24')+D'08'	;scale=15bin=035octave=01note=11
	retlw	(D'01'*D'24')+D'12'	;scale=15bin=036octave=01note=12
	retlw	(D'01'*D'24')+D'12'	;scale=15bin=037octave=01note=13
	retlw	(D'01'*D'24')+D'14'	;scale=15bin=038octave=01note=14
	retlw	(D'01'*D'24')+D'14'	;scale=15bin=039octave=01note=15
	retlw	(D'01'*D'24')+D'14'	;scale=15bin=040octave=01note=16
	retlw	(D'01'*D'24')+D'14'	;scale=15bin=041octave=01note=17
	retlw	(D'01'*D'24')+D'14'	;scale=15bin=042octave=01note=18
	retlw	(D'01'*D'24')+D'14'	;scale=15bin=043octave=01note=19
	retlw	(D'01'*D'24')+D'14'	;scale=15bin=044octave=01note=20
	retlw	(D'01'*D'24')+D'14'	;scale=15bin=045octave=01note=21
	retlw	(D'01'*D'24')+D'22'	;scale=15bin=046octave=01note=22
	retlw	(D'01'*D'24')+D'22'	;scale=15bin=047octave=01note=23
	retlw	(D'02'*D'24')+D'00'	;scale=15bin=048octave=02note=00
	retlw	(D'02'*D'24')+D'00'	;scale=15bin=049octave=02note=01
	retlw	(D'02'*D'24')+D'00'	;scale=15bin=050octave=02note=02
	retlw	(D'02'*D'24')+D'00'	;scale=15bin=051octave=02note=03
	retlw	(D'02'*D'24')+D'00'	;scale=15bin=052octave=02note=04
	retlw	(D'02'*D'24')+D'00'	;scale=15bin=053octave=02note=05
	retlw	(D'02'*D'24')+D'00'	;scale=15bin=054octave=02note=06
	retlw	(D'02'*D'24')+D'00'	;scale=15bin=055octave=02note=07
	retlw	(D'02'*D'24')+D'08'	;scale=15bin=056octave=02note=08
	retlw	(D'02'*D'24')+D'08'	;scale=15bin=057octave=02note=09
	retlw	(D'02'*D'24')+D'08'	;scale=15bin=058octave=02note=10
	retlw	(D'02'*D'24')+D'08'	;scale=15bin=059octave=02note=11
	retlw	(D'02'*D'24')+D'12'	;scale=15bin=060octave=02note=12
	retlw	(D'02'*D'24')+D'12'	;scale=15bin=061octave=02note=13
	retlw	(D'02'*D'24')+D'14'	;scale=15bin=062octave=02note=14
	retlw	(D'02'*D'24')+D'14'	;scale=15bin=063octave=02note=15
	retlw	(D'02'*D'24')+D'14'	;scale=15bin=064octave=02note=16
	retlw	(D'02'*D'24')+D'14'	;scale=15bin=065octave=02note=17
	retlw	(D'02'*D'24')+D'14'	;scale=15bin=066octave=02note=18
	retlw	(D'02'*D'24')+D'14'	;scale=15bin=067octave=02note=19
	retlw	(D'02'*D'24')+D'14'	;scale=15bin=068octave=02note=20
	retlw	(D'02'*D'24')+D'14'	;scale=15bin=069octave=02note=21
	retlw	(D'02'*D'24')+D'22'	;scale=15bin=070octave=02note=22
	retlw	(D'02'*D'24')+D'22'	;scale=15bin=071octave=02note=23
	retlw	(D'03'*D'24')+D'00'	;scale=15bin=072octave=03note=00
	retlw	(D'03'*D'24')+D'00'	;scale=15bin=073octave=03note=01
	retlw	(D'03'*D'24')+D'00'	;scale=15bin=074octave=03note=02
	retlw	(D'03'*D'24')+D'00'	;scale=15bin=075octave=03note=03
	retlw	(D'03'*D'24')+D'00'	;scale=15bin=076octave=03note=04
	retlw	(D'03'*D'24')+D'00'	;scale=15bin=077octave=03note=05
	retlw	(D'03'*D'24')+D'00'	;scale=15bin=078octave=03note=06
	retlw	(D'03'*D'24')+D'00'	;scale=15bin=079octave=03note=07
	retlw	(D'03'*D'24')+D'08'	;scale=15bin=080octave=03note=08
	retlw	(D'03'*D'24')+D'08'	;scale=15bin=081octave=03note=09
	retlw	(D'03'*D'24')+D'08'	;scale=15bin=082octave=03note=10
	retlw	(D'03'*D'24')+D'08'	;scale=15bin=083octave=03note=11
	retlw	(D'03'*D'24')+D'12'	;scale=15bin=084octave=03note=12
	retlw	(D'03'*D'24')+D'12'	;scale=15bin=085octave=03note=13
	retlw	(D'03'*D'24')+D'14'	;scale=15bin=086octave=03note=14
	retlw	(D'03'*D'24')+D'14'	;scale=15bin=087octave=03note=15
	retlw	(D'03'*D'24')+D'14'	;scale=15bin=088octave=03note=16
	retlw	(D'03'*D'24')+D'14'	;scale=15bin=089octave=03note=17
	retlw	(D'03'*D'24')+D'14'	;scale=15bin=090octave=03note=18
	retlw	(D'03'*D'24')+D'14'	;scale=15bin=091octave=03note=19
	retlw	(D'03'*D'24')+D'14'	;scale=15bin=092octave=03note=20
	retlw	(D'03'*D'24')+D'14'	;scale=15bin=093octave=03note=21
	retlw	(D'03'*D'24')+D'22'	;scale=15bin=094octave=03note=22
	retlw	(D'03'*D'24')+D'22'	;scale=15bin=095octave=03note=23
	retlw	(D'04'*D'24')+D'00'	;scale=15bin=096octave=04note=00
	retlw	(D'04'*D'24')+D'00'	;scale=15bin=097octave=04note=01
	retlw	(D'04'*D'24')+D'00'	;scale=15bin=098octave=04note=02
	retlw	(D'04'*D'24')+D'00'	;scale=15bin=099octave=04note=03
	retlw	(D'04'*D'24')+D'00'	;scale=15bin=100octave=04note=04
	retlw	(D'04'*D'24')+D'00'	;scale=15bin=101octave=04note=05
	retlw	(D'04'*D'24')+D'00'	;scale=15bin=102octave=04note=06
	retlw	(D'04'*D'24')+D'00'	;scale=15bin=103octave=04note=07
	retlw	(D'04'*D'24')+D'08'	;scale=15bin=104octave=04note=08
	retlw	(D'04'*D'24')+D'08'	;scale=15bin=105octave=04note=09
	retlw	(D'04'*D'24')+D'08'	;scale=15bin=106octave=04note=10
	retlw	(D'04'*D'24')+D'08'	;scale=15bin=107octave=04note=11
	retlw	(D'04'*D'24')+D'12'	;scale=15bin=108octave=04note=12
	retlw	(D'04'*D'24')+D'12'	;scale=15bin=109octave=04note=13
	retlw	(D'04'*D'24')+D'14'	;scale=15bin=110octave=04note=14
	retlw	(D'04'*D'24')+D'14'	;scale=15bin=111octave=04note=15
	retlw	(D'04'*D'24')+D'14'	;scale=15bin=112octave=04note=16
	retlw	(D'04'*D'24')+D'14'	;scale=15bin=113octave=04note=17
	retlw	(D'04'*D'24')+D'14'	;scale=15bin=114octave=04note=18
	retlw	(D'04'*D'24')+D'14'	;scale=15bin=115octave=04note=19
	retlw	(D'04'*D'24')+D'14'	;scale=15bin=116octave=04note=20
	retlw	(D'04'*D'24')+D'14'	;scale=15bin=117octave=04note=21
	retlw	(D'04'*D'24')+D'22'	;scale=15bin=118octave=04note=22
	retlw	(D'04'*D'24')+D'22'	;scale=15bin=119octave=04note=23
	retlw	(D'05'*D'24')+D'00'	;scale=15bin=120octave=05note=00
	retlw	(D'05'*D'24')+D'00'	;scale=15bin=121octave=05note=01
	retlw	(D'05'*D'24')+D'00'	;scale=15bin=122octave=05note=02
	retlw	(D'05'*D'24')+D'00'	;scale=15bin=123octave=05note=03
	retlw	(D'05'*D'24')+D'00'	;scale=15bin=124octave=05note=04
	retlw	(D'05'*D'24')+D'00'	;scale=15bin=125octave=05note=05
	retlw	(D'05'*D'24')+D'00'	;scale=15bin=126octave=05note=06
	retlw	(D'05'*D'24')+D'00'	;scale=15bin=127octave=05note=07
	retlw	(D'05'*D'24')+D'08'	;scale=15bin=128octave=05note=08
	retlw	(D'05'*D'24')+D'08'	;scale=15bin=129octave=05note=09
	retlw	(D'05'*D'24')+D'08'	;scale=15bin=130octave=05note=10
	retlw	(D'05'*D'24')+D'08'	;scale=15bin=131octave=05note=11
	retlw	(D'05'*D'24')+D'12'	;scale=15bin=132octave=05note=12
	retlw	(D'05'*D'24')+D'12'	;scale=15bin=133octave=05note=13
	retlw	(D'05'*D'24')+D'14'	;scale=15bin=134octave=05note=14
	retlw	(D'05'*D'24')+D'14'	;scale=15bin=135octave=05note=15
	retlw	(D'05'*D'24')+D'14'	;scale=15bin=136octave=05note=16
	retlw	(D'05'*D'24')+D'14'	;scale=15bin=137octave=05note=17
	retlw	(D'05'*D'24')+D'14'	;scale=15bin=138octave=05note=18
	retlw	(D'05'*D'24')+D'14'	;scale=15bin=139octave=05note=19
	retlw	(D'05'*D'24')+D'14'	;scale=15bin=140octave=05note=20
	retlw	(D'05'*D'24')+D'14'	;scale=15bin=141octave=05note=21
	retlw	(D'05'*D'24')+D'22'	;scale=15bin=142octave=05note=22
	retlw	(D'05'*D'24')+D'22'	;scale=15bin=143octave=05note=23
	retlw	(D'06'*D'24')+D'00'	;scale=15bin=144octave=06note=00
	retlw	(D'06'*D'24')+D'00'	;scale=15bin=145octave=06note=01
	retlw	(D'06'*D'24')+D'00'	;scale=15bin=146octave=06note=02
	retlw	(D'06'*D'24')+D'00'	;scale=15bin=147octave=06note=03
	retlw	(D'06'*D'24')+D'00'	;scale=15bin=148octave=06note=04
	retlw	(D'06'*D'24')+D'00'	;scale=15bin=149octave=06note=05
	retlw	(D'06'*D'24')+D'00'	;scale=15bin=150octave=06note=06
	retlw	(D'06'*D'24')+D'00'	;scale=15bin=151octave=06note=07
	retlw	(D'06'*D'24')+D'08'	;scale=15bin=152octave=06note=08
	retlw	(D'06'*D'24')+D'08'	;scale=15bin=153octave=06note=09
	retlw	(D'06'*D'24')+D'08'	;scale=15bin=154octave=06note=10
	retlw	(D'06'*D'24')+D'08'	;scale=15bin=155octave=06note=11
	retlw	(D'06'*D'24')+D'12'	;scale=15bin=156octave=06note=12
	retlw	(D'06'*D'24')+D'12'	;scale=15bin=157octave=06note=13
	retlw	(D'06'*D'24')+D'14'	;scale=15bin=158octave=06note=14
	retlw	(D'06'*D'24')+D'14'	;scale=15bin=159octave=06note=15
	retlw	(D'06'*D'24')+D'14'	;scale=15bin=160octave=06note=16
	retlw	(D'06'*D'24')+D'14'	;scale=15bin=161octave=06note=17
	retlw	(D'06'*D'24')+D'14'	;scale=15bin=162octave=06note=18
	retlw	(D'06'*D'24')+D'14'	;scale=15bin=163octave=06note=19
	retlw	(D'06'*D'24')+D'14'	;scale=15bin=164octave=06note=20
	retlw	(D'06'*D'24')+D'14'	;scale=15bin=165octave=06note=21
	retlw	(D'06'*D'24')+D'22'	;scale=15bin=166octave=06note=22
	retlw	(D'06'*D'24')+D'22'	;scale=15bin=167octave=06note=23
	retlw	(D'07'*D'24')+D'00'	;scale=15bin=168octave=07note=00
	retlw	(D'07'*D'24')+D'00'	;scale=15bin=169octave=07note=01
	retlw	(D'07'*D'24')+D'00'	;scale=15bin=170octave=07note=02
	retlw	(D'07'*D'24')+D'00'	;scale=15bin=171octave=07note=03
	retlw	(D'07'*D'24')+D'00'	;scale=15bin=172octave=07note=04
	retlw	(D'07'*D'24')+D'00'	;scale=15bin=173octave=07note=05
	retlw	(D'07'*D'24')+D'00'	;scale=15bin=174octave=07note=06
	retlw	(D'07'*D'24')+D'00'	;scale=15bin=175octave=07note=07
	retlw	(D'07'*D'24')+D'08'	;scale=15bin=176octave=07note=08
	retlw	(D'07'*D'24')+D'08'	;scale=15bin=177octave=07note=09
	retlw	(D'07'*D'24')+D'08'	;scale=15bin=178octave=07note=10
	retlw	(D'07'*D'24')+D'08'	;scale=15bin=179octave=07note=11
	retlw	(D'07'*D'24')+D'12'	;scale=15bin=180octave=07note=12
	retlw	(D'07'*D'24')+D'12'	;scale=15bin=181octave=07note=13
	retlw	(D'07'*D'24')+D'14'	;scale=15bin=182octave=07note=14
	retlw	(D'07'*D'24')+D'14'	;scale=15bin=183octave=07note=15
	retlw	(D'07'*D'24')+D'14'	;scale=15bin=184octave=07note=16
	retlw	(D'07'*D'24')+D'14'	;scale=15bin=185octave=07note=17
	retlw	(D'07'*D'24')+D'14'	;scale=15bin=186octave=07note=18
	retlw	(D'07'*D'24')+D'14'	;scale=15bin=187octave=07note=19
	retlw	(D'07'*D'24')+D'14'	;scale=15bin=188octave=07note=20
	retlw	(D'07'*D'24')+D'14'	;scale=15bin=189octave=07note=21
	retlw	(D'07'*D'24')+D'22'	;scale=15bin=190octave=07note=22
	retlw	(D'07'*D'24')+D'22'	;scale=15bin=191octave=07note=23
	retlw	(D'08'*D'24')+D'00'	;scale=15bin=192octave=08note=00
	retlw	(D'08'*D'24')+D'00'	;scale=15bin=193octave=08note=01
	retlw	(D'08'*D'24')+D'00'	;scale=15bin=194octave=08note=02
	retlw	(D'08'*D'24')+D'00'	;scale=15bin=195octave=08note=03
	retlw	(D'08'*D'24')+D'00'	;scale=15bin=196octave=08note=04
	retlw	(D'08'*D'24')+D'00'	;scale=15bin=197octave=08note=05
	retlw	(D'08'*D'24')+D'00'	;scale=15bin=198octave=08note=06
	retlw	(D'08'*D'24')+D'00'	;scale=15bin=199octave=08note=07
	retlw	(D'08'*D'24')+D'08'	;scale=15bin=200octave=08note=08
	retlw	(D'08'*D'24')+D'08'	;scale=15bin=201octave=08note=09
	retlw	(D'08'*D'24')+D'08'	;scale=15bin=202octave=08note=10
	retlw	(D'08'*D'24')+D'08'	;scale=15bin=203octave=08note=11
	retlw	(D'08'*D'24')+D'12'	;scale=15bin=204octave=08note=12
	retlw	(D'08'*D'24')+D'12'	;scale=15bin=205octave=08note=13
	retlw	(D'08'*D'24')+D'14'	;scale=15bin=206octave=08note=14
	retlw	(D'08'*D'24')+D'14'	;scale=15bin=207octave=08note=15
	retlw	(D'08'*D'24')+D'14'	;scale=15bin=208octave=08note=16
	retlw	(D'08'*D'24')+D'14'	;scale=15bin=209octave=08note=17
	retlw	(D'08'*D'24')+D'14'	;scale=15bin=210octave=08note=18
	retlw	(D'08'*D'24')+D'14'	;scale=15bin=211octave=08note=19
	retlw	(D'08'*D'24')+D'14'	;scale=15bin=212octave=08note=20
	retlw	(D'08'*D'24')+D'14'	;scale=15bin=213octave=08note=21
	retlw	(D'08'*D'24')+D'22'	;scale=15bin=214octave=08note=22
	retlw	(D'08'*D'24')+D'22'	;scale=15bin=215octave=08note=23
	retlw	(D'09'*D'24')+D'00'	;scale=15bin=216octave=09note=00
	retlw	(D'09'*D'24')+D'00'	;scale=15bin=217octave=09note=01
	retlw	(D'09'*D'24')+D'00'	;scale=15bin=218octave=09note=02
	retlw	(D'09'*D'24')+D'00'	;scale=15bin=219octave=09note=03
	retlw	(D'09'*D'24')+D'00'	;scale=15bin=220octave=09note=04
	retlw	(D'09'*D'24')+D'00'	;scale=15bin=221octave=09note=05
	retlw	(D'09'*D'24')+D'00'	;scale=15bin=222octave=09note=06
	retlw	(D'09'*D'24')+D'00'	;scale=15bin=223octave=09note=07
	retlw	(D'09'*D'24')+D'08'	;scale=15bin=224octave=09note=08
	retlw	(D'09'*D'24')+D'08'	;scale=15bin=225octave=09note=09
	retlw	(D'09'*D'24')+D'08'	;scale=15bin=226octave=09note=10
	retlw	(D'09'*D'24')+D'08'	;scale=15bin=227octave=09note=11
	retlw	(D'09'*D'24')+D'12'	;scale=15bin=228octave=09note=12
	retlw	(D'09'*D'24')+D'12'	;scale=15bin=229octave=09note=13
	retlw	(D'09'*D'24')+D'14'	;scale=15bin=230octave=09note=14
	retlw	(D'09'*D'24')+D'14'	;scale=15bin=231octave=09note=15
	retlw	(D'09'*D'24')+D'14'	;scale=15bin=232octave=09note=16
	retlw	(D'09'*D'24')+D'14'	;scale=15bin=233octave=09note=17
	retlw	(D'09'*D'24')+D'14'	;scale=15bin=234octave=09note=18
	retlw	(D'09'*D'24')+D'14'	;scale=15bin=235octave=09note=19
	retlw	(D'09'*D'24')+D'14'	;scale=15bin=236octave=09note=20
	retlw	(D'09'*D'24')+D'14'	;scale=15bin=237octave=09note=21
	retlw	(D'09'*D'24')+D'22'	;scale=15bin=238octave=09note=22
	retlw	(D'09'*D'24')+D'22'	;scale=15bin=239octave=09note=23
	retlw	(D'10'*D'24')+D'00'	;scale=15bin=240octave=10note=00
	retlw	(D'10'*D'24')+D'00'	;scale=15bin=241octave=10note=01
	retlw	(D'10'*D'24')+D'00'	;scale=15bin=242octave=10note=02
	retlw	(D'10'*D'24')+D'00'	;scale=15bin=243octave=10note=03
	retlw	(D'10'*D'24')+D'00'	;scale=15bin=244octave=10note=04
	retlw	(D'10'*D'24')+D'00'	;scale=15bin=245octave=10note=05
	retlw	(D'10'*D'24')+D'00'	;scale=15bin=246octave=10note=06
	retlw	(D'10'*D'24')+D'00'	;scale=15bin=247octave=10note=07
	retlw	(D'10'*D'24')+D'00'	;scale=15bin=248octave=10note=08
	retlw	(D'10'*D'24')+D'00'	;scale=15bin=249octave=10note=09
	retlw	(D'10'*D'24')+D'00'	;scale=15bin=250octave=10note=10
	retlw	(D'10'*D'24')+D'00'	;scale=15bin=251octave=10note=11
	retlw	(D'10'*D'24')+D'00'	;scale=15bin=252octave=10note=12
	retlw	(D'10'*D'24')+D'00'	;scale=15bin=253octave=10note=13
	retlw	(D'10'*D'24')+D'00'	;scale=15bin=254octave=10note=14
	retlw	(D'10'*D'24')+D'00'	;scale=15bin=255octave=10note=15

;	Hindu look-up table
	org	Hindu		;Hindu look-up table
	retlw	(D'00'*D'24')+D'00'	;scale=16bin=000octave=00note=00
	retlw	(D'00'*D'24')+D'00'	;scale=16bin=001octave=00note=01
	retlw	(D'00'*D'24')+D'00'	;scale=16bin=002octave=00note=02
	retlw	(D'00'*D'24')+D'00'	;scale=16bin=003octave=00note=03
	retlw	(D'00'*D'24')+D'04'	;scale=16bin=004octave=00note=04
	retlw	(D'00'*D'24')+D'04'	;scale=16bin=005octave=00note=05
	retlw	(D'00'*D'24')+D'04'	;scale=16bin=006octave=00note=06
	retlw	(D'00'*D'24')+D'04'	;scale=16bin=007octave=00note=07
	retlw	(D'00'*D'24')+D'08'	;scale=16bin=008octave=00note=08
	retlw	(D'00'*D'24')+D'08'	;scale=16bin=009octave=00note=09
	retlw	(D'00'*D'24')+D'10'	;scale=16bin=010octave=00note=10
	retlw	(D'00'*D'24')+D'10'	;scale=16bin=011octave=00note=11
	retlw	(D'00'*D'24')+D'10'	;scale=16bin=012octave=00note=12
	retlw	(D'00'*D'24')+D'10'	;scale=16bin=013octave=00note=13
	retlw	(D'00'*D'24')+D'14'	;scale=16bin=014octave=00note=14
	retlw	(D'00'*D'24')+D'14'	;scale=16bin=015octave=00note=15
	retlw	(D'00'*D'24')+D'16'	;scale=16bin=016octave=00note=16
	retlw	(D'00'*D'24')+D'16'	;scale=16bin=017octave=00note=17
	retlw	(D'00'*D'24')+D'16'	;scale=16bin=018octave=00note=18
	retlw	(D'00'*D'24')+D'16'	;scale=16bin=019octave=00note=19
	retlw	(D'00'*D'24')+D'20'	;scale=16bin=020octave=00note=20
	retlw	(D'00'*D'24')+D'20'	;scale=16bin=021octave=00note=21
	retlw	(D'00'*D'24')+D'20'	;scale=16bin=022octave=00note=22
	retlw	(D'00'*D'24')+D'20'	;scale=16bin=023octave=00note=23
	retlw	(D'01'*D'24')+D'00'	;scale=16bin=024octave=01note=00
	retlw	(D'01'*D'24')+D'00'	;scale=16bin=025octave=01note=01
	retlw	(D'01'*D'24')+D'00'	;scale=16bin=026octave=01note=02
	retlw	(D'01'*D'24')+D'00'	;scale=16bin=027octave=01note=03
	retlw	(D'01'*D'24')+D'04'	;scale=16bin=028octave=01note=04
	retlw	(D'01'*D'24')+D'04'	;scale=16bin=029octave=01note=05
	retlw	(D'01'*D'24')+D'04'	;scale=16bin=030octave=01note=06
	retlw	(D'01'*D'24')+D'04'	;scale=16bin=031octave=01note=07
	retlw	(D'01'*D'24')+D'08'	;scale=16bin=032octave=01note=08
	retlw	(D'01'*D'24')+D'08'	;scale=16bin=033octave=01note=09
	retlw	(D'01'*D'24')+D'10'	;scale=16bin=034octave=01note=10
	retlw	(D'01'*D'24')+D'10'	;scale=16bin=035octave=01note=11
	retlw	(D'01'*D'24')+D'10'	;scale=16bin=036octave=01note=12
	retlw	(D'01'*D'24')+D'10'	;scale=16bin=037octave=01note=13
	retlw	(D'01'*D'24')+D'14'	;scale=16bin=038octave=01note=14
	retlw	(D'01'*D'24')+D'14'	;scale=16bin=039octave=01note=15
	retlw	(D'01'*D'24')+D'16'	;scale=16bin=040octave=01note=16
	retlw	(D'01'*D'24')+D'16'	;scale=16bin=041octave=01note=17
	retlw	(D'01'*D'24')+D'16'	;scale=16bin=042octave=01note=18
	retlw	(D'01'*D'24')+D'16'	;scale=16bin=043octave=01note=19
	retlw	(D'01'*D'24')+D'20'	;scale=16bin=044octave=01note=20
	retlw	(D'01'*D'24')+D'20'	;scale=16bin=045octave=01note=21
	retlw	(D'01'*D'24')+D'20'	;scale=16bin=046octave=01note=22
	retlw	(D'01'*D'24')+D'20'	;scale=16bin=047octave=01note=23
	retlw	(D'02'*D'24')+D'00'	;scale=16bin=048octave=02note=00
	retlw	(D'02'*D'24')+D'00'	;scale=16bin=049octave=02note=01
	retlw	(D'02'*D'24')+D'00'	;scale=16bin=050octave=02note=02
	retlw	(D'02'*D'24')+D'00'	;scale=16bin=051octave=02note=03
	retlw	(D'02'*D'24')+D'04'	;scale=16bin=052octave=02note=04
	retlw	(D'02'*D'24')+D'04'	;scale=16bin=053octave=02note=05
	retlw	(D'02'*D'24')+D'04'	;scale=16bin=054octave=02note=06
	retlw	(D'02'*D'24')+D'04'	;scale=16bin=055octave=02note=07
	retlw	(D'02'*D'24')+D'08'	;scale=16bin=056octave=02note=08
	retlw	(D'02'*D'24')+D'08'	;scale=16bin=057octave=02note=09
	retlw	(D'02'*D'24')+D'10'	;scale=16bin=058octave=02note=10
	retlw	(D'02'*D'24')+D'10'	;scale=16bin=059octave=02note=11
	retlw	(D'02'*D'24')+D'10'	;scale=16bin=060octave=02note=12
	retlw	(D'02'*D'24')+D'10'	;scale=16bin=061octave=02note=13
	retlw	(D'02'*D'24')+D'14'	;scale=16bin=062octave=02note=14
	retlw	(D'02'*D'24')+D'14'	;scale=16bin=063octave=02note=15
	retlw	(D'02'*D'24')+D'16'	;scale=16bin=064octave=02note=16
	retlw	(D'02'*D'24')+D'16'	;scale=16bin=065octave=02note=17
	retlw	(D'02'*D'24')+D'16'	;scale=16bin=066octave=02note=18
	retlw	(D'02'*D'24')+D'16'	;scale=16bin=067octave=02note=19
	retlw	(D'02'*D'24')+D'20'	;scale=16bin=068octave=02note=20
	retlw	(D'02'*D'24')+D'20'	;scale=16bin=069octave=02note=21
	retlw	(D'02'*D'24')+D'20'	;scale=16bin=070octave=02note=22
	retlw	(D'02'*D'24')+D'20'	;scale=16bin=071octave=02note=23
	retlw	(D'03'*D'24')+D'00'	;scale=16bin=072octave=03note=00
	retlw	(D'03'*D'24')+D'00'	;scale=16bin=073octave=03note=01
	retlw	(D'03'*D'24')+D'00'	;scale=16bin=074octave=03note=02
	retlw	(D'03'*D'24')+D'00'	;scale=16bin=075octave=03note=03
	retlw	(D'03'*D'24')+D'04'	;scale=16bin=076octave=03note=04
	retlw	(D'03'*D'24')+D'04'	;scale=16bin=077octave=03note=05
	retlw	(D'03'*D'24')+D'04'	;scale=16bin=078octave=03note=06
	retlw	(D'03'*D'24')+D'04'	;scale=16bin=079octave=03note=07
	retlw	(D'03'*D'24')+D'08'	;scale=16bin=080octave=03note=08
	retlw	(D'03'*D'24')+D'08'	;scale=16bin=081octave=03note=09
	retlw	(D'03'*D'24')+D'10'	;scale=16bin=082octave=03note=10
	retlw	(D'03'*D'24')+D'10'	;scale=16bin=083octave=03note=11
	retlw	(D'03'*D'24')+D'10'	;scale=16bin=084octave=03note=12
	retlw	(D'03'*D'24')+D'10'	;scale=16bin=085octave=03note=13
	retlw	(D'03'*D'24')+D'14'	;scale=16bin=086octave=03note=14
	retlw	(D'03'*D'24')+D'14'	;scale=16bin=087octave=03note=15
	retlw	(D'03'*D'24')+D'16'	;scale=16bin=088octave=03note=16
	retlw	(D'03'*D'24')+D'16'	;scale=16bin=089octave=03note=17
	retlw	(D'03'*D'24')+D'16'	;scale=16bin=090octave=03note=18
	retlw	(D'03'*D'24')+D'16'	;scale=16bin=091octave=03note=19
	retlw	(D'03'*D'24')+D'20'	;scale=16bin=092octave=03note=20
	retlw	(D'03'*D'24')+D'20'	;scale=16bin=093octave=03note=21
	retlw	(D'03'*D'24')+D'20'	;scale=16bin=094octave=03note=22
	retlw	(D'03'*D'24')+D'20'	;scale=16bin=095octave=03note=23
	retlw	(D'04'*D'24')+D'00'	;scale=16bin=096octave=04note=00
	retlw	(D'04'*D'24')+D'00'	;scale=16bin=097octave=04note=01
	retlw	(D'04'*D'24')+D'00'	;scale=16bin=098octave=04note=02
	retlw	(D'04'*D'24')+D'00'	;scale=16bin=099octave=04note=03
	retlw	(D'04'*D'24')+D'04'	;scale=16bin=100octave=04note=04
	retlw	(D'04'*D'24')+D'04'	;scale=16bin=101octave=04note=05
	retlw	(D'04'*D'24')+D'04'	;scale=16bin=102octave=04note=06
	retlw	(D'04'*D'24')+D'04'	;scale=16bin=103octave=04note=07
	retlw	(D'04'*D'24')+D'08'	;scale=16bin=104octave=04note=08
	retlw	(D'04'*D'24')+D'08'	;scale=16bin=105octave=04note=09
	retlw	(D'04'*D'24')+D'10'	;scale=16bin=106octave=04note=10
	retlw	(D'04'*D'24')+D'10'	;scale=16bin=107octave=04note=11
	retlw	(D'04'*D'24')+D'10'	;scale=16bin=108octave=04note=12
	retlw	(D'04'*D'24')+D'10'	;scale=16bin=109octave=04note=13
	retlw	(D'04'*D'24')+D'14'	;scale=16bin=110octave=04note=14
	retlw	(D'04'*D'24')+D'14'	;scale=16bin=111octave=04note=15
	retlw	(D'04'*D'24')+D'16'	;scale=16bin=112octave=04note=16
	retlw	(D'04'*D'24')+D'16'	;scale=16bin=113octave=04note=17
	retlw	(D'04'*D'24')+D'16'	;scale=16bin=114octave=04note=18
	retlw	(D'04'*D'24')+D'16'	;scale=16bin=115octave=04note=19
	retlw	(D'04'*D'24')+D'20'	;scale=16bin=116octave=04note=20
	retlw	(D'04'*D'24')+D'20'	;scale=16bin=117octave=04note=21
	retlw	(D'04'*D'24')+D'20'	;scale=16bin=118octave=04note=22
	retlw	(D'04'*D'24')+D'20'	;scale=16bin=119octave=04note=23
	retlw	(D'05'*D'24')+D'00'	;scale=16bin=120octave=05note=00
	retlw	(D'05'*D'24')+D'00'	;scale=16bin=121octave=05note=01
	retlw	(D'05'*D'24')+D'00'	;scale=16bin=122octave=05note=02
	retlw	(D'05'*D'24')+D'00'	;scale=16bin=123octave=05note=03
	retlw	(D'05'*D'24')+D'04'	;scale=16bin=124octave=05note=04
	retlw	(D'05'*D'24')+D'04'	;scale=16bin=125octave=05note=05
	retlw	(D'05'*D'24')+D'04'	;scale=16bin=126octave=05note=06
	retlw	(D'05'*D'24')+D'04'	;scale=16bin=127octave=05note=07
	retlw	(D'05'*D'24')+D'08'	;scale=16bin=128octave=05note=08
	retlw	(D'05'*D'24')+D'08'	;scale=16bin=129octave=05note=09
	retlw	(D'05'*D'24')+D'10'	;scale=16bin=130octave=05note=10
	retlw	(D'05'*D'24')+D'10'	;scale=16bin=131octave=05note=11
	retlw	(D'05'*D'24')+D'10'	;scale=16bin=132octave=05note=12
	retlw	(D'05'*D'24')+D'10'	;scale=16bin=133octave=05note=13
	retlw	(D'05'*D'24')+D'14'	;scale=16bin=134octave=05note=14
	retlw	(D'05'*D'24')+D'14'	;scale=16bin=135octave=05note=15
	retlw	(D'05'*D'24')+D'16'	;scale=16bin=136octave=05note=16
	retlw	(D'05'*D'24')+D'16'	;scale=16bin=137octave=05note=17
	retlw	(D'05'*D'24')+D'16'	;scale=16bin=138octave=05note=18
	retlw	(D'05'*D'24')+D'16'	;scale=16bin=139octave=05note=19
	retlw	(D'05'*D'24')+D'20'	;scale=16bin=140octave=05note=20
	retlw	(D'05'*D'24')+D'20'	;scale=16bin=141octave=05note=21
	retlw	(D'05'*D'24')+D'20'	;scale=16bin=142octave=05note=22
	retlw	(D'05'*D'24')+D'20'	;scale=16bin=143octave=05note=23
	retlw	(D'06'*D'24')+D'00'	;scale=16bin=144octave=06note=00
	retlw	(D'06'*D'24')+D'00'	;scale=16bin=145octave=06note=01
	retlw	(D'06'*D'24')+D'00'	;scale=16bin=146octave=06note=02
	retlw	(D'06'*D'24')+D'00'	;scale=16bin=147octave=06note=03
	retlw	(D'06'*D'24')+D'04'	;scale=16bin=148octave=06note=04
	retlw	(D'06'*D'24')+D'04'	;scale=16bin=149octave=06note=05
	retlw	(D'06'*D'24')+D'04'	;scale=16bin=150octave=06note=06
	retlw	(D'06'*D'24')+D'04'	;scale=16bin=151octave=06note=07
	retlw	(D'06'*D'24')+D'08'	;scale=16bin=152octave=06note=08
	retlw	(D'06'*D'24')+D'08'	;scale=16bin=153octave=06note=09
	retlw	(D'06'*D'24')+D'10'	;scale=16bin=154octave=06note=10
	retlw	(D'06'*D'24')+D'10'	;scale=16bin=155octave=06note=11
	retlw	(D'06'*D'24')+D'10'	;scale=16bin=156octave=06note=12
	retlw	(D'06'*D'24')+D'10'	;scale=16bin=157octave=06note=13
	retlw	(D'06'*D'24')+D'14'	;scale=16bin=158octave=06note=14
	retlw	(D'06'*D'24')+D'14'	;scale=16bin=159octave=06note=15
	retlw	(D'06'*D'24')+D'16'	;scale=16bin=160octave=06note=16
	retlw	(D'06'*D'24')+D'16'	;scale=16bin=161octave=06note=17
	retlw	(D'06'*D'24')+D'16'	;scale=16bin=162octave=06note=18
	retlw	(D'06'*D'24')+D'16'	;scale=16bin=163octave=06note=19
	retlw	(D'06'*D'24')+D'20'	;scale=16bin=164octave=06note=20
	retlw	(D'06'*D'24')+D'20'	;scale=16bin=165octave=06note=21
	retlw	(D'06'*D'24')+D'20'	;scale=16bin=166octave=06note=22
	retlw	(D'06'*D'24')+D'20'	;scale=16bin=167octave=06note=23
	retlw	(D'07'*D'24')+D'00'	;scale=16bin=168octave=07note=00
	retlw	(D'07'*D'24')+D'00'	;scale=16bin=169octave=07note=01
	retlw	(D'07'*D'24')+D'00'	;scale=16bin=170octave=07note=02
	retlw	(D'07'*D'24')+D'00'	;scale=16bin=171octave=07note=03
	retlw	(D'07'*D'24')+D'04'	;scale=16bin=172octave=07note=04
	retlw	(D'07'*D'24')+D'04'	;scale=16bin=173octave=07note=05
	retlw	(D'07'*D'24')+D'04'	;scale=16bin=174octave=07note=06
	retlw	(D'07'*D'24')+D'04'	;scale=16bin=175octave=07note=07
	retlw	(D'07'*D'24')+D'08'	;scale=16bin=176octave=07note=08
	retlw	(D'07'*D'24')+D'08'	;scale=16bin=177octave=07note=09
	retlw	(D'07'*D'24')+D'10'	;scale=16bin=178octave=07note=10
	retlw	(D'07'*D'24')+D'10'	;scale=16bin=179octave=07note=11
	retlw	(D'07'*D'24')+D'10'	;scale=16bin=180octave=07note=12
	retlw	(D'07'*D'24')+D'10'	;scale=16bin=181octave=07note=13
	retlw	(D'07'*D'24')+D'14'	;scale=16bin=182octave=07note=14
	retlw	(D'07'*D'24')+D'14'	;scale=16bin=183octave=07note=15
	retlw	(D'07'*D'24')+D'16'	;scale=16bin=184octave=07note=16
	retlw	(D'07'*D'24')+D'16'	;scale=16bin=185octave=07note=17
	retlw	(D'07'*D'24')+D'16'	;scale=16bin=186octave=07note=18
	retlw	(D'07'*D'24')+D'16'	;scale=16bin=187octave=07note=19
	retlw	(D'07'*D'24')+D'20'	;scale=16bin=188octave=07note=20
	retlw	(D'07'*D'24')+D'20'	;scale=16bin=189octave=07note=21
	retlw	(D'07'*D'24')+D'20'	;scale=16bin=190octave=07note=22
	retlw	(D'07'*D'24')+D'20'	;scale=16bin=191octave=07note=23
	retlw	(D'08'*D'24')+D'00'	;scale=16bin=192octave=08note=00
	retlw	(D'08'*D'24')+D'00'	;scale=16bin=193octave=08note=01
	retlw	(D'08'*D'24')+D'00'	;scale=16bin=194octave=08note=02
	retlw	(D'08'*D'24')+D'00'	;scale=16bin=195octave=08note=03
	retlw	(D'08'*D'24')+D'04'	;scale=16bin=196octave=08note=04
	retlw	(D'08'*D'24')+D'04'	;scale=16bin=197octave=08note=05
	retlw	(D'08'*D'24')+D'04'	;scale=16bin=198octave=08note=06
	retlw	(D'08'*D'24')+D'04'	;scale=16bin=199octave=08note=07
	retlw	(D'08'*D'24')+D'08'	;scale=16bin=200octave=08note=08
	retlw	(D'08'*D'24')+D'08'	;scale=16bin=201octave=08note=09
	retlw	(D'08'*D'24')+D'10'	;scale=16bin=202octave=08note=10
	retlw	(D'08'*D'24')+D'10'	;scale=16bin=203octave=08note=11
	retlw	(D'08'*D'24')+D'10'	;scale=16bin=204octave=08note=12
	retlw	(D'08'*D'24')+D'10'	;scale=16bin=205octave=08note=13
	retlw	(D'08'*D'24')+D'14'	;scale=16bin=206octave=08note=14
	retlw	(D'08'*D'24')+D'14'	;scale=16bin=207octave=08note=15
	retlw	(D'08'*D'24')+D'16'	;scale=16bin=208octave=08note=16
	retlw	(D'08'*D'24')+D'16'	;scale=16bin=209octave=08note=17
	retlw	(D'08'*D'24')+D'16'	;scale=16bin=210octave=08note=18
	retlw	(D'08'*D'24')+D'16'	;scale=16bin=211octave=08note=19
	retlw	(D'08'*D'24')+D'20'	;scale=16bin=212octave=08note=20
	retlw	(D'08'*D'24')+D'20'	;scale=16bin=213octave=08note=21
	retlw	(D'08'*D'24')+D'20'	;scale=16bin=214octave=08note=22
	retlw	(D'08'*D'24')+D'20'	;scale=16bin=215octave=08note=23
	retlw	(D'09'*D'24')+D'00'	;scale=16bin=216octave=09note=00
	retlw	(D'09'*D'24')+D'00'	;scale=16bin=217octave=09note=01
	retlw	(D'09'*D'24')+D'00'	;scale=16bin=218octave=09note=02
	retlw	(D'09'*D'24')+D'00'	;scale=16bin=219octave=09note=03
	retlw	(D'09'*D'24')+D'04'	;scale=16bin=220octave=09note=04
	retlw	(D'09'*D'24')+D'04'	;scale=16bin=221octave=09note=05
	retlw	(D'09'*D'24')+D'04'	;scale=16bin=222octave=09note=06
	retlw	(D'09'*D'24')+D'04'	;scale=16bin=223octave=09note=07
	retlw	(D'09'*D'24')+D'08'	;scale=16bin=224octave=09note=08
	retlw	(D'09'*D'24')+D'08'	;scale=16bin=225octave=09note=09
	retlw	(D'09'*D'24')+D'10'	;scale=16bin=226octave=09note=10
	retlw	(D'09'*D'24')+D'10'	;scale=16bin=227octave=09note=11
	retlw	(D'09'*D'24')+D'10'	;scale=16bin=228octave=09note=12
	retlw	(D'09'*D'24')+D'10'	;scale=16bin=229octave=09note=13
	retlw	(D'09'*D'24')+D'14'	;scale=16bin=230octave=09note=14
	retlw	(D'09'*D'24')+D'14'	;scale=16bin=231octave=09note=15
	retlw	(D'09'*D'24')+D'16'	;scale=16bin=232octave=09note=16
	retlw	(D'09'*D'24')+D'16'	;scale=16bin=233octave=09note=17
	retlw	(D'09'*D'24')+D'16'	;scale=16bin=234octave=09note=18
	retlw	(D'09'*D'24')+D'16'	;scale=16bin=235octave=09note=19
	retlw	(D'09'*D'24')+D'20'	;scale=16bin=236octave=09note=20
	retlw	(D'09'*D'24')+D'20'	;scale=16bin=237octave=09note=21
	retlw	(D'09'*D'24')+D'20'	;scale=16bin=238octave=09note=22
	retlw	(D'09'*D'24')+D'20'	;scale=16bin=239octave=09note=23
	retlw	(D'10'*D'24')+D'00'	;scale=16bin=240octave=10note=00
	retlw	(D'10'*D'24')+D'00'	;scale=16bin=241octave=10note=01
	retlw	(D'10'*D'24')+D'00'	;scale=16bin=242octave=10note=02
	retlw	(D'10'*D'24')+D'00'	;scale=16bin=243octave=10note=03
	retlw	(D'10'*D'24')+D'00'	;scale=16bin=244octave=10note=04
	retlw	(D'10'*D'24')+D'00'	;scale=16bin=245octave=10note=05
	retlw	(D'10'*D'24')+D'00'	;scale=16bin=246octave=10note=06
	retlw	(D'10'*D'24')+D'00'	;scale=16bin=247octave=10note=07
	retlw	(D'10'*D'24')+D'00'	;scale=16bin=248octave=10note=08
	retlw	(D'10'*D'24')+D'00'	;scale=16bin=249octave=10note=09
	retlw	(D'10'*D'24')+D'00'	;scale=16bin=250octave=10note=10
	retlw	(D'10'*D'24')+D'00'	;scale=16bin=251octave=10note=11
	retlw	(D'10'*D'24')+D'00'	;scale=16bin=252octave=10note=12
	retlw	(D'10'*D'24')+D'00'	;scale=16bin=253octave=10note=13
	retlw	(D'10'*D'24')+D'00'	;scale=16bin=254octave=10note=14
	retlw	(D'10'*D'24')+D'00'	;scale=16bin=255octave=10note=15

;	Hungarian Minor look-up table
	org	HungMin		;Hungarian Minor look-up table
	retlw	(D'00'*D'24')+D'00'	;scale=17bin=000octave=00note=00
	retlw	(D'00'*D'24')+D'00'	;scale=17bin=001octave=00note=01
	retlw	(D'00'*D'24')+D'00'	;scale=17bin=002octave=00note=02
	retlw	(D'00'*D'24')+D'00'	;scale=17bin=003octave=00note=03
	retlw	(D'00'*D'24')+D'04'	;scale=17bin=004octave=00note=04
	retlw	(D'00'*D'24')+D'04'	;scale=17bin=005octave=00note=05
	retlw	(D'00'*D'24')+D'06'	;scale=17bin=006octave=00note=06
	retlw	(D'00'*D'24')+D'06'	;scale=17bin=007octave=00note=07
	retlw	(D'00'*D'24')+D'06'	;scale=17bin=008octave=00note=08
	retlw	(D'00'*D'24')+D'06'	;scale=17bin=009octave=00note=09
	retlw	(D'00'*D'24')+D'06'	;scale=17bin=010octave=00note=10
	retlw	(D'00'*D'24')+D'06'	;scale=17bin=011octave=00note=11
	retlw	(D'00'*D'24')+D'12'	;scale=17bin=012octave=00note=12
	retlw	(D'00'*D'24')+D'12'	;scale=17bin=013octave=00note=13
	retlw	(D'00'*D'24')+D'14'	;scale=17bin=014octave=00note=14
	retlw	(D'00'*D'24')+D'14'	;scale=17bin=015octave=00note=15
	retlw	(D'00'*D'24')+D'16'	;scale=17bin=016octave=00note=16
	retlw	(D'00'*D'24')+D'16'	;scale=17bin=017octave=00note=17
	retlw	(D'00'*D'24')+D'16'	;scale=17bin=018octave=00note=18
	retlw	(D'00'*D'24')+D'16'	;scale=17bin=019octave=00note=19
	retlw	(D'00'*D'24')+D'16'	;scale=17bin=020octave=00note=20
	retlw	(D'00'*D'24')+D'16'	;scale=17bin=021octave=00note=21
	retlw	(D'00'*D'24')+D'22'	;scale=17bin=022octave=00note=22
	retlw	(D'00'*D'24')+D'22'	;scale=17bin=023octave=00note=23
	retlw	(D'01'*D'24')+D'00'	;scale=17bin=024octave=01note=00
	retlw	(D'01'*D'24')+D'00'	;scale=17bin=025octave=01note=01
	retlw	(D'01'*D'24')+D'00'	;scale=17bin=026octave=01note=02
	retlw	(D'01'*D'24')+D'00'	;scale=17bin=027octave=01note=03
	retlw	(D'01'*D'24')+D'04'	;scale=17bin=028octave=01note=04
	retlw	(D'01'*D'24')+D'04'	;scale=17bin=029octave=01note=05
	retlw	(D'01'*D'24')+D'06'	;scale=17bin=030octave=01note=06
	retlw	(D'01'*D'24')+D'06'	;scale=17bin=031octave=01note=07
	retlw	(D'01'*D'24')+D'06'	;scale=17bin=032octave=01note=08
	retlw	(D'01'*D'24')+D'06'	;scale=17bin=033octave=01note=09
	retlw	(D'01'*D'24')+D'06'	;scale=17bin=034octave=01note=10
	retlw	(D'01'*D'24')+D'06'	;scale=17bin=035octave=01note=11
	retlw	(D'01'*D'24')+D'12'	;scale=17bin=036octave=01note=12
	retlw	(D'01'*D'24')+D'12'	;scale=17bin=037octave=01note=13
	retlw	(D'01'*D'24')+D'14'	;scale=17bin=038octave=01note=14
	retlw	(D'01'*D'24')+D'14'	;scale=17bin=039octave=01note=15
	retlw	(D'01'*D'24')+D'16'	;scale=17bin=040octave=01note=16
	retlw	(D'01'*D'24')+D'16'	;scale=17bin=041octave=01note=17
	retlw	(D'01'*D'24')+D'16'	;scale=17bin=042octave=01note=18
	retlw	(D'01'*D'24')+D'16'	;scale=17bin=043octave=01note=19
	retlw	(D'01'*D'24')+D'16'	;scale=17bin=044octave=01note=20
	retlw	(D'01'*D'24')+D'16'	;scale=17bin=045octave=01note=21
	retlw	(D'01'*D'24')+D'22'	;scale=17bin=046octave=01note=22
	retlw	(D'01'*D'24')+D'22'	;scale=17bin=047octave=01note=23
	retlw	(D'02'*D'24')+D'00'	;scale=17bin=048octave=02note=00
	retlw	(D'02'*D'24')+D'00'	;scale=17bin=049octave=02note=01
	retlw	(D'02'*D'24')+D'00'	;scale=17bin=050octave=02note=02
	retlw	(D'02'*D'24')+D'00'	;scale=17bin=051octave=02note=03
	retlw	(D'02'*D'24')+D'04'	;scale=17bin=052octave=02note=04
	retlw	(D'02'*D'24')+D'04'	;scale=17bin=053octave=02note=05
	retlw	(D'02'*D'24')+D'06'	;scale=17bin=054octave=02note=06
	retlw	(D'02'*D'24')+D'06'	;scale=17bin=055octave=02note=07
	retlw	(D'02'*D'24')+D'06'	;scale=17bin=056octave=02note=08
	retlw	(D'02'*D'24')+D'06'	;scale=17bin=057octave=02note=09
	retlw	(D'02'*D'24')+D'06'	;scale=17bin=058octave=02note=10
	retlw	(D'02'*D'24')+D'06'	;scale=17bin=059octave=02note=11
	retlw	(D'02'*D'24')+D'12'	;scale=17bin=060octave=02note=12
	retlw	(D'02'*D'24')+D'12'	;scale=17bin=061octave=02note=13
	retlw	(D'02'*D'24')+D'14'	;scale=17bin=062octave=02note=14
	retlw	(D'02'*D'24')+D'14'	;scale=17bin=063octave=02note=15
	retlw	(D'02'*D'24')+D'16'	;scale=17bin=064octave=02note=16
	retlw	(D'02'*D'24')+D'16'	;scale=17bin=065octave=02note=17
	retlw	(D'02'*D'24')+D'16'	;scale=17bin=066octave=02note=18
	retlw	(D'02'*D'24')+D'16'	;scale=17bin=067octave=02note=19
	retlw	(D'02'*D'24')+D'16'	;scale=17bin=068octave=02note=20
	retlw	(D'02'*D'24')+D'16'	;scale=17bin=069octave=02note=21
	retlw	(D'02'*D'24')+D'22'	;scale=17bin=070octave=02note=22
	retlw	(D'02'*D'24')+D'22'	;scale=17bin=071octave=02note=23
	retlw	(D'03'*D'24')+D'00'	;scale=17bin=072octave=03note=00
	retlw	(D'03'*D'24')+D'00'	;scale=17bin=073octave=03note=01
	retlw	(D'03'*D'24')+D'00'	;scale=17bin=074octave=03note=02
	retlw	(D'03'*D'24')+D'00'	;scale=17bin=075octave=03note=03
	retlw	(D'03'*D'24')+D'04'	;scale=17bin=076octave=03note=04
	retlw	(D'03'*D'24')+D'04'	;scale=17bin=077octave=03note=05
	retlw	(D'03'*D'24')+D'06'	;scale=17bin=078octave=03note=06
	retlw	(D'03'*D'24')+D'06'	;scale=17bin=079octave=03note=07
	retlw	(D'03'*D'24')+D'06'	;scale=17bin=080octave=03note=08
	retlw	(D'03'*D'24')+D'06'	;scale=17bin=081octave=03note=09
	retlw	(D'03'*D'24')+D'06'	;scale=17bin=082octave=03note=10
	retlw	(D'03'*D'24')+D'06'	;scale=17bin=083octave=03note=11
	retlw	(D'03'*D'24')+D'12'	;scale=17bin=084octave=03note=12
	retlw	(D'03'*D'24')+D'12'	;scale=17bin=085octave=03note=13
	retlw	(D'03'*D'24')+D'14'	;scale=17bin=086octave=03note=14
	retlw	(D'03'*D'24')+D'14'	;scale=17bin=087octave=03note=15
	retlw	(D'03'*D'24')+D'16'	;scale=17bin=088octave=03note=16
	retlw	(D'03'*D'24')+D'16'	;scale=17bin=089octave=03note=17
	retlw	(D'03'*D'24')+D'16'	;scale=17bin=090octave=03note=18
	retlw	(D'03'*D'24')+D'16'	;scale=17bin=091octave=03note=19
	retlw	(D'03'*D'24')+D'16'	;scale=17bin=092octave=03note=20
	retlw	(D'03'*D'24')+D'16'	;scale=17bin=093octave=03note=21
	retlw	(D'03'*D'24')+D'22'	;scale=17bin=094octave=03note=22
	retlw	(D'03'*D'24')+D'22'	;scale=17bin=095octave=03note=23
	retlw	(D'04'*D'24')+D'00'	;scale=17bin=096octave=04note=00
	retlw	(D'04'*D'24')+D'00'	;scale=17bin=097octave=04note=01
	retlw	(D'04'*D'24')+D'00'	;scale=17bin=098octave=04note=02
	retlw	(D'04'*D'24')+D'00'	;scale=17bin=099octave=04note=03
	retlw	(D'04'*D'24')+D'04'	;scale=17bin=100octave=04note=04
	retlw	(D'04'*D'24')+D'04'	;scale=17bin=101octave=04note=05
	retlw	(D'04'*D'24')+D'06'	;scale=17bin=102octave=04note=06
	retlw	(D'04'*D'24')+D'06'	;scale=17bin=103octave=04note=07
	retlw	(D'04'*D'24')+D'06'	;scale=17bin=104octave=04note=08
	retlw	(D'04'*D'24')+D'06'	;scale=17bin=105octave=04note=09
	retlw	(D'04'*D'24')+D'06'	;scale=17bin=106octave=04note=10
	retlw	(D'04'*D'24')+D'06'	;scale=17bin=107octave=04note=11
	retlw	(D'04'*D'24')+D'12'	;scale=17bin=108octave=04note=12
	retlw	(D'04'*D'24')+D'12'	;scale=17bin=109octave=04note=13
	retlw	(D'04'*D'24')+D'14'	;scale=17bin=110octave=04note=14
	retlw	(D'04'*D'24')+D'14'	;scale=17bin=111octave=04note=15
	retlw	(D'04'*D'24')+D'16'	;scale=17bin=112octave=04note=16
	retlw	(D'04'*D'24')+D'16'	;scale=17bin=113octave=04note=17
	retlw	(D'04'*D'24')+D'16'	;scale=17bin=114octave=04note=18
	retlw	(D'04'*D'24')+D'16'	;scale=17bin=115octave=04note=19
	retlw	(D'04'*D'24')+D'16'	;scale=17bin=116octave=04note=20
	retlw	(D'04'*D'24')+D'16'	;scale=17bin=117octave=04note=21
	retlw	(D'04'*D'24')+D'22'	;scale=17bin=118octave=04note=22
	retlw	(D'04'*D'24')+D'22'	;scale=17bin=119octave=04note=23
	retlw	(D'05'*D'24')+D'00'	;scale=17bin=120octave=05note=00
	retlw	(D'05'*D'24')+D'00'	;scale=17bin=121octave=05note=01
	retlw	(D'05'*D'24')+D'00'	;scale=17bin=122octave=05note=02
	retlw	(D'05'*D'24')+D'00'	;scale=17bin=123octave=05note=03
	retlw	(D'05'*D'24')+D'04'	;scale=17bin=124octave=05note=04
	retlw	(D'05'*D'24')+D'04'	;scale=17bin=125octave=05note=05
	retlw	(D'05'*D'24')+D'06'	;scale=17bin=126octave=05note=06
	retlw	(D'05'*D'24')+D'06'	;scale=17bin=127octave=05note=07
	retlw	(D'05'*D'24')+D'06'	;scale=17bin=128octave=05note=08
	retlw	(D'05'*D'24')+D'06'	;scale=17bin=129octave=05note=09
	retlw	(D'05'*D'24')+D'06'	;scale=17bin=130octave=05note=10
	retlw	(D'05'*D'24')+D'06'	;scale=17bin=131octave=05note=11
	retlw	(D'05'*D'24')+D'12'	;scale=17bin=132octave=05note=12
	retlw	(D'05'*D'24')+D'12'	;scale=17bin=133octave=05note=13
	retlw	(D'05'*D'24')+D'14'	;scale=17bin=134octave=05note=14
	retlw	(D'05'*D'24')+D'14'	;scale=17bin=135octave=05note=15
	retlw	(D'05'*D'24')+D'16'	;scale=17bin=136octave=05note=16
	retlw	(D'05'*D'24')+D'16'	;scale=17bin=137octave=05note=17
	retlw	(D'05'*D'24')+D'16'	;scale=17bin=138octave=05note=18
	retlw	(D'05'*D'24')+D'16'	;scale=17bin=139octave=05note=19
	retlw	(D'05'*D'24')+D'16'	;scale=17bin=140octave=05note=20
	retlw	(D'05'*D'24')+D'16'	;scale=17bin=141octave=05note=21
	retlw	(D'05'*D'24')+D'22'	;scale=17bin=142octave=05note=22
	retlw	(D'05'*D'24')+D'22'	;scale=17bin=143octave=05note=23
	retlw	(D'06'*D'24')+D'00'	;scale=17bin=144octave=06note=00
	retlw	(D'06'*D'24')+D'00'	;scale=17bin=145octave=06note=01
	retlw	(D'06'*D'24')+D'00'	;scale=17bin=146octave=06note=02
	retlw	(D'06'*D'24')+D'00'	;scale=17bin=147octave=06note=03
	retlw	(D'06'*D'24')+D'04'	;scale=17bin=148octave=06note=04
	retlw	(D'06'*D'24')+D'04'	;scale=17bin=149octave=06note=05
	retlw	(D'06'*D'24')+D'06'	;scale=17bin=150octave=06note=06
	retlw	(D'06'*D'24')+D'06'	;scale=17bin=151octave=06note=07
	retlw	(D'06'*D'24')+D'06'	;scale=17bin=152octave=06note=08
	retlw	(D'06'*D'24')+D'06'	;scale=17bin=153octave=06note=09
	retlw	(D'06'*D'24')+D'06'	;scale=17bin=154octave=06note=10
	retlw	(D'06'*D'24')+D'06'	;scale=17bin=155octave=06note=11
	retlw	(D'06'*D'24')+D'12'	;scale=17bin=156octave=06note=12
	retlw	(D'06'*D'24')+D'12'	;scale=17bin=157octave=06note=13
	retlw	(D'06'*D'24')+D'14'	;scale=17bin=158octave=06note=14
	retlw	(D'06'*D'24')+D'14'	;scale=17bin=159octave=06note=15
	retlw	(D'06'*D'24')+D'16'	;scale=17bin=160octave=06note=16
	retlw	(D'06'*D'24')+D'16'	;scale=17bin=161octave=06note=17
	retlw	(D'06'*D'24')+D'16'	;scale=17bin=162octave=06note=18
	retlw	(D'06'*D'24')+D'16'	;scale=17bin=163octave=06note=19
	retlw	(D'06'*D'24')+D'16'	;scale=17bin=164octave=06note=20
	retlw	(D'06'*D'24')+D'16'	;scale=17bin=165octave=06note=21
	retlw	(D'06'*D'24')+D'22'	;scale=17bin=166octave=06note=22
	retlw	(D'06'*D'24')+D'22'	;scale=17bin=167octave=06note=23
	retlw	(D'07'*D'24')+D'00'	;scale=17bin=168octave=07note=00
	retlw	(D'07'*D'24')+D'00'	;scale=17bin=169octave=07note=01
	retlw	(D'07'*D'24')+D'00'	;scale=17bin=170octave=07note=02
	retlw	(D'07'*D'24')+D'00'	;scale=17bin=171octave=07note=03
	retlw	(D'07'*D'24')+D'04'	;scale=17bin=172octave=07note=04
	retlw	(D'07'*D'24')+D'04'	;scale=17bin=173octave=07note=05
	retlw	(D'07'*D'24')+D'06'	;scale=17bin=174octave=07note=06
	retlw	(D'07'*D'24')+D'06'	;scale=17bin=175octave=07note=07
	retlw	(D'07'*D'24')+D'06'	;scale=17bin=176octave=07note=08
	retlw	(D'07'*D'24')+D'06'	;scale=17bin=177octave=07note=09
	retlw	(D'07'*D'24')+D'06'	;scale=17bin=178octave=07note=10
	retlw	(D'07'*D'24')+D'06'	;scale=17bin=179octave=07note=11
	retlw	(D'07'*D'24')+D'12'	;scale=17bin=180octave=07note=12
	retlw	(D'07'*D'24')+D'12'	;scale=17bin=181octave=07note=13
	retlw	(D'07'*D'24')+D'14'	;scale=17bin=182octave=07note=14
	retlw	(D'07'*D'24')+D'14'	;scale=17bin=183octave=07note=15
	retlw	(D'07'*D'24')+D'16'	;scale=17bin=184octave=07note=16
	retlw	(D'07'*D'24')+D'16'	;scale=17bin=185octave=07note=17
	retlw	(D'07'*D'24')+D'16'	;scale=17bin=186octave=07note=18
	retlw	(D'07'*D'24')+D'16'	;scale=17bin=187octave=07note=19
	retlw	(D'07'*D'24')+D'16'	;scale=17bin=188octave=07note=20
	retlw	(D'07'*D'24')+D'16'	;scale=17bin=189octave=07note=21
	retlw	(D'07'*D'24')+D'22'	;scale=17bin=190octave=07note=22
	retlw	(D'07'*D'24')+D'22'	;scale=17bin=191octave=07note=23
	retlw	(D'08'*D'24')+D'00'	;scale=17bin=192octave=08note=00
	retlw	(D'08'*D'24')+D'00'	;scale=17bin=193octave=08note=01
	retlw	(D'08'*D'24')+D'00'	;scale=17bin=194octave=08note=02
	retlw	(D'08'*D'24')+D'00'	;scale=17bin=195octave=08note=03
	retlw	(D'08'*D'24')+D'04'	;scale=17bin=196octave=08note=04
	retlw	(D'08'*D'24')+D'04'	;scale=17bin=197octave=08note=05
	retlw	(D'08'*D'24')+D'06'	;scale=17bin=198octave=08note=06
	retlw	(D'08'*D'24')+D'06'	;scale=17bin=199octave=08note=07
	retlw	(D'08'*D'24')+D'06'	;scale=17bin=200octave=08note=08
	retlw	(D'08'*D'24')+D'06'	;scale=17bin=201octave=08note=09
	retlw	(D'08'*D'24')+D'06'	;scale=17bin=202octave=08note=10
	retlw	(D'08'*D'24')+D'06'	;scale=17bin=203octave=08note=11
	retlw	(D'08'*D'24')+D'12'	;scale=17bin=204octave=08note=12
	retlw	(D'08'*D'24')+D'12'	;scale=17bin=205octave=08note=13
	retlw	(D'08'*D'24')+D'14'	;scale=17bin=206octave=08note=14
	retlw	(D'08'*D'24')+D'14'	;scale=17bin=207octave=08note=15
	retlw	(D'08'*D'24')+D'16'	;scale=17bin=208octave=08note=16
	retlw	(D'08'*D'24')+D'16'	;scale=17bin=209octave=08note=17
	retlw	(D'08'*D'24')+D'16'	;scale=17bin=210octave=08note=18
	retlw	(D'08'*D'24')+D'16'	;scale=17bin=211octave=08note=19
	retlw	(D'08'*D'24')+D'16'	;scale=17bin=212octave=08note=20
	retlw	(D'08'*D'24')+D'16'	;scale=17bin=213octave=08note=21
	retlw	(D'08'*D'24')+D'22'	;scale=17bin=214octave=08note=22
	retlw	(D'08'*D'24')+D'22'	;scale=17bin=215octave=08note=23
	retlw	(D'09'*D'24')+D'00'	;scale=17bin=216octave=09note=00
	retlw	(D'09'*D'24')+D'00'	;scale=17bin=217octave=09note=01
	retlw	(D'09'*D'24')+D'00'	;scale=17bin=218octave=09note=02
	retlw	(D'09'*D'24')+D'00'	;scale=17bin=219octave=09note=03
	retlw	(D'09'*D'24')+D'04'	;scale=17bin=220octave=09note=04
	retlw	(D'09'*D'24')+D'04'	;scale=17bin=221octave=09note=05
	retlw	(D'09'*D'24')+D'06'	;scale=17bin=222octave=09note=06
	retlw	(D'09'*D'24')+D'06'	;scale=17bin=223octave=09note=07
	retlw	(D'09'*D'24')+D'06'	;scale=17bin=224octave=09note=08
	retlw	(D'09'*D'24')+D'06'	;scale=17bin=225octave=09note=09
	retlw	(D'09'*D'24')+D'06'	;scale=17bin=226octave=09note=10
	retlw	(D'09'*D'24')+D'06'	;scale=17bin=227octave=09note=11
	retlw	(D'09'*D'24')+D'12'	;scale=17bin=228octave=09note=12
	retlw	(D'09'*D'24')+D'12'	;scale=17bin=229octave=09note=13
	retlw	(D'09'*D'24')+D'14'	;scale=17bin=230octave=09note=14
	retlw	(D'09'*D'24')+D'14'	;scale=17bin=231octave=09note=15
	retlw	(D'09'*D'24')+D'16'	;scale=17bin=232octave=09note=16
	retlw	(D'09'*D'24')+D'16'	;scale=17bin=233octave=09note=17
	retlw	(D'09'*D'24')+D'16'	;scale=17bin=234octave=09note=18
	retlw	(D'09'*D'24')+D'16'	;scale=17bin=235octave=09note=19
	retlw	(D'09'*D'24')+D'16'	;scale=17bin=236octave=09note=20
	retlw	(D'09'*D'24')+D'16'	;scale=17bin=237octave=09note=21
	retlw	(D'09'*D'24')+D'22'	;scale=17bin=238octave=09note=22
	retlw	(D'09'*D'24')+D'22'	;scale=17bin=239octave=09note=23
	retlw	(D'10'*D'24')+D'00'	;scale=17bin=240octave=10note=00
	retlw	(D'10'*D'24')+D'00'	;scale=17bin=241octave=10note=01
	retlw	(D'10'*D'24')+D'00'	;scale=17bin=242octave=10note=02
	retlw	(D'10'*D'24')+D'00'	;scale=17bin=243octave=10note=03
	retlw	(D'10'*D'24')+D'00'	;scale=17bin=244octave=10note=04
	retlw	(D'10'*D'24')+D'00'	;scale=17bin=245octave=10note=05
	retlw	(D'10'*D'24')+D'00'	;scale=17bin=246octave=10note=06
	retlw	(D'10'*D'24')+D'00'	;scale=17bin=247octave=10note=07
	retlw	(D'10'*D'24')+D'00'	;scale=17bin=248octave=10note=08
	retlw	(D'10'*D'24')+D'00'	;scale=17bin=249octave=10note=09
	retlw	(D'10'*D'24')+D'00'	;scale=17bin=250octave=10note=10
	retlw	(D'10'*D'24')+D'00'	;scale=17bin=251octave=10note=11
	retlw	(D'10'*D'24')+D'00'	;scale=17bin=252octave=10note=12
	retlw	(D'10'*D'24')+D'00'	;scale=17bin=253octave=10note=13
	retlw	(D'10'*D'24')+D'00'	;scale=17bin=254octave=10note=14
	retlw	(D'10'*D'24')+D'00'	;scale=17bin=255octave=10note=15

;	Sustained look-up table
	org	Sus		;Sustained look-up table
	retlw	(D'00'*D'24')+D'00'	;scale=18bin=000octave=00note=00
	retlw	(D'00'*D'24')+D'00'	;scale=18bin=001octave=00note=01
	retlw	(D'00'*D'24')+D'00'	;scale=18bin=002octave=00note=02
	retlw	(D'00'*D'24')+D'00'	;scale=18bin=003octave=00note=03
	retlw	(D'00'*D'24')+D'00'	;scale=18bin=004octave=00note=04
	retlw	(D'00'*D'24')+D'00'	;scale=18bin=005octave=00note=05
	retlw	(D'00'*D'24')+D'00'	;scale=18bin=006octave=00note=06
	retlw	(D'00'*D'24')+D'00'	;scale=18bin=007octave=00note=07
	retlw	(D'00'*D'24')+D'00'	;scale=18bin=008octave=00note=08
	retlw	(D'00'*D'24')+D'00'	;scale=18bin=009octave=00note=09
	retlw	(D'00'*D'24')+D'10'	;scale=18bin=010octave=00note=10
	retlw	(D'00'*D'24')+D'10'	;scale=18bin=011octave=00note=11
	retlw	(D'00'*D'24')+D'10'	;scale=18bin=012octave=00note=12
	retlw	(D'00'*D'24')+D'10'	;scale=18bin=013octave=00note=13
	retlw	(D'00'*D'24')+D'14'	;scale=18bin=014octave=00note=14
	retlw	(D'00'*D'24')+D'14'	;scale=18bin=015octave=00note=15
	retlw	(D'00'*D'24')+D'14'	;scale=18bin=016octave=00note=16
	retlw	(D'00'*D'24')+D'14'	;scale=18bin=017octave=00note=17
	retlw	(D'00'*D'24')+D'14'	;scale=18bin=018octave=00note=18
	retlw	(D'00'*D'24')+D'14'	;scale=18bin=019octave=00note=19
	retlw	(D'00'*D'24')+D'14'	;scale=18bin=020octave=00note=20
	retlw	(D'00'*D'24')+D'14'	;scale=18bin=021octave=00note=21
	retlw	(D'00'*D'24')+D'14'	;scale=18bin=022octave=00note=22
	retlw	(D'00'*D'24')+D'14'	;scale=18bin=023octave=00note=23
	retlw	(D'01'*D'24')+D'00'	;scale=18bin=024octave=01note=00
	retlw	(D'01'*D'24')+D'00'	;scale=18bin=025octave=01note=01
	retlw	(D'01'*D'24')+D'00'	;scale=18bin=026octave=01note=02
	retlw	(D'01'*D'24')+D'00'	;scale=18bin=027octave=01note=03
	retlw	(D'01'*D'24')+D'00'	;scale=18bin=028octave=01note=04
	retlw	(D'01'*D'24')+D'00'	;scale=18bin=029octave=01note=05
	retlw	(D'01'*D'24')+D'00'	;scale=18bin=030octave=01note=06
	retlw	(D'01'*D'24')+D'00'	;scale=18bin=031octave=01note=07
	retlw	(D'01'*D'24')+D'00'	;scale=18bin=032octave=01note=08
	retlw	(D'01'*D'24')+D'00'	;scale=18bin=033octave=01note=09
	retlw	(D'01'*D'24')+D'10'	;scale=18bin=034octave=01note=10
	retlw	(D'01'*D'24')+D'10'	;scale=18bin=035octave=01note=11
	retlw	(D'01'*D'24')+D'10'	;scale=18bin=036octave=01note=12
	retlw	(D'01'*D'24')+D'10'	;scale=18bin=037octave=01note=13
	retlw	(D'01'*D'24')+D'14'	;scale=18bin=038octave=01note=14
	retlw	(D'01'*D'24')+D'14'	;scale=18bin=039octave=01note=15
	retlw	(D'01'*D'24')+D'14'	;scale=18bin=040octave=01note=16
	retlw	(D'01'*D'24')+D'14'	;scale=18bin=041octave=01note=17
	retlw	(D'01'*D'24')+D'14'	;scale=18bin=042octave=01note=18
	retlw	(D'01'*D'24')+D'14'	;scale=18bin=043octave=01note=19
	retlw	(D'01'*D'24')+D'14'	;scale=18bin=044octave=01note=20
	retlw	(D'01'*D'24')+D'14'	;scale=18bin=045octave=01note=21
	retlw	(D'01'*D'24')+D'14'	;scale=18bin=046octave=01note=22
	retlw	(D'01'*D'24')+D'14'	;scale=18bin=047octave=01note=23
	retlw	(D'02'*D'24')+D'00'	;scale=18bin=048octave=02note=00
	retlw	(D'02'*D'24')+D'00'	;scale=18bin=049octave=02note=01
	retlw	(D'02'*D'24')+D'00'	;scale=18bin=050octave=02note=02
	retlw	(D'02'*D'24')+D'00'	;scale=18bin=051octave=02note=03
	retlw	(D'02'*D'24')+D'00'	;scale=18bin=052octave=02note=04
	retlw	(D'02'*D'24')+D'00'	;scale=18bin=053octave=02note=05
	retlw	(D'02'*D'24')+D'00'	;scale=18bin=054octave=02note=06
	retlw	(D'02'*D'24')+D'00'	;scale=18bin=055octave=02note=07
	retlw	(D'02'*D'24')+D'00'	;scale=18bin=056octave=02note=08
	retlw	(D'02'*D'24')+D'00'	;scale=18bin=057octave=02note=09
	retlw	(D'02'*D'24')+D'10'	;scale=18bin=058octave=02note=10
	retlw	(D'02'*D'24')+D'10'	;scale=18bin=059octave=02note=11
	retlw	(D'02'*D'24')+D'10'	;scale=18bin=060octave=02note=12
	retlw	(D'02'*D'24')+D'10'	;scale=18bin=061octave=02note=13
	retlw	(D'02'*D'24')+D'14'	;scale=18bin=062octave=02note=14
	retlw	(D'02'*D'24')+D'14'	;scale=18bin=063octave=02note=15
	retlw	(D'02'*D'24')+D'14'	;scale=18bin=064octave=02note=16
	retlw	(D'02'*D'24')+D'14'	;scale=18bin=065octave=02note=17
	retlw	(D'02'*D'24')+D'14'	;scale=18bin=066octave=02note=18
	retlw	(D'02'*D'24')+D'14'	;scale=18bin=067octave=02note=19
	retlw	(D'02'*D'24')+D'14'	;scale=18bin=068octave=02note=20
	retlw	(D'02'*D'24')+D'14'	;scale=18bin=069octave=02note=21
	retlw	(D'02'*D'24')+D'14'	;scale=18bin=070octave=02note=22
	retlw	(D'02'*D'24')+D'14'	;scale=18bin=071octave=02note=23
	retlw	(D'03'*D'24')+D'00'	;scale=18bin=072octave=03note=00
	retlw	(D'03'*D'24')+D'00'	;scale=18bin=073octave=03note=01
	retlw	(D'03'*D'24')+D'00'	;scale=18bin=074octave=03note=02
	retlw	(D'03'*D'24')+D'00'	;scale=18bin=075octave=03note=03
	retlw	(D'03'*D'24')+D'00'	;scale=18bin=076octave=03note=04
	retlw	(D'03'*D'24')+D'00'	;scale=18bin=077octave=03note=05
	retlw	(D'03'*D'24')+D'00'	;scale=18bin=078octave=03note=06
	retlw	(D'03'*D'24')+D'00'	;scale=18bin=079octave=03note=07
	retlw	(D'03'*D'24')+D'00'	;scale=18bin=080octave=03note=08
	retlw	(D'03'*D'24')+D'00'	;scale=18bin=081octave=03note=09
	retlw	(D'03'*D'24')+D'10'	;scale=18bin=082octave=03note=10
	retlw	(D'03'*D'24')+D'10'	;scale=18bin=083octave=03note=11
	retlw	(D'03'*D'24')+D'10'	;scale=18bin=084octave=03note=12
	retlw	(D'03'*D'24')+D'10'	;scale=18bin=085octave=03note=13
	retlw	(D'03'*D'24')+D'14'	;scale=18bin=086octave=03note=14
	retlw	(D'03'*D'24')+D'14'	;scale=18bin=087octave=03note=15
	retlw	(D'03'*D'24')+D'14'	;scale=18bin=088octave=03note=16
	retlw	(D'03'*D'24')+D'14'	;scale=18bin=089octave=03note=17
	retlw	(D'03'*D'24')+D'14'	;scale=18bin=090octave=03note=18
	retlw	(D'03'*D'24')+D'14'	;scale=18bin=091octave=03note=19
	retlw	(D'03'*D'24')+D'14'	;scale=18bin=092octave=03note=20
	retlw	(D'03'*D'24')+D'14'	;scale=18bin=093octave=03note=21
	retlw	(D'03'*D'24')+D'14'	;scale=18bin=094octave=03note=22
	retlw	(D'03'*D'24')+D'14'	;scale=18bin=095octave=03note=23
	retlw	(D'04'*D'24')+D'00'	;scale=18bin=096octave=04note=00
	retlw	(D'04'*D'24')+D'00'	;scale=18bin=097octave=04note=01
	retlw	(D'04'*D'24')+D'00'	;scale=18bin=098octave=04note=02
	retlw	(D'04'*D'24')+D'00'	;scale=18bin=099octave=04note=03
	retlw	(D'04'*D'24')+D'00'	;scale=18bin=100octave=04note=04
	retlw	(D'04'*D'24')+D'00'	;scale=18bin=101octave=04note=05
	retlw	(D'04'*D'24')+D'00'	;scale=18bin=102octave=04note=06
	retlw	(D'04'*D'24')+D'00'	;scale=18bin=103octave=04note=07
	retlw	(D'04'*D'24')+D'00'	;scale=18bin=104octave=04note=08
	retlw	(D'04'*D'24')+D'00'	;scale=18bin=105octave=04note=09
	retlw	(D'04'*D'24')+D'10'	;scale=18bin=106octave=04note=10
	retlw	(D'04'*D'24')+D'10'	;scale=18bin=107octave=04note=11
	retlw	(D'04'*D'24')+D'10'	;scale=18bin=108octave=04note=12
	retlw	(D'04'*D'24')+D'10'	;scale=18bin=109octave=04note=13
	retlw	(D'04'*D'24')+D'14'	;scale=18bin=110octave=04note=14
	retlw	(D'04'*D'24')+D'14'	;scale=18bin=111octave=04note=15
	retlw	(D'04'*D'24')+D'14'	;scale=18bin=112octave=04note=16
	retlw	(D'04'*D'24')+D'14'	;scale=18bin=113octave=04note=17
	retlw	(D'04'*D'24')+D'14'	;scale=18bin=114octave=04note=18
	retlw	(D'04'*D'24')+D'14'	;scale=18bin=115octave=04note=19
	retlw	(D'04'*D'24')+D'14'	;scale=18bin=116octave=04note=20
	retlw	(D'04'*D'24')+D'14'	;scale=18bin=117octave=04note=21
	retlw	(D'04'*D'24')+D'14'	;scale=18bin=118octave=04note=22
	retlw	(D'04'*D'24')+D'14'	;scale=18bin=119octave=04note=23
	retlw	(D'05'*D'24')+D'00'	;scale=18bin=120octave=05note=00
	retlw	(D'05'*D'24')+D'00'	;scale=18bin=121octave=05note=01
	retlw	(D'05'*D'24')+D'00'	;scale=18bin=122octave=05note=02
	retlw	(D'05'*D'24')+D'00'	;scale=18bin=123octave=05note=03
	retlw	(D'05'*D'24')+D'00'	;scale=18bin=124octave=05note=04
	retlw	(D'05'*D'24')+D'00'	;scale=18bin=125octave=05note=05
	retlw	(D'05'*D'24')+D'00'	;scale=18bin=126octave=05note=06
	retlw	(D'05'*D'24')+D'00'	;scale=18bin=127octave=05note=07
	retlw	(D'05'*D'24')+D'00'	;scale=18bin=128octave=05note=08
	retlw	(D'05'*D'24')+D'00'	;scale=18bin=129octave=05note=09
	retlw	(D'05'*D'24')+D'10'	;scale=18bin=130octave=05note=10
	retlw	(D'05'*D'24')+D'10'	;scale=18bin=131octave=05note=11
	retlw	(D'05'*D'24')+D'10'	;scale=18bin=132octave=05note=12
	retlw	(D'05'*D'24')+D'10'	;scale=18bin=133octave=05note=13
	retlw	(D'05'*D'24')+D'14'	;scale=18bin=134octave=05note=14
	retlw	(D'05'*D'24')+D'14'	;scale=18bin=135octave=05note=15
	retlw	(D'05'*D'24')+D'14'	;scale=18bin=136octave=05note=16
	retlw	(D'05'*D'24')+D'14'	;scale=18bin=137octave=05note=17
	retlw	(D'05'*D'24')+D'14'	;scale=18bin=138octave=05note=18
	retlw	(D'05'*D'24')+D'14'	;scale=18bin=139octave=05note=19
	retlw	(D'05'*D'24')+D'14'	;scale=18bin=140octave=05note=20
	retlw	(D'05'*D'24')+D'14'	;scale=18bin=141octave=05note=21
	retlw	(D'05'*D'24')+D'14'	;scale=18bin=142octave=05note=22
	retlw	(D'05'*D'24')+D'14'	;scale=18bin=143octave=05note=23
	retlw	(D'06'*D'24')+D'00'	;scale=18bin=144octave=06note=00
	retlw	(D'06'*D'24')+D'00'	;scale=18bin=145octave=06note=01
	retlw	(D'06'*D'24')+D'00'	;scale=18bin=146octave=06note=02
	retlw	(D'06'*D'24')+D'00'	;scale=18bin=147octave=06note=03
	retlw	(D'06'*D'24')+D'00'	;scale=18bin=148octave=06note=04
	retlw	(D'06'*D'24')+D'00'	;scale=18bin=149octave=06note=05
	retlw	(D'06'*D'24')+D'00'	;scale=18bin=150octave=06note=06
	retlw	(D'06'*D'24')+D'00'	;scale=18bin=151octave=06note=07
	retlw	(D'06'*D'24')+D'00'	;scale=18bin=152octave=06note=08
	retlw	(D'06'*D'24')+D'00'	;scale=18bin=153octave=06note=09
	retlw	(D'06'*D'24')+D'10'	;scale=18bin=154octave=06note=10
	retlw	(D'06'*D'24')+D'10'	;scale=18bin=155octave=06note=11
	retlw	(D'06'*D'24')+D'10'	;scale=18bin=156octave=06note=12
	retlw	(D'06'*D'24')+D'10'	;scale=18bin=157octave=06note=13
	retlw	(D'06'*D'24')+D'14'	;scale=18bin=158octave=06note=14
	retlw	(D'06'*D'24')+D'14'	;scale=18bin=159octave=06note=15
	retlw	(D'06'*D'24')+D'14'	;scale=18bin=160octave=06note=16
	retlw	(D'06'*D'24')+D'14'	;scale=18bin=161octave=06note=17
	retlw	(D'06'*D'24')+D'14'	;scale=18bin=162octave=06note=18
	retlw	(D'06'*D'24')+D'14'	;scale=18bin=163octave=06note=19
	retlw	(D'06'*D'24')+D'14'	;scale=18bin=164octave=06note=20
	retlw	(D'06'*D'24')+D'14'	;scale=18bin=165octave=06note=21
	retlw	(D'06'*D'24')+D'14'	;scale=18bin=166octave=06note=22
	retlw	(D'06'*D'24')+D'14'	;scale=18bin=167octave=06note=23
	retlw	(D'07'*D'24')+D'00'	;scale=18bin=168octave=07note=00
	retlw	(D'07'*D'24')+D'00'	;scale=18bin=169octave=07note=01
	retlw	(D'07'*D'24')+D'00'	;scale=18bin=170octave=07note=02
	retlw	(D'07'*D'24')+D'00'	;scale=18bin=171octave=07note=03
	retlw	(D'07'*D'24')+D'00'	;scale=18bin=172octave=07note=04
	retlw	(D'07'*D'24')+D'00'	;scale=18bin=173octave=07note=05
	retlw	(D'07'*D'24')+D'00'	;scale=18bin=174octave=07note=06
	retlw	(D'07'*D'24')+D'00'	;scale=18bin=175octave=07note=07
	retlw	(D'07'*D'24')+D'00'	;scale=18bin=176octave=07note=08
	retlw	(D'07'*D'24')+D'00'	;scale=18bin=177octave=07note=09
	retlw	(D'07'*D'24')+D'10'	;scale=18bin=178octave=07note=10
	retlw	(D'07'*D'24')+D'10'	;scale=18bin=179octave=07note=11
	retlw	(D'07'*D'24')+D'10'	;scale=18bin=180octave=07note=12
	retlw	(D'07'*D'24')+D'10'	;scale=18bin=181octave=07note=13
	retlw	(D'07'*D'24')+D'14'	;scale=18bin=182octave=07note=14
	retlw	(D'07'*D'24')+D'14'	;scale=18bin=183octave=07note=15
	retlw	(D'07'*D'24')+D'14'	;scale=18bin=184octave=07note=16
	retlw	(D'07'*D'24')+D'14'	;scale=18bin=185octave=07note=17
	retlw	(D'07'*D'24')+D'14'	;scale=18bin=186octave=07note=18
	retlw	(D'07'*D'24')+D'14'	;scale=18bin=187octave=07note=19
	retlw	(D'07'*D'24')+D'14'	;scale=18bin=188octave=07note=20
	retlw	(D'07'*D'24')+D'14'	;scale=18bin=189octave=07note=21
	retlw	(D'07'*D'24')+D'14'	;scale=18bin=190octave=07note=22
	retlw	(D'07'*D'24')+D'14'	;scale=18bin=191octave=07note=23
	retlw	(D'08'*D'24')+D'00'	;scale=18bin=192octave=08note=00
	retlw	(D'08'*D'24')+D'00'	;scale=18bin=193octave=08note=01
	retlw	(D'08'*D'24')+D'00'	;scale=18bin=194octave=08note=02
	retlw	(D'08'*D'24')+D'00'	;scale=18bin=195octave=08note=03
	retlw	(D'08'*D'24')+D'00'	;scale=18bin=196octave=08note=04
	retlw	(D'08'*D'24')+D'00'	;scale=18bin=197octave=08note=05
	retlw	(D'08'*D'24')+D'00'	;scale=18bin=198octave=08note=06
	retlw	(D'08'*D'24')+D'00'	;scale=18bin=199octave=08note=07
	retlw	(D'08'*D'24')+D'00'	;scale=18bin=200octave=08note=08
	retlw	(D'08'*D'24')+D'00'	;scale=18bin=201octave=08note=09
	retlw	(D'08'*D'24')+D'10'	;scale=18bin=202octave=08note=10
	retlw	(D'08'*D'24')+D'10'	;scale=18bin=203octave=08note=11
	retlw	(D'08'*D'24')+D'10'	;scale=18bin=204octave=08note=12
	retlw	(D'08'*D'24')+D'10'	;scale=18bin=205octave=08note=13
	retlw	(D'08'*D'24')+D'14'	;scale=18bin=206octave=08note=14
	retlw	(D'08'*D'24')+D'14'	;scale=18bin=207octave=08note=15
	retlw	(D'08'*D'24')+D'14'	;scale=18bin=208octave=08note=16
	retlw	(D'08'*D'24')+D'14'	;scale=18bin=209octave=08note=17
	retlw	(D'08'*D'24')+D'14'	;scale=18bin=210octave=08note=18
	retlw	(D'08'*D'24')+D'14'	;scale=18bin=211octave=08note=19
	retlw	(D'08'*D'24')+D'14'	;scale=18bin=212octave=08note=20
	retlw	(D'08'*D'24')+D'14'	;scale=18bin=213octave=08note=21
	retlw	(D'08'*D'24')+D'14'	;scale=18bin=214octave=08note=22
	retlw	(D'08'*D'24')+D'14'	;scale=18bin=215octave=08note=23
	retlw	(D'09'*D'24')+D'00'	;scale=18bin=216octave=09note=00
	retlw	(D'09'*D'24')+D'00'	;scale=18bin=217octave=09note=01
	retlw	(D'09'*D'24')+D'00'	;scale=18bin=218octave=09note=02
	retlw	(D'09'*D'24')+D'00'	;scale=18bin=219octave=09note=03
	retlw	(D'09'*D'24')+D'00'	;scale=18bin=220octave=09note=04
	retlw	(D'09'*D'24')+D'00'	;scale=18bin=221octave=09note=05
	retlw	(D'09'*D'24')+D'00'	;scale=18bin=222octave=09note=06
	retlw	(D'09'*D'24')+D'00'	;scale=18bin=223octave=09note=07
	retlw	(D'09'*D'24')+D'00'	;scale=18bin=224octave=09note=08
	retlw	(D'09'*D'24')+D'00'	;scale=18bin=225octave=09note=09
	retlw	(D'09'*D'24')+D'10'	;scale=18bin=226octave=09note=10
	retlw	(D'09'*D'24')+D'10'	;scale=18bin=227octave=09note=11
	retlw	(D'09'*D'24')+D'10'	;scale=18bin=228octave=09note=12
	retlw	(D'09'*D'24')+D'10'	;scale=18bin=229octave=09note=13
	retlw	(D'09'*D'24')+D'14'	;scale=18bin=230octave=09note=14
	retlw	(D'09'*D'24')+D'14'	;scale=18bin=231octave=09note=15
	retlw	(D'09'*D'24')+D'14'	;scale=18bin=232octave=09note=16
	retlw	(D'09'*D'24')+D'14'	;scale=18bin=233octave=09note=17
	retlw	(D'09'*D'24')+D'14'	;scale=18bin=234octave=09note=18
	retlw	(D'09'*D'24')+D'14'	;scale=18bin=235octave=09note=19
	retlw	(D'09'*D'24')+D'14'	;scale=18bin=236octave=09note=20
	retlw	(D'09'*D'24')+D'14'	;scale=18bin=237octave=09note=21
	retlw	(D'09'*D'24')+D'14'	;scale=18bin=238octave=09note=22
	retlw	(D'09'*D'24')+D'14'	;scale=18bin=239octave=09note=23
	retlw	(D'10'*D'24')+D'00'	;scale=18bin=240octave=10note=00
	retlw	(D'10'*D'24')+D'00'	;scale=18bin=241octave=10note=01
	retlw	(D'10'*D'24')+D'00'	;scale=18bin=242octave=10note=02
	retlw	(D'10'*D'24')+D'00'	;scale=18bin=243octave=10note=03
	retlw	(D'10'*D'24')+D'00'	;scale=18bin=244octave=10note=04
	retlw	(D'10'*D'24')+D'00'	;scale=18bin=245octave=10note=05
	retlw	(D'10'*D'24')+D'00'	;scale=18bin=246octave=10note=06
	retlw	(D'10'*D'24')+D'00'	;scale=18bin=247octave=10note=07
	retlw	(D'10'*D'24')+D'00'	;scale=18bin=248octave=10note=08
	retlw	(D'10'*D'24')+D'00'	;scale=18bin=249octave=10note=09
	retlw	(D'10'*D'24')+D'00'	;scale=18bin=250octave=10note=10
	retlw	(D'10'*D'24')+D'00'	;scale=18bin=251octave=10note=11
	retlw	(D'10'*D'24')+D'00'	;scale=18bin=252octave=10note=12
	retlw	(D'10'*D'24')+D'00'	;scale=18bin=253octave=10note=13
	retlw	(D'10'*D'24')+D'00'	;scale=18bin=254octave=10note=14
	retlw	(D'10'*D'24')+D'00'	;scale=18bin=255octave=10note=15

;	Diminished look-up table
	org	Dim		;Diminsished look-up table
	retlw	(D'00'*D'24')+D'00'	;scale=19bin=000octave=00note=00
	retlw	(D'00'*D'24')+D'00'	;scale=19bin=001octave=00note=01
	retlw	(D'00'*D'24')+D'00'	;scale=19bin=002octave=00note=02
	retlw	(D'00'*D'24')+D'00'	;scale=19bin=003octave=00note=03
	retlw	(D'00'*D'24')+D'04'	;scale=19bin=004octave=00note=04
	retlw	(D'00'*D'24')+D'04'	;scale=19bin=005octave=00note=05
	retlw	(D'00'*D'24')+D'06'	;scale=19bin=006octave=00note=06
	retlw	(D'00'*D'24')+D'06'	;scale=19bin=007octave=00note=07
	retlw	(D'00'*D'24')+D'06'	;scale=19bin=008octave=00note=08
	retlw	(D'00'*D'24')+D'06'	;scale=19bin=009octave=00note=09
	retlw	(D'00'*D'24')+D'10'	;scale=19bin=010octave=00note=10
	retlw	(D'00'*D'24')+D'10'	;scale=19bin=011octave=00note=11
	retlw	(D'00'*D'24')+D'12'	;scale=19bin=012octave=00note=12
	retlw	(D'00'*D'24')+D'12'	;scale=19bin=013octave=00note=13
	retlw	(D'00'*D'24')+D'12'	;scale=19bin=014octave=00note=14
	retlw	(D'00'*D'24')+D'12'	;scale=19bin=015octave=00note=15
	retlw	(D'00'*D'24')+D'16'	;scale=19bin=016octave=00note=16
	retlw	(D'00'*D'24')+D'16'	;scale=19bin=017octave=00note=17
	retlw	(D'00'*D'24')+D'18'	;scale=19bin=018octave=00note=18
	retlw	(D'00'*D'24')+D'18'	;scale=19bin=019octave=00note=19
	retlw	(D'00'*D'24')+D'18'	;scale=19bin=020octave=00note=20
	retlw	(D'00'*D'24')+D'18'	;scale=19bin=021octave=00note=21
	retlw	(D'00'*D'24')+D'22'	;scale=19bin=022octave=00note=22
	retlw	(D'00'*D'24')+D'22'	;scale=19bin=023octave=00note=23
	retlw	(D'01'*D'24')+D'00'	;scale=19bin=024octave=01note=00
	retlw	(D'01'*D'24')+D'00'	;scale=19bin=025octave=01note=01
	retlw	(D'01'*D'24')+D'00'	;scale=19bin=026octave=01note=02
	retlw	(D'01'*D'24')+D'00'	;scale=19bin=027octave=01note=03
	retlw	(D'01'*D'24')+D'04'	;scale=19bin=028octave=01note=04
	retlw	(D'01'*D'24')+D'04'	;scale=19bin=029octave=01note=05
	retlw	(D'01'*D'24')+D'06'	;scale=19bin=030octave=01note=06
	retlw	(D'01'*D'24')+D'06'	;scale=19bin=031octave=01note=07
	retlw	(D'01'*D'24')+D'06'	;scale=19bin=032octave=01note=08
	retlw	(D'01'*D'24')+D'06'	;scale=19bin=033octave=01note=09
	retlw	(D'01'*D'24')+D'10'	;scale=19bin=034octave=01note=10
	retlw	(D'01'*D'24')+D'10'	;scale=19bin=035octave=01note=11
	retlw	(D'01'*D'24')+D'12'	;scale=19bin=036octave=01note=12
	retlw	(D'01'*D'24')+D'12'	;scale=19bin=037octave=01note=13
	retlw	(D'01'*D'24')+D'12'	;scale=19bin=038octave=01note=14
	retlw	(D'01'*D'24')+D'12'	;scale=19bin=039octave=01note=15
	retlw	(D'01'*D'24')+D'16'	;scale=19bin=040octave=01note=16
	retlw	(D'01'*D'24')+D'16'	;scale=19bin=041octave=01note=17
	retlw	(D'01'*D'24')+D'18'	;scale=19bin=042octave=01note=18
	retlw	(D'01'*D'24')+D'18'	;scale=19bin=043octave=01note=19
	retlw	(D'01'*D'24')+D'18'	;scale=19bin=044octave=01note=20
	retlw	(D'01'*D'24')+D'18'	;scale=19bin=045octave=01note=21
	retlw	(D'01'*D'24')+D'22'	;scale=19bin=046octave=01note=22
	retlw	(D'01'*D'24')+D'22'	;scale=19bin=047octave=01note=23
	retlw	(D'02'*D'24')+D'00'	;scale=19bin=048octave=02note=00
	retlw	(D'02'*D'24')+D'00'	;scale=19bin=049octave=02note=01
	retlw	(D'02'*D'24')+D'00'	;scale=19bin=050octave=02note=02
	retlw	(D'02'*D'24')+D'00'	;scale=19bin=051octave=02note=03
	retlw	(D'02'*D'24')+D'04'	;scale=19bin=052octave=02note=04
	retlw	(D'02'*D'24')+D'04'	;scale=19bin=053octave=02note=05
	retlw	(D'02'*D'24')+D'06'	;scale=19bin=054octave=02note=06
	retlw	(D'02'*D'24')+D'06'	;scale=19bin=055octave=02note=07
	retlw	(D'02'*D'24')+D'06'	;scale=19bin=056octave=02note=08
	retlw	(D'02'*D'24')+D'06'	;scale=19bin=057octave=02note=09
	retlw	(D'02'*D'24')+D'10'	;scale=19bin=058octave=02note=10
	retlw	(D'02'*D'24')+D'10'	;scale=19bin=059octave=02note=11
	retlw	(D'02'*D'24')+D'12'	;scale=19bin=060octave=02note=12
	retlw	(D'02'*D'24')+D'12'	;scale=19bin=061octave=02note=13
	retlw	(D'02'*D'24')+D'12'	;scale=19bin=062octave=02note=14
	retlw	(D'02'*D'24')+D'12'	;scale=19bin=063octave=02note=15
	retlw	(D'02'*D'24')+D'16'	;scale=19bin=064octave=02note=16
	retlw	(D'02'*D'24')+D'16'	;scale=19bin=065octave=02note=17
	retlw	(D'02'*D'24')+D'18'	;scale=19bin=066octave=02note=18
	retlw	(D'02'*D'24')+D'18'	;scale=19bin=067octave=02note=19
	retlw	(D'02'*D'24')+D'18'	;scale=19bin=068octave=02note=20
	retlw	(D'02'*D'24')+D'18'	;scale=19bin=069octave=02note=21
	retlw	(D'02'*D'24')+D'22'	;scale=19bin=070octave=02note=22
	retlw	(D'02'*D'24')+D'22'	;scale=19bin=071octave=02note=23
	retlw	(D'03'*D'24')+D'00'	;scale=19bin=072octave=03note=00
	retlw	(D'03'*D'24')+D'00'	;scale=19bin=073octave=03note=01
	retlw	(D'03'*D'24')+D'00'	;scale=19bin=074octave=03note=02
	retlw	(D'03'*D'24')+D'00'	;scale=19bin=075octave=03note=03
	retlw	(D'03'*D'24')+D'04'	;scale=19bin=076octave=03note=04
	retlw	(D'03'*D'24')+D'04'	;scale=19bin=077octave=03note=05
	retlw	(D'03'*D'24')+D'06'	;scale=19bin=078octave=03note=06
	retlw	(D'03'*D'24')+D'06'	;scale=19bin=079octave=03note=07
	retlw	(D'03'*D'24')+D'06'	;scale=19bin=080octave=03note=08
	retlw	(D'03'*D'24')+D'06'	;scale=19bin=081octave=03note=09
	retlw	(D'03'*D'24')+D'10'	;scale=19bin=082octave=03note=10
	retlw	(D'03'*D'24')+D'10'	;scale=19bin=083octave=03note=11
	retlw	(D'03'*D'24')+D'12'	;scale=19bin=084octave=03note=12
	retlw	(D'03'*D'24')+D'12'	;scale=19bin=085octave=03note=13
	retlw	(D'03'*D'24')+D'12'	;scale=19bin=086octave=03note=14
	retlw	(D'03'*D'24')+D'12'	;scale=19bin=087octave=03note=15
	retlw	(D'03'*D'24')+D'16'	;scale=19bin=088octave=03note=16
	retlw	(D'03'*D'24')+D'16'	;scale=19bin=089octave=03note=17
	retlw	(D'03'*D'24')+D'18'	;scale=19bin=090octave=03note=18
	retlw	(D'03'*D'24')+D'18'	;scale=19bin=091octave=03note=19
	retlw	(D'03'*D'24')+D'18'	;scale=19bin=092octave=03note=20
	retlw	(D'03'*D'24')+D'18'	;scale=19bin=093octave=03note=21
	retlw	(D'03'*D'24')+D'22'	;scale=19bin=094octave=03note=22
	retlw	(D'03'*D'24')+D'22'	;scale=19bin=095octave=03note=23
	retlw	(D'04'*D'24')+D'00'	;scale=19bin=096octave=04note=00
	retlw	(D'04'*D'24')+D'00'	;scale=19bin=097octave=04note=01
	retlw	(D'04'*D'24')+D'00'	;scale=19bin=098octave=04note=02
	retlw	(D'04'*D'24')+D'00'	;scale=19bin=099octave=04note=03
	retlw	(D'04'*D'24')+D'04'	;scale=19bin=100octave=04note=04
	retlw	(D'04'*D'24')+D'04'	;scale=19bin=101octave=04note=05
	retlw	(D'04'*D'24')+D'06'	;scale=19bin=102octave=04note=06
	retlw	(D'04'*D'24')+D'06'	;scale=19bin=103octave=04note=07
	retlw	(D'04'*D'24')+D'06'	;scale=19bin=104octave=04note=08
	retlw	(D'04'*D'24')+D'06'	;scale=19bin=105octave=04note=09
	retlw	(D'04'*D'24')+D'10'	;scale=19bin=106octave=04note=10
	retlw	(D'04'*D'24')+D'10'	;scale=19bin=107octave=04note=11
	retlw	(D'04'*D'24')+D'12'	;scale=19bin=108octave=04note=12
	retlw	(D'04'*D'24')+D'12'	;scale=19bin=109octave=04note=13
	retlw	(D'04'*D'24')+D'12'	;scale=19bin=110octave=04note=14
	retlw	(D'04'*D'24')+D'12'	;scale=19bin=111octave=04note=15
	retlw	(D'04'*D'24')+D'16'	;scale=19bin=112octave=04note=16
	retlw	(D'04'*D'24')+D'16'	;scale=19bin=113octave=04note=17
	retlw	(D'04'*D'24')+D'18'	;scale=19bin=114octave=04note=18
	retlw	(D'04'*D'24')+D'18'	;scale=19bin=115octave=04note=19
	retlw	(D'04'*D'24')+D'18'	;scale=19bin=116octave=04note=20
	retlw	(D'04'*D'24')+D'18'	;scale=19bin=117octave=04note=21
	retlw	(D'04'*D'24')+D'22'	;scale=19bin=118octave=04note=22
	retlw	(D'04'*D'24')+D'22'	;scale=19bin=119octave=04note=23
	retlw	(D'05'*D'24')+D'00'	;scale=19bin=120octave=05note=00
	retlw	(D'05'*D'24')+D'00'	;scale=19bin=121octave=05note=01
	retlw	(D'05'*D'24')+D'00'	;scale=19bin=122octave=05note=02
	retlw	(D'05'*D'24')+D'00'	;scale=19bin=123octave=05note=03
	retlw	(D'05'*D'24')+D'04'	;scale=19bin=124octave=05note=04
	retlw	(D'05'*D'24')+D'04'	;scale=19bin=125octave=05note=05
	retlw	(D'05'*D'24')+D'06'	;scale=19bin=126octave=05note=06
	retlw	(D'05'*D'24')+D'06'	;scale=19bin=127octave=05note=07
	retlw	(D'05'*D'24')+D'06'	;scale=19bin=128octave=05note=08
	retlw	(D'05'*D'24')+D'06'	;scale=19bin=129octave=05note=09
	retlw	(D'05'*D'24')+D'10'	;scale=19bin=130octave=05note=10
	retlw	(D'05'*D'24')+D'10'	;scale=19bin=131octave=05note=11
	retlw	(D'05'*D'24')+D'12'	;scale=19bin=132octave=05note=12
	retlw	(D'05'*D'24')+D'12'	;scale=19bin=133octave=05note=13
	retlw	(D'05'*D'24')+D'12'	;scale=19bin=134octave=05note=14
	retlw	(D'05'*D'24')+D'12'	;scale=19bin=135octave=05note=15
	retlw	(D'05'*D'24')+D'16'	;scale=19bin=136octave=05note=16
	retlw	(D'05'*D'24')+D'16'	;scale=19bin=137octave=05note=17
	retlw	(D'05'*D'24')+D'18'	;scale=19bin=138octave=05note=18
	retlw	(D'05'*D'24')+D'18'	;scale=19bin=139octave=05note=19
	retlw	(D'05'*D'24')+D'18'	;scale=19bin=140octave=05note=20
	retlw	(D'05'*D'24')+D'18'	;scale=19bin=141octave=05note=21
	retlw	(D'05'*D'24')+D'22'	;scale=19bin=142octave=05note=22
	retlw	(D'05'*D'24')+D'22'	;scale=19bin=143octave=05note=23
	retlw	(D'06'*D'24')+D'00'	;scale=19bin=144octave=06note=00
	retlw	(D'06'*D'24')+D'00'	;scale=19bin=145octave=06note=01
	retlw	(D'06'*D'24')+D'00'	;scale=19bin=146octave=06note=02
	retlw	(D'06'*D'24')+D'00'	;scale=19bin=147octave=06note=03
	retlw	(D'06'*D'24')+D'04'	;scale=19bin=148octave=06note=04
	retlw	(D'06'*D'24')+D'04'	;scale=19bin=149octave=06note=05
	retlw	(D'06'*D'24')+D'06'	;scale=19bin=150octave=06note=06
	retlw	(D'06'*D'24')+D'06'	;scale=19bin=151octave=06note=07
	retlw	(D'06'*D'24')+D'06'	;scale=19bin=152octave=06note=08
	retlw	(D'06'*D'24')+D'06'	;scale=19bin=153octave=06note=09
	retlw	(D'06'*D'24')+D'10'	;scale=19bin=154octave=06note=10
	retlw	(D'06'*D'24')+D'10'	;scale=19bin=155octave=06note=11
	retlw	(D'06'*D'24')+D'12'	;scale=19bin=156octave=06note=12
	retlw	(D'06'*D'24')+D'12'	;scale=19bin=157octave=06note=13
	retlw	(D'06'*D'24')+D'12'	;scale=19bin=158octave=06note=14
	retlw	(D'06'*D'24')+D'12'	;scale=19bin=159octave=06note=15
	retlw	(D'06'*D'24')+D'16'	;scale=19bin=160octave=06note=16
	retlw	(D'06'*D'24')+D'16'	;scale=19bin=161octave=06note=17
	retlw	(D'06'*D'24')+D'18'	;scale=19bin=162octave=06note=18
	retlw	(D'06'*D'24')+D'18'	;scale=19bin=163octave=06note=19
	retlw	(D'06'*D'24')+D'18'	;scale=19bin=164octave=06note=20
	retlw	(D'06'*D'24')+D'18'	;scale=19bin=165octave=06note=21
	retlw	(D'06'*D'24')+D'22'	;scale=19bin=166octave=06note=22
	retlw	(D'06'*D'24')+D'22'	;scale=19bin=167octave=06note=23
	retlw	(D'07'*D'24')+D'00'	;scale=19bin=168octave=07note=00
	retlw	(D'07'*D'24')+D'00'	;scale=19bin=169octave=07note=01
	retlw	(D'07'*D'24')+D'00'	;scale=19bin=170octave=07note=02
	retlw	(D'07'*D'24')+D'00'	;scale=19bin=171octave=07note=03
	retlw	(D'07'*D'24')+D'04'	;scale=19bin=172octave=07note=04
	retlw	(D'07'*D'24')+D'04'	;scale=19bin=173octave=07note=05
	retlw	(D'07'*D'24')+D'06'	;scale=19bin=174octave=07note=06
	retlw	(D'07'*D'24')+D'06'	;scale=19bin=175octave=07note=07
	retlw	(D'07'*D'24')+D'06'	;scale=19bin=176octave=07note=08
	retlw	(D'07'*D'24')+D'06'	;scale=19bin=177octave=07note=09
	retlw	(D'07'*D'24')+D'10'	;scale=19bin=178octave=07note=10
	retlw	(D'07'*D'24')+D'10'	;scale=19bin=179octave=07note=11
	retlw	(D'07'*D'24')+D'12'	;scale=19bin=180octave=07note=12
	retlw	(D'07'*D'24')+D'12'	;scale=19bin=181octave=07note=13
	retlw	(D'07'*D'24')+D'12'	;scale=19bin=182octave=07note=14
	retlw	(D'07'*D'24')+D'12'	;scale=19bin=183octave=07note=15
	retlw	(D'07'*D'24')+D'16'	;scale=19bin=184octave=07note=16
	retlw	(D'07'*D'24')+D'16'	;scale=19bin=185octave=07note=17
	retlw	(D'07'*D'24')+D'18'	;scale=19bin=186octave=07note=18
	retlw	(D'07'*D'24')+D'18'	;scale=19bin=187octave=07note=19
	retlw	(D'07'*D'24')+D'18'	;scale=19bin=188octave=07note=20
	retlw	(D'07'*D'24')+D'18'	;scale=19bin=189octave=07note=21
	retlw	(D'07'*D'24')+D'22'	;scale=19bin=190octave=07note=22
	retlw	(D'07'*D'24')+D'22'	;scale=19bin=191octave=07note=23
	retlw	(D'08'*D'24')+D'00'	;scale=19bin=192octave=08note=00
	retlw	(D'08'*D'24')+D'00'	;scale=19bin=193octave=08note=01
	retlw	(D'08'*D'24')+D'00'	;scale=19bin=194octave=08note=02
	retlw	(D'08'*D'24')+D'00'	;scale=19bin=195octave=08note=03
	retlw	(D'08'*D'24')+D'04'	;scale=19bin=196octave=08note=04
	retlw	(D'08'*D'24')+D'04'	;scale=19bin=197octave=08note=05
	retlw	(D'08'*D'24')+D'06'	;scale=19bin=198octave=08note=06
	retlw	(D'08'*D'24')+D'06'	;scale=19bin=199octave=08note=07
	retlw	(D'08'*D'24')+D'06'	;scale=19bin=200octave=08note=08
	retlw	(D'08'*D'24')+D'06'	;scale=19bin=201octave=08note=09
	retlw	(D'08'*D'24')+D'10'	;scale=19bin=202octave=08note=10
	retlw	(D'08'*D'24')+D'10'	;scale=19bin=203octave=08note=11
	retlw	(D'08'*D'24')+D'12'	;scale=19bin=204octave=08note=12
	retlw	(D'08'*D'24')+D'12'	;scale=19bin=205octave=08note=13
	retlw	(D'08'*D'24')+D'12'	;scale=19bin=206octave=08note=14
	retlw	(D'08'*D'24')+D'12'	;scale=19bin=207octave=08note=15
	retlw	(D'08'*D'24')+D'16'	;scale=19bin=208octave=08note=16
	retlw	(D'08'*D'24')+D'16'	;scale=19bin=209octave=08note=17
	retlw	(D'08'*D'24')+D'18'	;scale=19bin=210octave=08note=18
	retlw	(D'08'*D'24')+D'18'	;scale=19bin=211octave=08note=19
	retlw	(D'08'*D'24')+D'18'	;scale=19bin=212octave=08note=20
	retlw	(D'08'*D'24')+D'18'	;scale=19bin=213octave=08note=21
	retlw	(D'08'*D'24')+D'22'	;scale=19bin=214octave=08note=22
	retlw	(D'08'*D'24')+D'22'	;scale=19bin=215octave=08note=23
	retlw	(D'09'*D'24')+D'00'	;scale=19bin=216octave=09note=00
	retlw	(D'09'*D'24')+D'00'	;scale=19bin=217octave=09note=01
	retlw	(D'09'*D'24')+D'00'	;scale=19bin=218octave=09note=02
	retlw	(D'09'*D'24')+D'00'	;scale=19bin=219octave=09note=03
	retlw	(D'09'*D'24')+D'04'	;scale=19bin=220octave=09note=04
	retlw	(D'09'*D'24')+D'04'	;scale=19bin=221octave=09note=05
	retlw	(D'09'*D'24')+D'06'	;scale=19bin=222octave=09note=06
	retlw	(D'09'*D'24')+D'06'	;scale=19bin=223octave=09note=07
	retlw	(D'09'*D'24')+D'06'	;scale=19bin=224octave=09note=08
	retlw	(D'09'*D'24')+D'06'	;scale=19bin=225octave=09note=09
	retlw	(D'09'*D'24')+D'10'	;scale=19bin=226octave=09note=10
	retlw	(D'09'*D'24')+D'10'	;scale=19bin=227octave=09note=11
	retlw	(D'09'*D'24')+D'12'	;scale=19bin=228octave=09note=12
	retlw	(D'09'*D'24')+D'12'	;scale=19bin=229octave=09note=13
	retlw	(D'09'*D'24')+D'12'	;scale=19bin=230octave=09note=14
	retlw	(D'09'*D'24')+D'12'	;scale=19bin=231octave=09note=15
	retlw	(D'09'*D'24')+D'16'	;scale=19bin=232octave=09note=16
	retlw	(D'09'*D'24')+D'16'	;scale=19bin=233octave=09note=17
	retlw	(D'09'*D'24')+D'18'	;scale=19bin=234octave=09note=18
	retlw	(D'09'*D'24')+D'18'	;scale=19bin=235octave=09note=19
	retlw	(D'09'*D'24')+D'18'	;scale=19bin=236octave=09note=20
	retlw	(D'09'*D'24')+D'18'	;scale=19bin=237octave=09note=21
	retlw	(D'09'*D'24')+D'22'	;scale=19bin=238octave=09note=22
	retlw	(D'09'*D'24')+D'22'	;scale=19bin=239octave=09note=23
	retlw	(D'10'*D'24')+D'00'	;scale=19bin=240octave=10note=00
	retlw	(D'10'*D'24')+D'00'	;scale=19bin=241octave=10note=01
	retlw	(D'10'*D'24')+D'00'	;scale=19bin=242octave=10note=02
	retlw	(D'10'*D'24')+D'00'	;scale=19bin=243octave=10note=03
	retlw	(D'10'*D'24')+D'00'	;scale=19bin=244octave=10note=04
	retlw	(D'10'*D'24')+D'00'	;scale=19bin=245octave=10note=05
	retlw	(D'10'*D'24')+D'00'	;scale=19bin=246octave=10note=06
	retlw	(D'10'*D'24')+D'00'	;scale=19bin=247octave=10note=07
	retlw	(D'10'*D'24')+D'00'	;scale=19bin=248octave=10note=08
	retlw	(D'10'*D'24')+D'00'	;scale=19bin=249octave=10note=09
	retlw	(D'10'*D'24')+D'00'	;scale=19bin=250octave=10note=10
	retlw	(D'10'*D'24')+D'00'	;scale=19bin=251octave=10note=11
	retlw	(D'10'*D'24')+D'00'	;scale=19bin=252octave=10note=12
	retlw	(D'10'*D'24')+D'00'	;scale=19bin=253octave=10note=13
	retlw	(D'10'*D'24')+D'00'	;scale=19bin=254octave=10note=14
	retlw	(D'10'*D'24')+D'00'	;scale=19bin=255octave=10note=15

;	Augmented look-up table
	org	Aug		;Augmented look-up table
	retlw	(D'00'*D'24')+D'00'	;scale=20bin=000octave=00note=00
	retlw	(D'00'*D'24')+D'00'	;scale=20bin=001octave=00note=01
	retlw	(D'00'*D'24')+D'00'	;scale=20bin=002octave=00note=02
	retlw	(D'00'*D'24')+D'00'	;scale=20bin=003octave=00note=03
	retlw	(D'00'*D'24')+D'00'	;scale=20bin=004octave=00note=04
	retlw	(D'00'*D'24')+D'00'	;scale=20bin=005octave=00note=05
	retlw	(D'00'*D'24')+D'06'	;scale=20bin=006octave=00note=06
	retlw	(D'00'*D'24')+D'06'	;scale=20bin=007octave=00note=07
	retlw	(D'00'*D'24')+D'08'	;scale=20bin=008octave=00note=08
	retlw	(D'00'*D'24')+D'08'	;scale=20bin=009octave=00note=09
	retlw	(D'00'*D'24')+D'08'	;scale=20bin=010octave=00note=10
	retlw	(D'00'*D'24')+D'08'	;scale=20bin=011octave=00note=11
	retlw	(D'00'*D'24')+D'08'	;scale=20bin=012octave=00note=12
	retlw	(D'00'*D'24')+D'08'	;scale=20bin=013octave=00note=13
	retlw	(D'00'*D'24')+D'14'	;scale=20bin=014octave=00note=14
	retlw	(D'00'*D'24')+D'14'	;scale=20bin=015octave=00note=15
	retlw	(D'00'*D'24')+D'16'	;scale=20bin=016octave=00note=16
	retlw	(D'00'*D'24')+D'16'	;scale=20bin=017octave=00note=17
	retlw	(D'00'*D'24')+D'16'	;scale=20bin=018octave=00note=18
	retlw	(D'00'*D'24')+D'16'	;scale=20bin=019octave=00note=19
	retlw	(D'00'*D'24')+D'16'	;scale=20bin=020octave=00note=20
	retlw	(D'00'*D'24')+D'16'	;scale=20bin=021octave=00note=21
	retlw	(D'00'*D'24')+D'22'	;scale=20bin=022octave=00note=22
	retlw	(D'00'*D'24')+D'22'	;scale=20bin=023octave=00note=23
	retlw	(D'01'*D'24')+D'00'	;scale=20bin=024octave=01note=00
	retlw	(D'01'*D'24')+D'00'	;scale=20bin=025octave=01note=01
	retlw	(D'01'*D'24')+D'00'	;scale=20bin=026octave=01note=02
	retlw	(D'01'*D'24')+D'00'	;scale=20bin=027octave=01note=03
	retlw	(D'01'*D'24')+D'00'	;scale=20bin=028octave=01note=04
	retlw	(D'01'*D'24')+D'00'	;scale=20bin=029octave=01note=05
	retlw	(D'01'*D'24')+D'06'	;scale=20bin=030octave=01note=06
	retlw	(D'01'*D'24')+D'06'	;scale=20bin=031octave=01note=07
	retlw	(D'01'*D'24')+D'08'	;scale=20bin=032octave=01note=08
	retlw	(D'01'*D'24')+D'08'	;scale=20bin=033octave=01note=09
	retlw	(D'01'*D'24')+D'08'	;scale=20bin=034octave=01note=10
	retlw	(D'01'*D'24')+D'08'	;scale=20bin=035octave=01note=11
	retlw	(D'01'*D'24')+D'08'	;scale=20bin=036octave=01note=12
	retlw	(D'01'*D'24')+D'08'	;scale=20bin=037octave=01note=13
	retlw	(D'01'*D'24')+D'14'	;scale=20bin=038octave=01note=14
	retlw	(D'01'*D'24')+D'14'	;scale=20bin=039octave=01note=15
	retlw	(D'01'*D'24')+D'16'	;scale=20bin=040octave=01note=16
	retlw	(D'01'*D'24')+D'16'	;scale=20bin=041octave=01note=17
	retlw	(D'01'*D'24')+D'16'	;scale=20bin=042octave=01note=18
	retlw	(D'01'*D'24')+D'16'	;scale=20bin=043octave=01note=19
	retlw	(D'01'*D'24')+D'16'	;scale=20bin=044octave=01note=20
	retlw	(D'01'*D'24')+D'16'	;scale=20bin=045octave=01note=21
	retlw	(D'01'*D'24')+D'22'	;scale=20bin=046octave=01note=22
	retlw	(D'01'*D'24')+D'22'	;scale=20bin=047octave=01note=23
	retlw	(D'02'*D'24')+D'00'	;scale=20bin=048octave=02note=00
	retlw	(D'02'*D'24')+D'00'	;scale=20bin=049octave=02note=01
	retlw	(D'02'*D'24')+D'00'	;scale=20bin=050octave=02note=02
	retlw	(D'02'*D'24')+D'00'	;scale=20bin=051octave=02note=03
	retlw	(D'02'*D'24')+D'00'	;scale=20bin=052octave=02note=04
	retlw	(D'02'*D'24')+D'00'	;scale=20bin=053octave=02note=05
	retlw	(D'02'*D'24')+D'06'	;scale=20bin=054octave=02note=06
	retlw	(D'02'*D'24')+D'06'	;scale=20bin=055octave=02note=07
	retlw	(D'02'*D'24')+D'08'	;scale=20bin=056octave=02note=08
	retlw	(D'02'*D'24')+D'08'	;scale=20bin=057octave=02note=09
	retlw	(D'02'*D'24')+D'08'	;scale=20bin=058octave=02note=10
	retlw	(D'02'*D'24')+D'08'	;scale=20bin=059octave=02note=11
	retlw	(D'02'*D'24')+D'08'	;scale=20bin=060octave=02note=12
	retlw	(D'02'*D'24')+D'08'	;scale=20bin=061octave=02note=13
	retlw	(D'02'*D'24')+D'14'	;scale=20bin=062octave=02note=14
	retlw	(D'02'*D'24')+D'14'	;scale=20bin=063octave=02note=15
	retlw	(D'02'*D'24')+D'16'	;scale=20bin=064octave=02note=16
	retlw	(D'02'*D'24')+D'16'	;scale=20bin=065octave=02note=17
	retlw	(D'02'*D'24')+D'16'	;scale=20bin=066octave=02note=18
	retlw	(D'02'*D'24')+D'16'	;scale=20bin=067octave=02note=19
	retlw	(D'02'*D'24')+D'16'	;scale=20bin=068octave=02note=20
	retlw	(D'02'*D'24')+D'16'	;scale=20bin=069octave=02note=21
	retlw	(D'02'*D'24')+D'22'	;scale=20bin=070octave=02note=22
	retlw	(D'02'*D'24')+D'22'	;scale=20bin=071octave=02note=23
	retlw	(D'03'*D'24')+D'00'	;scale=20bin=072octave=03note=00
	retlw	(D'03'*D'24')+D'00'	;scale=20bin=073octave=03note=01
	retlw	(D'03'*D'24')+D'00'	;scale=20bin=074octave=03note=02
	retlw	(D'03'*D'24')+D'00'	;scale=20bin=075octave=03note=03
	retlw	(D'03'*D'24')+D'00'	;scale=20bin=076octave=03note=04
	retlw	(D'03'*D'24')+D'00'	;scale=20bin=077octave=03note=05
	retlw	(D'03'*D'24')+D'06'	;scale=20bin=078octave=03note=06
	retlw	(D'03'*D'24')+D'06'	;scale=20bin=079octave=03note=07
	retlw	(D'03'*D'24')+D'08'	;scale=20bin=080octave=03note=08
	retlw	(D'03'*D'24')+D'08'	;scale=20bin=081octave=03note=09
	retlw	(D'03'*D'24')+D'08'	;scale=20bin=082octave=03note=10
	retlw	(D'03'*D'24')+D'08'	;scale=20bin=083octave=03note=11
	retlw	(D'03'*D'24')+D'08'	;scale=20bin=084octave=03note=12
	retlw	(D'03'*D'24')+D'08'	;scale=20bin=085octave=03note=13
	retlw	(D'03'*D'24')+D'14'	;scale=20bin=086octave=03note=14
	retlw	(D'03'*D'24')+D'14'	;scale=20bin=087octave=03note=15
	retlw	(D'03'*D'24')+D'16'	;scale=20bin=088octave=03note=16
	retlw	(D'03'*D'24')+D'16'	;scale=20bin=089octave=03note=17
	retlw	(D'03'*D'24')+D'16'	;scale=20bin=090octave=03note=18
	retlw	(D'03'*D'24')+D'16'	;scale=20bin=091octave=03note=19
	retlw	(D'03'*D'24')+D'16'	;scale=20bin=092octave=03note=20
	retlw	(D'03'*D'24')+D'16'	;scale=20bin=093octave=03note=21
	retlw	(D'03'*D'24')+D'22'	;scale=20bin=094octave=03note=22
	retlw	(D'03'*D'24')+D'22'	;scale=20bin=095octave=03note=23
	retlw	(D'04'*D'24')+D'00'	;scale=20bin=096octave=04note=00
	retlw	(D'04'*D'24')+D'00'	;scale=20bin=097octave=04note=01
	retlw	(D'04'*D'24')+D'00'	;scale=20bin=098octave=04note=02
	retlw	(D'04'*D'24')+D'00'	;scale=20bin=099octave=04note=03
	retlw	(D'04'*D'24')+D'00'	;scale=20bin=100octave=04note=04
	retlw	(D'04'*D'24')+D'00'	;scale=20bin=101octave=04note=05
	retlw	(D'04'*D'24')+D'06'	;scale=20bin=102octave=04note=06
	retlw	(D'04'*D'24')+D'06'	;scale=20bin=103octave=04note=07
	retlw	(D'04'*D'24')+D'08'	;scale=20bin=104octave=04note=08
	retlw	(D'04'*D'24')+D'08'	;scale=20bin=105octave=04note=09
	retlw	(D'04'*D'24')+D'08'	;scale=20bin=106octave=04note=10
	retlw	(D'04'*D'24')+D'08'	;scale=20bin=107octave=04note=11
	retlw	(D'04'*D'24')+D'08'	;scale=20bin=108octave=04note=12
	retlw	(D'04'*D'24')+D'08'	;scale=20bin=109octave=04note=13
	retlw	(D'04'*D'24')+D'14'	;scale=20bin=110octave=04note=14
	retlw	(D'04'*D'24')+D'14'	;scale=20bin=111octave=04note=15
	retlw	(D'04'*D'24')+D'16'	;scale=20bin=112octave=04note=16
	retlw	(D'04'*D'24')+D'16'	;scale=20bin=113octave=04note=17
	retlw	(D'04'*D'24')+D'16'	;scale=20bin=114octave=04note=18
	retlw	(D'04'*D'24')+D'16'	;scale=20bin=115octave=04note=19
	retlw	(D'04'*D'24')+D'16'	;scale=20bin=116octave=04note=20
	retlw	(D'04'*D'24')+D'16'	;scale=20bin=117octave=04note=21
	retlw	(D'04'*D'24')+D'22'	;scale=20bin=118octave=04note=22
	retlw	(D'04'*D'24')+D'22'	;scale=20bin=119octave=04note=23
	retlw	(D'05'*D'24')+D'00'	;scale=20bin=120octave=05note=00
	retlw	(D'05'*D'24')+D'00'	;scale=20bin=121octave=05note=01
	retlw	(D'05'*D'24')+D'00'	;scale=20bin=122octave=05note=02
	retlw	(D'05'*D'24')+D'00'	;scale=20bin=123octave=05note=03
	retlw	(D'05'*D'24')+D'00'	;scale=20bin=124octave=05note=04
	retlw	(D'05'*D'24')+D'00'	;scale=20bin=125octave=05note=05
	retlw	(D'05'*D'24')+D'06'	;scale=20bin=126octave=05note=06
	retlw	(D'05'*D'24')+D'06'	;scale=20bin=127octave=05note=07
	retlw	(D'05'*D'24')+D'08'	;scale=20bin=128octave=05note=08
	retlw	(D'05'*D'24')+D'08'	;scale=20bin=129octave=05note=09
	retlw	(D'05'*D'24')+D'08'	;scale=20bin=130octave=05note=10
	retlw	(D'05'*D'24')+D'08'	;scale=20bin=131octave=05note=11
	retlw	(D'05'*D'24')+D'08'	;scale=20bin=132octave=05note=12
	retlw	(D'05'*D'24')+D'08'	;scale=20bin=133octave=05note=13
	retlw	(D'05'*D'24')+D'14'	;scale=20bin=134octave=05note=14
	retlw	(D'05'*D'24')+D'14'	;scale=20bin=135octave=05note=15
	retlw	(D'05'*D'24')+D'16'	;scale=20bin=136octave=05note=16
	retlw	(D'05'*D'24')+D'16'	;scale=20bin=137octave=05note=17
	retlw	(D'05'*D'24')+D'16'	;scale=20bin=138octave=05note=18
	retlw	(D'05'*D'24')+D'16'	;scale=20bin=139octave=05note=19
	retlw	(D'05'*D'24')+D'16'	;scale=20bin=140octave=05note=20
	retlw	(D'05'*D'24')+D'16'	;scale=20bin=141octave=05note=21
	retlw	(D'05'*D'24')+D'22'	;scale=20bin=142octave=05note=22
	retlw	(D'05'*D'24')+D'22'	;scale=20bin=143octave=05note=23
	retlw	(D'06'*D'24')+D'00'	;scale=20bin=144octave=06note=00
	retlw	(D'06'*D'24')+D'00'	;scale=20bin=145octave=06note=01
	retlw	(D'06'*D'24')+D'00'	;scale=20bin=146octave=06note=02
	retlw	(D'06'*D'24')+D'00'	;scale=20bin=147octave=06note=03
	retlw	(D'06'*D'24')+D'00'	;scale=20bin=148octave=06note=04
	retlw	(D'06'*D'24')+D'00'	;scale=20bin=149octave=06note=05
	retlw	(D'06'*D'24')+D'06'	;scale=20bin=150octave=06note=06
	retlw	(D'06'*D'24')+D'06'	;scale=20bin=151octave=06note=07
	retlw	(D'06'*D'24')+D'08'	;scale=20bin=152octave=06note=08
	retlw	(D'06'*D'24')+D'08'	;scale=20bin=153octave=06note=09
	retlw	(D'06'*D'24')+D'08'	;scale=20bin=154octave=06note=10
	retlw	(D'06'*D'24')+D'08'	;scale=20bin=155octave=06note=11
	retlw	(D'06'*D'24')+D'08'	;scale=20bin=156octave=06note=12
	retlw	(D'06'*D'24')+D'08'	;scale=20bin=157octave=06note=13
	retlw	(D'06'*D'24')+D'14'	;scale=20bin=158octave=06note=14
	retlw	(D'06'*D'24')+D'14'	;scale=20bin=159octave=06note=15
	retlw	(D'06'*D'24')+D'16'	;scale=20bin=160octave=06note=16
	retlw	(D'06'*D'24')+D'16'	;scale=20bin=161octave=06note=17
	retlw	(D'06'*D'24')+D'16'	;scale=20bin=162octave=06note=18
	retlw	(D'06'*D'24')+D'16'	;scale=20bin=163octave=06note=19
	retlw	(D'06'*D'24')+D'16'	;scale=20bin=164octave=06note=20
	retlw	(D'06'*D'24')+D'16'	;scale=20bin=165octave=06note=21
	retlw	(D'06'*D'24')+D'22'	;scale=20bin=166octave=06note=22
	retlw	(D'06'*D'24')+D'22'	;scale=20bin=167octave=06note=23
	retlw	(D'07'*D'24')+D'00'	;scale=20bin=168octave=07note=00
	retlw	(D'07'*D'24')+D'00'	;scale=20bin=169octave=07note=01
	retlw	(D'07'*D'24')+D'00'	;scale=20bin=170octave=07note=02
	retlw	(D'07'*D'24')+D'00'	;scale=20bin=171octave=07note=03
	retlw	(D'07'*D'24')+D'00'	;scale=20bin=172octave=07note=04
	retlw	(D'07'*D'24')+D'00'	;scale=20bin=173octave=07note=05
	retlw	(D'07'*D'24')+D'06'	;scale=20bin=174octave=07note=06
	retlw	(D'07'*D'24')+D'06'	;scale=20bin=175octave=07note=07
	retlw	(D'07'*D'24')+D'08'	;scale=20bin=176octave=07note=08
	retlw	(D'07'*D'24')+D'08'	;scale=20bin=177octave=07note=09
	retlw	(D'07'*D'24')+D'08'	;scale=20bin=178octave=07note=10
	retlw	(D'07'*D'24')+D'08'	;scale=20bin=179octave=07note=11
	retlw	(D'07'*D'24')+D'08'	;scale=20bin=180octave=07note=12
	retlw	(D'07'*D'24')+D'08'	;scale=20bin=181octave=07note=13
	retlw	(D'07'*D'24')+D'14'	;scale=20bin=182octave=07note=14
	retlw	(D'07'*D'24')+D'14'	;scale=20bin=183octave=07note=15
	retlw	(D'07'*D'24')+D'16'	;scale=20bin=184octave=07note=16
	retlw	(D'07'*D'24')+D'16'	;scale=20bin=185octave=07note=17
	retlw	(D'07'*D'24')+D'16'	;scale=20bin=186octave=07note=18
	retlw	(D'07'*D'24')+D'16'	;scale=20bin=187octave=07note=19
	retlw	(D'07'*D'24')+D'16'	;scale=20bin=188octave=07note=20
	retlw	(D'07'*D'24')+D'16'	;scale=20bin=189octave=07note=21
	retlw	(D'07'*D'24')+D'22'	;scale=20bin=190octave=07note=22
	retlw	(D'07'*D'24')+D'22'	;scale=20bin=191octave=07note=23
	retlw	(D'08'*D'24')+D'00'	;scale=20bin=192octave=08note=00
	retlw	(D'08'*D'24')+D'00'	;scale=20bin=193octave=08note=01
	retlw	(D'08'*D'24')+D'00'	;scale=20bin=194octave=08note=02
	retlw	(D'08'*D'24')+D'00'	;scale=20bin=195octave=08note=03
	retlw	(D'08'*D'24')+D'00'	;scale=20bin=196octave=08note=04
	retlw	(D'08'*D'24')+D'00'	;scale=20bin=197octave=08note=05
	retlw	(D'08'*D'24')+D'06'	;scale=20bin=198octave=08note=06
	retlw	(D'08'*D'24')+D'06'	;scale=20bin=199octave=08note=07
	retlw	(D'08'*D'24')+D'08'	;scale=20bin=200octave=08note=08
	retlw	(D'08'*D'24')+D'08'	;scale=20bin=201octave=08note=09
	retlw	(D'08'*D'24')+D'08'	;scale=20bin=202octave=08note=10
	retlw	(D'08'*D'24')+D'08'	;scale=20bin=203octave=08note=11
	retlw	(D'08'*D'24')+D'08'	;scale=20bin=204octave=08note=12
	retlw	(D'08'*D'24')+D'08'	;scale=20bin=205octave=08note=13
	retlw	(D'08'*D'24')+D'14'	;scale=20bin=206octave=08note=14
	retlw	(D'08'*D'24')+D'14'	;scale=20bin=207octave=08note=15
	retlw	(D'08'*D'24')+D'16'	;scale=20bin=208octave=08note=16
	retlw	(D'08'*D'24')+D'16'	;scale=20bin=209octave=08note=17
	retlw	(D'08'*D'24')+D'16'	;scale=20bin=210octave=08note=18
	retlw	(D'08'*D'24')+D'16'	;scale=20bin=211octave=08note=19
	retlw	(D'08'*D'24')+D'16'	;scale=20bin=212octave=08note=20
	retlw	(D'08'*D'24')+D'16'	;scale=20bin=213octave=08note=21
	retlw	(D'08'*D'24')+D'22'	;scale=20bin=214octave=08note=22
	retlw	(D'08'*D'24')+D'22'	;scale=20bin=215octave=08note=23
	retlw	(D'09'*D'24')+D'00'	;scale=20bin=216octave=09note=00
	retlw	(D'09'*D'24')+D'00'	;scale=20bin=217octave=09note=01
	retlw	(D'09'*D'24')+D'00'	;scale=20bin=218octave=09note=02
	retlw	(D'09'*D'24')+D'00'	;scale=20bin=219octave=09note=03
	retlw	(D'09'*D'24')+D'00'	;scale=20bin=220octave=09note=04
	retlw	(D'09'*D'24')+D'00'	;scale=20bin=221octave=09note=05
	retlw	(D'09'*D'24')+D'06'	;scale=20bin=222octave=09note=06
	retlw	(D'09'*D'24')+D'06'	;scale=20bin=223octave=09note=07
	retlw	(D'09'*D'24')+D'08'	;scale=20bin=224octave=09note=08
	retlw	(D'09'*D'24')+D'08'	;scale=20bin=225octave=09note=09
	retlw	(D'09'*D'24')+D'08'	;scale=20bin=226octave=09note=10
	retlw	(D'09'*D'24')+D'08'	;scale=20bin=227octave=09note=11
	retlw	(D'09'*D'24')+D'08'	;scale=20bin=228octave=09note=12
	retlw	(D'09'*D'24')+D'08'	;scale=20bin=229octave=09note=13
	retlw	(D'09'*D'24')+D'14'	;scale=20bin=230octave=09note=14
	retlw	(D'09'*D'24')+D'14'	;scale=20bin=231octave=09note=15
	retlw	(D'09'*D'24')+D'16'	;scale=20bin=232octave=09note=16
	retlw	(D'09'*D'24')+D'16'	;scale=20bin=233octave=09note=17
	retlw	(D'09'*D'24')+D'16'	;scale=20bin=234octave=09note=18
	retlw	(D'09'*D'24')+D'16'	;scale=20bin=235octave=09note=19
	retlw	(D'09'*D'24')+D'16'	;scale=20bin=236octave=09note=20
	retlw	(D'09'*D'24')+D'16'	;scale=20bin=237octave=09note=21
	retlw	(D'09'*D'24')+D'22'	;scale=20bin=238octave=09note=22
	retlw	(D'09'*D'24')+D'22'	;scale=20bin=239octave=09note=23
	retlw	(D'10'*D'24')+D'00'	;scale=20bin=240octave=10note=00
	retlw	(D'10'*D'24')+D'00'	;scale=20bin=241octave=10note=01
	retlw	(D'10'*D'24')+D'00'	;scale=20bin=242octave=10note=02
	retlw	(D'10'*D'24')+D'00'	;scale=20bin=243octave=10note=03
	retlw	(D'10'*D'24')+D'00'	;scale=20bin=244octave=10note=04
	retlw	(D'10'*D'24')+D'00'	;scale=20bin=245octave=10note=05
	retlw	(D'10'*D'24')+D'00'	;scale=20bin=246octave=10note=06
	retlw	(D'10'*D'24')+D'00'	;scale=20bin=247octave=10note=07
	retlw	(D'10'*D'24')+D'00'	;scale=20bin=248octave=10note=08
	retlw	(D'10'*D'24')+D'00'	;scale=20bin=249octave=10note=09
	retlw	(D'10'*D'24')+D'00'	;scale=20bin=250octave=10note=10
	retlw	(D'10'*D'24')+D'00'	;scale=20bin=251octave=10note=11
	retlw	(D'10'*D'24')+D'00'	;scale=20bin=252octave=10note=12
	retlw	(D'10'*D'24')+D'00'	;scale=20bin=253octave=10note=13
	retlw	(D'10'*D'24')+D'00'	;scale=20bin=254octave=10note=14
	retlw	(D'10'*D'24')+D'00'	;scale=20bin=255octave=10note=15

;	Seventh look-up table
	org	Seventh		;Seventh look-up table
	retlw	(D'00'*D'24')+D'00'	;scale=21bin=000octave=00note=00
	retlw	(D'00'*D'24')+D'00'	;scale=21bin=001octave=00note=01
	retlw	(D'00'*D'24')+D'00'	;scale=21bin=002octave=00note=02
	retlw	(D'00'*D'24')+D'00'	;scale=21bin=003octave=00note=03
	retlw	(D'00'*D'24')+D'00'	;scale=21bin=004octave=00note=04
	retlw	(D'00'*D'24')+D'00'	;scale=21bin=005octave=00note=05
	retlw	(D'00'*D'24')+D'00'	;scale=21bin=006octave=00note=06
	retlw	(D'00'*D'24')+D'00'	;scale=21bin=007octave=00note=07
	retlw	(D'00'*D'24')+D'08'	;scale=21bin=008octave=00note=08
	retlw	(D'00'*D'24')+D'08'	;scale=21bin=009octave=00note=09
	retlw	(D'00'*D'24')+D'08'	;scale=21bin=010octave=00note=10
	retlw	(D'00'*D'24')+D'08'	;scale=21bin=011octave=00note=11
	retlw	(D'00'*D'24')+D'08'	;scale=21bin=012octave=00note=12
	retlw	(D'00'*D'24')+D'08'	;scale=21bin=013octave=00note=13
	retlw	(D'00'*D'24')+D'14'	;scale=21bin=014octave=00note=14
	retlw	(D'00'*D'24')+D'14'	;scale=21bin=015octave=00note=15
	retlw	(D'00'*D'24')+D'14'	;scale=21bin=016octave=00note=16
	retlw	(D'00'*D'24')+D'14'	;scale=21bin=017octave=00note=17
	retlw	(D'00'*D'24')+D'14'	;scale=21bin=018octave=00note=18
	retlw	(D'00'*D'24')+D'14'	;scale=21bin=019octave=00note=19
	retlw	(D'00'*D'24')+D'14'	;scale=21bin=020octave=00note=20
	retlw	(D'00'*D'24')+D'14'	;scale=21bin=021octave=00note=21
	retlw	(D'00'*D'24')+D'22'	;scale=21bin=022octave=00note=22
	retlw	(D'00'*D'24')+D'22'	;scale=21bin=023octave=00note=23
	retlw	(D'01'*D'24')+D'00'	;scale=21bin=024octave=01note=00
	retlw	(D'01'*D'24')+D'00'	;scale=21bin=025octave=01note=01
	retlw	(D'01'*D'24')+D'00'	;scale=21bin=026octave=01note=02
	retlw	(D'01'*D'24')+D'00'	;scale=21bin=027octave=01note=03
	retlw	(D'01'*D'24')+D'00'	;scale=21bin=028octave=01note=04
	retlw	(D'01'*D'24')+D'00'	;scale=21bin=029octave=01note=05
	retlw	(D'01'*D'24')+D'00'	;scale=21bin=030octave=01note=06
	retlw	(D'01'*D'24')+D'00'	;scale=21bin=031octave=01note=07
	retlw	(D'01'*D'24')+D'08'	;scale=21bin=032octave=01note=08
	retlw	(D'01'*D'24')+D'08'	;scale=21bin=033octave=01note=09
	retlw	(D'01'*D'24')+D'08'	;scale=21bin=034octave=01note=10
	retlw	(D'01'*D'24')+D'08'	;scale=21bin=035octave=01note=11
	retlw	(D'01'*D'24')+D'08'	;scale=21bin=036octave=01note=12
	retlw	(D'01'*D'24')+D'08'	;scale=21bin=037octave=01note=13
	retlw	(D'01'*D'24')+D'14'	;scale=21bin=038octave=01note=14
	retlw	(D'01'*D'24')+D'14'	;scale=21bin=039octave=01note=15
	retlw	(D'01'*D'24')+D'14'	;scale=21bin=040octave=01note=16
	retlw	(D'01'*D'24')+D'14'	;scale=21bin=041octave=01note=17
	retlw	(D'01'*D'24')+D'14'	;scale=21bin=042octave=01note=18
	retlw	(D'01'*D'24')+D'14'	;scale=21bin=043octave=01note=19
	retlw	(D'01'*D'24')+D'14'	;scale=21bin=044octave=01note=20
	retlw	(D'01'*D'24')+D'14'	;scale=21bin=045octave=01note=21
	retlw	(D'01'*D'24')+D'22'	;scale=21bin=046octave=01note=22
	retlw	(D'01'*D'24')+D'22'	;scale=21bin=047octave=01note=23
	retlw	(D'02'*D'24')+D'00'	;scale=21bin=048octave=02note=00
	retlw	(D'02'*D'24')+D'00'	;scale=21bin=049octave=02note=01
	retlw	(D'02'*D'24')+D'00'	;scale=21bin=050octave=02note=02
	retlw	(D'02'*D'24')+D'00'	;scale=21bin=051octave=02note=03
	retlw	(D'02'*D'24')+D'00'	;scale=21bin=052octave=02note=04
	retlw	(D'02'*D'24')+D'00'	;scale=21bin=053octave=02note=05
	retlw	(D'02'*D'24')+D'00'	;scale=21bin=054octave=02note=06
	retlw	(D'02'*D'24')+D'00'	;scale=21bin=055octave=02note=07
	retlw	(D'02'*D'24')+D'08'	;scale=21bin=056octave=02note=08
	retlw	(D'02'*D'24')+D'08'	;scale=21bin=057octave=02note=09
	retlw	(D'02'*D'24')+D'08'	;scale=21bin=058octave=02note=10
	retlw	(D'02'*D'24')+D'08'	;scale=21bin=059octave=02note=11
	retlw	(D'02'*D'24')+D'08'	;scale=21bin=060octave=02note=12
	retlw	(D'02'*D'24')+D'08'	;scale=21bin=061octave=02note=13
	retlw	(D'02'*D'24')+D'14'	;scale=21bin=062octave=02note=14
	retlw	(D'02'*D'24')+D'14'	;scale=21bin=063octave=02note=15
	retlw	(D'02'*D'24')+D'14'	;scale=21bin=064octave=02note=16
	retlw	(D'02'*D'24')+D'14'	;scale=21bin=065octave=02note=17
	retlw	(D'02'*D'24')+D'14'	;scale=21bin=066octave=02note=18
	retlw	(D'02'*D'24')+D'14'	;scale=21bin=067octave=02note=19
	retlw	(D'02'*D'24')+D'14'	;scale=21bin=068octave=02note=20
	retlw	(D'02'*D'24')+D'14'	;scale=21bin=069octave=02note=21
	retlw	(D'02'*D'24')+D'22'	;scale=21bin=070octave=02note=22
	retlw	(D'02'*D'24')+D'22'	;scale=21bin=071octave=02note=23
	retlw	(D'03'*D'24')+D'00'	;scale=21bin=072octave=03note=00
	retlw	(D'03'*D'24')+D'00'	;scale=21bin=073octave=03note=01
	retlw	(D'03'*D'24')+D'00'	;scale=21bin=074octave=03note=02
	retlw	(D'03'*D'24')+D'00'	;scale=21bin=075octave=03note=03
	retlw	(D'03'*D'24')+D'00'	;scale=21bin=076octave=03note=04
	retlw	(D'03'*D'24')+D'00'	;scale=21bin=077octave=03note=05
	retlw	(D'03'*D'24')+D'00'	;scale=21bin=078octave=03note=06
	retlw	(D'03'*D'24')+D'00'	;scale=21bin=079octave=03note=07
	retlw	(D'03'*D'24')+D'08'	;scale=21bin=080octave=03note=08
	retlw	(D'03'*D'24')+D'08'	;scale=21bin=081octave=03note=09
	retlw	(D'03'*D'24')+D'08'	;scale=21bin=082octave=03note=10
	retlw	(D'03'*D'24')+D'08'	;scale=21bin=083octave=03note=11
	retlw	(D'03'*D'24')+D'08'	;scale=21bin=084octave=03note=12
	retlw	(D'03'*D'24')+D'08'	;scale=21bin=085octave=03note=13
	retlw	(D'03'*D'24')+D'14'	;scale=21bin=086octave=03note=14
	retlw	(D'03'*D'24')+D'14'	;scale=21bin=087octave=03note=15
	retlw	(D'03'*D'24')+D'14'	;scale=21bin=088octave=03note=16
	retlw	(D'03'*D'24')+D'14'	;scale=21bin=089octave=03note=17
	retlw	(D'03'*D'24')+D'14'	;scale=21bin=090octave=03note=18
	retlw	(D'03'*D'24')+D'14'	;scale=21bin=091octave=03note=19
	retlw	(D'03'*D'24')+D'14'	;scale=21bin=092octave=03note=20
	retlw	(D'03'*D'24')+D'14'	;scale=21bin=093octave=03note=21
	retlw	(D'03'*D'24')+D'22'	;scale=21bin=094octave=03note=22
	retlw	(D'03'*D'24')+D'22'	;scale=21bin=095octave=03note=23
	retlw	(D'04'*D'24')+D'00'	;scale=21bin=096octave=04note=00
	retlw	(D'04'*D'24')+D'00'	;scale=21bin=097octave=04note=01
	retlw	(D'04'*D'24')+D'00'	;scale=21bin=098octave=04note=02
	retlw	(D'04'*D'24')+D'00'	;scale=21bin=099octave=04note=03
	retlw	(D'04'*D'24')+D'00'	;scale=21bin=100octave=04note=04
	retlw	(D'04'*D'24')+D'00'	;scale=21bin=101octave=04note=05
	retlw	(D'04'*D'24')+D'00'	;scale=21bin=102octave=04note=06
	retlw	(D'04'*D'24')+D'00'	;scale=21bin=103octave=04note=07
	retlw	(D'04'*D'24')+D'08'	;scale=21bin=104octave=04note=08
	retlw	(D'04'*D'24')+D'08'	;scale=21bin=105octave=04note=09
	retlw	(D'04'*D'24')+D'08'	;scale=21bin=106octave=04note=10
	retlw	(D'04'*D'24')+D'08'	;scale=21bin=107octave=04note=11
	retlw	(D'04'*D'24')+D'08'	;scale=21bin=108octave=04note=12
	retlw	(D'04'*D'24')+D'08'	;scale=21bin=109octave=04note=13
	retlw	(D'04'*D'24')+D'14'	;scale=21bin=110octave=04note=14
	retlw	(D'04'*D'24')+D'14'	;scale=21bin=111octave=04note=15
	retlw	(D'04'*D'24')+D'14'	;scale=21bin=112octave=04note=16
	retlw	(D'04'*D'24')+D'14'	;scale=21bin=113octave=04note=17
	retlw	(D'04'*D'24')+D'14'	;scale=21bin=114octave=04note=18
	retlw	(D'04'*D'24')+D'14'	;scale=21bin=115octave=04note=19
	retlw	(D'04'*D'24')+D'14'	;scale=21bin=116octave=04note=20
	retlw	(D'04'*D'24')+D'14'	;scale=21bin=117octave=04note=21
	retlw	(D'04'*D'24')+D'22'	;scale=21bin=118octave=04note=22
	retlw	(D'04'*D'24')+D'22'	;scale=21bin=119octave=04note=23
	retlw	(D'05'*D'24')+D'00'	;scale=21bin=120octave=05note=00
	retlw	(D'05'*D'24')+D'00'	;scale=21bin=121octave=05note=01
	retlw	(D'05'*D'24')+D'00'	;scale=21bin=122octave=05note=02
	retlw	(D'05'*D'24')+D'00'	;scale=21bin=123octave=05note=03
	retlw	(D'05'*D'24')+D'00'	;scale=21bin=124octave=05note=04
	retlw	(D'05'*D'24')+D'00'	;scale=21bin=125octave=05note=05
	retlw	(D'05'*D'24')+D'00'	;scale=21bin=126octave=05note=06
	retlw	(D'05'*D'24')+D'00'	;scale=21bin=127octave=05note=07
	retlw	(D'05'*D'24')+D'08'	;scale=21bin=128octave=05note=08
	retlw	(D'05'*D'24')+D'08'	;scale=21bin=129octave=05note=09
	retlw	(D'05'*D'24')+D'08'	;scale=21bin=130octave=05note=10
	retlw	(D'05'*D'24')+D'08'	;scale=21bin=131octave=05note=11
	retlw	(D'05'*D'24')+D'08'	;scale=21bin=132octave=05note=12
	retlw	(D'05'*D'24')+D'08'	;scale=21bin=133octave=05note=13
	retlw	(D'05'*D'24')+D'14'	;scale=21bin=134octave=05note=14
	retlw	(D'05'*D'24')+D'14'	;scale=21bin=135octave=05note=15
	retlw	(D'05'*D'24')+D'14'	;scale=21bin=136octave=05note=16
	retlw	(D'05'*D'24')+D'14'	;scale=21bin=137octave=05note=17
	retlw	(D'05'*D'24')+D'14'	;scale=21bin=138octave=05note=18
	retlw	(D'05'*D'24')+D'14'	;scale=21bin=139octave=05note=19
	retlw	(D'05'*D'24')+D'14'	;scale=21bin=140octave=05note=20
	retlw	(D'05'*D'24')+D'14'	;scale=21bin=141octave=05note=21
	retlw	(D'05'*D'24')+D'22'	;scale=21bin=142octave=05note=22
	retlw	(D'05'*D'24')+D'22'	;scale=21bin=143octave=05note=23
	retlw	(D'06'*D'24')+D'00'	;scale=21bin=144octave=06note=00
	retlw	(D'06'*D'24')+D'00'	;scale=21bin=145octave=06note=01
	retlw	(D'06'*D'24')+D'00'	;scale=21bin=146octave=06note=02
	retlw	(D'06'*D'24')+D'00'	;scale=21bin=147octave=06note=03
	retlw	(D'06'*D'24')+D'00'	;scale=21bin=148octave=06note=04
	retlw	(D'06'*D'24')+D'00'	;scale=21bin=149octave=06note=05
	retlw	(D'06'*D'24')+D'00'	;scale=21bin=150octave=06note=06
	retlw	(D'06'*D'24')+D'00'	;scale=21bin=151octave=06note=07
	retlw	(D'06'*D'24')+D'08'	;scale=21bin=152octave=06note=08
	retlw	(D'06'*D'24')+D'08'	;scale=21bin=153octave=06note=09
	retlw	(D'06'*D'24')+D'08'	;scale=21bin=154octave=06note=10
	retlw	(D'06'*D'24')+D'08'	;scale=21bin=155octave=06note=11
	retlw	(D'06'*D'24')+D'08'	;scale=21bin=156octave=06note=12
	retlw	(D'06'*D'24')+D'08'	;scale=21bin=157octave=06note=13
	retlw	(D'06'*D'24')+D'14'	;scale=21bin=158octave=06note=14
	retlw	(D'06'*D'24')+D'14'	;scale=21bin=159octave=06note=15
	retlw	(D'06'*D'24')+D'14'	;scale=21bin=160octave=06note=16
	retlw	(D'06'*D'24')+D'14'	;scale=21bin=161octave=06note=17
	retlw	(D'06'*D'24')+D'14'	;scale=21bin=162octave=06note=18
	retlw	(D'06'*D'24')+D'14'	;scale=21bin=163octave=06note=19
	retlw	(D'06'*D'24')+D'14'	;scale=21bin=164octave=06note=20
	retlw	(D'06'*D'24')+D'14'	;scale=21bin=165octave=06note=21
	retlw	(D'06'*D'24')+D'22'	;scale=21bin=166octave=06note=22
	retlw	(D'06'*D'24')+D'22'	;scale=21bin=167octave=06note=23
	retlw	(D'07'*D'24')+D'00'	;scale=21bin=168octave=07note=00
	retlw	(D'07'*D'24')+D'00'	;scale=21bin=169octave=07note=01
	retlw	(D'07'*D'24')+D'00'	;scale=21bin=170octave=07note=02
	retlw	(D'07'*D'24')+D'00'	;scale=21bin=171octave=07note=03
	retlw	(D'07'*D'24')+D'00'	;scale=21bin=172octave=07note=04
	retlw	(D'07'*D'24')+D'00'	;scale=21bin=173octave=07note=05
	retlw	(D'07'*D'24')+D'00'	;scale=21bin=174octave=07note=06
	retlw	(D'07'*D'24')+D'00'	;scale=21bin=175octave=07note=07
	retlw	(D'07'*D'24')+D'08'	;scale=21bin=176octave=07note=08
	retlw	(D'07'*D'24')+D'08'	;scale=21bin=177octave=07note=09
	retlw	(D'07'*D'24')+D'08'	;scale=21bin=178octave=07note=10
	retlw	(D'07'*D'24')+D'08'	;scale=21bin=179octave=07note=11
	retlw	(D'07'*D'24')+D'08'	;scale=21bin=180octave=07note=12
	retlw	(D'07'*D'24')+D'08'	;scale=21bin=181octave=07note=13
	retlw	(D'07'*D'24')+D'14'	;scale=21bin=182octave=07note=14
	retlw	(D'07'*D'24')+D'14'	;scale=21bin=183octave=07note=15
	retlw	(D'07'*D'24')+D'14'	;scale=21bin=184octave=07note=16
	retlw	(D'07'*D'24')+D'14'	;scale=21bin=185octave=07note=17
	retlw	(D'07'*D'24')+D'14'	;scale=21bin=186octave=07note=18
	retlw	(D'07'*D'24')+D'14'	;scale=21bin=187octave=07note=19
	retlw	(D'07'*D'24')+D'14'	;scale=21bin=188octave=07note=20
	retlw	(D'07'*D'24')+D'14'	;scale=21bin=189octave=07note=21
	retlw	(D'07'*D'24')+D'22'	;scale=21bin=190octave=07note=22
	retlw	(D'07'*D'24')+D'22'	;scale=21bin=191octave=07note=23
	retlw	(D'08'*D'24')+D'00'	;scale=21bin=192octave=08note=00
	retlw	(D'08'*D'24')+D'00'	;scale=21bin=193octave=08note=01
	retlw	(D'08'*D'24')+D'00'	;scale=21bin=194octave=08note=02
	retlw	(D'08'*D'24')+D'00'	;scale=21bin=195octave=08note=03
	retlw	(D'08'*D'24')+D'00'	;scale=21bin=196octave=08note=04
	retlw	(D'08'*D'24')+D'00'	;scale=21bin=197octave=08note=05
	retlw	(D'08'*D'24')+D'00'	;scale=21bin=198octave=08note=06
	retlw	(D'08'*D'24')+D'00'	;scale=21bin=199octave=08note=07
	retlw	(D'08'*D'24')+D'08'	;scale=21bin=200octave=08note=08
	retlw	(D'08'*D'24')+D'08'	;scale=21bin=201octave=08note=09
	retlw	(D'08'*D'24')+D'08'	;scale=21bin=202octave=08note=10
	retlw	(D'08'*D'24')+D'08'	;scale=21bin=203octave=08note=11
	retlw	(D'08'*D'24')+D'08'	;scale=21bin=204octave=08note=12
	retlw	(D'08'*D'24')+D'08'	;scale=21bin=205octave=08note=13
	retlw	(D'08'*D'24')+D'14'	;scale=21bin=206octave=08note=14
	retlw	(D'08'*D'24')+D'14'	;scale=21bin=207octave=08note=15
	retlw	(D'08'*D'24')+D'14'	;scale=21bin=208octave=08note=16
	retlw	(D'08'*D'24')+D'14'	;scale=21bin=209octave=08note=17
	retlw	(D'08'*D'24')+D'14'	;scale=21bin=210octave=08note=18
	retlw	(D'08'*D'24')+D'14'	;scale=21bin=211octave=08note=19
	retlw	(D'08'*D'24')+D'14'	;scale=21bin=212octave=08note=20
	retlw	(D'08'*D'24')+D'14'	;scale=21bin=213octave=08note=21
	retlw	(D'08'*D'24')+D'22'	;scale=21bin=214octave=08note=22
	retlw	(D'08'*D'24')+D'22'	;scale=21bin=215octave=08note=23
	retlw	(D'09'*D'24')+D'00'	;scale=21bin=216octave=09note=00
	retlw	(D'09'*D'24')+D'00'	;scale=21bin=217octave=09note=01
	retlw	(D'09'*D'24')+D'00'	;scale=21bin=218octave=09note=02
	retlw	(D'09'*D'24')+D'00'	;scale=21bin=219octave=09note=03
	retlw	(D'09'*D'24')+D'00'	;scale=21bin=220octave=09note=04
	retlw	(D'09'*D'24')+D'00'	;scale=21bin=221octave=09note=05
	retlw	(D'09'*D'24')+D'00'	;scale=21bin=222octave=09note=06
	retlw	(D'09'*D'24')+D'00'	;scale=21bin=223octave=09note=07
	retlw	(D'09'*D'24')+D'08'	;scale=21bin=224octave=09note=08
	retlw	(D'09'*D'24')+D'08'	;scale=21bin=225octave=09note=09
	retlw	(D'09'*D'24')+D'08'	;scale=21bin=226octave=09note=10
	retlw	(D'09'*D'24')+D'08'	;scale=21bin=227octave=09note=11
	retlw	(D'09'*D'24')+D'08'	;scale=21bin=228octave=09note=12
	retlw	(D'09'*D'24')+D'08'	;scale=21bin=229octave=09note=13
	retlw	(D'09'*D'24')+D'14'	;scale=21bin=230octave=09note=14
	retlw	(D'09'*D'24')+D'14'	;scale=21bin=231octave=09note=15
	retlw	(D'09'*D'24')+D'14'	;scale=21bin=232octave=09note=16
	retlw	(D'09'*D'24')+D'14'	;scale=21bin=233octave=09note=17
	retlw	(D'09'*D'24')+D'14'	;scale=21bin=234octave=09note=18
	retlw	(D'09'*D'24')+D'14'	;scale=21bin=235octave=09note=19
	retlw	(D'09'*D'24')+D'14'	;scale=21bin=236octave=09note=20
	retlw	(D'09'*D'24')+D'14'	;scale=21bin=237octave=09note=21
	retlw	(D'09'*D'24')+D'22'	;scale=21bin=238octave=09note=22
	retlw	(D'09'*D'24')+D'22'	;scale=21bin=239octave=09note=23
	retlw	(D'10'*D'24')+D'00'	;scale=21bin=240octave=10note=00
	retlw	(D'10'*D'24')+D'00'	;scale=21bin=241octave=10note=01
	retlw	(D'10'*D'24')+D'00'	;scale=21bin=242octave=10note=02
	retlw	(D'10'*D'24')+D'00'	;scale=21bin=243octave=10note=03
	retlw	(D'10'*D'24')+D'00'	;scale=21bin=244octave=10note=04
	retlw	(D'10'*D'24')+D'00'	;scale=21bin=245octave=10note=05
	retlw	(D'10'*D'24')+D'00'	;scale=21bin=246octave=10note=06
	retlw	(D'10'*D'24')+D'00'	;scale=21bin=247octave=10note=07
	retlw	(D'10'*D'24')+D'00'	;scale=21bin=248octave=10note=08
	retlw	(D'10'*D'24')+D'00'	;scale=21bin=249octave=10note=09
	retlw	(D'10'*D'24')+D'00'	;scale=21bin=250octave=10note=10
	retlw	(D'10'*D'24')+D'00'	;scale=21bin=251octave=10note=11
	retlw	(D'10'*D'24')+D'00'	;scale=21bin=252octave=10note=12
	retlw	(D'10'*D'24')+D'00'	;scale=21bin=253octave=10note=13
	retlw	(D'10'*D'24')+D'00'	;scale=21bin=254octave=10note=14
	retlw	(D'10'*D'24')+D'00'	;scale=21bin=255octave=10note=15

;	Minor Seventh look-up table
	org	MinorSev		;Minor Seventh look-up table
	retlw	(D'00'*D'24')+D'00'	;scale=22bin=000octave=00note=00
	retlw	(D'00'*D'24')+D'00'	;scale=22bin=001octave=00note=01
	retlw	(D'00'*D'24')+D'00'	;scale=22bin=002octave=00note=02
	retlw	(D'00'*D'24')+D'00'	;scale=22bin=003octave=00note=03
	retlw	(D'00'*D'24')+D'00'	;scale=22bin=004octave=00note=04
	retlw	(D'00'*D'24')+D'00'	;scale=22bin=005octave=00note=05
	retlw	(D'00'*D'24')+D'06'	;scale=22bin=006octave=00note=06
	retlw	(D'00'*D'24')+D'06'	;scale=22bin=007octave=00note=07
	retlw	(D'00'*D'24')+D'06'	;scale=22bin=008octave=00note=08
	retlw	(D'00'*D'24')+D'06'	;scale=22bin=009octave=00note=09
	retlw	(D'00'*D'24')+D'06'	;scale=22bin=010octave=00note=10
	retlw	(D'00'*D'24')+D'06'	;scale=22bin=011octave=00note=11
	retlw	(D'00'*D'24')+D'06'	;scale=22bin=012octave=00note=12
	retlw	(D'00'*D'24')+D'06'	;scale=22bin=013octave=00note=13
	retlw	(D'00'*D'24')+D'14'	;scale=22bin=014octave=00note=14
	retlw	(D'00'*D'24')+D'14'	;scale=22bin=015octave=00note=15
	retlw	(D'00'*D'24')+D'14'	;scale=22bin=016octave=00note=16
	retlw	(D'00'*D'24')+D'14'	;scale=22bin=017octave=00note=17
	retlw	(D'00'*D'24')+D'14'	;scale=22bin=018octave=00note=18
	retlw	(D'00'*D'24')+D'14'	;scale=22bin=019octave=00note=19
	retlw	(D'00'*D'24')+D'14'	;scale=22bin=020octave=00note=20
	retlw	(D'00'*D'24')+D'14'	;scale=22bin=021octave=00note=21
	retlw	(D'00'*D'24')+D'22'	;scale=22bin=022octave=00note=22
	retlw	(D'00'*D'24')+D'22'	;scale=22bin=023octave=00note=23
	retlw	(D'01'*D'24')+D'00'	;scale=22bin=024octave=01note=00
	retlw	(D'01'*D'24')+D'00'	;scale=22bin=025octave=01note=01
	retlw	(D'01'*D'24')+D'00'	;scale=22bin=026octave=01note=02
	retlw	(D'01'*D'24')+D'00'	;scale=22bin=027octave=01note=03
	retlw	(D'01'*D'24')+D'00'	;scale=22bin=028octave=01note=04
	retlw	(D'01'*D'24')+D'00'	;scale=22bin=029octave=01note=05
	retlw	(D'01'*D'24')+D'06'	;scale=22bin=030octave=01note=06
	retlw	(D'01'*D'24')+D'06'	;scale=22bin=031octave=01note=07
	retlw	(D'01'*D'24')+D'06'	;scale=22bin=032octave=01note=08
	retlw	(D'01'*D'24')+D'06'	;scale=22bin=033octave=01note=09
	retlw	(D'01'*D'24')+D'06'	;scale=22bin=034octave=01note=10
	retlw	(D'01'*D'24')+D'06'	;scale=22bin=035octave=01note=11
	retlw	(D'01'*D'24')+D'06'	;scale=22bin=036octave=01note=12
	retlw	(D'01'*D'24')+D'06'	;scale=22bin=037octave=01note=13
	retlw	(D'01'*D'24')+D'14'	;scale=22bin=038octave=01note=14
	retlw	(D'01'*D'24')+D'14'	;scale=22bin=039octave=01note=15
	retlw	(D'01'*D'24')+D'14'	;scale=22bin=040octave=01note=16
	retlw	(D'01'*D'24')+D'14'	;scale=22bin=041octave=01note=17
	retlw	(D'01'*D'24')+D'14'	;scale=22bin=042octave=01note=18
	retlw	(D'01'*D'24')+D'14'	;scale=22bin=043octave=01note=19
	retlw	(D'01'*D'24')+D'14'	;scale=22bin=044octave=01note=20
	retlw	(D'01'*D'24')+D'14'	;scale=22bin=045octave=01note=21
	retlw	(D'01'*D'24')+D'22'	;scale=22bin=046octave=01note=22
	retlw	(D'01'*D'24')+D'22'	;scale=22bin=047octave=01note=23
	retlw	(D'02'*D'24')+D'00'	;scale=22bin=048octave=02note=00
	retlw	(D'02'*D'24')+D'00'	;scale=22bin=049octave=02note=01
	retlw	(D'02'*D'24')+D'00'	;scale=22bin=050octave=02note=02
	retlw	(D'02'*D'24')+D'00'	;scale=22bin=051octave=02note=03
	retlw	(D'02'*D'24')+D'00'	;scale=22bin=052octave=02note=04
	retlw	(D'02'*D'24')+D'00'	;scale=22bin=053octave=02note=05
	retlw	(D'02'*D'24')+D'06'	;scale=22bin=054octave=02note=06
	retlw	(D'02'*D'24')+D'06'	;scale=22bin=055octave=02note=07
	retlw	(D'02'*D'24')+D'06'	;scale=22bin=056octave=02note=08
	retlw	(D'02'*D'24')+D'06'	;scale=22bin=057octave=02note=09
	retlw	(D'02'*D'24')+D'06'	;scale=22bin=058octave=02note=10
	retlw	(D'02'*D'24')+D'06'	;scale=22bin=059octave=02note=11
	retlw	(D'02'*D'24')+D'06'	;scale=22bin=060octave=02note=12
	retlw	(D'02'*D'24')+D'06'	;scale=22bin=061octave=02note=13
	retlw	(D'02'*D'24')+D'14'	;scale=22bin=062octave=02note=14
	retlw	(D'02'*D'24')+D'14'	;scale=22bin=063octave=02note=15
	retlw	(D'02'*D'24')+D'14'	;scale=22bin=064octave=02note=16
	retlw	(D'02'*D'24')+D'14'	;scale=22bin=065octave=02note=17
	retlw	(D'02'*D'24')+D'14'	;scale=22bin=066octave=02note=18
	retlw	(D'02'*D'24')+D'14'	;scale=22bin=067octave=02note=19
	retlw	(D'02'*D'24')+D'14'	;scale=22bin=068octave=02note=20
	retlw	(D'02'*D'24')+D'14'	;scale=22bin=069octave=02note=21
	retlw	(D'02'*D'24')+D'22'	;scale=22bin=070octave=02note=22
	retlw	(D'02'*D'24')+D'22'	;scale=22bin=071octave=02note=23
	retlw	(D'03'*D'24')+D'00'	;scale=22bin=072octave=03note=00
	retlw	(D'03'*D'24')+D'00'	;scale=22bin=073octave=03note=01
	retlw	(D'03'*D'24')+D'00'	;scale=22bin=074octave=03note=02
	retlw	(D'03'*D'24')+D'00'	;scale=22bin=075octave=03note=03
	retlw	(D'03'*D'24')+D'00'	;scale=22bin=076octave=03note=04
	retlw	(D'03'*D'24')+D'00'	;scale=22bin=077octave=03note=05
	retlw	(D'03'*D'24')+D'06'	;scale=22bin=078octave=03note=06
	retlw	(D'03'*D'24')+D'06'	;scale=22bin=079octave=03note=07
	retlw	(D'03'*D'24')+D'06'	;scale=22bin=080octave=03note=08
	retlw	(D'03'*D'24')+D'06'	;scale=22bin=081octave=03note=09
	retlw	(D'03'*D'24')+D'06'	;scale=22bin=082octave=03note=10
	retlw	(D'03'*D'24')+D'06'	;scale=22bin=083octave=03note=11
	retlw	(D'03'*D'24')+D'06'	;scale=22bin=084octave=03note=12
	retlw	(D'03'*D'24')+D'06'	;scale=22bin=085octave=03note=13
	retlw	(D'03'*D'24')+D'14'	;scale=22bin=086octave=03note=14
	retlw	(D'03'*D'24')+D'14'	;scale=22bin=087octave=03note=15
	retlw	(D'03'*D'24')+D'14'	;scale=22bin=088octave=03note=16
	retlw	(D'03'*D'24')+D'14'	;scale=22bin=089octave=03note=17
	retlw	(D'03'*D'24')+D'14'	;scale=22bin=090octave=03note=18
	retlw	(D'03'*D'24')+D'14'	;scale=22bin=091octave=03note=19
	retlw	(D'03'*D'24')+D'14'	;scale=22bin=092octave=03note=20
	retlw	(D'03'*D'24')+D'14'	;scale=22bin=093octave=03note=21
	retlw	(D'03'*D'24')+D'22'	;scale=22bin=094octave=03note=22
	retlw	(D'03'*D'24')+D'22'	;scale=22bin=095octave=03note=23
	retlw	(D'04'*D'24')+D'00'	;scale=22bin=096octave=04note=00
	retlw	(D'04'*D'24')+D'00'	;scale=22bin=097octave=04note=01
	retlw	(D'04'*D'24')+D'00'	;scale=22bin=098octave=04note=02
	retlw	(D'04'*D'24')+D'00'	;scale=22bin=099octave=04note=03
	retlw	(D'04'*D'24')+D'00'	;scale=22bin=100octave=04note=04
	retlw	(D'04'*D'24')+D'00'	;scale=22bin=101octave=04note=05
	retlw	(D'04'*D'24')+D'06'	;scale=22bin=102octave=04note=06
	retlw	(D'04'*D'24')+D'06'	;scale=22bin=103octave=04note=07
	retlw	(D'04'*D'24')+D'06'	;scale=22bin=104octave=04note=08
	retlw	(D'04'*D'24')+D'06'	;scale=22bin=105octave=04note=09
	retlw	(D'04'*D'24')+D'06'	;scale=22bin=106octave=04note=10
	retlw	(D'04'*D'24')+D'06'	;scale=22bin=107octave=04note=11
	retlw	(D'04'*D'24')+D'06'	;scale=22bin=108octave=04note=12
	retlw	(D'04'*D'24')+D'06'	;scale=22bin=109octave=04note=13
	retlw	(D'04'*D'24')+D'14'	;scale=22bin=110octave=04note=14
	retlw	(D'04'*D'24')+D'14'	;scale=22bin=111octave=04note=15
	retlw	(D'04'*D'24')+D'14'	;scale=22bin=112octave=04note=16
	retlw	(D'04'*D'24')+D'14'	;scale=22bin=113octave=04note=17
	retlw	(D'04'*D'24')+D'14'	;scale=22bin=114octave=04note=18
	retlw	(D'04'*D'24')+D'14'	;scale=22bin=115octave=04note=19
	retlw	(D'04'*D'24')+D'14'	;scale=22bin=116octave=04note=20
	retlw	(D'04'*D'24')+D'14'	;scale=22bin=117octave=04note=21
	retlw	(D'04'*D'24')+D'22'	;scale=22bin=118octave=04note=22
	retlw	(D'04'*D'24')+D'22'	;scale=22bin=119octave=04note=23
	retlw	(D'05'*D'24')+D'00'	;scale=22bin=120octave=05note=00
	retlw	(D'05'*D'24')+D'00'	;scale=22bin=121octave=05note=01
	retlw	(D'05'*D'24')+D'00'	;scale=22bin=122octave=05note=02
	retlw	(D'05'*D'24')+D'00'	;scale=22bin=123octave=05note=03
	retlw	(D'05'*D'24')+D'00'	;scale=22bin=124octave=05note=04
	retlw	(D'05'*D'24')+D'00'	;scale=22bin=125octave=05note=05
	retlw	(D'05'*D'24')+D'06'	;scale=22bin=126octave=05note=06
	retlw	(D'05'*D'24')+D'06'	;scale=22bin=127octave=05note=07
	retlw	(D'05'*D'24')+D'06'	;scale=22bin=128octave=05note=08
	retlw	(D'05'*D'24')+D'06'	;scale=22bin=129octave=05note=09
	retlw	(D'05'*D'24')+D'06'	;scale=22bin=130octave=05note=10
	retlw	(D'05'*D'24')+D'06'	;scale=22bin=131octave=05note=11
	retlw	(D'05'*D'24')+D'06'	;scale=22bin=132octave=05note=12
	retlw	(D'05'*D'24')+D'06'	;scale=22bin=133octave=05note=13
	retlw	(D'05'*D'24')+D'14'	;scale=22bin=134octave=05note=14
	retlw	(D'05'*D'24')+D'14'	;scale=22bin=135octave=05note=15
	retlw	(D'05'*D'24')+D'14'	;scale=22bin=136octave=05note=16
	retlw	(D'05'*D'24')+D'14'	;scale=22bin=137octave=05note=17
	retlw	(D'05'*D'24')+D'14'	;scale=22bin=138octave=05note=18
	retlw	(D'05'*D'24')+D'14'	;scale=22bin=139octave=05note=19
	retlw	(D'05'*D'24')+D'14'	;scale=22bin=140octave=05note=20
	retlw	(D'05'*D'24')+D'14'	;scale=22bin=141octave=05note=21
	retlw	(D'05'*D'24')+D'22'	;scale=22bin=142octave=05note=22
	retlw	(D'05'*D'24')+D'22'	;scale=22bin=143octave=05note=23
	retlw	(D'06'*D'24')+D'00'	;scale=22bin=144octave=06note=00
	retlw	(D'06'*D'24')+D'00'	;scale=22bin=145octave=06note=01
	retlw	(D'06'*D'24')+D'00'	;scale=22bin=146octave=06note=02
	retlw	(D'06'*D'24')+D'00'	;scale=22bin=147octave=06note=03
	retlw	(D'06'*D'24')+D'00'	;scale=22bin=148octave=06note=04
	retlw	(D'06'*D'24')+D'00'	;scale=22bin=149octave=06note=05
	retlw	(D'06'*D'24')+D'06'	;scale=22bin=150octave=06note=06
	retlw	(D'06'*D'24')+D'06'	;scale=22bin=151octave=06note=07
	retlw	(D'06'*D'24')+D'06'	;scale=22bin=152octave=06note=08
	retlw	(D'06'*D'24')+D'06'	;scale=22bin=153octave=06note=09
	retlw	(D'06'*D'24')+D'06'	;scale=22bin=154octave=06note=10
	retlw	(D'06'*D'24')+D'06'	;scale=22bin=155octave=06note=11
	retlw	(D'06'*D'24')+D'06'	;scale=22bin=156octave=06note=12
	retlw	(D'06'*D'24')+D'06'	;scale=22bin=157octave=06note=13
	retlw	(D'06'*D'24')+D'14'	;scale=22bin=158octave=06note=14
	retlw	(D'06'*D'24')+D'14'	;scale=22bin=159octave=06note=15
	retlw	(D'06'*D'24')+D'14'	;scale=22bin=160octave=06note=16
	retlw	(D'06'*D'24')+D'14'	;scale=22bin=161octave=06note=17
	retlw	(D'06'*D'24')+D'14'	;scale=22bin=162octave=06note=18
	retlw	(D'06'*D'24')+D'14'	;scale=22bin=163octave=06note=19
	retlw	(D'06'*D'24')+D'14'	;scale=22bin=164octave=06note=20
	retlw	(D'06'*D'24')+D'14'	;scale=22bin=165octave=06note=21
	retlw	(D'06'*D'24')+D'22'	;scale=22bin=166octave=06note=22
	retlw	(D'06'*D'24')+D'22'	;scale=22bin=167octave=06note=23
	retlw	(D'07'*D'24')+D'00'	;scale=22bin=168octave=07note=00
	retlw	(D'07'*D'24')+D'00'	;scale=22bin=169octave=07note=01
	retlw	(D'07'*D'24')+D'00'	;scale=22bin=170octave=07note=02
	retlw	(D'07'*D'24')+D'00'	;scale=22bin=171octave=07note=03
	retlw	(D'07'*D'24')+D'00'	;scale=22bin=172octave=07note=04
	retlw	(D'07'*D'24')+D'00'	;scale=22bin=173octave=07note=05
	retlw	(D'07'*D'24')+D'06'	;scale=22bin=174octave=07note=06
	retlw	(D'07'*D'24')+D'06'	;scale=22bin=175octave=07note=07
	retlw	(D'07'*D'24')+D'06'	;scale=22bin=176octave=07note=08
	retlw	(D'07'*D'24')+D'06'	;scale=22bin=177octave=07note=09
	retlw	(D'07'*D'24')+D'06'	;scale=22bin=178octave=07note=10
	retlw	(D'07'*D'24')+D'06'	;scale=22bin=179octave=07note=11
	retlw	(D'07'*D'24')+D'06'	;scale=22bin=180octave=07note=12
	retlw	(D'07'*D'24')+D'06'	;scale=22bin=181octave=07note=13
	retlw	(D'07'*D'24')+D'14'	;scale=22bin=182octave=07note=14
	retlw	(D'07'*D'24')+D'14'	;scale=22bin=183octave=07note=15
	retlw	(D'07'*D'24')+D'14'	;scale=22bin=184octave=07note=16
	retlw	(D'07'*D'24')+D'14'	;scale=22bin=185octave=07note=17
	retlw	(D'07'*D'24')+D'14'	;scale=22bin=186octave=07note=18
	retlw	(D'07'*D'24')+D'14'	;scale=22bin=187octave=07note=19
	retlw	(D'07'*D'24')+D'14'	;scale=22bin=188octave=07note=20
	retlw	(D'07'*D'24')+D'14'	;scale=22bin=189octave=07note=21
	retlw	(D'07'*D'24')+D'22'	;scale=22bin=190octave=07note=22
	retlw	(D'07'*D'24')+D'22'	;scale=22bin=191octave=07note=23
	retlw	(D'08'*D'24')+D'00'	;scale=22bin=192octave=08note=00
	retlw	(D'08'*D'24')+D'00'	;scale=22bin=193octave=08note=01
	retlw	(D'08'*D'24')+D'00'	;scale=22bin=194octave=08note=02
	retlw	(D'08'*D'24')+D'00'	;scale=22bin=195octave=08note=03
	retlw	(D'08'*D'24')+D'00'	;scale=22bin=196octave=08note=04
	retlw	(D'08'*D'24')+D'00'	;scale=22bin=197octave=08note=05
	retlw	(D'08'*D'24')+D'06'	;scale=22bin=198octave=08note=06
	retlw	(D'08'*D'24')+D'06'	;scale=22bin=199octave=08note=07
	retlw	(D'08'*D'24')+D'06'	;scale=22bin=200octave=08note=08
	retlw	(D'08'*D'24')+D'06'	;scale=22bin=201octave=08note=09
	retlw	(D'08'*D'24')+D'06'	;scale=22bin=202octave=08note=10
	retlw	(D'08'*D'24')+D'06'	;scale=22bin=203octave=08note=11
	retlw	(D'08'*D'24')+D'06'	;scale=22bin=204octave=08note=12
	retlw	(D'08'*D'24')+D'06'	;scale=22bin=205octave=08note=13
	retlw	(D'08'*D'24')+D'14'	;scale=22bin=206octave=08note=14
	retlw	(D'08'*D'24')+D'14'	;scale=22bin=207octave=08note=15
	retlw	(D'08'*D'24')+D'14'	;scale=22bin=208octave=08note=16
	retlw	(D'08'*D'24')+D'14'	;scale=22bin=209octave=08note=17
	retlw	(D'08'*D'24')+D'14'	;scale=22bin=210octave=08note=18
	retlw	(D'08'*D'24')+D'14'	;scale=22bin=211octave=08note=19
	retlw	(D'08'*D'24')+D'14'	;scale=22bin=212octave=08note=20
	retlw	(D'08'*D'24')+D'14'	;scale=22bin=213octave=08note=21
	retlw	(D'08'*D'24')+D'22'	;scale=22bin=214octave=08note=22
	retlw	(D'08'*D'24')+D'22'	;scale=22bin=215octave=08note=23
	retlw	(D'09'*D'24')+D'00'	;scale=22bin=216octave=09note=00
	retlw	(D'09'*D'24')+D'00'	;scale=22bin=217octave=09note=01
	retlw	(D'09'*D'24')+D'00'	;scale=22bin=218octave=09note=02
	retlw	(D'09'*D'24')+D'00'	;scale=22bin=219octave=09note=03
	retlw	(D'09'*D'24')+D'00'	;scale=22bin=220octave=09note=04
	retlw	(D'09'*D'24')+D'00'	;scale=22bin=221octave=09note=05
	retlw	(D'09'*D'24')+D'06'	;scale=22bin=222octave=09note=06
	retlw	(D'09'*D'24')+D'06'	;scale=22bin=223octave=09note=07
	retlw	(D'09'*D'24')+D'06'	;scale=22bin=224octave=09note=08
	retlw	(D'09'*D'24')+D'06'	;scale=22bin=225octave=09note=09
	retlw	(D'09'*D'24')+D'06'	;scale=22bin=226octave=09note=10
	retlw	(D'09'*D'24')+D'06'	;scale=22bin=227octave=09note=11
	retlw	(D'09'*D'24')+D'06'	;scale=22bin=228octave=09note=12
	retlw	(D'09'*D'24')+D'06'	;scale=22bin=229octave=09note=13
	retlw	(D'09'*D'24')+D'14'	;scale=22bin=230octave=09note=14
	retlw	(D'09'*D'24')+D'14'	;scale=22bin=231octave=09note=15
	retlw	(D'09'*D'24')+D'14'	;scale=22bin=232octave=09note=16
	retlw	(D'09'*D'24')+D'14'	;scale=22bin=233octave=09note=17
	retlw	(D'09'*D'24')+D'14'	;scale=22bin=234octave=09note=18
	retlw	(D'09'*D'24')+D'14'	;scale=22bin=235octave=09note=19
	retlw	(D'09'*D'24')+D'14'	;scale=22bin=236octave=09note=20
	retlw	(D'09'*D'24')+D'14'	;scale=22bin=237octave=09note=21
	retlw	(D'09'*D'24')+D'22'	;scale=22bin=238octave=09note=22
	retlw	(D'09'*D'24')+D'22'	;scale=22bin=239octave=09note=23
	retlw	(D'10'*D'24')+D'00'	;scale=22bin=240octave=10note=00
	retlw	(D'10'*D'24')+D'00'	;scale=22bin=241octave=10note=01
	retlw	(D'10'*D'24')+D'00'	;scale=22bin=242octave=10note=02
	retlw	(D'10'*D'24')+D'00'	;scale=22bin=243octave=10note=03
	retlw	(D'10'*D'24')+D'00'	;scale=22bin=244octave=10note=04
	retlw	(D'10'*D'24')+D'00'	;scale=22bin=245octave=10note=05
	retlw	(D'10'*D'24')+D'00'	;scale=22bin=246octave=10note=06
	retlw	(D'10'*D'24')+D'00'	;scale=22bin=247octave=10note=07
	retlw	(D'10'*D'24')+D'00'	;scale=22bin=248octave=10note=08
	retlw	(D'10'*D'24')+D'00'	;scale=22bin=249octave=10note=09
	retlw	(D'10'*D'24')+D'00'	;scale=22bin=250octave=10note=10
	retlw	(D'10'*D'24')+D'00'	;scale=22bin=251octave=10note=11
	retlw	(D'10'*D'24')+D'00'	;scale=22bin=252octave=10note=12
	retlw	(D'10'*D'24')+D'00'	;scale=22bin=253octave=10note=13
	retlw	(D'10'*D'24')+D'00'	;scale=22bin=254octave=10note=14
	retlw	(D'10'*D'24')+D'00'	;scale=22bin=255octave=10note=15

;	Thirds look-up table
	org	Thirds		;Thirds look-up table
	retlw	(D'00'*D'24')+D'00'	;scale=23bin=000octave=00note=00
	retlw	(D'00'*D'24')+D'00'	;scale=23bin=001octave=00note=01
	retlw	(D'00'*D'24')+D'00'	;scale=23bin=002octave=00note=02
	retlw	(D'00'*D'24')+D'00'	;scale=23bin=003octave=00note=03
	retlw	(D'00'*D'24')+D'00'	;scale=23bin=004octave=00note=04
	retlw	(D'00'*D'24')+D'00'	;scale=23bin=005octave=00note=05
	retlw	(D'00'*D'24')+D'00'	;scale=23bin=006octave=00note=06
	retlw	(D'00'*D'24')+D'00'	;scale=23bin=007octave=00note=07
	retlw	(D'00'*D'24')+D'08'	;scale=23bin=008octave=00note=08
	retlw	(D'00'*D'24')+D'08'	;scale=23bin=009octave=00note=09
	retlw	(D'00'*D'24')+D'08'	;scale=23bin=010octave=00note=10
	retlw	(D'00'*D'24')+D'08'	;scale=23bin=011octave=00note=11
	retlw	(D'00'*D'24')+D'08'	;scale=23bin=012octave=00note=12
	retlw	(D'00'*D'24')+D'08'	;scale=23bin=013octave=00note=13
	retlw	(D'00'*D'24')+D'08'	;scale=23bin=014octave=00note=14
	retlw	(D'00'*D'24')+D'08'	;scale=23bin=015octave=00note=15
	retlw	(D'00'*D'24')+D'16'	;scale=23bin=016octave=00note=16
	retlw	(D'00'*D'24')+D'16'	;scale=23bin=017octave=00note=17
	retlw	(D'00'*D'24')+D'16'	;scale=23bin=018octave=00note=18
	retlw	(D'00'*D'24')+D'16'	;scale=23bin=019octave=00note=19
	retlw	(D'00'*D'24')+D'16'	;scale=23bin=020octave=00note=20
	retlw	(D'00'*D'24')+D'16'	;scale=23bin=021octave=00note=21
	retlw	(D'00'*D'24')+D'16'	;scale=23bin=022octave=00note=22
	retlw	(D'00'*D'24')+D'16'	;scale=23bin=023octave=00note=23
	retlw	(D'01'*D'24')+D'00'	;scale=23bin=024octave=01note=00
	retlw	(D'01'*D'24')+D'00'	;scale=23bin=025octave=01note=01
	retlw	(D'01'*D'24')+D'00'	;scale=23bin=026octave=01note=02
	retlw	(D'01'*D'24')+D'00'	;scale=23bin=027octave=01note=03
	retlw	(D'01'*D'24')+D'00'	;scale=23bin=028octave=01note=04
	retlw	(D'01'*D'24')+D'00'	;scale=23bin=029octave=01note=05
	retlw	(D'01'*D'24')+D'00'	;scale=23bin=030octave=01note=06
	retlw	(D'01'*D'24')+D'00'	;scale=23bin=031octave=01note=07
	retlw	(D'01'*D'24')+D'08'	;scale=23bin=032octave=01note=08
	retlw	(D'01'*D'24')+D'08'	;scale=23bin=033octave=01note=09
	retlw	(D'01'*D'24')+D'08'	;scale=23bin=034octave=01note=10
	retlw	(D'01'*D'24')+D'08'	;scale=23bin=035octave=01note=11
	retlw	(D'01'*D'24')+D'08'	;scale=23bin=036octave=01note=12
	retlw	(D'01'*D'24')+D'08'	;scale=23bin=037octave=01note=13
	retlw	(D'01'*D'24')+D'08'	;scale=23bin=038octave=01note=14
	retlw	(D'01'*D'24')+D'08'	;scale=23bin=039octave=01note=15
	retlw	(D'01'*D'24')+D'16'	;scale=23bin=040octave=01note=16
	retlw	(D'01'*D'24')+D'16'	;scale=23bin=041octave=01note=17
	retlw	(D'01'*D'24')+D'16'	;scale=23bin=042octave=01note=18
	retlw	(D'01'*D'24')+D'16'	;scale=23bin=043octave=01note=19
	retlw	(D'01'*D'24')+D'16'	;scale=23bin=044octave=01note=20
	retlw	(D'01'*D'24')+D'16'	;scale=23bin=045octave=01note=21
	retlw	(D'01'*D'24')+D'16'	;scale=23bin=046octave=01note=22
	retlw	(D'01'*D'24')+D'16'	;scale=23bin=047octave=01note=23
	retlw	(D'02'*D'24')+D'00'	;scale=23bin=048octave=02note=00
	retlw	(D'02'*D'24')+D'00'	;scale=23bin=049octave=02note=01
	retlw	(D'02'*D'24')+D'00'	;scale=23bin=050octave=02note=02
	retlw	(D'02'*D'24')+D'00'	;scale=23bin=051octave=02note=03
	retlw	(D'02'*D'24')+D'00'	;scale=23bin=052octave=02note=04
	retlw	(D'02'*D'24')+D'00'	;scale=23bin=053octave=02note=05
	retlw	(D'02'*D'24')+D'00'	;scale=23bin=054octave=02note=06
	retlw	(D'02'*D'24')+D'00'	;scale=23bin=055octave=02note=07
	retlw	(D'02'*D'24')+D'08'	;scale=23bin=056octave=02note=08
	retlw	(D'02'*D'24')+D'08'	;scale=23bin=057octave=02note=09
	retlw	(D'02'*D'24')+D'08'	;scale=23bin=058octave=02note=10
	retlw	(D'02'*D'24')+D'08'	;scale=23bin=059octave=02note=11
	retlw	(D'02'*D'24')+D'08'	;scale=23bin=060octave=02note=12
	retlw	(D'02'*D'24')+D'08'	;scale=23bin=061octave=02note=13
	retlw	(D'02'*D'24')+D'08'	;scale=23bin=062octave=02note=14
	retlw	(D'02'*D'24')+D'08'	;scale=23bin=063octave=02note=15
	retlw	(D'02'*D'24')+D'16'	;scale=23bin=064octave=02note=16
	retlw	(D'02'*D'24')+D'16'	;scale=23bin=065octave=02note=17
	retlw	(D'02'*D'24')+D'16'	;scale=23bin=066octave=02note=18
	retlw	(D'02'*D'24')+D'16'	;scale=23bin=067octave=02note=19
	retlw	(D'02'*D'24')+D'16'	;scale=23bin=068octave=02note=20
	retlw	(D'02'*D'24')+D'16'	;scale=23bin=069octave=02note=21
	retlw	(D'02'*D'24')+D'16'	;scale=23bin=070octave=02note=22
	retlw	(D'02'*D'24')+D'16'	;scale=23bin=071octave=02note=23
	retlw	(D'03'*D'24')+D'00'	;scale=23bin=072octave=03note=00
	retlw	(D'03'*D'24')+D'00'	;scale=23bin=073octave=03note=01
	retlw	(D'03'*D'24')+D'00'	;scale=23bin=074octave=03note=02
	retlw	(D'03'*D'24')+D'00'	;scale=23bin=075octave=03note=03
	retlw	(D'03'*D'24')+D'00'	;scale=23bin=076octave=03note=04
	retlw	(D'03'*D'24')+D'00'	;scale=23bin=077octave=03note=05
	retlw	(D'03'*D'24')+D'00'	;scale=23bin=078octave=03note=06
	retlw	(D'03'*D'24')+D'00'	;scale=23bin=079octave=03note=07
	retlw	(D'03'*D'24')+D'08'	;scale=23bin=080octave=03note=08
	retlw	(D'03'*D'24')+D'08'	;scale=23bin=081octave=03note=09
	retlw	(D'03'*D'24')+D'08'	;scale=23bin=082octave=03note=10
	retlw	(D'03'*D'24')+D'08'	;scale=23bin=083octave=03note=11
	retlw	(D'03'*D'24')+D'08'	;scale=23bin=084octave=03note=12
	retlw	(D'03'*D'24')+D'08'	;scale=23bin=085octave=03note=13
	retlw	(D'03'*D'24')+D'08'	;scale=23bin=086octave=03note=14
	retlw	(D'03'*D'24')+D'08'	;scale=23bin=087octave=03note=15
	retlw	(D'03'*D'24')+D'16'	;scale=23bin=088octave=03note=16
	retlw	(D'03'*D'24')+D'16'	;scale=23bin=089octave=03note=17
	retlw	(D'03'*D'24')+D'16'	;scale=23bin=090octave=03note=18
	retlw	(D'03'*D'24')+D'16'	;scale=23bin=091octave=03note=19
	retlw	(D'03'*D'24')+D'16'	;scale=23bin=092octave=03note=20
	retlw	(D'03'*D'24')+D'16'	;scale=23bin=093octave=03note=21
	retlw	(D'03'*D'24')+D'16'	;scale=23bin=094octave=03note=22
	retlw	(D'03'*D'24')+D'16'	;scale=23bin=095octave=03note=23
	retlw	(D'04'*D'24')+D'00'	;scale=23bin=096octave=04note=00
	retlw	(D'04'*D'24')+D'00'	;scale=23bin=097octave=04note=01
	retlw	(D'04'*D'24')+D'00'	;scale=23bin=098octave=04note=02
	retlw	(D'04'*D'24')+D'00'	;scale=23bin=099octave=04note=03
	retlw	(D'04'*D'24')+D'00'	;scale=23bin=100octave=04note=04
	retlw	(D'04'*D'24')+D'00'	;scale=23bin=101octave=04note=05
	retlw	(D'04'*D'24')+D'00'	;scale=23bin=102octave=04note=06
	retlw	(D'04'*D'24')+D'00'	;scale=23bin=103octave=04note=07
	retlw	(D'04'*D'24')+D'08'	;scale=23bin=104octave=04note=08
	retlw	(D'04'*D'24')+D'08'	;scale=23bin=105octave=04note=09
	retlw	(D'04'*D'24')+D'08'	;scale=23bin=106octave=04note=10
	retlw	(D'04'*D'24')+D'08'	;scale=23bin=107octave=04note=11
	retlw	(D'04'*D'24')+D'08'	;scale=23bin=108octave=04note=12
	retlw	(D'04'*D'24')+D'08'	;scale=23bin=109octave=04note=13
	retlw	(D'04'*D'24')+D'08'	;scale=23bin=110octave=04note=14
	retlw	(D'04'*D'24')+D'08'	;scale=23bin=111octave=04note=15
	retlw	(D'04'*D'24')+D'16'	;scale=23bin=112octave=04note=16
	retlw	(D'04'*D'24')+D'16'	;scale=23bin=113octave=04note=17
	retlw	(D'04'*D'24')+D'16'	;scale=23bin=114octave=04note=18
	retlw	(D'04'*D'24')+D'16'	;scale=23bin=115octave=04note=19
	retlw	(D'04'*D'24')+D'16'	;scale=23bin=116octave=04note=20
	retlw	(D'04'*D'24')+D'16'	;scale=23bin=117octave=04note=21
	retlw	(D'04'*D'24')+D'16'	;scale=23bin=118octave=04note=22
	retlw	(D'04'*D'24')+D'16'	;scale=23bin=119octave=04note=23
	retlw	(D'05'*D'24')+D'00'	;scale=23bin=120octave=05note=00
	retlw	(D'05'*D'24')+D'00'	;scale=23bin=121octave=05note=01
	retlw	(D'05'*D'24')+D'00'	;scale=23bin=122octave=05note=02
	retlw	(D'05'*D'24')+D'00'	;scale=23bin=123octave=05note=03
	retlw	(D'05'*D'24')+D'00'	;scale=23bin=124octave=05note=04
	retlw	(D'05'*D'24')+D'00'	;scale=23bin=125octave=05note=05
	retlw	(D'05'*D'24')+D'00'	;scale=23bin=126octave=05note=06
	retlw	(D'05'*D'24')+D'00'	;scale=23bin=127octave=05note=07
	retlw	(D'05'*D'24')+D'08'	;scale=23bin=128octave=05note=08
	retlw	(D'05'*D'24')+D'08'	;scale=23bin=129octave=05note=09
	retlw	(D'05'*D'24')+D'08'	;scale=23bin=130octave=05note=10
	retlw	(D'05'*D'24')+D'08'	;scale=23bin=131octave=05note=11
	retlw	(D'05'*D'24')+D'08'	;scale=23bin=132octave=05note=12
	retlw	(D'05'*D'24')+D'08'	;scale=23bin=133octave=05note=13
	retlw	(D'05'*D'24')+D'08'	;scale=23bin=134octave=05note=14
	retlw	(D'05'*D'24')+D'08'	;scale=23bin=135octave=05note=15
	retlw	(D'05'*D'24')+D'16'	;scale=23bin=136octave=05note=16
	retlw	(D'05'*D'24')+D'16'	;scale=23bin=137octave=05note=17
	retlw	(D'05'*D'24')+D'16'	;scale=23bin=138octave=05note=18
	retlw	(D'05'*D'24')+D'16'	;scale=23bin=139octave=05note=19
	retlw	(D'05'*D'24')+D'16'	;scale=23bin=140octave=05note=20
	retlw	(D'05'*D'24')+D'16'	;scale=23bin=141octave=05note=21
	retlw	(D'05'*D'24')+D'16'	;scale=23bin=142octave=05note=22
	retlw	(D'05'*D'24')+D'16'	;scale=23bin=143octave=05note=23
	retlw	(D'06'*D'24')+D'00'	;scale=23bin=144octave=06note=00
	retlw	(D'06'*D'24')+D'00'	;scale=23bin=145octave=06note=01
	retlw	(D'06'*D'24')+D'00'	;scale=23bin=146octave=06note=02
	retlw	(D'06'*D'24')+D'00'	;scale=23bin=147octave=06note=03
	retlw	(D'06'*D'24')+D'00'	;scale=23bin=148octave=06note=04
	retlw	(D'06'*D'24')+D'00'	;scale=23bin=149octave=06note=05
	retlw	(D'06'*D'24')+D'00'	;scale=23bin=150octave=06note=06
	retlw	(D'06'*D'24')+D'00'	;scale=23bin=151octave=06note=07
	retlw	(D'06'*D'24')+D'08'	;scale=23bin=152octave=06note=08
	retlw	(D'06'*D'24')+D'08'	;scale=23bin=153octave=06note=09
	retlw	(D'06'*D'24')+D'08'	;scale=23bin=154octave=06note=10
	retlw	(D'06'*D'24')+D'08'	;scale=23bin=155octave=06note=11
	retlw	(D'06'*D'24')+D'08'	;scale=23bin=156octave=06note=12
	retlw	(D'06'*D'24')+D'08'	;scale=23bin=157octave=06note=13
	retlw	(D'06'*D'24')+D'08'	;scale=23bin=158octave=06note=14
	retlw	(D'06'*D'24')+D'08'	;scale=23bin=159octave=06note=15
	retlw	(D'06'*D'24')+D'16'	;scale=23bin=160octave=06note=16
	retlw	(D'06'*D'24')+D'16'	;scale=23bin=161octave=06note=17
	retlw	(D'06'*D'24')+D'16'	;scale=23bin=162octave=06note=18
	retlw	(D'06'*D'24')+D'16'	;scale=23bin=163octave=06note=19
	retlw	(D'06'*D'24')+D'16'	;scale=23bin=164octave=06note=20
	retlw	(D'06'*D'24')+D'16'	;scale=23bin=165octave=06note=21
	retlw	(D'06'*D'24')+D'16'	;scale=23bin=166octave=06note=22
	retlw	(D'06'*D'24')+D'16'	;scale=23bin=167octave=06note=23
	retlw	(D'07'*D'24')+D'00'	;scale=23bin=168octave=07note=00
	retlw	(D'07'*D'24')+D'00'	;scale=23bin=169octave=07note=01
	retlw	(D'07'*D'24')+D'00'	;scale=23bin=170octave=07note=02
	retlw	(D'07'*D'24')+D'00'	;scale=23bin=171octave=07note=03
	retlw	(D'07'*D'24')+D'00'	;scale=23bin=172octave=07note=04
	retlw	(D'07'*D'24')+D'00'	;scale=23bin=173octave=07note=05
	retlw	(D'07'*D'24')+D'00'	;scale=23bin=174octave=07note=06
	retlw	(D'07'*D'24')+D'00'	;scale=23bin=175octave=07note=07
	retlw	(D'07'*D'24')+D'08'	;scale=23bin=176octave=07note=08
	retlw	(D'07'*D'24')+D'08'	;scale=23bin=177octave=07note=09
	retlw	(D'07'*D'24')+D'08'	;scale=23bin=178octave=07note=10
	retlw	(D'07'*D'24')+D'08'	;scale=23bin=179octave=07note=11
	retlw	(D'07'*D'24')+D'08'	;scale=23bin=180octave=07note=12
	retlw	(D'07'*D'24')+D'08'	;scale=23bin=181octave=07note=13
	retlw	(D'07'*D'24')+D'08'	;scale=23bin=182octave=07note=14
	retlw	(D'07'*D'24')+D'08'	;scale=23bin=183octave=07note=15
	retlw	(D'07'*D'24')+D'16'	;scale=23bin=184octave=07note=16
	retlw	(D'07'*D'24')+D'16'	;scale=23bin=185octave=07note=17
	retlw	(D'07'*D'24')+D'16'	;scale=23bin=186octave=07note=18
	retlw	(D'07'*D'24')+D'16'	;scale=23bin=187octave=07note=19
	retlw	(D'07'*D'24')+D'16'	;scale=23bin=188octave=07note=20
	retlw	(D'07'*D'24')+D'16'	;scale=23bin=189octave=07note=21
	retlw	(D'07'*D'24')+D'16'	;scale=23bin=190octave=07note=22
	retlw	(D'07'*D'24')+D'16'	;scale=23bin=191octave=07note=23
	retlw	(D'08'*D'24')+D'00'	;scale=23bin=192octave=08note=00
	retlw	(D'08'*D'24')+D'00'	;scale=23bin=193octave=08note=01
	retlw	(D'08'*D'24')+D'00'	;scale=23bin=194octave=08note=02
	retlw	(D'08'*D'24')+D'00'	;scale=23bin=195octave=08note=03
	retlw	(D'08'*D'24')+D'00'	;scale=23bin=196octave=08note=04
	retlw	(D'08'*D'24')+D'00'	;scale=23bin=197octave=08note=05
	retlw	(D'08'*D'24')+D'00'	;scale=23bin=198octave=08note=06
	retlw	(D'08'*D'24')+D'00'	;scale=23bin=199octave=08note=07
	retlw	(D'08'*D'24')+D'08'	;scale=23bin=200octave=08note=08
	retlw	(D'08'*D'24')+D'08'	;scale=23bin=201octave=08note=09
	retlw	(D'08'*D'24')+D'08'	;scale=23bin=202octave=08note=10
	retlw	(D'08'*D'24')+D'08'	;scale=23bin=203octave=08note=11
	retlw	(D'08'*D'24')+D'08'	;scale=23bin=204octave=08note=12
	retlw	(D'08'*D'24')+D'08'	;scale=23bin=205octave=08note=13
	retlw	(D'08'*D'24')+D'08'	;scale=23bin=206octave=08note=14
	retlw	(D'08'*D'24')+D'08'	;scale=23bin=207octave=08note=15
	retlw	(D'08'*D'24')+D'16'	;scale=23bin=208octave=08note=16
	retlw	(D'08'*D'24')+D'16'	;scale=23bin=209octave=08note=17
	retlw	(D'08'*D'24')+D'16'	;scale=23bin=210octave=08note=18
	retlw	(D'08'*D'24')+D'16'	;scale=23bin=211octave=08note=19
	retlw	(D'08'*D'24')+D'16'	;scale=23bin=212octave=08note=20
	retlw	(D'08'*D'24')+D'16'	;scale=23bin=213octave=08note=21
	retlw	(D'08'*D'24')+D'16'	;scale=23bin=214octave=08note=22
	retlw	(D'08'*D'24')+D'16'	;scale=23bin=215octave=08note=23
	retlw	(D'09'*D'24')+D'00'	;scale=23bin=216octave=09note=00
	retlw	(D'09'*D'24')+D'00'	;scale=23bin=217octave=09note=01
	retlw	(D'09'*D'24')+D'00'	;scale=23bin=218octave=09note=02
	retlw	(D'09'*D'24')+D'00'	;scale=23bin=219octave=09note=03
	retlw	(D'09'*D'24')+D'00'	;scale=23bin=220octave=09note=04
	retlw	(D'09'*D'24')+D'00'	;scale=23bin=221octave=09note=05
	retlw	(D'09'*D'24')+D'00'	;scale=23bin=222octave=09note=06
	retlw	(D'09'*D'24')+D'00'	;scale=23bin=223octave=09note=07
	retlw	(D'09'*D'24')+D'08'	;scale=23bin=224octave=09note=08
	retlw	(D'09'*D'24')+D'08'	;scale=23bin=225octave=09note=09
	retlw	(D'09'*D'24')+D'08'	;scale=23bin=226octave=09note=10
	retlw	(D'09'*D'24')+D'08'	;scale=23bin=227octave=09note=11
	retlw	(D'09'*D'24')+D'08'	;scale=23bin=228octave=09note=12
	retlw	(D'09'*D'24')+D'08'	;scale=23bin=229octave=09note=13
	retlw	(D'09'*D'24')+D'08'	;scale=23bin=230octave=09note=14
	retlw	(D'09'*D'24')+D'08'	;scale=23bin=231octave=09note=15
	retlw	(D'09'*D'24')+D'16'	;scale=23bin=232octave=09note=16
	retlw	(D'09'*D'24')+D'16'	;scale=23bin=233octave=09note=17
	retlw	(D'09'*D'24')+D'16'	;scale=23bin=234octave=09note=18
	retlw	(D'09'*D'24')+D'16'	;scale=23bin=235octave=09note=19
	retlw	(D'09'*D'24')+D'16'	;scale=23bin=236octave=09note=20
	retlw	(D'09'*D'24')+D'16'	;scale=23bin=237octave=09note=21
	retlw	(D'09'*D'24')+D'16'	;scale=23bin=238octave=09note=22
	retlw	(D'09'*D'24')+D'16'	;scale=23bin=239octave=09note=23
	retlw	(D'10'*D'24')+D'00'	;scale=23bin=240octave=10note=00
	retlw	(D'10'*D'24')+D'00'	;scale=23bin=241octave=10note=01
	retlw	(D'10'*D'24')+D'00'	;scale=23bin=242octave=10note=02
	retlw	(D'10'*D'24')+D'00'	;scale=23bin=243octave=10note=03
	retlw	(D'10'*D'24')+D'00'	;scale=23bin=244octave=10note=04
	retlw	(D'10'*D'24')+D'00'	;scale=23bin=245octave=10note=05
	retlw	(D'10'*D'24')+D'00'	;scale=23bin=246octave=10note=06
	retlw	(D'10'*D'24')+D'00'	;scale=23bin=247octave=10note=07
	retlw	(D'10'*D'24')+D'00'	;scale=23bin=248octave=10note=08
	retlw	(D'10'*D'24')+D'00'	;scale=23bin=249octave=10note=09
	retlw	(D'10'*D'24')+D'00'	;scale=23bin=250octave=10note=10
	retlw	(D'10'*D'24')+D'00'	;scale=23bin=251octave=10note=11
	retlw	(D'10'*D'24')+D'00'	;scale=23bin=252octave=10note=12
	retlw	(D'10'*D'24')+D'00'	;scale=23bin=253octave=10note=13
	retlw	(D'10'*D'24')+D'00'	;scale=23bin=254octave=10note=14
	retlw	(D'10'*D'24')+D'00'	;scale=23bin=255octave=10note=15

;	Minor Thirds look-up table
	org	MinorThrd		;Minor Thirds look-up table
	retlw	(D'00'*D'24')+D'00'	;scale=24bin=000octave=00note=00
	retlw	(D'00'*D'24')+D'00'	;scale=24bin=001octave=00note=01
	retlw	(D'00'*D'24')+D'00'	;scale=24bin=002octave=00note=02
	retlw	(D'00'*D'24')+D'00'	;scale=24bin=003octave=00note=03
	retlw	(D'00'*D'24')+D'00'	;scale=24bin=004octave=00note=04
	retlw	(D'00'*D'24')+D'00'	;scale=24bin=005octave=00note=05
	retlw	(D'00'*D'24')+D'06'	;scale=24bin=006octave=00note=06
	retlw	(D'00'*D'24')+D'06'	;scale=24bin=007octave=00note=07
	retlw	(D'00'*D'24')+D'06'	;scale=24bin=008octave=00note=08
	retlw	(D'00'*D'24')+D'06'	;scale=24bin=009octave=00note=09
	retlw	(D'00'*D'24')+D'06'	;scale=24bin=010octave=00note=10
	retlw	(D'00'*D'24')+D'06'	;scale=24bin=011octave=00note=11
	retlw	(D'00'*D'24')+D'12'	;scale=24bin=012octave=00note=12
	retlw	(D'00'*D'24')+D'12'	;scale=24bin=013octave=00note=13
	retlw	(D'00'*D'24')+D'12'	;scale=24bin=014octave=00note=14
	retlw	(D'00'*D'24')+D'12'	;scale=24bin=015octave=00note=15
	retlw	(D'00'*D'24')+D'12'	;scale=24bin=016octave=00note=16
	retlw	(D'00'*D'24')+D'12'	;scale=24bin=017octave=00note=17
	retlw	(D'00'*D'24')+D'18'	;scale=24bin=018octave=00note=18
	retlw	(D'00'*D'24')+D'18'	;scale=24bin=019octave=00note=19
	retlw	(D'00'*D'24')+D'18'	;scale=24bin=020octave=00note=20
	retlw	(D'00'*D'24')+D'18'	;scale=24bin=021octave=00note=21
	retlw	(D'00'*D'24')+D'18'	;scale=24bin=022octave=00note=22
	retlw	(D'00'*D'24')+D'18'	;scale=24bin=023octave=00note=23
	retlw	(D'01'*D'24')+D'00'	;scale=24bin=024octave=01note=00
	retlw	(D'01'*D'24')+D'00'	;scale=24bin=025octave=01note=01
	retlw	(D'01'*D'24')+D'00'	;scale=24bin=026octave=01note=02
	retlw	(D'01'*D'24')+D'00'	;scale=24bin=027octave=01note=03
	retlw	(D'01'*D'24')+D'00'	;scale=24bin=028octave=01note=04
	retlw	(D'01'*D'24')+D'00'	;scale=24bin=029octave=01note=05
	retlw	(D'01'*D'24')+D'06'	;scale=24bin=030octave=01note=06
	retlw	(D'01'*D'24')+D'06'	;scale=24bin=031octave=01note=07
	retlw	(D'01'*D'24')+D'06'	;scale=24bin=032octave=01note=08
	retlw	(D'01'*D'24')+D'06'	;scale=24bin=033octave=01note=09
	retlw	(D'01'*D'24')+D'06'	;scale=24bin=034octave=01note=10
	retlw	(D'01'*D'24')+D'06'	;scale=24bin=035octave=01note=11
	retlw	(D'01'*D'24')+D'12'	;scale=24bin=036octave=01note=12
	retlw	(D'01'*D'24')+D'12'	;scale=24bin=037octave=01note=13
	retlw	(D'01'*D'24')+D'12'	;scale=24bin=038octave=01note=14
	retlw	(D'01'*D'24')+D'12'	;scale=24bin=039octave=01note=15
	retlw	(D'01'*D'24')+D'12'	;scale=24bin=040octave=01note=16
	retlw	(D'01'*D'24')+D'12'	;scale=24bin=041octave=01note=17
	retlw	(D'01'*D'24')+D'18'	;scale=24bin=042octave=01note=18
	retlw	(D'01'*D'24')+D'18'	;scale=24bin=043octave=01note=19
	retlw	(D'01'*D'24')+D'18'	;scale=24bin=044octave=01note=20
	retlw	(D'01'*D'24')+D'18'	;scale=24bin=045octave=01note=21
	retlw	(D'01'*D'24')+D'18'	;scale=24bin=046octave=01note=22
	retlw	(D'01'*D'24')+D'18'	;scale=24bin=047octave=01note=23
	retlw	(D'02'*D'24')+D'00'	;scale=24bin=048octave=02note=00
	retlw	(D'02'*D'24')+D'00'	;scale=24bin=049octave=02note=01
	retlw	(D'02'*D'24')+D'00'	;scale=24bin=050octave=02note=02
	retlw	(D'02'*D'24')+D'00'	;scale=24bin=051octave=02note=03
	retlw	(D'02'*D'24')+D'00'	;scale=24bin=052octave=02note=04
	retlw	(D'02'*D'24')+D'00'	;scale=24bin=053octave=02note=05
	retlw	(D'02'*D'24')+D'06'	;scale=24bin=054octave=02note=06
	retlw	(D'02'*D'24')+D'06'	;scale=24bin=055octave=02note=07
	retlw	(D'02'*D'24')+D'06'	;scale=24bin=056octave=02note=08
	retlw	(D'02'*D'24')+D'06'	;scale=24bin=057octave=02note=09
	retlw	(D'02'*D'24')+D'06'	;scale=24bin=058octave=02note=10
	retlw	(D'02'*D'24')+D'06'	;scale=24bin=059octave=02note=11
	retlw	(D'02'*D'24')+D'12'	;scale=24bin=060octave=02note=12
	retlw	(D'02'*D'24')+D'12'	;scale=24bin=061octave=02note=13
	retlw	(D'02'*D'24')+D'12'	;scale=24bin=062octave=02note=14
	retlw	(D'02'*D'24')+D'12'	;scale=24bin=063octave=02note=15
	retlw	(D'02'*D'24')+D'12'	;scale=24bin=064octave=02note=16
	retlw	(D'02'*D'24')+D'12'	;scale=24bin=065octave=02note=17
	retlw	(D'02'*D'24')+D'18'	;scale=24bin=066octave=02note=18
	retlw	(D'02'*D'24')+D'18'	;scale=24bin=067octave=02note=19
	retlw	(D'02'*D'24')+D'18'	;scale=24bin=068octave=02note=20
	retlw	(D'02'*D'24')+D'18'	;scale=24bin=069octave=02note=21
	retlw	(D'02'*D'24')+D'18'	;scale=24bin=070octave=02note=22
	retlw	(D'02'*D'24')+D'18'	;scale=24bin=071octave=02note=23
	retlw	(D'03'*D'24')+D'00'	;scale=24bin=072octave=03note=00
	retlw	(D'03'*D'24')+D'00'	;scale=24bin=073octave=03note=01
	retlw	(D'03'*D'24')+D'00'	;scale=24bin=074octave=03note=02
	retlw	(D'03'*D'24')+D'00'	;scale=24bin=075octave=03note=03
	retlw	(D'03'*D'24')+D'00'	;scale=24bin=076octave=03note=04
	retlw	(D'03'*D'24')+D'00'	;scale=24bin=077octave=03note=05
	retlw	(D'03'*D'24')+D'06'	;scale=24bin=078octave=03note=06
	retlw	(D'03'*D'24')+D'06'	;scale=24bin=079octave=03note=07
	retlw	(D'03'*D'24')+D'06'	;scale=24bin=080octave=03note=08
	retlw	(D'03'*D'24')+D'06'	;scale=24bin=081octave=03note=09
	retlw	(D'03'*D'24')+D'06'	;scale=24bin=082octave=03note=10
	retlw	(D'03'*D'24')+D'06'	;scale=24bin=083octave=03note=11
	retlw	(D'03'*D'24')+D'12'	;scale=24bin=084octave=03note=12
	retlw	(D'03'*D'24')+D'12'	;scale=24bin=085octave=03note=13
	retlw	(D'03'*D'24')+D'12'	;scale=24bin=086octave=03note=14
	retlw	(D'03'*D'24')+D'12'	;scale=24bin=087octave=03note=15
	retlw	(D'03'*D'24')+D'12'	;scale=24bin=088octave=03note=16
	retlw	(D'03'*D'24')+D'12'	;scale=24bin=089octave=03note=17
	retlw	(D'03'*D'24')+D'18'	;scale=24bin=090octave=03note=18
	retlw	(D'03'*D'24')+D'18'	;scale=24bin=091octave=03note=19
	retlw	(D'03'*D'24')+D'18'	;scale=24bin=092octave=03note=20
	retlw	(D'03'*D'24')+D'18'	;scale=24bin=093octave=03note=21
	retlw	(D'03'*D'24')+D'18'	;scale=24bin=094octave=03note=22
	retlw	(D'03'*D'24')+D'18'	;scale=24bin=095octave=03note=23
	retlw	(D'04'*D'24')+D'00'	;scale=24bin=096octave=04note=00
	retlw	(D'04'*D'24')+D'00'	;scale=24bin=097octave=04note=01
	retlw	(D'04'*D'24')+D'00'	;scale=24bin=098octave=04note=02
	retlw	(D'04'*D'24')+D'00'	;scale=24bin=099octave=04note=03
	retlw	(D'04'*D'24')+D'00'	;scale=24bin=100octave=04note=04
	retlw	(D'04'*D'24')+D'00'	;scale=24bin=101octave=04note=05
	retlw	(D'04'*D'24')+D'06'	;scale=24bin=102octave=04note=06
	retlw	(D'04'*D'24')+D'06'	;scale=24bin=103octave=04note=07
	retlw	(D'04'*D'24')+D'06'	;scale=24bin=104octave=04note=08
	retlw	(D'04'*D'24')+D'06'	;scale=24bin=105octave=04note=09
	retlw	(D'04'*D'24')+D'06'	;scale=24bin=106octave=04note=10
	retlw	(D'04'*D'24')+D'06'	;scale=24bin=107octave=04note=11
	retlw	(D'04'*D'24')+D'12'	;scale=24bin=108octave=04note=12
	retlw	(D'04'*D'24')+D'12'	;scale=24bin=109octave=04note=13
	retlw	(D'04'*D'24')+D'12'	;scale=24bin=110octave=04note=14
	retlw	(D'04'*D'24')+D'12'	;scale=24bin=111octave=04note=15
	retlw	(D'04'*D'24')+D'12'	;scale=24bin=112octave=04note=16
	retlw	(D'04'*D'24')+D'12'	;scale=24bin=113octave=04note=17
	retlw	(D'04'*D'24')+D'18'	;scale=24bin=114octave=04note=18
	retlw	(D'04'*D'24')+D'18'	;scale=24bin=115octave=04note=19
	retlw	(D'04'*D'24')+D'18'	;scale=24bin=116octave=04note=20
	retlw	(D'04'*D'24')+D'18'	;scale=24bin=117octave=04note=21
	retlw	(D'04'*D'24')+D'18'	;scale=24bin=118octave=04note=22
	retlw	(D'04'*D'24')+D'18'	;scale=24bin=119octave=04note=23
	retlw	(D'05'*D'24')+D'00'	;scale=24bin=120octave=05note=00
	retlw	(D'05'*D'24')+D'00'	;scale=24bin=121octave=05note=01
	retlw	(D'05'*D'24')+D'00'	;scale=24bin=122octave=05note=02
	retlw	(D'05'*D'24')+D'00'	;scale=24bin=123octave=05note=03
	retlw	(D'05'*D'24')+D'00'	;scale=24bin=124octave=05note=04
	retlw	(D'05'*D'24')+D'00'	;scale=24bin=125octave=05note=05
	retlw	(D'05'*D'24')+D'06'	;scale=24bin=126octave=05note=06
	retlw	(D'05'*D'24')+D'06'	;scale=24bin=127octave=05note=07
	retlw	(D'05'*D'24')+D'06'	;scale=24bin=128octave=05note=08
	retlw	(D'05'*D'24')+D'06'	;scale=24bin=129octave=05note=09
	retlw	(D'05'*D'24')+D'06'	;scale=24bin=130octave=05note=10
	retlw	(D'05'*D'24')+D'06'	;scale=24bin=131octave=05note=11
	retlw	(D'05'*D'24')+D'12'	;scale=24bin=132octave=05note=12
	retlw	(D'05'*D'24')+D'12'	;scale=24bin=133octave=05note=13
	retlw	(D'05'*D'24')+D'12'	;scale=24bin=134octave=05note=14
	retlw	(D'05'*D'24')+D'12'	;scale=24bin=135octave=05note=15
	retlw	(D'05'*D'24')+D'12'	;scale=24bin=136octave=05note=16
	retlw	(D'05'*D'24')+D'12'	;scale=24bin=137octave=05note=17
	retlw	(D'05'*D'24')+D'18'	;scale=24bin=138octave=05note=18
	retlw	(D'05'*D'24')+D'18'	;scale=24bin=139octave=05note=19
	retlw	(D'05'*D'24')+D'18'	;scale=24bin=140octave=05note=20
	retlw	(D'05'*D'24')+D'18'	;scale=24bin=141octave=05note=21
	retlw	(D'05'*D'24')+D'18'	;scale=24bin=142octave=05note=22
	retlw	(D'05'*D'24')+D'18'	;scale=24bin=143octave=05note=23
	retlw	(D'06'*D'24')+D'00'	;scale=24bin=144octave=06note=00
	retlw	(D'06'*D'24')+D'00'	;scale=24bin=145octave=06note=01
	retlw	(D'06'*D'24')+D'00'	;scale=24bin=146octave=06note=02
	retlw	(D'06'*D'24')+D'00'	;scale=24bin=147octave=06note=03
	retlw	(D'06'*D'24')+D'00'	;scale=24bin=148octave=06note=04
	retlw	(D'06'*D'24')+D'00'	;scale=24bin=149octave=06note=05
	retlw	(D'06'*D'24')+D'06'	;scale=24bin=150octave=06note=06
	retlw	(D'06'*D'24')+D'06'	;scale=24bin=151octave=06note=07
	retlw	(D'06'*D'24')+D'06'	;scale=24bin=152octave=06note=08
	retlw	(D'06'*D'24')+D'06'	;scale=24bin=153octave=06note=09
	retlw	(D'06'*D'24')+D'06'	;scale=24bin=154octave=06note=10
	retlw	(D'06'*D'24')+D'06'	;scale=24bin=155octave=06note=11
	retlw	(D'06'*D'24')+D'12'	;scale=24bin=156octave=06note=12
	retlw	(D'06'*D'24')+D'12'	;scale=24bin=157octave=06note=13
	retlw	(D'06'*D'24')+D'12'	;scale=24bin=158octave=06note=14
	retlw	(D'06'*D'24')+D'12'	;scale=24bin=159octave=06note=15
	retlw	(D'06'*D'24')+D'12'	;scale=24bin=160octave=06note=16
	retlw	(D'06'*D'24')+D'12'	;scale=24bin=161octave=06note=17
	retlw	(D'06'*D'24')+D'18'	;scale=24bin=162octave=06note=18
	retlw	(D'06'*D'24')+D'18'	;scale=24bin=163octave=06note=19
	retlw	(D'06'*D'24')+D'18'	;scale=24bin=164octave=06note=20
	retlw	(D'06'*D'24')+D'18'	;scale=24bin=165octave=06note=21
	retlw	(D'06'*D'24')+D'18'	;scale=24bin=166octave=06note=22
	retlw	(D'06'*D'24')+D'18'	;scale=24bin=167octave=06note=23
	retlw	(D'07'*D'24')+D'00'	;scale=24bin=168octave=07note=00
	retlw	(D'07'*D'24')+D'00'	;scale=24bin=169octave=07note=01
	retlw	(D'07'*D'24')+D'00'	;scale=24bin=170octave=07note=02
	retlw	(D'07'*D'24')+D'00'	;scale=24bin=171octave=07note=03
	retlw	(D'07'*D'24')+D'00'	;scale=24bin=172octave=07note=04
	retlw	(D'07'*D'24')+D'00'	;scale=24bin=173octave=07note=05
	retlw	(D'07'*D'24')+D'06'	;scale=24bin=174octave=07note=06
	retlw	(D'07'*D'24')+D'06'	;scale=24bin=175octave=07note=07
	retlw	(D'07'*D'24')+D'06'	;scale=24bin=176octave=07note=08
	retlw	(D'07'*D'24')+D'06'	;scale=24bin=177octave=07note=09
	retlw	(D'07'*D'24')+D'06'	;scale=24bin=178octave=07note=10
	retlw	(D'07'*D'24')+D'06'	;scale=24bin=179octave=07note=11
	retlw	(D'07'*D'24')+D'12'	;scale=24bin=180octave=07note=12
	retlw	(D'07'*D'24')+D'12'	;scale=24bin=181octave=07note=13
	retlw	(D'07'*D'24')+D'12'	;scale=24bin=182octave=07note=14
	retlw	(D'07'*D'24')+D'12'	;scale=24bin=183octave=07note=15
	retlw	(D'07'*D'24')+D'12'	;scale=24bin=184octave=07note=16
	retlw	(D'07'*D'24')+D'12'	;scale=24bin=185octave=07note=17
	retlw	(D'07'*D'24')+D'18'	;scale=24bin=186octave=07note=18
	retlw	(D'07'*D'24')+D'18'	;scale=24bin=187octave=07note=19
	retlw	(D'07'*D'24')+D'18'	;scale=24bin=188octave=07note=20
	retlw	(D'07'*D'24')+D'18'	;scale=24bin=189octave=07note=21
	retlw	(D'07'*D'24')+D'18'	;scale=24bin=190octave=07note=22
	retlw	(D'07'*D'24')+D'18'	;scale=24bin=191octave=07note=23
	retlw	(D'08'*D'24')+D'00'	;scale=24bin=192octave=08note=00
	retlw	(D'08'*D'24')+D'00'	;scale=24bin=193octave=08note=01
	retlw	(D'08'*D'24')+D'00'	;scale=24bin=194octave=08note=02
	retlw	(D'08'*D'24')+D'00'	;scale=24bin=195octave=08note=03
	retlw	(D'08'*D'24')+D'00'	;scale=24bin=196octave=08note=04
	retlw	(D'08'*D'24')+D'00'	;scale=24bin=197octave=08note=05
	retlw	(D'08'*D'24')+D'06'	;scale=24bin=198octave=08note=06
	retlw	(D'08'*D'24')+D'06'	;scale=24bin=199octave=08note=07
	retlw	(D'08'*D'24')+D'06'	;scale=24bin=200octave=08note=08
	retlw	(D'08'*D'24')+D'06'	;scale=24bin=201octave=08note=09
	retlw	(D'08'*D'24')+D'06'	;scale=24bin=202octave=08note=10
	retlw	(D'08'*D'24')+D'06'	;scale=24bin=203octave=08note=11
	retlw	(D'08'*D'24')+D'12'	;scale=24bin=204octave=08note=12
	retlw	(D'08'*D'24')+D'12'	;scale=24bin=205octave=08note=13
	retlw	(D'08'*D'24')+D'12'	;scale=24bin=206octave=08note=14
	retlw	(D'08'*D'24')+D'12'	;scale=24bin=207octave=08note=15
	retlw	(D'08'*D'24')+D'12'	;scale=24bin=208octave=08note=16
	retlw	(D'08'*D'24')+D'12'	;scale=24bin=209octave=08note=17
	retlw	(D'08'*D'24')+D'18'	;scale=24bin=210octave=08note=18
	retlw	(D'08'*D'24')+D'18'	;scale=24bin=211octave=08note=19
	retlw	(D'08'*D'24')+D'18'	;scale=24bin=212octave=08note=20
	retlw	(D'08'*D'24')+D'18'	;scale=24bin=213octave=08note=21
	retlw	(D'08'*D'24')+D'18'	;scale=24bin=214octave=08note=22
	retlw	(D'08'*D'24')+D'18'	;scale=24bin=215octave=08note=23
	retlw	(D'09'*D'24')+D'00'	;scale=24bin=216octave=09note=00
	retlw	(D'09'*D'24')+D'00'	;scale=24bin=217octave=09note=01
	retlw	(D'09'*D'24')+D'00'	;scale=24bin=218octave=09note=02
	retlw	(D'09'*D'24')+D'00'	;scale=24bin=219octave=09note=03
	retlw	(D'09'*D'24')+D'00'	;scale=24bin=220octave=09note=04
	retlw	(D'09'*D'24')+D'00'	;scale=24bin=221octave=09note=05
	retlw	(D'09'*D'24')+D'06'	;scale=24bin=222octave=09note=06
	retlw	(D'09'*D'24')+D'06'	;scale=24bin=223octave=09note=07
	retlw	(D'09'*D'24')+D'06'	;scale=24bin=224octave=09note=08
	retlw	(D'09'*D'24')+D'06'	;scale=24bin=225octave=09note=09
	retlw	(D'09'*D'24')+D'06'	;scale=24bin=226octave=09note=10
	retlw	(D'09'*D'24')+D'06'	;scale=24bin=227octave=09note=11
	retlw	(D'09'*D'24')+D'12'	;scale=24bin=228octave=09note=12
	retlw	(D'09'*D'24')+D'12'	;scale=24bin=229octave=09note=13
	retlw	(D'09'*D'24')+D'12'	;scale=24bin=230octave=09note=14
	retlw	(D'09'*D'24')+D'12'	;scale=24bin=231octave=09note=15
	retlw	(D'09'*D'24')+D'12'	;scale=24bin=232octave=09note=16
	retlw	(D'09'*D'24')+D'12'	;scale=24bin=233octave=09note=17
	retlw	(D'09'*D'24')+D'18'	;scale=24bin=234octave=09note=18
	retlw	(D'09'*D'24')+D'18'	;scale=24bin=235octave=09note=19
	retlw	(D'09'*D'24')+D'18'	;scale=24bin=236octave=09note=20
	retlw	(D'09'*D'24')+D'18'	;scale=24bin=237octave=09note=21
	retlw	(D'09'*D'24')+D'18'	;scale=24bin=238octave=09note=22
	retlw	(D'09'*D'24')+D'18'	;scale=24bin=239octave=09note=23
	retlw	(D'10'*D'24')+D'00'	;scale=24bin=240octave=10note=00
	retlw	(D'10'*D'24')+D'00'	;scale=24bin=241octave=10note=01
	retlw	(D'10'*D'24')+D'00'	;scale=24bin=242octave=10note=02
	retlw	(D'10'*D'24')+D'00'	;scale=24bin=243octave=10note=03
	retlw	(D'10'*D'24')+D'00'	;scale=24bin=244octave=10note=04
	retlw	(D'10'*D'24')+D'00'	;scale=24bin=245octave=10note=05
	retlw	(D'10'*D'24')+D'00'	;scale=24bin=246octave=10note=06
	retlw	(D'10'*D'24')+D'00'	;scale=24bin=247octave=10note=07
	retlw	(D'10'*D'24')+D'00'	;scale=24bin=248octave=10note=08
	retlw	(D'10'*D'24')+D'00'	;scale=24bin=249octave=10note=09
	retlw	(D'10'*D'24')+D'00'	;scale=24bin=250octave=10note=10
	retlw	(D'10'*D'24')+D'00'	;scale=24bin=251octave=10note=11
	retlw	(D'10'*D'24')+D'00'	;scale=24bin=252octave=10note=12
	retlw	(D'10'*D'24')+D'00'	;scale=24bin=253octave=10note=13
	retlw	(D'10'*D'24')+D'00'	;scale=24bin=254octave=10note=14
	retlw	(D'10'*D'24')+D'00'	;scale=24bin=255octave=10note=15

;	Fourths look-up table
	org	Fourth		;Fourths look-up table
	retlw	(D'00'*D'24')+D'00'	;scale=25bin=000octave=00note=00
	retlw	(D'00'*D'24')+D'00'	;scale=25bin=001octave=00note=01
	retlw	(D'00'*D'24')+D'00'	;scale=25bin=002octave=00note=02
	retlw	(D'00'*D'24')+D'00'	;scale=25bin=003octave=00note=03
	retlw	(D'00'*D'24')+D'00'	;scale=25bin=004octave=00note=04
	retlw	(D'00'*D'24')+D'00'	;scale=25bin=005octave=00note=05
	retlw	(D'00'*D'24')+D'00'	;scale=25bin=006octave=00note=06
	retlw	(D'00'*D'24')+D'00'	;scale=25bin=007octave=00note=07
	retlw	(D'00'*D'24')+D'00'	;scale=25bin=008octave=00note=08
	retlw	(D'00'*D'24')+D'00'	;scale=25bin=009octave=00note=09
	retlw	(D'00'*D'24')+D'10'	;scale=25bin=010octave=00note=10
	retlw	(D'00'*D'24')+D'10'	;scale=25bin=011octave=00note=11
	retlw	(D'00'*D'24')+D'10'	;scale=25bin=012octave=00note=12
	retlw	(D'00'*D'24')+D'10'	;scale=25bin=013octave=00note=13
	retlw	(D'00'*D'24')+D'10'	;scale=25bin=014octave=00note=14
	retlw	(D'00'*D'24')+D'10'	;scale=25bin=015octave=00note=15
	retlw	(D'00'*D'24')+D'10'	;scale=25bin=016octave=00note=16
	retlw	(D'00'*D'24')+D'10'	;scale=25bin=017octave=00note=17
	retlw	(D'00'*D'24')+D'10'	;scale=25bin=018octave=00note=18
	retlw	(D'00'*D'24')+D'10'	;scale=25bin=019octave=00note=19
	retlw	(D'00'*D'24')+D'20'	;scale=25bin=020octave=00note=20
	retlw	(D'00'*D'24')+D'20'	;scale=25bin=021octave=00note=21
	retlw	(D'00'*D'24')+D'20'	;scale=25bin=022octave=00note=22
	retlw	(D'00'*D'24')+D'20'	;scale=25bin=023octave=00note=23
	retlw	(D'01'*D'24')+D'00'	;scale=25bin=024octave=01note=00
	retlw	(D'01'*D'24')+D'00'	;scale=25bin=025octave=01note=01
	retlw	(D'01'*D'24')+D'00'	;scale=25bin=026octave=01note=02
	retlw	(D'01'*D'24')+D'00'	;scale=25bin=027octave=01note=03
	retlw	(D'01'*D'24')+D'00'	;scale=25bin=028octave=01note=04
	retlw	(D'01'*D'24')+D'00'	;scale=25bin=029octave=01note=05
	retlw	(D'01'*D'24')+D'00'	;scale=25bin=030octave=01note=06
	retlw	(D'01'*D'24')+D'00'	;scale=25bin=031octave=01note=07
	retlw	(D'01'*D'24')+D'00'	;scale=25bin=032octave=01note=08
	retlw	(D'01'*D'24')+D'00'	;scale=25bin=033octave=01note=09
	retlw	(D'01'*D'24')+D'10'	;scale=25bin=034octave=01note=10
	retlw	(D'01'*D'24')+D'10'	;scale=25bin=035octave=01note=11
	retlw	(D'01'*D'24')+D'10'	;scale=25bin=036octave=01note=12
	retlw	(D'01'*D'24')+D'10'	;scale=25bin=037octave=01note=13
	retlw	(D'01'*D'24')+D'10'	;scale=25bin=038octave=01note=14
	retlw	(D'01'*D'24')+D'10'	;scale=25bin=039octave=01note=15
	retlw	(D'01'*D'24')+D'10'	;scale=25bin=040octave=01note=16
	retlw	(D'01'*D'24')+D'10'	;scale=25bin=041octave=01note=17
	retlw	(D'01'*D'24')+D'10'	;scale=25bin=042octave=01note=18
	retlw	(D'01'*D'24')+D'10'	;scale=25bin=043octave=01note=19
	retlw	(D'01'*D'24')+D'20'	;scale=25bin=044octave=01note=20
	retlw	(D'01'*D'24')+D'20'	;scale=25bin=045octave=01note=21
	retlw	(D'01'*D'24')+D'20'	;scale=25bin=046octave=01note=22
	retlw	(D'01'*D'24')+D'20'	;scale=25bin=047octave=01note=23
	retlw	(D'02'*D'24')+D'00'	;scale=25bin=048octave=02note=00
	retlw	(D'02'*D'24')+D'00'	;scale=25bin=049octave=02note=01
	retlw	(D'02'*D'24')+D'00'	;scale=25bin=050octave=02note=02
	retlw	(D'02'*D'24')+D'00'	;scale=25bin=051octave=02note=03
	retlw	(D'02'*D'24')+D'00'	;scale=25bin=052octave=02note=04
	retlw	(D'02'*D'24')+D'00'	;scale=25bin=053octave=02note=05
	retlw	(D'02'*D'24')+D'00'	;scale=25bin=054octave=02note=06
	retlw	(D'02'*D'24')+D'00'	;scale=25bin=055octave=02note=07
	retlw	(D'02'*D'24')+D'00'	;scale=25bin=056octave=02note=08
	retlw	(D'02'*D'24')+D'00'	;scale=25bin=057octave=02note=09
	retlw	(D'02'*D'24')+D'10'	;scale=25bin=058octave=02note=10
	retlw	(D'02'*D'24')+D'10'	;scale=25bin=059octave=02note=11
	retlw	(D'02'*D'24')+D'10'	;scale=25bin=060octave=02note=12
	retlw	(D'02'*D'24')+D'10'	;scale=25bin=061octave=02note=13
	retlw	(D'02'*D'24')+D'10'	;scale=25bin=062octave=02note=14
	retlw	(D'02'*D'24')+D'10'	;scale=25bin=063octave=02note=15
	retlw	(D'02'*D'24')+D'10'	;scale=25bin=064octave=02note=16
	retlw	(D'02'*D'24')+D'10'	;scale=25bin=065octave=02note=17
	retlw	(D'02'*D'24')+D'10'	;scale=25bin=066octave=02note=18
	retlw	(D'02'*D'24')+D'10'	;scale=25bin=067octave=02note=19
	retlw	(D'02'*D'24')+D'20'	;scale=25bin=068octave=02note=20
	retlw	(D'02'*D'24')+D'20'	;scale=25bin=069octave=02note=21
	retlw	(D'02'*D'24')+D'20'	;scale=25bin=070octave=02note=22
	retlw	(D'02'*D'24')+D'20'	;scale=25bin=071octave=02note=23
	retlw	(D'03'*D'24')+D'00'	;scale=25bin=072octave=03note=00
	retlw	(D'03'*D'24')+D'00'	;scale=25bin=073octave=03note=01
	retlw	(D'03'*D'24')+D'00'	;scale=25bin=074octave=03note=02
	retlw	(D'03'*D'24')+D'00'	;scale=25bin=075octave=03note=03
	retlw	(D'03'*D'24')+D'00'	;scale=25bin=076octave=03note=04
	retlw	(D'03'*D'24')+D'00'	;scale=25bin=077octave=03note=05
	retlw	(D'03'*D'24')+D'00'	;scale=25bin=078octave=03note=06
	retlw	(D'03'*D'24')+D'00'	;scale=25bin=079octave=03note=07
	retlw	(D'03'*D'24')+D'00'	;scale=25bin=080octave=03note=08
	retlw	(D'03'*D'24')+D'00'	;scale=25bin=081octave=03note=09
	retlw	(D'03'*D'24')+D'10'	;scale=25bin=082octave=03note=10
	retlw	(D'03'*D'24')+D'10'	;scale=25bin=083octave=03note=11
	retlw	(D'03'*D'24')+D'10'	;scale=25bin=084octave=03note=12
	retlw	(D'03'*D'24')+D'10'	;scale=25bin=085octave=03note=13
	retlw	(D'03'*D'24')+D'10'	;scale=25bin=086octave=03note=14
	retlw	(D'03'*D'24')+D'10'	;scale=25bin=087octave=03note=15
	retlw	(D'03'*D'24')+D'10'	;scale=25bin=088octave=03note=16
	retlw	(D'03'*D'24')+D'10'	;scale=25bin=089octave=03note=17
	retlw	(D'03'*D'24')+D'10'	;scale=25bin=090octave=03note=18
	retlw	(D'03'*D'24')+D'10'	;scale=25bin=091octave=03note=19
	retlw	(D'03'*D'24')+D'20'	;scale=25bin=092octave=03note=20
	retlw	(D'03'*D'24')+D'20'	;scale=25bin=093octave=03note=21
	retlw	(D'03'*D'24')+D'20'	;scale=25bin=094octave=03note=22
	retlw	(D'03'*D'24')+D'20'	;scale=25bin=095octave=03note=23
	retlw	(D'04'*D'24')+D'00'	;scale=25bin=096octave=04note=00
	retlw	(D'04'*D'24')+D'00'	;scale=25bin=097octave=04note=01
	retlw	(D'04'*D'24')+D'00'	;scale=25bin=098octave=04note=02
	retlw	(D'04'*D'24')+D'00'	;scale=25bin=099octave=04note=03
	retlw	(D'04'*D'24')+D'00'	;scale=25bin=100octave=04note=04
	retlw	(D'04'*D'24')+D'00'	;scale=25bin=101octave=04note=05
	retlw	(D'04'*D'24')+D'00'	;scale=25bin=102octave=04note=06
	retlw	(D'04'*D'24')+D'00'	;scale=25bin=103octave=04note=07
	retlw	(D'04'*D'24')+D'00'	;scale=25bin=104octave=04note=08
	retlw	(D'04'*D'24')+D'00'	;scale=25bin=105octave=04note=09
	retlw	(D'04'*D'24')+D'10'	;scale=25bin=106octave=04note=10
	retlw	(D'04'*D'24')+D'10'	;scale=25bin=107octave=04note=11
	retlw	(D'04'*D'24')+D'10'	;scale=25bin=108octave=04note=12
	retlw	(D'04'*D'24')+D'10'	;scale=25bin=109octave=04note=13
	retlw	(D'04'*D'24')+D'10'	;scale=25bin=110octave=04note=14
	retlw	(D'04'*D'24')+D'10'	;scale=25bin=111octave=04note=15
	retlw	(D'04'*D'24')+D'10'	;scale=25bin=112octave=04note=16
	retlw	(D'04'*D'24')+D'10'	;scale=25bin=113octave=04note=17
	retlw	(D'04'*D'24')+D'10'	;scale=25bin=114octave=04note=18
	retlw	(D'04'*D'24')+D'10'	;scale=25bin=115octave=04note=19
	retlw	(D'04'*D'24')+D'20'	;scale=25bin=116octave=04note=20
	retlw	(D'04'*D'24')+D'20'	;scale=25bin=117octave=04note=21
	retlw	(D'04'*D'24')+D'20'	;scale=25bin=118octave=04note=22
	retlw	(D'04'*D'24')+D'20'	;scale=25bin=119octave=04note=23
	retlw	(D'05'*D'24')+D'00'	;scale=25bin=120octave=05note=00
	retlw	(D'05'*D'24')+D'00'	;scale=25bin=121octave=05note=01
	retlw	(D'05'*D'24')+D'00'	;scale=25bin=122octave=05note=02
	retlw	(D'05'*D'24')+D'00'	;scale=25bin=123octave=05note=03
	retlw	(D'05'*D'24')+D'00'	;scale=25bin=124octave=05note=04
	retlw	(D'05'*D'24')+D'00'	;scale=25bin=125octave=05note=05
	retlw	(D'05'*D'24')+D'00'	;scale=25bin=126octave=05note=06
	retlw	(D'05'*D'24')+D'00'	;scale=25bin=127octave=05note=07
	retlw	(D'05'*D'24')+D'00'	;scale=25bin=128octave=05note=08
	retlw	(D'05'*D'24')+D'00'	;scale=25bin=129octave=05note=09
	retlw	(D'05'*D'24')+D'10'	;scale=25bin=130octave=05note=10
	retlw	(D'05'*D'24')+D'10'	;scale=25bin=131octave=05note=11
	retlw	(D'05'*D'24')+D'10'	;scale=25bin=132octave=05note=12
	retlw	(D'05'*D'24')+D'10'	;scale=25bin=133octave=05note=13
	retlw	(D'05'*D'24')+D'10'	;scale=25bin=134octave=05note=14
	retlw	(D'05'*D'24')+D'10'	;scale=25bin=135octave=05note=15
	retlw	(D'05'*D'24')+D'10'	;scale=25bin=136octave=05note=16
	retlw	(D'05'*D'24')+D'10'	;scale=25bin=137octave=05note=17
	retlw	(D'05'*D'24')+D'10'	;scale=25bin=138octave=05note=18
	retlw	(D'05'*D'24')+D'10'	;scale=25bin=139octave=05note=19
	retlw	(D'05'*D'24')+D'20'	;scale=25bin=140octave=05note=20
	retlw	(D'05'*D'24')+D'20'	;scale=25bin=141octave=05note=21
	retlw	(D'05'*D'24')+D'20'	;scale=25bin=142octave=05note=22
	retlw	(D'05'*D'24')+D'20'	;scale=25bin=143octave=05note=23
	retlw	(D'06'*D'24')+D'00'	;scale=25bin=144octave=06note=00
	retlw	(D'06'*D'24')+D'00'	;scale=25bin=145octave=06note=01
	retlw	(D'06'*D'24')+D'00'	;scale=25bin=146octave=06note=02
	retlw	(D'06'*D'24')+D'00'	;scale=25bin=147octave=06note=03
	retlw	(D'06'*D'24')+D'00'	;scale=25bin=148octave=06note=04
	retlw	(D'06'*D'24')+D'00'	;scale=25bin=149octave=06note=05
	retlw	(D'06'*D'24')+D'00'	;scale=25bin=150octave=06note=06
	retlw	(D'06'*D'24')+D'00'	;scale=25bin=151octave=06note=07
	retlw	(D'06'*D'24')+D'00'	;scale=25bin=152octave=06note=08
	retlw	(D'06'*D'24')+D'00'	;scale=25bin=153octave=06note=09
	retlw	(D'06'*D'24')+D'10'	;scale=25bin=154octave=06note=10
	retlw	(D'06'*D'24')+D'10'	;scale=25bin=155octave=06note=11
	retlw	(D'06'*D'24')+D'10'	;scale=25bin=156octave=06note=12
	retlw	(D'06'*D'24')+D'10'	;scale=25bin=157octave=06note=13
	retlw	(D'06'*D'24')+D'10'	;scale=25bin=158octave=06note=14
	retlw	(D'06'*D'24')+D'10'	;scale=25bin=159octave=06note=15
	retlw	(D'06'*D'24')+D'10'	;scale=25bin=160octave=06note=16
	retlw	(D'06'*D'24')+D'10'	;scale=25bin=161octave=06note=17
	retlw	(D'06'*D'24')+D'10'	;scale=25bin=162octave=06note=18
	retlw	(D'06'*D'24')+D'10'	;scale=25bin=163octave=06note=19
	retlw	(D'06'*D'24')+D'20'	;scale=25bin=164octave=06note=20
	retlw	(D'06'*D'24')+D'20'	;scale=25bin=165octave=06note=21
	retlw	(D'06'*D'24')+D'20'	;scale=25bin=166octave=06note=22
	retlw	(D'06'*D'24')+D'20'	;scale=25bin=167octave=06note=23
	retlw	(D'07'*D'24')+D'00'	;scale=25bin=168octave=07note=00
	retlw	(D'07'*D'24')+D'00'	;scale=25bin=169octave=07note=01
	retlw	(D'07'*D'24')+D'00'	;scale=25bin=170octave=07note=02
	retlw	(D'07'*D'24')+D'00'	;scale=25bin=171octave=07note=03
	retlw	(D'07'*D'24')+D'00'	;scale=25bin=172octave=07note=04
	retlw	(D'07'*D'24')+D'00'	;scale=25bin=173octave=07note=05
	retlw	(D'07'*D'24')+D'00'	;scale=25bin=174octave=07note=06
	retlw	(D'07'*D'24')+D'00'	;scale=25bin=175octave=07note=07
	retlw	(D'07'*D'24')+D'00'	;scale=25bin=176octave=07note=08
	retlw	(D'07'*D'24')+D'00'	;scale=25bin=177octave=07note=09
	retlw	(D'07'*D'24')+D'10'	;scale=25bin=178octave=07note=10
	retlw	(D'07'*D'24')+D'10'	;scale=25bin=179octave=07note=11
	retlw	(D'07'*D'24')+D'10'	;scale=25bin=180octave=07note=12
	retlw	(D'07'*D'24')+D'10'	;scale=25bin=181octave=07note=13
	retlw	(D'07'*D'24')+D'10'	;scale=25bin=182octave=07note=14
	retlw	(D'07'*D'24')+D'10'	;scale=25bin=183octave=07note=15
	retlw	(D'07'*D'24')+D'10'	;scale=25bin=184octave=07note=16
	retlw	(D'07'*D'24')+D'10'	;scale=25bin=185octave=07note=17
	retlw	(D'07'*D'24')+D'10'	;scale=25bin=186octave=07note=18
	retlw	(D'07'*D'24')+D'10'	;scale=25bin=187octave=07note=19
	retlw	(D'07'*D'24')+D'20'	;scale=25bin=188octave=07note=20
	retlw	(D'07'*D'24')+D'20'	;scale=25bin=189octave=07note=21
	retlw	(D'07'*D'24')+D'20'	;scale=25bin=190octave=07note=22
	retlw	(D'07'*D'24')+D'20'	;scale=25bin=191octave=07note=23
	retlw	(D'08'*D'24')+D'00'	;scale=25bin=192octave=08note=00
	retlw	(D'08'*D'24')+D'00'	;scale=25bin=193octave=08note=01
	retlw	(D'08'*D'24')+D'00'	;scale=25bin=194octave=08note=02
	retlw	(D'08'*D'24')+D'00'	;scale=25bin=195octave=08note=03
	retlw	(D'08'*D'24')+D'00'	;scale=25bin=196octave=08note=04
	retlw	(D'08'*D'24')+D'00'	;scale=25bin=197octave=08note=05
	retlw	(D'08'*D'24')+D'00'	;scale=25bin=198octave=08note=06
	retlw	(D'08'*D'24')+D'00'	;scale=25bin=199octave=08note=07
	retlw	(D'08'*D'24')+D'00'	;scale=25bin=200octave=08note=08
	retlw	(D'08'*D'24')+D'00'	;scale=25bin=201octave=08note=09
	retlw	(D'08'*D'24')+D'10'	;scale=25bin=202octave=08note=10
	retlw	(D'08'*D'24')+D'10'	;scale=25bin=203octave=08note=11
	retlw	(D'08'*D'24')+D'10'	;scale=25bin=204octave=08note=12
	retlw	(D'08'*D'24')+D'10'	;scale=25bin=205octave=08note=13
	retlw	(D'08'*D'24')+D'10'	;scale=25bin=206octave=08note=14
	retlw	(D'08'*D'24')+D'10'	;scale=25bin=207octave=08note=15
	retlw	(D'08'*D'24')+D'10'	;scale=25bin=208octave=08note=16
	retlw	(D'08'*D'24')+D'10'	;scale=25bin=209octave=08note=17
	retlw	(D'08'*D'24')+D'10'	;scale=25bin=210octave=08note=18
	retlw	(D'08'*D'24')+D'10'	;scale=25bin=211octave=08note=19
	retlw	(D'08'*D'24')+D'20'	;scale=25bin=212octave=08note=20
	retlw	(D'08'*D'24')+D'20'	;scale=25bin=213octave=08note=21
	retlw	(D'08'*D'24')+D'20'	;scale=25bin=214octave=08note=22
	retlw	(D'08'*D'24')+D'20'	;scale=25bin=215octave=08note=23
	retlw	(D'09'*D'24')+D'00'	;scale=25bin=216octave=09note=00
	retlw	(D'09'*D'24')+D'00'	;scale=25bin=217octave=09note=01
	retlw	(D'09'*D'24')+D'00'	;scale=25bin=218octave=09note=02
	retlw	(D'09'*D'24')+D'00'	;scale=25bin=219octave=09note=03
	retlw	(D'09'*D'24')+D'00'	;scale=25bin=220octave=09note=04
	retlw	(D'09'*D'24')+D'00'	;scale=25bin=221octave=09note=05
	retlw	(D'09'*D'24')+D'00'	;scale=25bin=222octave=09note=06
	retlw	(D'09'*D'24')+D'00'	;scale=25bin=223octave=09note=07
	retlw	(D'09'*D'24')+D'00'	;scale=25bin=224octave=09note=08
	retlw	(D'09'*D'24')+D'00'	;scale=25bin=225octave=09note=09
	retlw	(D'09'*D'24')+D'10'	;scale=25bin=226octave=09note=10
	retlw	(D'09'*D'24')+D'10'	;scale=25bin=227octave=09note=11
	retlw	(D'09'*D'24')+D'10'	;scale=25bin=228octave=09note=12
	retlw	(D'09'*D'24')+D'10'	;scale=25bin=229octave=09note=13
	retlw	(D'09'*D'24')+D'10'	;scale=25bin=230octave=09note=14
	retlw	(D'09'*D'24')+D'10'	;scale=25bin=231octave=09note=15
	retlw	(D'09'*D'24')+D'10'	;scale=25bin=232octave=09note=16
	retlw	(D'09'*D'24')+D'10'	;scale=25bin=233octave=09note=17
	retlw	(D'09'*D'24')+D'10'	;scale=25bin=234octave=09note=18
	retlw	(D'09'*D'24')+D'10'	;scale=25bin=235octave=09note=19
	retlw	(D'09'*D'24')+D'20'	;scale=25bin=236octave=09note=20
	retlw	(D'09'*D'24')+D'20'	;scale=25bin=237octave=09note=21
	retlw	(D'09'*D'24')+D'20'	;scale=25bin=238octave=09note=22
	retlw	(D'09'*D'24')+D'20'	;scale=25bin=239octave=09note=23
	retlw	(D'10'*D'24')+D'00'	;scale=25bin=240octave=10note=00
	retlw	(D'10'*D'24')+D'00'	;scale=25bin=241octave=10note=01
	retlw	(D'10'*D'24')+D'00'	;scale=25bin=242octave=10note=02
	retlw	(D'10'*D'24')+D'00'	;scale=25bin=243octave=10note=03
	retlw	(D'10'*D'24')+D'00'	;scale=25bin=244octave=10note=04
	retlw	(D'10'*D'24')+D'00'	;scale=25bin=245octave=10note=05
	retlw	(D'10'*D'24')+D'00'	;scale=25bin=246octave=10note=06
	retlw	(D'10'*D'24')+D'00'	;scale=25bin=247octave=10note=07
	retlw	(D'10'*D'24')+D'00'	;scale=25bin=248octave=10note=08
	retlw	(D'10'*D'24')+D'00'	;scale=25bin=249octave=10note=09
	retlw	(D'10'*D'24')+D'00'	;scale=25bin=250octave=10note=10
	retlw	(D'10'*D'24')+D'00'	;scale=25bin=251octave=10note=11
	retlw	(D'10'*D'24')+D'00'	;scale=25bin=252octave=10note=12
	retlw	(D'10'*D'24')+D'00'	;scale=25bin=253octave=10note=13
	retlw	(D'10'*D'24')+D'00'	;scale=25bin=254octave=10note=14
	retlw	(D'10'*D'24')+D'00'	;scale=25bin=255octave=10note=15

;	Eight Tone look-up table
	org	EightT		;Eight Tone look-up table
	retlw	(D'00'*D'24')+D'00'	;scale=26bin=000octave=00note=00
	retlw	(D'00'*D'24')+D'00'	;scale=26bin=001octave=00note=01
	retlw	(D'00'*D'24')+D'02'	;scale=26bin=002octave=00note=02
	retlw	(D'00'*D'24')+D'02'	;scale=26bin=003octave=00note=03
	retlw	(D'00'*D'24')+D'02'	;scale=26bin=004octave=00note=04
	retlw	(D'00'*D'24')+D'02'	;scale=26bin=005octave=00note=05
	retlw	(D'00'*D'24')+D'06'	;scale=26bin=006octave=00note=06
	retlw	(D'00'*D'24')+D'06'	;scale=26bin=007octave=00note=07
	retlw	(D'00'*D'24')+D'08'	;scale=26bin=008octave=00note=08
	retlw	(D'00'*D'24')+D'08'	;scale=26bin=009octave=00note=09
	retlw	(D'00'*D'24')+D'08'	;scale=26bin=010octave=00note=10
	retlw	(D'00'*D'24')+D'08'	;scale=26bin=011octave=00note=11
	retlw	(D'00'*D'24')+D'12'	;scale=26bin=012octave=00note=12
	retlw	(D'00'*D'24')+D'12'	;scale=26bin=013octave=00note=13
	retlw	(D'00'*D'24')+D'14'	;scale=26bin=014octave=00note=14
	retlw	(D'00'*D'24')+D'14'	;scale=26bin=015octave=00note=15
	retlw	(D'00'*D'24')+D'14'	;scale=26bin=016octave=00note=16
	retlw	(D'00'*D'24')+D'14'	;scale=26bin=017octave=00note=17
	retlw	(D'00'*D'24')+D'18'	;scale=26bin=018octave=00note=18
	retlw	(D'00'*D'24')+D'18'	;scale=26bin=019octave=00note=19
	retlw	(D'00'*D'24')+D'20'	;scale=26bin=020octave=00note=20
	retlw	(D'00'*D'24')+D'20'	;scale=26bin=021octave=00note=21
	retlw	(D'00'*D'24')+D'20'	;scale=26bin=022octave=00note=22
	retlw	(D'00'*D'24')+D'20'	;scale=26bin=023octave=00note=23
	retlw	(D'01'*D'24')+D'00'	;scale=26bin=024octave=01note=00
	retlw	(D'01'*D'24')+D'00'	;scale=26bin=025octave=01note=01
	retlw	(D'01'*D'24')+D'02'	;scale=26bin=026octave=01note=02
	retlw	(D'01'*D'24')+D'02'	;scale=26bin=027octave=01note=03
	retlw	(D'01'*D'24')+D'02'	;scale=26bin=028octave=01note=04
	retlw	(D'01'*D'24')+D'02'	;scale=26bin=029octave=01note=05
	retlw	(D'01'*D'24')+D'06'	;scale=26bin=030octave=01note=06
	retlw	(D'01'*D'24')+D'06'	;scale=26bin=031octave=01note=07
	retlw	(D'01'*D'24')+D'08'	;scale=26bin=032octave=01note=08
	retlw	(D'01'*D'24')+D'08'	;scale=26bin=033octave=01note=09
	retlw	(D'01'*D'24')+D'08'	;scale=26bin=034octave=01note=10
	retlw	(D'01'*D'24')+D'08'	;scale=26bin=035octave=01note=11
	retlw	(D'01'*D'24')+D'12'	;scale=26bin=036octave=01note=12
	retlw	(D'01'*D'24')+D'12'	;scale=26bin=037octave=01note=13
	retlw	(D'01'*D'24')+D'14'	;scale=26bin=038octave=01note=14
	retlw	(D'01'*D'24')+D'14'	;scale=26bin=039octave=01note=15
	retlw	(D'01'*D'24')+D'14'	;scale=26bin=040octave=01note=16
	retlw	(D'01'*D'24')+D'14'	;scale=26bin=041octave=01note=17
	retlw	(D'01'*D'24')+D'18'	;scale=26bin=042octave=01note=18
	retlw	(D'01'*D'24')+D'18'	;scale=26bin=043octave=01note=19
	retlw	(D'01'*D'24')+D'20'	;scale=26bin=044octave=01note=20
	retlw	(D'01'*D'24')+D'20'	;scale=26bin=045octave=01note=21
	retlw	(D'01'*D'24')+D'20'	;scale=26bin=046octave=01note=22
	retlw	(D'01'*D'24')+D'20'	;scale=26bin=047octave=01note=23
	retlw	(D'02'*D'24')+D'00'	;scale=26bin=048octave=02note=00
	retlw	(D'02'*D'24')+D'00'	;scale=26bin=049octave=02note=01
	retlw	(D'02'*D'24')+D'02'	;scale=26bin=050octave=02note=02
	retlw	(D'02'*D'24')+D'02'	;scale=26bin=051octave=02note=03
	retlw	(D'02'*D'24')+D'02'	;scale=26bin=052octave=02note=04
	retlw	(D'02'*D'24')+D'02'	;scale=26bin=053octave=02note=05
	retlw	(D'02'*D'24')+D'06'	;scale=26bin=054octave=02note=06
	retlw	(D'02'*D'24')+D'06'	;scale=26bin=055octave=02note=07
	retlw	(D'02'*D'24')+D'08'	;scale=26bin=056octave=02note=08
	retlw	(D'02'*D'24')+D'08'	;scale=26bin=057octave=02note=09
	retlw	(D'02'*D'24')+D'08'	;scale=26bin=058octave=02note=10
	retlw	(D'02'*D'24')+D'08'	;scale=26bin=059octave=02note=11
	retlw	(D'02'*D'24')+D'12'	;scale=26bin=060octave=02note=12
	retlw	(D'02'*D'24')+D'12'	;scale=26bin=061octave=02note=13
	retlw	(D'02'*D'24')+D'14'	;scale=26bin=062octave=02note=14
	retlw	(D'02'*D'24')+D'14'	;scale=26bin=063octave=02note=15
	retlw	(D'02'*D'24')+D'14'	;scale=26bin=064octave=02note=16
	retlw	(D'02'*D'24')+D'14'	;scale=26bin=065octave=02note=17
	retlw	(D'02'*D'24')+D'18'	;scale=26bin=066octave=02note=18
	retlw	(D'02'*D'24')+D'18'	;scale=26bin=067octave=02note=19
	retlw	(D'02'*D'24')+D'20'	;scale=26bin=068octave=02note=20
	retlw	(D'02'*D'24')+D'20'	;scale=26bin=069octave=02note=21
	retlw	(D'02'*D'24')+D'20'	;scale=26bin=070octave=02note=22
	retlw	(D'02'*D'24')+D'20'	;scale=26bin=071octave=02note=23
	retlw	(D'03'*D'24')+D'00'	;scale=26bin=072octave=03note=00
	retlw	(D'03'*D'24')+D'00'	;scale=26bin=073octave=03note=01
	retlw	(D'03'*D'24')+D'02'	;scale=26bin=074octave=03note=02
	retlw	(D'03'*D'24')+D'02'	;scale=26bin=075octave=03note=03
	retlw	(D'03'*D'24')+D'02'	;scale=26bin=076octave=03note=04
	retlw	(D'03'*D'24')+D'02'	;scale=26bin=077octave=03note=05
	retlw	(D'03'*D'24')+D'06'	;scale=26bin=078octave=03note=06
	retlw	(D'03'*D'24')+D'06'	;scale=26bin=079octave=03note=07
	retlw	(D'03'*D'24')+D'08'	;scale=26bin=080octave=03note=08
	retlw	(D'03'*D'24')+D'08'	;scale=26bin=081octave=03note=09
	retlw	(D'03'*D'24')+D'08'	;scale=26bin=082octave=03note=10
	retlw	(D'03'*D'24')+D'08'	;scale=26bin=083octave=03note=11
	retlw	(D'03'*D'24')+D'12'	;scale=26bin=084octave=03note=12
	retlw	(D'03'*D'24')+D'12'	;scale=26bin=085octave=03note=13
	retlw	(D'03'*D'24')+D'14'	;scale=26bin=086octave=03note=14
	retlw	(D'03'*D'24')+D'14'	;scale=26bin=087octave=03note=15
	retlw	(D'03'*D'24')+D'14'	;scale=26bin=088octave=03note=16
	retlw	(D'03'*D'24')+D'14'	;scale=26bin=089octave=03note=17
	retlw	(D'03'*D'24')+D'18'	;scale=26bin=090octave=03note=18
	retlw	(D'03'*D'24')+D'18'	;scale=26bin=091octave=03note=19
	retlw	(D'03'*D'24')+D'20'	;scale=26bin=092octave=03note=20
	retlw	(D'03'*D'24')+D'20'	;scale=26bin=093octave=03note=21
	retlw	(D'03'*D'24')+D'20'	;scale=26bin=094octave=03note=22
	retlw	(D'03'*D'24')+D'20'	;scale=26bin=095octave=03note=23
	retlw	(D'04'*D'24')+D'00'	;scale=26bin=096octave=04note=00
	retlw	(D'04'*D'24')+D'00'	;scale=26bin=097octave=04note=01
	retlw	(D'04'*D'24')+D'02'	;scale=26bin=098octave=04note=02
	retlw	(D'04'*D'24')+D'02'	;scale=26bin=099octave=04note=03
	retlw	(D'04'*D'24')+D'02'	;scale=26bin=100octave=04note=04
	retlw	(D'04'*D'24')+D'02'	;scale=26bin=101octave=04note=05
	retlw	(D'04'*D'24')+D'06'	;scale=26bin=102octave=04note=06
	retlw	(D'04'*D'24')+D'06'	;scale=26bin=103octave=04note=07
	retlw	(D'04'*D'24')+D'08'	;scale=26bin=104octave=04note=08
	retlw	(D'04'*D'24')+D'08'	;scale=26bin=105octave=04note=09
	retlw	(D'04'*D'24')+D'08'	;scale=26bin=106octave=04note=10
	retlw	(D'04'*D'24')+D'08'	;scale=26bin=107octave=04note=11
	retlw	(D'04'*D'24')+D'12'	;scale=26bin=108octave=04note=12
	retlw	(D'04'*D'24')+D'12'	;scale=26bin=109octave=04note=13
	retlw	(D'04'*D'24')+D'14'	;scale=26bin=110octave=04note=14
	retlw	(D'04'*D'24')+D'14'	;scale=26bin=111octave=04note=15
	retlw	(D'04'*D'24')+D'14'	;scale=26bin=112octave=04note=16
	retlw	(D'04'*D'24')+D'14'	;scale=26bin=113octave=04note=17
	retlw	(D'04'*D'24')+D'18'	;scale=26bin=114octave=04note=18
	retlw	(D'04'*D'24')+D'18'	;scale=26bin=115octave=04note=19
	retlw	(D'04'*D'24')+D'20'	;scale=26bin=116octave=04note=20
	retlw	(D'04'*D'24')+D'20'	;scale=26bin=117octave=04note=21
	retlw	(D'04'*D'24')+D'20'	;scale=26bin=118octave=04note=22
	retlw	(D'04'*D'24')+D'20'	;scale=26bin=119octave=04note=23
	retlw	(D'05'*D'24')+D'00'	;scale=26bin=120octave=05note=00
	retlw	(D'05'*D'24')+D'00'	;scale=26bin=121octave=05note=01
	retlw	(D'05'*D'24')+D'02'	;scale=26bin=122octave=05note=02
	retlw	(D'05'*D'24')+D'02'	;scale=26bin=123octave=05note=03
	retlw	(D'05'*D'24')+D'02'	;scale=26bin=124octave=05note=04
	retlw	(D'05'*D'24')+D'02'	;scale=26bin=125octave=05note=05
	retlw	(D'05'*D'24')+D'06'	;scale=26bin=126octave=05note=06
	retlw	(D'05'*D'24')+D'06'	;scale=26bin=127octave=05note=07
	retlw	(D'05'*D'24')+D'08'	;scale=26bin=128octave=05note=08
	retlw	(D'05'*D'24')+D'08'	;scale=26bin=129octave=05note=09
	retlw	(D'05'*D'24')+D'08'	;scale=26bin=130octave=05note=10
	retlw	(D'05'*D'24')+D'08'	;scale=26bin=131octave=05note=11
	retlw	(D'05'*D'24')+D'12'	;scale=26bin=132octave=05note=12
	retlw	(D'05'*D'24')+D'12'	;scale=26bin=133octave=05note=13
	retlw	(D'05'*D'24')+D'14'	;scale=26bin=134octave=05note=14
	retlw	(D'05'*D'24')+D'14'	;scale=26bin=135octave=05note=15
	retlw	(D'05'*D'24')+D'14'	;scale=26bin=136octave=05note=16
	retlw	(D'05'*D'24')+D'14'	;scale=26bin=137octave=05note=17
	retlw	(D'05'*D'24')+D'18'	;scale=26bin=138octave=05note=18
	retlw	(D'05'*D'24')+D'18'	;scale=26bin=139octave=05note=19
	retlw	(D'05'*D'24')+D'20'	;scale=26bin=140octave=05note=20
	retlw	(D'05'*D'24')+D'20'	;scale=26bin=141octave=05note=21
	retlw	(D'05'*D'24')+D'20'	;scale=26bin=142octave=05note=22
	retlw	(D'05'*D'24')+D'20'	;scale=26bin=143octave=05note=23
	retlw	(D'06'*D'24')+D'00'	;scale=26bin=144octave=06note=00
	retlw	(D'06'*D'24')+D'00'	;scale=26bin=145octave=06note=01
	retlw	(D'06'*D'24')+D'02'	;scale=26bin=146octave=06note=02
	retlw	(D'06'*D'24')+D'02'	;scale=26bin=147octave=06note=03
	retlw	(D'06'*D'24')+D'02'	;scale=26bin=148octave=06note=04
	retlw	(D'06'*D'24')+D'02'	;scale=26bin=149octave=06note=05
	retlw	(D'06'*D'24')+D'06'	;scale=26bin=150octave=06note=06
	retlw	(D'06'*D'24')+D'06'	;scale=26bin=151octave=06note=07
	retlw	(D'06'*D'24')+D'08'	;scale=26bin=152octave=06note=08
	retlw	(D'06'*D'24')+D'08'	;scale=26bin=153octave=06note=09
	retlw	(D'06'*D'24')+D'08'	;scale=26bin=154octave=06note=10
	retlw	(D'06'*D'24')+D'08'	;scale=26bin=155octave=06note=11
	retlw	(D'06'*D'24')+D'12'	;scale=26bin=156octave=06note=12
	retlw	(D'06'*D'24')+D'12'	;scale=26bin=157octave=06note=13
	retlw	(D'06'*D'24')+D'14'	;scale=26bin=158octave=06note=14
	retlw	(D'06'*D'24')+D'14'	;scale=26bin=159octave=06note=15
	retlw	(D'06'*D'24')+D'14'	;scale=26bin=160octave=06note=16
	retlw	(D'06'*D'24')+D'14'	;scale=26bin=161octave=06note=17
	retlw	(D'06'*D'24')+D'18'	;scale=26bin=162octave=06note=18
	retlw	(D'06'*D'24')+D'18'	;scale=26bin=163octave=06note=19
	retlw	(D'06'*D'24')+D'20'	;scale=26bin=164octave=06note=20
	retlw	(D'06'*D'24')+D'20'	;scale=26bin=165octave=06note=21
	retlw	(D'06'*D'24')+D'20'	;scale=26bin=166octave=06note=22
	retlw	(D'06'*D'24')+D'20'	;scale=26bin=167octave=06note=23
	retlw	(D'07'*D'24')+D'00'	;scale=26bin=168octave=07note=00
	retlw	(D'07'*D'24')+D'00'	;scale=26bin=169octave=07note=01
	retlw	(D'07'*D'24')+D'02'	;scale=26bin=170octave=07note=02
	retlw	(D'07'*D'24')+D'02'	;scale=26bin=171octave=07note=03
	retlw	(D'07'*D'24')+D'02'	;scale=26bin=172octave=07note=04
	retlw	(D'07'*D'24')+D'02'	;scale=26bin=173octave=07note=05
	retlw	(D'07'*D'24')+D'06'	;scale=26bin=174octave=07note=06
	retlw	(D'07'*D'24')+D'06'	;scale=26bin=175octave=07note=07
	retlw	(D'07'*D'24')+D'08'	;scale=26bin=176octave=07note=08
	retlw	(D'07'*D'24')+D'08'	;scale=26bin=177octave=07note=09
	retlw	(D'07'*D'24')+D'08'	;scale=26bin=178octave=07note=10
	retlw	(D'07'*D'24')+D'08'	;scale=26bin=179octave=07note=11
	retlw	(D'07'*D'24')+D'12'	;scale=26bin=180octave=07note=12
	retlw	(D'07'*D'24')+D'12'	;scale=26bin=181octave=07note=13
	retlw	(D'07'*D'24')+D'14'	;scale=26bin=182octave=07note=14
	retlw	(D'07'*D'24')+D'14'	;scale=26bin=183octave=07note=15
	retlw	(D'07'*D'24')+D'14'	;scale=26bin=184octave=07note=16
	retlw	(D'07'*D'24')+D'14'	;scale=26bin=185octave=07note=17
	retlw	(D'07'*D'24')+D'18'	;scale=26bin=186octave=07note=18
	retlw	(D'07'*D'24')+D'18'	;scale=26bin=187octave=07note=19
	retlw	(D'07'*D'24')+D'20'	;scale=26bin=188octave=07note=20
	retlw	(D'07'*D'24')+D'20'	;scale=26bin=189octave=07note=21
	retlw	(D'07'*D'24')+D'20'	;scale=26bin=190octave=07note=22
	retlw	(D'07'*D'24')+D'20'	;scale=26bin=191octave=07note=23
	retlw	(D'08'*D'24')+D'00'	;scale=26bin=192octave=08note=00
	retlw	(D'08'*D'24')+D'00'	;scale=26bin=193octave=08note=01
	retlw	(D'08'*D'24')+D'02'	;scale=26bin=194octave=08note=02
	retlw	(D'08'*D'24')+D'02'	;scale=26bin=195octave=08note=03
	retlw	(D'08'*D'24')+D'02'	;scale=26bin=196octave=08note=04
	retlw	(D'08'*D'24')+D'02'	;scale=26bin=197octave=08note=05
	retlw	(D'08'*D'24')+D'06'	;scale=26bin=198octave=08note=06
	retlw	(D'08'*D'24')+D'06'	;scale=26bin=199octave=08note=07
	retlw	(D'08'*D'24')+D'08'	;scale=26bin=200octave=08note=08
	retlw	(D'08'*D'24')+D'08'	;scale=26bin=201octave=08note=09
	retlw	(D'08'*D'24')+D'08'	;scale=26bin=202octave=08note=10
	retlw	(D'08'*D'24')+D'08'	;scale=26bin=203octave=08note=11
	retlw	(D'08'*D'24')+D'12'	;scale=26bin=204octave=08note=12
	retlw	(D'08'*D'24')+D'12'	;scale=26bin=205octave=08note=13
	retlw	(D'08'*D'24')+D'14'	;scale=26bin=206octave=08note=14
	retlw	(D'08'*D'24')+D'14'	;scale=26bin=207octave=08note=15
	retlw	(D'08'*D'24')+D'14'	;scale=26bin=208octave=08note=16
	retlw	(D'08'*D'24')+D'14'	;scale=26bin=209octave=08note=17
	retlw	(D'08'*D'24')+D'18'	;scale=26bin=210octave=08note=18
	retlw	(D'08'*D'24')+D'18'	;scale=26bin=211octave=08note=19
	retlw	(D'08'*D'24')+D'20'	;scale=26bin=212octave=08note=20
	retlw	(D'08'*D'24')+D'20'	;scale=26bin=213octave=08note=21
	retlw	(D'08'*D'24')+D'20'	;scale=26bin=214octave=08note=22
	retlw	(D'08'*D'24')+D'20'	;scale=26bin=215octave=08note=23
	retlw	(D'09'*D'24')+D'00'	;scale=26bin=216octave=09note=00
	retlw	(D'09'*D'24')+D'00'	;scale=26bin=217octave=09note=01
	retlw	(D'09'*D'24')+D'02'	;scale=26bin=218octave=09note=02
	retlw	(D'09'*D'24')+D'02'	;scale=26bin=219octave=09note=03
	retlw	(D'09'*D'24')+D'02'	;scale=26bin=220octave=09note=04
	retlw	(D'09'*D'24')+D'02'	;scale=26bin=221octave=09note=05
	retlw	(D'09'*D'24')+D'06'	;scale=26bin=222octave=09note=06
	retlw	(D'09'*D'24')+D'06'	;scale=26bin=223octave=09note=07
	retlw	(D'09'*D'24')+D'08'	;scale=26bin=224octave=09note=08
	retlw	(D'09'*D'24')+D'08'	;scale=26bin=225octave=09note=09
	retlw	(D'09'*D'24')+D'08'	;scale=26bin=226octave=09note=10
	retlw	(D'09'*D'24')+D'08'	;scale=26bin=227octave=09note=11
	retlw	(D'09'*D'24')+D'12'	;scale=26bin=228octave=09note=12
	retlw	(D'09'*D'24')+D'12'	;scale=26bin=229octave=09note=13
	retlw	(D'09'*D'24')+D'14'	;scale=26bin=230octave=09note=14
	retlw	(D'09'*D'24')+D'14'	;scale=26bin=231octave=09note=15
	retlw	(D'09'*D'24')+D'14'	;scale=26bin=232octave=09note=16
	retlw	(D'09'*D'24')+D'14'	;scale=26bin=233octave=09note=17
	retlw	(D'09'*D'24')+D'18'	;scale=26bin=234octave=09note=18
	retlw	(D'09'*D'24')+D'18'	;scale=26bin=235octave=09note=19
	retlw	(D'09'*D'24')+D'20'	;scale=26bin=236octave=09note=20
	retlw	(D'09'*D'24')+D'20'	;scale=26bin=237octave=09note=21
	retlw	(D'09'*D'24')+D'20'	;scale=26bin=238octave=09note=22
	retlw	(D'09'*D'24')+D'20'	;scale=26bin=239octave=09note=23
	retlw	(D'10'*D'24')+D'00'	;scale=26bin=240octave=10note=00
	retlw	(D'10'*D'24')+D'00'	;scale=26bin=241octave=10note=01
	retlw	(D'10'*D'24')+D'00'	;scale=26bin=242octave=10note=02
	retlw	(D'10'*D'24')+D'00'	;scale=26bin=243octave=10note=03
	retlw	(D'10'*D'24')+D'00'	;scale=26bin=244octave=10note=04
	retlw	(D'10'*D'24')+D'00'	;scale=26bin=245octave=10note=05
	retlw	(D'10'*D'24')+D'00'	;scale=26bin=246octave=10note=06
	retlw	(D'10'*D'24')+D'00'	;scale=26bin=247octave=10note=07
	retlw	(D'10'*D'24')+D'00'	;scale=26bin=248octave=10note=08
	retlw	(D'10'*D'24')+D'00'	;scale=26bin=249octave=10note=09
	retlw	(D'10'*D'24')+D'00'	;scale=26bin=250octave=10note=10
	retlw	(D'10'*D'24')+D'00'	;scale=26bin=251octave=10note=11
	retlw	(D'10'*D'24')+D'00'	;scale=26bin=252octave=10note=12
	retlw	(D'10'*D'24')+D'00'	;scale=26bin=253octave=10note=13
	retlw	(D'10'*D'24')+D'00'	;scale=26bin=254octave=10note=14
	retlw	(D'10'*D'24')+D'00'	;scale=26bin=255octave=10note=15

;	Quarter Tone look-up table
	org	QuarterT		;Quartr Tone look-up table
	retlw	(D'00'*D'24')+D'00'	;scale=27bin=000octave=00note=00
	retlw	(D'00'*D'24')+D'01'	;scale=27bin=001octave=00note=01
	retlw	(D'00'*D'24')+D'02'	;scale=27bin=002octave=00note=02
	retlw	(D'00'*D'24')+D'03'	;scale=27bin=003octave=00note=03
	retlw	(D'00'*D'24')+D'04'	;scale=27bin=004octave=00note=04
	retlw	(D'00'*D'24')+D'05'	;scale=27bin=005octave=00note=05
	retlw	(D'00'*D'24')+D'06'	;scale=27bin=006octave=00note=06
	retlw	(D'00'*D'24')+D'07'	;scale=27bin=007octave=00note=07
	retlw	(D'00'*D'24')+D'08'	;scale=27bin=008octave=00note=08
	retlw	(D'00'*D'24')+D'09'	;scale=27bin=009octave=00note=09
	retlw	(D'00'*D'24')+D'10'	;scale=27bin=010octave=00note=10
	retlw	(D'00'*D'24')+D'11'	;scale=27bin=011octave=00note=11
	retlw	(D'00'*D'24')+D'12'	;scale=27bin=012octave=00note=12
	retlw	(D'00'*D'24')+D'13'	;scale=27bin=013octave=00note=13
	retlw	(D'00'*D'24')+D'14'	;scale=27bin=014octave=00note=14
	retlw	(D'00'*D'24')+D'15'	;scale=27bin=015octave=00note=15
	retlw	(D'00'*D'24')+D'16'	;scale=27bin=016octave=00note=16
	retlw	(D'00'*D'24')+D'17'	;scale=27bin=017octave=00note=17
	retlw	(D'00'*D'24')+D'18'	;scale=27bin=018octave=00note=18
	retlw	(D'00'*D'24')+D'19'	;scale=27bin=019octave=00note=19
	retlw	(D'00'*D'24')+D'20'	;scale=27bin=020octave=00note=20
	retlw	(D'00'*D'24')+D'21'	;scale=27bin=021octave=00note=21
	retlw	(D'00'*D'24')+D'22'	;scale=27bin=022octave=00note=22
	retlw	(D'00'*D'24')+D'23'	;scale=27bin=023octave=00note=23
	retlw	(D'01'*D'24')+D'00'	;scale=27bin=024octave=01note=00
	retlw	(D'01'*D'24')+D'01'	;scale=27bin=025octave=01note=01
	retlw	(D'01'*D'24')+D'02'	;scale=27bin=026octave=01note=02
	retlw	(D'01'*D'24')+D'03'	;scale=27bin=027octave=01note=03
	retlw	(D'01'*D'24')+D'04'	;scale=27bin=028octave=01note=04
	retlw	(D'01'*D'24')+D'05'	;scale=27bin=029octave=01note=05
	retlw	(D'01'*D'24')+D'06'	;scale=27bin=030octave=01note=06
	retlw	(D'01'*D'24')+D'07'	;scale=27bin=031octave=01note=07
	retlw	(D'01'*D'24')+D'08'	;scale=27bin=032octave=01note=08
	retlw	(D'01'*D'24')+D'09'	;scale=27bin=033octave=01note=09
	retlw	(D'01'*D'24')+D'10'	;scale=27bin=034octave=01note=10
	retlw	(D'01'*D'24')+D'11'	;scale=27bin=035octave=01note=11
	retlw	(D'01'*D'24')+D'12'	;scale=27bin=036octave=01note=12
	retlw	(D'01'*D'24')+D'13'	;scale=27bin=037octave=01note=13
	retlw	(D'01'*D'24')+D'14'	;scale=27bin=038octave=01note=14
	retlw	(D'01'*D'24')+D'15'	;scale=27bin=039octave=01note=15
	retlw	(D'01'*D'24')+D'16'	;scale=27bin=040octave=01note=16
	retlw	(D'01'*D'24')+D'17'	;scale=27bin=041octave=01note=17
	retlw	(D'01'*D'24')+D'18'	;scale=27bin=042octave=01note=18
	retlw	(D'01'*D'24')+D'19'	;scale=27bin=043octave=01note=19
	retlw	(D'01'*D'24')+D'20'	;scale=27bin=044octave=01note=20
	retlw	(D'01'*D'24')+D'21'	;scale=27bin=045octave=01note=21
	retlw	(D'01'*D'24')+D'22'	;scale=27bin=046octave=01note=22
	retlw	(D'01'*D'24')+D'23'	;scale=27bin=047octave=01note=23
	retlw	(D'02'*D'24')+D'00'	;scale=27bin=048octave=02note=00
	retlw	(D'02'*D'24')+D'01'	;scale=27bin=049octave=02note=01
	retlw	(D'02'*D'24')+D'02'	;scale=27bin=050octave=02note=02
	retlw	(D'02'*D'24')+D'03'	;scale=27bin=051octave=02note=03
	retlw	(D'02'*D'24')+D'04'	;scale=27bin=052octave=02note=04
	retlw	(D'02'*D'24')+D'05'	;scale=27bin=053octave=02note=05
	retlw	(D'02'*D'24')+D'06'	;scale=27bin=054octave=02note=06
	retlw	(D'02'*D'24')+D'07'	;scale=27bin=055octave=02note=07
	retlw	(D'02'*D'24')+D'08'	;scale=27bin=056octave=02note=08
	retlw	(D'02'*D'24')+D'09'	;scale=27bin=057octave=02note=09
	retlw	(D'02'*D'24')+D'10'	;scale=27bin=058octave=02note=10
	retlw	(D'02'*D'24')+D'11'	;scale=27bin=059octave=02note=11
	retlw	(D'02'*D'24')+D'12'	;scale=27bin=060octave=02note=12
	retlw	(D'02'*D'24')+D'13'	;scale=27bin=061octave=02note=13
	retlw	(D'02'*D'24')+D'14'	;scale=27bin=062octave=02note=14
	retlw	(D'02'*D'24')+D'15'	;scale=27bin=063octave=02note=15
	retlw	(D'02'*D'24')+D'16'	;scale=27bin=064octave=02note=16
	retlw	(D'02'*D'24')+D'17'	;scale=27bin=065octave=02note=17
	retlw	(D'02'*D'24')+D'18'	;scale=27bin=066octave=02note=18
	retlw	(D'02'*D'24')+D'19'	;scale=27bin=067octave=02note=19
	retlw	(D'02'*D'24')+D'20'	;scale=27bin=068octave=02note=20
	retlw	(D'02'*D'24')+D'21'	;scale=27bin=069octave=02note=21
	retlw	(D'02'*D'24')+D'22'	;scale=27bin=070octave=02note=22
	retlw	(D'02'*D'24')+D'23'	;scale=27bin=071octave=02note=23
	retlw	(D'03'*D'24')+D'00'	;scale=27bin=072octave=03note=00
	retlw	(D'03'*D'24')+D'01'	;scale=27bin=073octave=03note=01
	retlw	(D'03'*D'24')+D'02'	;scale=27bin=074octave=03note=02
	retlw	(D'03'*D'24')+D'03'	;scale=27bin=075octave=03note=03
	retlw	(D'03'*D'24')+D'04'	;scale=27bin=076octave=03note=04
	retlw	(D'03'*D'24')+D'05'	;scale=27bin=077octave=03note=05
	retlw	(D'03'*D'24')+D'06'	;scale=27bin=078octave=03note=06
	retlw	(D'03'*D'24')+D'07'	;scale=27bin=079octave=03note=07
	retlw	(D'03'*D'24')+D'08'	;scale=27bin=080octave=03note=08
	retlw	(D'03'*D'24')+D'09'	;scale=27bin=081octave=03note=09
	retlw	(D'03'*D'24')+D'10'	;scale=27bin=082octave=03note=10
	retlw	(D'03'*D'24')+D'11'	;scale=27bin=083octave=03note=11
	retlw	(D'03'*D'24')+D'12'	;scale=27bin=084octave=03note=12
	retlw	(D'03'*D'24')+D'13'	;scale=27bin=085octave=03note=13
	retlw	(D'03'*D'24')+D'14'	;scale=27bin=086octave=03note=14
	retlw	(D'03'*D'24')+D'15'	;scale=27bin=087octave=03note=15
	retlw	(D'03'*D'24')+D'16'	;scale=27bin=088octave=03note=16
	retlw	(D'03'*D'24')+D'17'	;scale=27bin=089octave=03note=17
	retlw	(D'03'*D'24')+D'18'	;scale=27bin=090octave=03note=18
	retlw	(D'03'*D'24')+D'19'	;scale=27bin=091octave=03note=19
	retlw	(D'03'*D'24')+D'20'	;scale=27bin=092octave=03note=20
	retlw	(D'03'*D'24')+D'21'	;scale=27bin=093octave=03note=21
	retlw	(D'03'*D'24')+D'22'	;scale=27bin=094octave=03note=22
	retlw	(D'03'*D'24')+D'23'	;scale=27bin=095octave=03note=23
	retlw	(D'04'*D'24')+D'00'	;scale=27bin=096octave=04note=00
	retlw	(D'04'*D'24')+D'01'	;scale=27bin=097octave=04note=01
	retlw	(D'04'*D'24')+D'02'	;scale=27bin=098octave=04note=02
	retlw	(D'04'*D'24')+D'03'	;scale=27bin=099octave=04note=03
	retlw	(D'04'*D'24')+D'04'	;scale=27bin=100octave=04note=04
	retlw	(D'04'*D'24')+D'05'	;scale=27bin=101octave=04note=05
	retlw	(D'04'*D'24')+D'06'	;scale=27bin=102octave=04note=06
	retlw	(D'04'*D'24')+D'07'	;scale=27bin=103octave=04note=07
	retlw	(D'04'*D'24')+D'08'	;scale=27bin=104octave=04note=08
	retlw	(D'04'*D'24')+D'09'	;scale=27bin=105octave=04note=09
	retlw	(D'04'*D'24')+D'10'	;scale=27bin=106octave=04note=10
	retlw	(D'04'*D'24')+D'11'	;scale=27bin=107octave=04note=11
	retlw	(D'04'*D'24')+D'12'	;scale=27bin=108octave=04note=12
	retlw	(D'04'*D'24')+D'13'	;scale=27bin=109octave=04note=13
	retlw	(D'04'*D'24')+D'14'	;scale=27bin=110octave=04note=14
	retlw	(D'04'*D'24')+D'15'	;scale=27bin=111octave=04note=15
	retlw	(D'04'*D'24')+D'16'	;scale=27bin=112octave=04note=16
	retlw	(D'04'*D'24')+D'17'	;scale=27bin=113octave=04note=17
	retlw	(D'04'*D'24')+D'18'	;scale=27bin=114octave=04note=18
	retlw	(D'04'*D'24')+D'19'	;scale=27bin=115octave=04note=19
	retlw	(D'04'*D'24')+D'20'	;scale=27bin=116octave=04note=20
	retlw	(D'04'*D'24')+D'21'	;scale=27bin=117octave=04note=21
	retlw	(D'04'*D'24')+D'22'	;scale=27bin=118octave=04note=22
	retlw	(D'04'*D'24')+D'23'	;scale=27bin=119octave=04note=23
	retlw	(D'05'*D'24')+D'00'	;scale=27bin=120octave=05note=00
	retlw	(D'05'*D'24')+D'01'	;scale=27bin=121octave=05note=01
	retlw	(D'05'*D'24')+D'02'	;scale=27bin=122octave=05note=02
	retlw	(D'05'*D'24')+D'03'	;scale=27bin=123octave=05note=03
	retlw	(D'05'*D'24')+D'04'	;scale=27bin=124octave=05note=04
	retlw	(D'05'*D'24')+D'05'	;scale=27bin=125octave=05note=05
	retlw	(D'05'*D'24')+D'06'	;scale=27bin=126octave=05note=06
	retlw	(D'05'*D'24')+D'07'	;scale=27bin=127octave=05note=07
	retlw	(D'05'*D'24')+D'08'	;scale=27bin=128octave=05note=08
	retlw	(D'05'*D'24')+D'09'	;scale=27bin=129octave=05note=09
	retlw	(D'05'*D'24')+D'10'	;scale=27bin=130octave=05note=10
	retlw	(D'05'*D'24')+D'11'	;scale=27bin=131octave=05note=11
	retlw	(D'05'*D'24')+D'12'	;scale=27bin=132octave=05note=12
	retlw	(D'05'*D'24')+D'13'	;scale=27bin=133octave=05note=13
	retlw	(D'05'*D'24')+D'14'	;scale=27bin=134octave=05note=14
	retlw	(D'05'*D'24')+D'15'	;scale=27bin=135octave=05note=15
	retlw	(D'05'*D'24')+D'16'	;scale=27bin=136octave=05note=16
	retlw	(D'05'*D'24')+D'17'	;scale=27bin=137octave=05note=17
	retlw	(D'05'*D'24')+D'18'	;scale=27bin=138octave=05note=18
	retlw	(D'05'*D'24')+D'19'	;scale=27bin=139octave=05note=19
	retlw	(D'05'*D'24')+D'20'	;scale=27bin=140octave=05note=20
	retlw	(D'05'*D'24')+D'21'	;scale=27bin=141octave=05note=21
	retlw	(D'05'*D'24')+D'22'	;scale=27bin=142octave=05note=22
	retlw	(D'05'*D'24')+D'23'	;scale=27bin=143octave=05note=23
	retlw	(D'06'*D'24')+D'00'	;scale=27bin=144octave=06note=00
	retlw	(D'06'*D'24')+D'01'	;scale=27bin=145octave=06note=01
	retlw	(D'06'*D'24')+D'02'	;scale=27bin=146octave=06note=02
	retlw	(D'06'*D'24')+D'03'	;scale=27bin=147octave=06note=03
	retlw	(D'06'*D'24')+D'04'	;scale=27bin=148octave=06note=04
	retlw	(D'06'*D'24')+D'05'	;scale=27bin=149octave=06note=05
	retlw	(D'06'*D'24')+D'06'	;scale=27bin=150octave=06note=06
	retlw	(D'06'*D'24')+D'07'	;scale=27bin=151octave=06note=07
	retlw	(D'06'*D'24')+D'08'	;scale=27bin=152octave=06note=08
	retlw	(D'06'*D'24')+D'09'	;scale=27bin=153octave=06note=09
	retlw	(D'06'*D'24')+D'10'	;scale=27bin=154octave=06note=10
	retlw	(D'06'*D'24')+D'11'	;scale=27bin=155octave=06note=11
	retlw	(D'06'*D'24')+D'12'	;scale=27bin=156octave=06note=12
	retlw	(D'06'*D'24')+D'13'	;scale=27bin=157octave=06note=13
	retlw	(D'06'*D'24')+D'14'	;scale=27bin=158octave=06note=14
	retlw	(D'06'*D'24')+D'15'	;scale=27bin=159octave=06note=15
	retlw	(D'06'*D'24')+D'16'	;scale=27bin=160octave=06note=16
	retlw	(D'06'*D'24')+D'17'	;scale=27bin=161octave=06note=17
	retlw	(D'06'*D'24')+D'18'	;scale=27bin=162octave=06note=18
	retlw	(D'06'*D'24')+D'19'	;scale=27bin=163octave=06note=19
	retlw	(D'06'*D'24')+D'20'	;scale=27bin=164octave=06note=20
	retlw	(D'06'*D'24')+D'21'	;scale=27bin=165octave=06note=21
	retlw	(D'06'*D'24')+D'22'	;scale=27bin=166octave=06note=22
	retlw	(D'06'*D'24')+D'23'	;scale=27bin=167octave=06note=23
	retlw	(D'07'*D'24')+D'00'	;scale=27bin=168octave=07note=00
	retlw	(D'07'*D'24')+D'01'	;scale=27bin=169octave=07note=01
	retlw	(D'07'*D'24')+D'02'	;scale=27bin=170octave=07note=02
	retlw	(D'07'*D'24')+D'03'	;scale=27bin=171octave=07note=03
	retlw	(D'07'*D'24')+D'04'	;scale=27bin=172octave=07note=04
	retlw	(D'07'*D'24')+D'05'	;scale=27bin=173octave=07note=05
	retlw	(D'07'*D'24')+D'06'	;scale=27bin=174octave=07note=06
	retlw	(D'07'*D'24')+D'07'	;scale=27bin=175octave=07note=07
	retlw	(D'07'*D'24')+D'08'	;scale=27bin=176octave=07note=08
	retlw	(D'07'*D'24')+D'09'	;scale=27bin=177octave=07note=09
	retlw	(D'07'*D'24')+D'10'	;scale=27bin=178octave=07note=10
	retlw	(D'07'*D'24')+D'11'	;scale=27bin=179octave=07note=11
	retlw	(D'07'*D'24')+D'12'	;scale=27bin=180octave=07note=12
	retlw	(D'07'*D'24')+D'13'	;scale=27bin=181octave=07note=13
	retlw	(D'07'*D'24')+D'14'	;scale=27bin=182octave=07note=14
	retlw	(D'07'*D'24')+D'15'	;scale=27bin=183octave=07note=15
	retlw	(D'07'*D'24')+D'16'	;scale=27bin=184octave=07note=16
	retlw	(D'07'*D'24')+D'17'	;scale=27bin=185octave=07note=17
	retlw	(D'07'*D'24')+D'18'	;scale=27bin=186octave=07note=18
	retlw	(D'07'*D'24')+D'19'	;scale=27bin=187octave=07note=19
	retlw	(D'07'*D'24')+D'20'	;scale=27bin=188octave=07note=20
	retlw	(D'07'*D'24')+D'21'	;scale=27bin=189octave=07note=21
	retlw	(D'07'*D'24')+D'22'	;scale=27bin=190octave=07note=22
	retlw	(D'07'*D'24')+D'23'	;scale=27bin=191octave=07note=23
	retlw	(D'08'*D'24')+D'00'	;scale=27bin=192octave=08note=00
	retlw	(D'08'*D'24')+D'01'	;scale=27bin=193octave=08note=01
	retlw	(D'08'*D'24')+D'02'	;scale=27bin=194octave=08note=02
	retlw	(D'08'*D'24')+D'03'	;scale=27bin=195octave=08note=03
	retlw	(D'08'*D'24')+D'04'	;scale=27bin=196octave=08note=04
	retlw	(D'08'*D'24')+D'05'	;scale=27bin=197octave=08note=05
	retlw	(D'08'*D'24')+D'06'	;scale=27bin=198octave=08note=06
	retlw	(D'08'*D'24')+D'07'	;scale=27bin=199octave=08note=07
	retlw	(D'08'*D'24')+D'08'	;scale=27bin=200octave=08note=08
	retlw	(D'08'*D'24')+D'09'	;scale=27bin=201octave=08note=09
	retlw	(D'08'*D'24')+D'10'	;scale=27bin=202octave=08note=10
	retlw	(D'08'*D'24')+D'11'	;scale=27bin=203octave=08note=11
	retlw	(D'08'*D'24')+D'12'	;scale=27bin=204octave=08note=12
	retlw	(D'08'*D'24')+D'13'	;scale=27bin=205octave=08note=13
	retlw	(D'08'*D'24')+D'14'	;scale=27bin=206octave=08note=14
	retlw	(D'08'*D'24')+D'15'	;scale=27bin=207octave=08note=15
	retlw	(D'08'*D'24')+D'16'	;scale=27bin=208octave=08note=16
	retlw	(D'08'*D'24')+D'17'	;scale=27bin=209octave=08note=17
	retlw	(D'08'*D'24')+D'18'	;scale=27bin=210octave=08note=18
	retlw	(D'08'*D'24')+D'19'	;scale=27bin=211octave=08note=19
	retlw	(D'08'*D'24')+D'20'	;scale=27bin=212octave=08note=20
	retlw	(D'08'*D'24')+D'21'	;scale=27bin=213octave=08note=21
	retlw	(D'08'*D'24')+D'22'	;scale=27bin=214octave=08note=22
	retlw	(D'08'*D'24')+D'23'	;scale=27bin=215octave=08note=23
	retlw	(D'09'*D'24')+D'00'	;scale=27bin=216octave=09note=00
	retlw	(D'09'*D'24')+D'01'	;scale=27bin=217octave=09note=01
	retlw	(D'09'*D'24')+D'02'	;scale=27bin=218octave=09note=02
	retlw	(D'09'*D'24')+D'03'	;scale=27bin=219octave=09note=03
	retlw	(D'09'*D'24')+D'04'	;scale=27bin=220octave=09note=04
	retlw	(D'09'*D'24')+D'05'	;scale=27bin=221octave=09note=05
	retlw	(D'09'*D'24')+D'06'	;scale=27bin=222octave=09note=06
	retlw	(D'09'*D'24')+D'07'	;scale=27bin=223octave=09note=07
	retlw	(D'09'*D'24')+D'08'	;scale=27bin=224octave=09note=08
	retlw	(D'09'*D'24')+D'09'	;scale=27bin=225octave=09note=09
	retlw	(D'09'*D'24')+D'10'	;scale=27bin=226octave=09note=10
	retlw	(D'09'*D'24')+D'11'	;scale=27bin=227octave=09note=11
	retlw	(D'09'*D'24')+D'12'	;scale=27bin=228octave=09note=12
	retlw	(D'09'*D'24')+D'13'	;scale=27bin=229octave=09note=13
	retlw	(D'09'*D'24')+D'14'	;scale=27bin=230octave=09note=14
	retlw	(D'09'*D'24')+D'15'	;scale=27bin=231octave=09note=15
	retlw	(D'09'*D'24')+D'16'	;scale=27bin=232octave=09note=16
	retlw	(D'09'*D'24')+D'17'	;scale=27bin=233octave=09note=17
	retlw	(D'09'*D'24')+D'18'	;scale=27bin=234octave=09note=18
	retlw	(D'09'*D'24')+D'19'	;scale=27bin=235octave=09note=19
	retlw	(D'09'*D'24')+D'20'	;scale=27bin=236octave=09note=20
	retlw	(D'09'*D'24')+D'21'	;scale=27bin=237octave=09note=21
	retlw	(D'09'*D'24')+D'22'	;scale=27bin=238octave=09note=22
	retlw	(D'09'*D'24')+D'23'	;scale=27bin=239octave=09note=23
	retlw	(D'10'*D'24')+D'00'	;scale=27bin=240octave=10note=00
	retlw	(D'10'*D'24')+D'00'	;scale=27bin=241octave=10note=01
	retlw	(D'10'*D'24')+D'00'	;scale=27bin=242octave=10note=02
	retlw	(D'10'*D'24')+D'00'	;scale=27bin=243octave=10note=03
	retlw	(D'10'*D'24')+D'00'	;scale=27bin=244octave=10note=04
	retlw	(D'10'*D'24')+D'00'	;scale=27bin=245octave=10note=05
	retlw	(D'10'*D'24')+D'00'	;scale=27bin=246octave=10note=06
	retlw	(D'10'*D'24')+D'00'	;scale=27bin=247octave=10note=07
	retlw	(D'10'*D'24')+D'00'	;scale=27bin=248octave=10note=08
	retlw	(D'10'*D'24')+D'00'	;scale=27bin=249octave=10note=09
	retlw	(D'10'*D'24')+D'00'	;scale=27bin=250octave=10note=10
	retlw	(D'10'*D'24')+D'00'	;scale=27bin=251octave=10note=11
	retlw	(D'10'*D'24')+D'00'	;scale=27bin=252octave=10note=12
	retlw	(D'10'*D'24')+D'00'	;scale=27bin=253octave=10note=13
	retlw	(D'10'*D'24')+D'00'	;scale=27bin=254octave=10note=14
	retlw	(D'10'*D'24')+D'00'	;scale=27bin=255octave=10note=15

;	Greek Lydian Quarter Tone look-up table
	org	GreekLQT		;Greek Lydian Quarter Tone look-up table
	retlw	(D'00'*D'24')+D'00'	;scale=28bin=000octave=00note=00
	retlw	(D'00'*D'24')+D'00'	;scale=28bin=001octave=00note=01
	retlw	(D'00'*D'24')+D'00'	;scale=28bin=002octave=00note=02
	retlw	(D'00'*D'24')+D'00'	;scale=28bin=003octave=00note=03
	retlw	(D'00'*D'24')+D'00'	;scale=28bin=004octave=00note=04
	retlw	(D'00'*D'24')+D'00'	;scale=28bin=005octave=00note=05
	retlw	(D'00'*D'24')+D'00'	;scale=28bin=006octave=00note=06
	retlw	(D'00'*D'24')+D'00'	;scale=28bin=007octave=00note=07
	retlw	(D'00'*D'24')+D'08'	;scale=28bin=008octave=00note=08
	retlw	(D'00'*D'24')+D'09'	;scale=28bin=009octave=00note=09
	retlw	(D'00'*D'24')+D'10'	;scale=28bin=010octave=00note=10
	retlw	(D'00'*D'24')+D'10'	;scale=28bin=011octave=00note=11
	retlw	(D'00'*D'24')+D'10'	;scale=28bin=012octave=00note=12
	retlw	(D'00'*D'24')+D'10'	;scale=28bin=013octave=00note=13
	retlw	(D'00'*D'24')+D'14'	;scale=28bin=014octave=00note=14
	retlw	(D'00'*D'24')+D'14'	;scale=28bin=015octave=00note=15
	retlw	(D'00'*D'24')+D'14'	;scale=28bin=016octave=00note=16
	retlw	(D'00'*D'24')+D'14'	;scale=28bin=017octave=00note=17
	retlw	(D'00'*D'24')+D'14'	;scale=28bin=018octave=00note=18
	retlw	(D'00'*D'24')+D'14'	;scale=28bin=019octave=00note=19
	retlw	(D'00'*D'24')+D'14'	;scale=28bin=020octave=00note=20
	retlw	(D'00'*D'24')+D'14'	;scale=28bin=021octave=00note=21
	retlw	(D'00'*D'24')+D'22'	;scale=28bin=022octave=00note=22
	retlw	(D'00'*D'24')+D'23'	;scale=28bin=023octave=00note=23
	retlw	(D'01'*D'24')+D'00'	;scale=28bin=024octave=01note=00
	retlw	(D'01'*D'24')+D'00'	;scale=28bin=025octave=01note=01
	retlw	(D'01'*D'24')+D'00'	;scale=28bin=026octave=01note=02
	retlw	(D'01'*D'24')+D'00'	;scale=28bin=027octave=01note=03
	retlw	(D'01'*D'24')+D'00'	;scale=28bin=028octave=01note=04
	retlw	(D'01'*D'24')+D'00'	;scale=28bin=029octave=01note=05
	retlw	(D'01'*D'24')+D'00'	;scale=28bin=030octave=01note=06
	retlw	(D'01'*D'24')+D'00'	;scale=28bin=031octave=01note=07
	retlw	(D'01'*D'24')+D'08'	;scale=28bin=032octave=01note=08
	retlw	(D'01'*D'24')+D'09'	;scale=28bin=033octave=01note=09
	retlw	(D'01'*D'24')+D'10'	;scale=28bin=034octave=01note=10
	retlw	(D'01'*D'24')+D'10'	;scale=28bin=035octave=01note=11
	retlw	(D'01'*D'24')+D'10'	;scale=28bin=036octave=01note=12
	retlw	(D'01'*D'24')+D'10'	;scale=28bin=037octave=01note=13
	retlw	(D'01'*D'24')+D'14'	;scale=28bin=038octave=01note=14
	retlw	(D'01'*D'24')+D'14'	;scale=28bin=039octave=01note=15
	retlw	(D'01'*D'24')+D'14'	;scale=28bin=040octave=01note=16
	retlw	(D'01'*D'24')+D'14'	;scale=28bin=041octave=01note=17
	retlw	(D'01'*D'24')+D'14'	;scale=28bin=042octave=01note=18
	retlw	(D'01'*D'24')+D'14'	;scale=28bin=043octave=01note=19
	retlw	(D'01'*D'24')+D'14'	;scale=28bin=044octave=01note=20
	retlw	(D'01'*D'24')+D'14'	;scale=28bin=045octave=01note=21
	retlw	(D'01'*D'24')+D'22'	;scale=28bin=046octave=01note=22
	retlw	(D'01'*D'24')+D'23'	;scale=28bin=047octave=01note=23
	retlw	(D'02'*D'24')+D'00'	;scale=28bin=048octave=02note=00
	retlw	(D'02'*D'24')+D'00'	;scale=28bin=049octave=02note=01
	retlw	(D'02'*D'24')+D'00'	;scale=28bin=050octave=02note=02
	retlw	(D'02'*D'24')+D'00'	;scale=28bin=051octave=02note=03
	retlw	(D'02'*D'24')+D'00'	;scale=28bin=052octave=02note=04
	retlw	(D'02'*D'24')+D'00'	;scale=28bin=053octave=02note=05
	retlw	(D'02'*D'24')+D'00'	;scale=28bin=054octave=02note=06
	retlw	(D'02'*D'24')+D'00'	;scale=28bin=055octave=02note=07
	retlw	(D'02'*D'24')+D'08'	;scale=28bin=056octave=02note=08
	retlw	(D'02'*D'24')+D'09'	;scale=28bin=057octave=02note=09
	retlw	(D'02'*D'24')+D'10'	;scale=28bin=058octave=02note=10
	retlw	(D'02'*D'24')+D'10'	;scale=28bin=059octave=02note=11
	retlw	(D'02'*D'24')+D'10'	;scale=28bin=060octave=02note=12
	retlw	(D'02'*D'24')+D'10'	;scale=28bin=061octave=02note=13
	retlw	(D'02'*D'24')+D'14'	;scale=28bin=062octave=02note=14
	retlw	(D'02'*D'24')+D'14'	;scale=28bin=063octave=02note=15
	retlw	(D'02'*D'24')+D'14'	;scale=28bin=064octave=02note=16
	retlw	(D'02'*D'24')+D'14'	;scale=28bin=065octave=02note=17
	retlw	(D'02'*D'24')+D'14'	;scale=28bin=066octave=02note=18
	retlw	(D'02'*D'24')+D'14'	;scale=28bin=067octave=02note=19
	retlw	(D'02'*D'24')+D'14'	;scale=28bin=068octave=02note=20
	retlw	(D'02'*D'24')+D'14'	;scale=28bin=069octave=02note=21
	retlw	(D'02'*D'24')+D'22'	;scale=28bin=070octave=02note=22
	retlw	(D'02'*D'24')+D'23'	;scale=28bin=071octave=02note=23
	retlw	(D'03'*D'24')+D'00'	;scale=28bin=072octave=03note=00
	retlw	(D'03'*D'24')+D'00'	;scale=28bin=073octave=03note=01
	retlw	(D'03'*D'24')+D'00'	;scale=28bin=074octave=03note=02
	retlw	(D'03'*D'24')+D'00'	;scale=28bin=075octave=03note=03
	retlw	(D'03'*D'24')+D'00'	;scale=28bin=076octave=03note=04
	retlw	(D'03'*D'24')+D'00'	;scale=28bin=077octave=03note=05
	retlw	(D'03'*D'24')+D'00'	;scale=28bin=078octave=03note=06
	retlw	(D'03'*D'24')+D'00'	;scale=28bin=079octave=03note=07
	retlw	(D'03'*D'24')+D'08'	;scale=28bin=080octave=03note=08
	retlw	(D'03'*D'24')+D'09'	;scale=28bin=081octave=03note=09
	retlw	(D'03'*D'24')+D'10'	;scale=28bin=082octave=03note=10
	retlw	(D'03'*D'24')+D'10'	;scale=28bin=083octave=03note=11
	retlw	(D'03'*D'24')+D'10'	;scale=28bin=084octave=03note=12
	retlw	(D'03'*D'24')+D'10'	;scale=28bin=085octave=03note=13
	retlw	(D'03'*D'24')+D'14'	;scale=28bin=086octave=03note=14
	retlw	(D'03'*D'24')+D'14'	;scale=28bin=087octave=03note=15
	retlw	(D'03'*D'24')+D'14'	;scale=28bin=088octave=03note=16
	retlw	(D'03'*D'24')+D'14'	;scale=28bin=089octave=03note=17
	retlw	(D'03'*D'24')+D'14'	;scale=28bin=090octave=03note=18
	retlw	(D'03'*D'24')+D'14'	;scale=28bin=091octave=03note=19
	retlw	(D'03'*D'24')+D'14'	;scale=28bin=092octave=03note=20
	retlw	(D'03'*D'24')+D'14'	;scale=28bin=093octave=03note=21
	retlw	(D'03'*D'24')+D'22'	;scale=28bin=094octave=03note=22
	retlw	(D'03'*D'24')+D'23'	;scale=28bin=095octave=03note=23
	retlw	(D'04'*D'24')+D'00'	;scale=28bin=096octave=04note=00
	retlw	(D'04'*D'24')+D'00'	;scale=28bin=097octave=04note=01
	retlw	(D'04'*D'24')+D'00'	;scale=28bin=098octave=04note=02
	retlw	(D'04'*D'24')+D'00'	;scale=28bin=099octave=04note=03
	retlw	(D'04'*D'24')+D'00'	;scale=28bin=100octave=04note=04
	retlw	(D'04'*D'24')+D'00'	;scale=28bin=101octave=04note=05
	retlw	(D'04'*D'24')+D'00'	;scale=28bin=102octave=04note=06
	retlw	(D'04'*D'24')+D'00'	;scale=28bin=103octave=04note=07
	retlw	(D'04'*D'24')+D'08'	;scale=28bin=104octave=04note=08
	retlw	(D'04'*D'24')+D'09'	;scale=28bin=105octave=04note=09
	retlw	(D'04'*D'24')+D'10'	;scale=28bin=106octave=04note=10
	retlw	(D'04'*D'24')+D'10'	;scale=28bin=107octave=04note=11
	retlw	(D'04'*D'24')+D'10'	;scale=28bin=108octave=04note=12
	retlw	(D'04'*D'24')+D'10'	;scale=28bin=109octave=04note=13
	retlw	(D'04'*D'24')+D'14'	;scale=28bin=110octave=04note=14
	retlw	(D'04'*D'24')+D'14'	;scale=28bin=111octave=04note=15
	retlw	(D'04'*D'24')+D'14'	;scale=28bin=112octave=04note=16
	retlw	(D'04'*D'24')+D'14'	;scale=28bin=113octave=04note=17
	retlw	(D'04'*D'24')+D'14'	;scale=28bin=114octave=04note=18
	retlw	(D'04'*D'24')+D'14'	;scale=28bin=115octave=04note=19
	retlw	(D'04'*D'24')+D'14'	;scale=28bin=116octave=04note=20
	retlw	(D'04'*D'24')+D'14'	;scale=28bin=117octave=04note=21
	retlw	(D'04'*D'24')+D'22'	;scale=28bin=118octave=04note=22
	retlw	(D'04'*D'24')+D'23'	;scale=28bin=119octave=04note=23
	retlw	(D'05'*D'24')+D'00'	;scale=28bin=120octave=05note=00
	retlw	(D'05'*D'24')+D'00'	;scale=28bin=121octave=05note=01
	retlw	(D'05'*D'24')+D'00'	;scale=28bin=122octave=05note=02
	retlw	(D'05'*D'24')+D'00'	;scale=28bin=123octave=05note=03
	retlw	(D'05'*D'24')+D'00'	;scale=28bin=124octave=05note=04
	retlw	(D'05'*D'24')+D'00'	;scale=28bin=125octave=05note=05
	retlw	(D'05'*D'24')+D'00'	;scale=28bin=126octave=05note=06
	retlw	(D'05'*D'24')+D'00'	;scale=28bin=127octave=05note=07
	retlw	(D'05'*D'24')+D'08'	;scale=28bin=128octave=05note=08
	retlw	(D'05'*D'24')+D'09'	;scale=28bin=129octave=05note=09
	retlw	(D'05'*D'24')+D'10'	;scale=28bin=130octave=05note=10
	retlw	(D'05'*D'24')+D'10'	;scale=28bin=131octave=05note=11
	retlw	(D'05'*D'24')+D'10'	;scale=28bin=132octave=05note=12
	retlw	(D'05'*D'24')+D'10'	;scale=28bin=133octave=05note=13
	retlw	(D'05'*D'24')+D'14'	;scale=28bin=134octave=05note=14
	retlw	(D'05'*D'24')+D'14'	;scale=28bin=135octave=05note=15
	retlw	(D'05'*D'24')+D'14'	;scale=28bin=136octave=05note=16
	retlw	(D'05'*D'24')+D'14'	;scale=28bin=137octave=05note=17
	retlw	(D'05'*D'24')+D'14'	;scale=28bin=138octave=05note=18
	retlw	(D'05'*D'24')+D'14'	;scale=28bin=139octave=05note=19
	retlw	(D'05'*D'24')+D'14'	;scale=28bin=140octave=05note=20
	retlw	(D'05'*D'24')+D'14'	;scale=28bin=141octave=05note=21
	retlw	(D'05'*D'24')+D'22'	;scale=28bin=142octave=05note=22
	retlw	(D'05'*D'24')+D'23'	;scale=28bin=143octave=05note=23
	retlw	(D'06'*D'24')+D'00'	;scale=28bin=144octave=06note=00
	retlw	(D'06'*D'24')+D'00'	;scale=28bin=145octave=06note=01
	retlw	(D'06'*D'24')+D'00'	;scale=28bin=146octave=06note=02
	retlw	(D'06'*D'24')+D'00'	;scale=28bin=147octave=06note=03
	retlw	(D'06'*D'24')+D'00'	;scale=28bin=148octave=06note=04
	retlw	(D'06'*D'24')+D'00'	;scale=28bin=149octave=06note=05
	retlw	(D'06'*D'24')+D'00'	;scale=28bin=150octave=06note=06
	retlw	(D'06'*D'24')+D'00'	;scale=28bin=151octave=06note=07
	retlw	(D'06'*D'24')+D'08'	;scale=28bin=152octave=06note=08
	retlw	(D'06'*D'24')+D'09'	;scale=28bin=153octave=06note=09
	retlw	(D'06'*D'24')+D'10'	;scale=28bin=154octave=06note=10
	retlw	(D'06'*D'24')+D'10'	;scale=28bin=155octave=06note=11
	retlw	(D'06'*D'24')+D'10'	;scale=28bin=156octave=06note=12
	retlw	(D'06'*D'24')+D'10'	;scale=28bin=157octave=06note=13
	retlw	(D'06'*D'24')+D'14'	;scale=28bin=158octave=06note=14
	retlw	(D'06'*D'24')+D'14'	;scale=28bin=159octave=06note=15
	retlw	(D'06'*D'24')+D'14'	;scale=28bin=160octave=06note=16
	retlw	(D'06'*D'24')+D'14'	;scale=28bin=161octave=06note=17
	retlw	(D'06'*D'24')+D'14'	;scale=28bin=162octave=06note=18
	retlw	(D'06'*D'24')+D'14'	;scale=28bin=163octave=06note=19
	retlw	(D'06'*D'24')+D'14'	;scale=28bin=164octave=06note=20
	retlw	(D'06'*D'24')+D'14'	;scale=28bin=165octave=06note=21
	retlw	(D'06'*D'24')+D'22'	;scale=28bin=166octave=06note=22
	retlw	(D'06'*D'24')+D'23'	;scale=28bin=167octave=06note=23
	retlw	(D'07'*D'24')+D'00'	;scale=28bin=168octave=07note=00
	retlw	(D'07'*D'24')+D'00'	;scale=28bin=169octave=07note=01
	retlw	(D'07'*D'24')+D'00'	;scale=28bin=170octave=07note=02
	retlw	(D'07'*D'24')+D'00'	;scale=28bin=171octave=07note=03
	retlw	(D'07'*D'24')+D'00'	;scale=28bin=172octave=07note=04
	retlw	(D'07'*D'24')+D'00'	;scale=28bin=173octave=07note=05
	retlw	(D'07'*D'24')+D'00'	;scale=28bin=174octave=07note=06
	retlw	(D'07'*D'24')+D'00'	;scale=28bin=175octave=07note=07
	retlw	(D'07'*D'24')+D'08'	;scale=28bin=176octave=07note=08
	retlw	(D'07'*D'24')+D'09'	;scale=28bin=177octave=07note=09
	retlw	(D'07'*D'24')+D'10'	;scale=28bin=178octave=07note=10
	retlw	(D'07'*D'24')+D'10'	;scale=28bin=179octave=07note=11
	retlw	(D'07'*D'24')+D'10'	;scale=28bin=180octave=07note=12
	retlw	(D'07'*D'24')+D'10'	;scale=28bin=181octave=07note=13
	retlw	(D'07'*D'24')+D'14'	;scale=28bin=182octave=07note=14
	retlw	(D'07'*D'24')+D'14'	;scale=28bin=183octave=07note=15
	retlw	(D'07'*D'24')+D'14'	;scale=28bin=184octave=07note=16
	retlw	(D'07'*D'24')+D'14'	;scale=28bin=185octave=07note=17
	retlw	(D'07'*D'24')+D'14'	;scale=28bin=186octave=07note=18
	retlw	(D'07'*D'24')+D'14'	;scale=28bin=187octave=07note=19
	retlw	(D'07'*D'24')+D'14'	;scale=28bin=188octave=07note=20
	retlw	(D'07'*D'24')+D'14'	;scale=28bin=189octave=07note=21
	retlw	(D'07'*D'24')+D'22'	;scale=28bin=190octave=07note=22
	retlw	(D'07'*D'24')+D'23'	;scale=28bin=191octave=07note=23
	retlw	(D'08'*D'24')+D'00'	;scale=28bin=192octave=08note=00
	retlw	(D'08'*D'24')+D'00'	;scale=28bin=193octave=08note=01
	retlw	(D'08'*D'24')+D'00'	;scale=28bin=194octave=08note=02
	retlw	(D'08'*D'24')+D'00'	;scale=28bin=195octave=08note=03
	retlw	(D'08'*D'24')+D'00'	;scale=28bin=196octave=08note=04
	retlw	(D'08'*D'24')+D'00'	;scale=28bin=197octave=08note=05
	retlw	(D'08'*D'24')+D'00'	;scale=28bin=198octave=08note=06
	retlw	(D'08'*D'24')+D'00'	;scale=28bin=199octave=08note=07
	retlw	(D'08'*D'24')+D'08'	;scale=28bin=200octave=08note=08
	retlw	(D'08'*D'24')+D'09'	;scale=28bin=201octave=08note=09
	retlw	(D'08'*D'24')+D'10'	;scale=28bin=202octave=08note=10
	retlw	(D'08'*D'24')+D'10'	;scale=28bin=203octave=08note=11
	retlw	(D'08'*D'24')+D'10'	;scale=28bin=204octave=08note=12
	retlw	(D'08'*D'24')+D'10'	;scale=28bin=205octave=08note=13
	retlw	(D'08'*D'24')+D'14'	;scale=28bin=206octave=08note=14
	retlw	(D'08'*D'24')+D'14'	;scale=28bin=207octave=08note=15
	retlw	(D'08'*D'24')+D'14'	;scale=28bin=208octave=08note=16
	retlw	(D'08'*D'24')+D'14'	;scale=28bin=209octave=08note=17
	retlw	(D'08'*D'24')+D'14'	;scale=28bin=210octave=08note=18
	retlw	(D'08'*D'24')+D'14'	;scale=28bin=211octave=08note=19
	retlw	(D'08'*D'24')+D'14'	;scale=28bin=212octave=08note=20
	retlw	(D'08'*D'24')+D'14'	;scale=28bin=213octave=08note=21
	retlw	(D'08'*D'24')+D'22'	;scale=28bin=214octave=08note=22
	retlw	(D'08'*D'24')+D'23'	;scale=28bin=215octave=08note=23
	retlw	(D'09'*D'24')+D'00'	;scale=28bin=216octave=09note=00
	retlw	(D'09'*D'24')+D'00'	;scale=28bin=217octave=09note=01
	retlw	(D'09'*D'24')+D'00'	;scale=28bin=218octave=09note=02
	retlw	(D'09'*D'24')+D'00'	;scale=28bin=219octave=09note=03
	retlw	(D'09'*D'24')+D'00'	;scale=28bin=220octave=09note=04
	retlw	(D'09'*D'24')+D'00'	;scale=28bin=221octave=09note=05
	retlw	(D'09'*D'24')+D'00'	;scale=28bin=222octave=09note=06
	retlw	(D'09'*D'24')+D'00'	;scale=28bin=223octave=09note=07
	retlw	(D'09'*D'24')+D'08'	;scale=28bin=224octave=09note=08
	retlw	(D'09'*D'24')+D'09'	;scale=28bin=225octave=09note=09
	retlw	(D'09'*D'24')+D'10'	;scale=28bin=226octave=09note=10
	retlw	(D'09'*D'24')+D'10'	;scale=28bin=227octave=09note=11
	retlw	(D'09'*D'24')+D'10'	;scale=28bin=228octave=09note=12
	retlw	(D'09'*D'24')+D'10'	;scale=28bin=229octave=09note=13
	retlw	(D'09'*D'24')+D'14'	;scale=28bin=230octave=09note=14
	retlw	(D'09'*D'24')+D'14'	;scale=28bin=231octave=09note=15
	retlw	(D'09'*D'24')+D'14'	;scale=28bin=232octave=09note=16
	retlw	(D'09'*D'24')+D'14'	;scale=28bin=233octave=09note=17
	retlw	(D'09'*D'24')+D'14'	;scale=28bin=234octave=09note=18
	retlw	(D'09'*D'24')+D'14'	;scale=28bin=235octave=09note=19
	retlw	(D'09'*D'24')+D'14'	;scale=28bin=236octave=09note=20
	retlw	(D'09'*D'24')+D'14'	;scale=28bin=237octave=09note=21
	retlw	(D'09'*D'24')+D'22'	;scale=28bin=238octave=09note=22
	retlw	(D'09'*D'24')+D'23'	;scale=28bin=239octave=09note=23
	retlw	(D'10'*D'24')+D'00'	;scale=28bin=240octave=10note=00
	retlw	(D'10'*D'24')+D'00'	;scale=28bin=241octave=10note=01
	retlw	(D'10'*D'24')+D'00'	;scale=28bin=242octave=10note=02
	retlw	(D'10'*D'24')+D'00'	;scale=28bin=243octave=10note=03
	retlw	(D'10'*D'24')+D'00'	;scale=28bin=244octave=10note=04
	retlw	(D'10'*D'24')+D'00'	;scale=28bin=245octave=10note=05
	retlw	(D'10'*D'24')+D'00'	;scale=28bin=246octave=10note=06
	retlw	(D'10'*D'24')+D'00'	;scale=28bin=247octave=10note=07
	retlw	(D'10'*D'24')+D'00'	;scale=28bin=248octave=10note=08
	retlw	(D'10'*D'24')+D'00'	;scale=28bin=249octave=10note=09
	retlw	(D'10'*D'24')+D'00'	;scale=28bin=250octave=10note=10
	retlw	(D'10'*D'24')+D'00'	;scale=28bin=251octave=10note=11
	retlw	(D'10'*D'24')+D'00'	;scale=28bin=252octave=10note=12
	retlw	(D'10'*D'24')+D'00'	;scale=28bin=253octave=10note=13
	retlw	(D'10'*D'24')+D'00'	;scale=28bin=254octave=10note=14
	retlw	(D'10'*D'24')+D'00'	;scale=28bin=255octave=10note=15

;	Aolian Quarter Tone look-up table
	org	AolianQT		;Aolian Quarter Tone look-up table
	retlw	(D'00'*D'24')+D'00'	;scale=29bin=000octave=00note=00
	retlw	(D'00'*D'24')+D'00'	;scale=29bin=001octave=00note=01
	retlw	(D'00'*D'24')+D'00'	;scale=29bin=002octave=00note=02
	retlw	(D'00'*D'24')+D'00'	;scale=29bin=003octave=00note=03
	retlw	(D'00'*D'24')+D'04'	;scale=29bin=004octave=00note=04
	retlw	(D'00'*D'24')+D'05'	;scale=29bin=005octave=00note=05
	retlw	(D'00'*D'24')+D'05'	;scale=29bin=006octave=00note=06
	retlw	(D'00'*D'24')+D'05'	;scale=29bin=007octave=00note=07
	retlw	(D'00'*D'24')+D'05'	;scale=29bin=008octave=00note=08
	retlw	(D'00'*D'24')+D'05'	;scale=29bin=009octave=00note=09
	retlw	(D'00'*D'24')+D'10'	;scale=29bin=010octave=00note=10
	retlw	(D'00'*D'24')+D'10'	;scale=29bin=011octave=00note=11
	retlw	(D'00'*D'24')+D'10'	;scale=29bin=012octave=00note=12
	retlw	(D'00'*D'24')+D'10'	;scale=29bin=013octave=00note=13
	retlw	(D'00'*D'24')+D'14'	;scale=29bin=014octave=00note=14
	retlw	(D'00'*D'24')+D'15'	;scale=29bin=015octave=00note=15
	retlw	(D'00'*D'24')+D'15'	;scale=29bin=016octave=00note=16
	retlw	(D'00'*D'24')+D'15'	;scale=29bin=017octave=00note=17
	retlw	(D'00'*D'24')+D'15'	;scale=29bin=018octave=00note=18
	retlw	(D'00'*D'24')+D'15'	;scale=29bin=019octave=00note=19
	retlw	(D'00'*D'24')+D'20'	;scale=29bin=020octave=00note=20
	retlw	(D'00'*D'24')+D'20'	;scale=29bin=021octave=00note=21
	retlw	(D'00'*D'24')+D'20'	;scale=29bin=022octave=00note=22
	retlw	(D'00'*D'24')+D'20'	;scale=29bin=023octave=00note=23
	retlw	(D'01'*D'24')+D'00'	;scale=29bin=024octave=01note=00
	retlw	(D'01'*D'24')+D'00'	;scale=29bin=025octave=01note=01
	retlw	(D'01'*D'24')+D'00'	;scale=29bin=026octave=01note=02
	retlw	(D'01'*D'24')+D'00'	;scale=29bin=027octave=01note=03
	retlw	(D'01'*D'24')+D'04'	;scale=29bin=028octave=01note=04
	retlw	(D'01'*D'24')+D'05'	;scale=29bin=029octave=01note=05
	retlw	(D'01'*D'24')+D'05'	;scale=29bin=030octave=01note=06
	retlw	(D'01'*D'24')+D'05'	;scale=29bin=031octave=01note=07
	retlw	(D'01'*D'24')+D'05'	;scale=29bin=032octave=01note=08
	retlw	(D'01'*D'24')+D'05'	;scale=29bin=033octave=01note=09
	retlw	(D'01'*D'24')+D'10'	;scale=29bin=034octave=01note=10
	retlw	(D'01'*D'24')+D'10'	;scale=29bin=035octave=01note=11
	retlw	(D'01'*D'24')+D'10'	;scale=29bin=036octave=01note=12
	retlw	(D'01'*D'24')+D'10'	;scale=29bin=037octave=01note=13
	retlw	(D'01'*D'24')+D'14'	;scale=29bin=038octave=01note=14
	retlw	(D'01'*D'24')+D'15'	;scale=29bin=039octave=01note=15
	retlw	(D'01'*D'24')+D'15'	;scale=29bin=040octave=01note=16
	retlw	(D'01'*D'24')+D'15'	;scale=29bin=041octave=01note=17
	retlw	(D'01'*D'24')+D'15'	;scale=29bin=042octave=01note=18
	retlw	(D'01'*D'24')+D'15'	;scale=29bin=043octave=01note=19
	retlw	(D'01'*D'24')+D'20'	;scale=29bin=044octave=01note=20
	retlw	(D'01'*D'24')+D'20'	;scale=29bin=045octave=01note=21
	retlw	(D'01'*D'24')+D'20'	;scale=29bin=046octave=01note=22
	retlw	(D'01'*D'24')+D'20'	;scale=29bin=047octave=01note=23
	retlw	(D'02'*D'24')+D'00'	;scale=29bin=048octave=02note=00
	retlw	(D'02'*D'24')+D'00'	;scale=29bin=049octave=02note=01
	retlw	(D'02'*D'24')+D'00'	;scale=29bin=050octave=02note=02
	retlw	(D'02'*D'24')+D'00'	;scale=29bin=051octave=02note=03
	retlw	(D'02'*D'24')+D'04'	;scale=29bin=052octave=02note=04
	retlw	(D'02'*D'24')+D'05'	;scale=29bin=053octave=02note=05
	retlw	(D'02'*D'24')+D'05'	;scale=29bin=054octave=02note=06
	retlw	(D'02'*D'24')+D'05'	;scale=29bin=055octave=02note=07
	retlw	(D'02'*D'24')+D'05'	;scale=29bin=056octave=02note=08
	retlw	(D'02'*D'24')+D'05'	;scale=29bin=057octave=02note=09
	retlw	(D'02'*D'24')+D'10'	;scale=29bin=058octave=02note=10
	retlw	(D'02'*D'24')+D'10'	;scale=29bin=059octave=02note=11
	retlw	(D'02'*D'24')+D'10'	;scale=29bin=060octave=02note=12
	retlw	(D'02'*D'24')+D'10'	;scale=29bin=061octave=02note=13
	retlw	(D'02'*D'24')+D'14'	;scale=29bin=062octave=02note=14
	retlw	(D'02'*D'24')+D'15'	;scale=29bin=063octave=02note=15
	retlw	(D'02'*D'24')+D'15'	;scale=29bin=064octave=02note=16
	retlw	(D'02'*D'24')+D'15'	;scale=29bin=065octave=02note=17
	retlw	(D'02'*D'24')+D'15'	;scale=29bin=066octave=02note=18
	retlw	(D'02'*D'24')+D'15'	;scale=29bin=067octave=02note=19
	retlw	(D'02'*D'24')+D'20'	;scale=29bin=068octave=02note=20
	retlw	(D'02'*D'24')+D'20'	;scale=29bin=069octave=02note=21
	retlw	(D'02'*D'24')+D'20'	;scale=29bin=070octave=02note=22
	retlw	(D'02'*D'24')+D'20'	;scale=29bin=071octave=02note=23
	retlw	(D'03'*D'24')+D'00'	;scale=29bin=072octave=03note=00
	retlw	(D'03'*D'24')+D'00'	;scale=29bin=073octave=03note=01
	retlw	(D'03'*D'24')+D'00'	;scale=29bin=074octave=03note=02
	retlw	(D'03'*D'24')+D'00'	;scale=29bin=075octave=03note=03
	retlw	(D'03'*D'24')+D'04'	;scale=29bin=076octave=03note=04
	retlw	(D'03'*D'24')+D'05'	;scale=29bin=077octave=03note=05
	retlw	(D'03'*D'24')+D'05'	;scale=29bin=078octave=03note=06
	retlw	(D'03'*D'24')+D'05'	;scale=29bin=079octave=03note=07
	retlw	(D'03'*D'24')+D'05'	;scale=29bin=080octave=03note=08
	retlw	(D'03'*D'24')+D'05'	;scale=29bin=081octave=03note=09
	retlw	(D'03'*D'24')+D'10'	;scale=29bin=082octave=03note=10
	retlw	(D'03'*D'24')+D'10'	;scale=29bin=083octave=03note=11
	retlw	(D'03'*D'24')+D'10'	;scale=29bin=084octave=03note=12
	retlw	(D'03'*D'24')+D'10'	;scale=29bin=085octave=03note=13
	retlw	(D'03'*D'24')+D'14'	;scale=29bin=086octave=03note=14
	retlw	(D'03'*D'24')+D'15'	;scale=29bin=087octave=03note=15
	retlw	(D'03'*D'24')+D'15'	;scale=29bin=088octave=03note=16
	retlw	(D'03'*D'24')+D'15'	;scale=29bin=089octave=03note=17
	retlw	(D'03'*D'24')+D'15'	;scale=29bin=090octave=03note=18
	retlw	(D'03'*D'24')+D'15'	;scale=29bin=091octave=03note=19
	retlw	(D'03'*D'24')+D'20'	;scale=29bin=092octave=03note=20
	retlw	(D'03'*D'24')+D'20'	;scale=29bin=093octave=03note=21
	retlw	(D'03'*D'24')+D'20'	;scale=29bin=094octave=03note=22
	retlw	(D'03'*D'24')+D'20'	;scale=29bin=095octave=03note=23
	retlw	(D'04'*D'24')+D'00'	;scale=29bin=096octave=04note=00
	retlw	(D'04'*D'24')+D'00'	;scale=29bin=097octave=04note=01
	retlw	(D'04'*D'24')+D'00'	;scale=29bin=098octave=04note=02
	retlw	(D'04'*D'24')+D'00'	;scale=29bin=099octave=04note=03
	retlw	(D'04'*D'24')+D'04'	;scale=29bin=100octave=04note=04
	retlw	(D'04'*D'24')+D'05'	;scale=29bin=101octave=04note=05
	retlw	(D'04'*D'24')+D'05'	;scale=29bin=102octave=04note=06
	retlw	(D'04'*D'24')+D'05'	;scale=29bin=103octave=04note=07
	retlw	(D'04'*D'24')+D'05'	;scale=29bin=104octave=04note=08
	retlw	(D'04'*D'24')+D'05'	;scale=29bin=105octave=04note=09
	retlw	(D'04'*D'24')+D'10'	;scale=29bin=106octave=04note=10
	retlw	(D'04'*D'24')+D'10'	;scale=29bin=107octave=04note=11
	retlw	(D'04'*D'24')+D'10'	;scale=29bin=108octave=04note=12
	retlw	(D'04'*D'24')+D'10'	;scale=29bin=109octave=04note=13
	retlw	(D'04'*D'24')+D'14'	;scale=29bin=110octave=04note=14
	retlw	(D'04'*D'24')+D'15'	;scale=29bin=111octave=04note=15
	retlw	(D'04'*D'24')+D'15'	;scale=29bin=112octave=04note=16
	retlw	(D'04'*D'24')+D'15'	;scale=29bin=113octave=04note=17
	retlw	(D'04'*D'24')+D'15'	;scale=29bin=114octave=04note=18
	retlw	(D'04'*D'24')+D'15'	;scale=29bin=115octave=04note=19
	retlw	(D'04'*D'24')+D'20'	;scale=29bin=116octave=04note=20
	retlw	(D'04'*D'24')+D'20'	;scale=29bin=117octave=04note=21
	retlw	(D'04'*D'24')+D'20'	;scale=29bin=118octave=04note=22
	retlw	(D'04'*D'24')+D'20'	;scale=29bin=119octave=04note=23
	retlw	(D'05'*D'24')+D'00'	;scale=29bin=120octave=05note=00
	retlw	(D'05'*D'24')+D'00'	;scale=29bin=121octave=05note=01
	retlw	(D'05'*D'24')+D'00'	;scale=29bin=122octave=05note=02
	retlw	(D'05'*D'24')+D'00'	;scale=29bin=123octave=05note=03
	retlw	(D'05'*D'24')+D'04'	;scale=29bin=124octave=05note=04
	retlw	(D'05'*D'24')+D'05'	;scale=29bin=125octave=05note=05
	retlw	(D'05'*D'24')+D'05'	;scale=29bin=126octave=05note=06
	retlw	(D'05'*D'24')+D'05'	;scale=29bin=127octave=05note=07
	retlw	(D'05'*D'24')+D'05'	;scale=29bin=128octave=05note=08
	retlw	(D'05'*D'24')+D'05'	;scale=29bin=129octave=05note=09
	retlw	(D'05'*D'24')+D'10'	;scale=29bin=130octave=05note=10
	retlw	(D'05'*D'24')+D'10'	;scale=29bin=131octave=05note=11
	retlw	(D'05'*D'24')+D'10'	;scale=29bin=132octave=05note=12
	retlw	(D'05'*D'24')+D'10'	;scale=29bin=133octave=05note=13
	retlw	(D'05'*D'24')+D'14'	;scale=29bin=134octave=05note=14
	retlw	(D'05'*D'24')+D'15'	;scale=29bin=135octave=05note=15
	retlw	(D'05'*D'24')+D'15'	;scale=29bin=136octave=05note=16
	retlw	(D'05'*D'24')+D'15'	;scale=29bin=137octave=05note=17
	retlw	(D'05'*D'24')+D'15'	;scale=29bin=138octave=05note=18
	retlw	(D'05'*D'24')+D'15'	;scale=29bin=139octave=05note=19
	retlw	(D'05'*D'24')+D'20'	;scale=29bin=140octave=05note=20
	retlw	(D'05'*D'24')+D'20'	;scale=29bin=141octave=05note=21
	retlw	(D'05'*D'24')+D'20'	;scale=29bin=142octave=05note=22
	retlw	(D'05'*D'24')+D'20'	;scale=29bin=143octave=05note=23
	retlw	(D'06'*D'24')+D'00'	;scale=29bin=144octave=06note=00
	retlw	(D'06'*D'24')+D'00'	;scale=29bin=145octave=06note=01
	retlw	(D'06'*D'24')+D'00'	;scale=29bin=146octave=06note=02
	retlw	(D'06'*D'24')+D'00'	;scale=29bin=147octave=06note=03
	retlw	(D'06'*D'24')+D'04'	;scale=29bin=148octave=06note=04
	retlw	(D'06'*D'24')+D'05'	;scale=29bin=149octave=06note=05
	retlw	(D'06'*D'24')+D'05'	;scale=29bin=150octave=06note=06
	retlw	(D'06'*D'24')+D'05'	;scale=29bin=151octave=06note=07
	retlw	(D'06'*D'24')+D'05'	;scale=29bin=152octave=06note=08
	retlw	(D'06'*D'24')+D'05'	;scale=29bin=153octave=06note=09
	retlw	(D'06'*D'24')+D'10'	;scale=29bin=154octave=06note=10
	retlw	(D'06'*D'24')+D'10'	;scale=29bin=155octave=06note=11
	retlw	(D'06'*D'24')+D'10'	;scale=29bin=156octave=06note=12
	retlw	(D'06'*D'24')+D'10'	;scale=29bin=157octave=06note=13
	retlw	(D'06'*D'24')+D'14'	;scale=29bin=158octave=06note=14
	retlw	(D'06'*D'24')+D'15'	;scale=29bin=159octave=06note=15
	retlw	(D'06'*D'24')+D'15'	;scale=29bin=160octave=06note=16
	retlw	(D'06'*D'24')+D'15'	;scale=29bin=161octave=06note=17
	retlw	(D'06'*D'24')+D'15'	;scale=29bin=162octave=06note=18
	retlw	(D'06'*D'24')+D'15'	;scale=29bin=163octave=06note=19
	retlw	(D'06'*D'24')+D'20'	;scale=29bin=164octave=06note=20
	retlw	(D'06'*D'24')+D'20'	;scale=29bin=165octave=06note=21
	retlw	(D'06'*D'24')+D'20'	;scale=29bin=166octave=06note=22
	retlw	(D'06'*D'24')+D'20'	;scale=29bin=167octave=06note=23
	retlw	(D'07'*D'24')+D'00'	;scale=29bin=168octave=07note=00
	retlw	(D'07'*D'24')+D'00'	;scale=29bin=169octave=07note=01
	retlw	(D'07'*D'24')+D'00'	;scale=29bin=170octave=07note=02
	retlw	(D'07'*D'24')+D'00'	;scale=29bin=171octave=07note=03
	retlw	(D'07'*D'24')+D'04'	;scale=29bin=172octave=07note=04
	retlw	(D'07'*D'24')+D'05'	;scale=29bin=173octave=07note=05
	retlw	(D'07'*D'24')+D'05'	;scale=29bin=174octave=07note=06
	retlw	(D'07'*D'24')+D'05'	;scale=29bin=175octave=07note=07
	retlw	(D'07'*D'24')+D'05'	;scale=29bin=176octave=07note=08
	retlw	(D'07'*D'24')+D'05'	;scale=29bin=177octave=07note=09
	retlw	(D'07'*D'24')+D'10'	;scale=29bin=178octave=07note=10
	retlw	(D'07'*D'24')+D'10'	;scale=29bin=179octave=07note=11
	retlw	(D'07'*D'24')+D'10'	;scale=29bin=180octave=07note=12
	retlw	(D'07'*D'24')+D'10'	;scale=29bin=181octave=07note=13
	retlw	(D'07'*D'24')+D'14'	;scale=29bin=182octave=07note=14
	retlw	(D'07'*D'24')+D'15'	;scale=29bin=183octave=07note=15
	retlw	(D'07'*D'24')+D'15'	;scale=29bin=184octave=07note=16
	retlw	(D'07'*D'24')+D'15'	;scale=29bin=185octave=07note=17
	retlw	(D'07'*D'24')+D'15'	;scale=29bin=186octave=07note=18
	retlw	(D'07'*D'24')+D'15'	;scale=29bin=187octave=07note=19
	retlw	(D'07'*D'24')+D'20'	;scale=29bin=188octave=07note=20
	retlw	(D'07'*D'24')+D'20'	;scale=29bin=189octave=07note=21
	retlw	(D'07'*D'24')+D'20'	;scale=29bin=190octave=07note=22
	retlw	(D'07'*D'24')+D'20'	;scale=29bin=191octave=07note=23
	retlw	(D'08'*D'24')+D'00'	;scale=29bin=192octave=08note=00
	retlw	(D'08'*D'24')+D'00'	;scale=29bin=193octave=08note=01
	retlw	(D'08'*D'24')+D'00'	;scale=29bin=194octave=08note=02
	retlw	(D'08'*D'24')+D'00'	;scale=29bin=195octave=08note=03
	retlw	(D'08'*D'24')+D'04'	;scale=29bin=196octave=08note=04
	retlw	(D'08'*D'24')+D'05'	;scale=29bin=197octave=08note=05
	retlw	(D'08'*D'24')+D'05'	;scale=29bin=198octave=08note=06
	retlw	(D'08'*D'24')+D'05'	;scale=29bin=199octave=08note=07
	retlw	(D'08'*D'24')+D'05'	;scale=29bin=200octave=08note=08
	retlw	(D'08'*D'24')+D'05'	;scale=29bin=201octave=08note=09
	retlw	(D'08'*D'24')+D'10'	;scale=29bin=202octave=08note=10
	retlw	(D'08'*D'24')+D'10'	;scale=29bin=203octave=08note=11
	retlw	(D'08'*D'24')+D'10'	;scale=29bin=204octave=08note=12
	retlw	(D'08'*D'24')+D'10'	;scale=29bin=205octave=08note=13
	retlw	(D'08'*D'24')+D'14'	;scale=29bin=206octave=08note=14
	retlw	(D'08'*D'24')+D'15'	;scale=29bin=207octave=08note=15
	retlw	(D'08'*D'24')+D'15'	;scale=29bin=208octave=08note=16
	retlw	(D'08'*D'24')+D'15'	;scale=29bin=209octave=08note=17
	retlw	(D'08'*D'24')+D'15'	;scale=29bin=210octave=08note=18
	retlw	(D'08'*D'24')+D'15'	;scale=29bin=211octave=08note=19
	retlw	(D'08'*D'24')+D'20'	;scale=29bin=212octave=08note=20
	retlw	(D'08'*D'24')+D'20'	;scale=29bin=213octave=08note=21
	retlw	(D'08'*D'24')+D'20'	;scale=29bin=214octave=08note=22
	retlw	(D'08'*D'24')+D'20'	;scale=29bin=215octave=08note=23
	retlw	(D'09'*D'24')+D'00'	;scale=29bin=216octave=09note=00
	retlw	(D'09'*D'24')+D'00'	;scale=29bin=217octave=09note=01
	retlw	(D'09'*D'24')+D'00'	;scale=29bin=218octave=09note=02
	retlw	(D'09'*D'24')+D'00'	;scale=29bin=219octave=09note=03
	retlw	(D'09'*D'24')+D'04'	;scale=29bin=220octave=09note=04
	retlw	(D'09'*D'24')+D'05'	;scale=29bin=221octave=09note=05
	retlw	(D'09'*D'24')+D'05'	;scale=29bin=222octave=09note=06
	retlw	(D'09'*D'24')+D'05'	;scale=29bin=223octave=09note=07
	retlw	(D'09'*D'24')+D'05'	;scale=29bin=224octave=09note=08
	retlw	(D'09'*D'24')+D'05'	;scale=29bin=225octave=09note=09
	retlw	(D'09'*D'24')+D'10'	;scale=29bin=226octave=09note=10
	retlw	(D'09'*D'24')+D'10'	;scale=29bin=227octave=09note=11
	retlw	(D'09'*D'24')+D'10'	;scale=29bin=228octave=09note=12
	retlw	(D'09'*D'24')+D'10'	;scale=29bin=229octave=09note=13
	retlw	(D'09'*D'24')+D'14'	;scale=29bin=230octave=09note=14
	retlw	(D'09'*D'24')+D'15'	;scale=29bin=231octave=09note=15
	retlw	(D'09'*D'24')+D'15'	;scale=29bin=232octave=09note=16
	retlw	(D'09'*D'24')+D'15'	;scale=29bin=233octave=09note=17
	retlw	(D'09'*D'24')+D'15'	;scale=29bin=234octave=09note=18
	retlw	(D'09'*D'24')+D'15'	;scale=29bin=235octave=09note=19
	retlw	(D'09'*D'24')+D'20'	;scale=29bin=236octave=09note=20
	retlw	(D'09'*D'24')+D'20'	;scale=29bin=237octave=09note=21
	retlw	(D'09'*D'24')+D'20'	;scale=29bin=238octave=09note=22
	retlw	(D'09'*D'24')+D'20'	;scale=29bin=239octave=09note=23
	retlw	(D'10'*D'24')+D'00'	;scale=29bin=240octave=10note=00
	retlw	(D'10'*D'24')+D'00'	;scale=29bin=241octave=10note=01
	retlw	(D'10'*D'24')+D'00'	;scale=29bin=242octave=10note=02
	retlw	(D'10'*D'24')+D'00'	;scale=29bin=243octave=10note=03
	retlw	(D'10'*D'24')+D'00'	;scale=29bin=244octave=10note=04
	retlw	(D'10'*D'24')+D'00'	;scale=29bin=245octave=10note=05
	retlw	(D'10'*D'24')+D'00'	;scale=29bin=246octave=10note=06
	retlw	(D'10'*D'24')+D'00'	;scale=29bin=247octave=10note=07
	retlw	(D'10'*D'24')+D'00'	;scale=29bin=248octave=10note=08
	retlw	(D'10'*D'24')+D'00'	;scale=29bin=249octave=10note=09
	retlw	(D'10'*D'24')+D'00'	;scale=29bin=250octave=10note=10
	retlw	(D'10'*D'24')+D'00'	;scale=29bin=251octave=10note=11
	retlw	(D'10'*D'24')+D'00'	;scale=29bin=252octave=10note=12
	retlw	(D'10'*D'24')+D'00'	;scale=29bin=253octave=10note=13
	retlw	(D'10'*D'24')+D'00'	;scale=29bin=254octave=10note=14
	retlw	(D'10'*D'24')+D'00'	;scale=29bin=255octave=10note=15

;	Equal Quarter Tone look-up table
	org	EqualQT		;Equal Quarter Tone look-up table
	retlw	(D'00'*D'24')+D'00'	;scale=30bin=000octave=00note=00
	retlw	(D'00'*D'24')+D'00'	;scale=30bin=001octave=00note=01
	retlw	(D'00'*D'24')+D'00'	;scale=30bin=002octave=00note=02
	retlw	(D'00'*D'24')+D'03'	;scale=30bin=003octave=00note=03
	retlw	(D'00'*D'24')+D'03'	;scale=30bin=004octave=00note=04
	retlw	(D'00'*D'24')+D'03'	;scale=30bin=005octave=00note=05
	retlw	(D'00'*D'24')+D'06'	;scale=30bin=006octave=00note=06
	retlw	(D'00'*D'24')+D'06'	;scale=30bin=007octave=00note=07
	retlw	(D'00'*D'24')+D'06'	;scale=30bin=008octave=00note=08
	retlw	(D'00'*D'24')+D'09'	;scale=30bin=009octave=00note=09
	retlw	(D'00'*D'24')+D'09'	;scale=30bin=010octave=00note=10
	retlw	(D'00'*D'24')+D'09'	;scale=30bin=011octave=00note=11
	retlw	(D'00'*D'24')+D'12'	;scale=30bin=012octave=00note=12
	retlw	(D'00'*D'24')+D'12'	;scale=30bin=013octave=00note=13
	retlw	(D'00'*D'24')+D'12'	;scale=30bin=014octave=00note=14
	retlw	(D'00'*D'24')+D'15'	;scale=30bin=015octave=00note=15
	retlw	(D'00'*D'24')+D'15'	;scale=30bin=016octave=00note=16
	retlw	(D'00'*D'24')+D'15'	;scale=30bin=017octave=00note=17
	retlw	(D'00'*D'24')+D'18'	;scale=30bin=018octave=00note=18
	retlw	(D'00'*D'24')+D'18'	;scale=30bin=019octave=00note=19
	retlw	(D'00'*D'24')+D'18'	;scale=30bin=020octave=00note=20
	retlw	(D'00'*D'24')+D'21'	;scale=30bin=021octave=00note=21
	retlw	(D'00'*D'24')+D'21'	;scale=30bin=022octave=00note=22
	retlw	(D'00'*D'24')+D'21'	;scale=30bin=023octave=00note=23
	retlw	(D'01'*D'24')+D'00'	;scale=30bin=024octave=01note=00
	retlw	(D'01'*D'24')+D'00'	;scale=30bin=025octave=01note=01
	retlw	(D'01'*D'24')+D'00'	;scale=30bin=026octave=01note=02
	retlw	(D'01'*D'24')+D'03'	;scale=30bin=027octave=01note=03
	retlw	(D'01'*D'24')+D'03'	;scale=30bin=028octave=01note=04
	retlw	(D'01'*D'24')+D'03'	;scale=30bin=029octave=01note=05
	retlw	(D'01'*D'24')+D'06'	;scale=30bin=030octave=01note=06
	retlw	(D'01'*D'24')+D'06'	;scale=30bin=031octave=01note=07
	retlw	(D'01'*D'24')+D'06'	;scale=30bin=032octave=01note=08
	retlw	(D'01'*D'24')+D'09'	;scale=30bin=033octave=01note=09
	retlw	(D'01'*D'24')+D'09'	;scale=30bin=034octave=01note=10
	retlw	(D'01'*D'24')+D'09'	;scale=30bin=035octave=01note=11
	retlw	(D'01'*D'24')+D'12'	;scale=30bin=036octave=01note=12
	retlw	(D'01'*D'24')+D'12'	;scale=30bin=037octave=01note=13
	retlw	(D'01'*D'24')+D'12'	;scale=30bin=038octave=01note=14
	retlw	(D'01'*D'24')+D'15'	;scale=30bin=039octave=01note=15
	retlw	(D'01'*D'24')+D'15'	;scale=30bin=040octave=01note=16
	retlw	(D'01'*D'24')+D'15'	;scale=30bin=041octave=01note=17
	retlw	(D'01'*D'24')+D'18'	;scale=30bin=042octave=01note=18
	retlw	(D'01'*D'24')+D'18'	;scale=30bin=043octave=01note=19
	retlw	(D'01'*D'24')+D'18'	;scale=30bin=044octave=01note=20
	retlw	(D'01'*D'24')+D'21'	;scale=30bin=045octave=01note=21
	retlw	(D'01'*D'24')+D'21'	;scale=30bin=046octave=01note=22
	retlw	(D'01'*D'24')+D'21'	;scale=30bin=047octave=01note=23
	retlw	(D'02'*D'24')+D'00'	;scale=30bin=048octave=02note=00
	retlw	(D'02'*D'24')+D'00'	;scale=30bin=049octave=02note=01
	retlw	(D'02'*D'24')+D'00'	;scale=30bin=050octave=02note=02
	retlw	(D'02'*D'24')+D'03'	;scale=30bin=051octave=02note=03
	retlw	(D'02'*D'24')+D'03'	;scale=30bin=052octave=02note=04
	retlw	(D'02'*D'24')+D'03'	;scale=30bin=053octave=02note=05
	retlw	(D'02'*D'24')+D'06'	;scale=30bin=054octave=02note=06
	retlw	(D'02'*D'24')+D'06'	;scale=30bin=055octave=02note=07
	retlw	(D'02'*D'24')+D'06'	;scale=30bin=056octave=02note=08
	retlw	(D'02'*D'24')+D'09'	;scale=30bin=057octave=02note=09
	retlw	(D'02'*D'24')+D'09'	;scale=30bin=058octave=02note=10
	retlw	(D'02'*D'24')+D'09'	;scale=30bin=059octave=02note=11
	retlw	(D'02'*D'24')+D'12'	;scale=30bin=060octave=02note=12
	retlw	(D'02'*D'24')+D'12'	;scale=30bin=061octave=02note=13
	retlw	(D'02'*D'24')+D'12'	;scale=30bin=062octave=02note=14
	retlw	(D'02'*D'24')+D'15'	;scale=30bin=063octave=02note=15
	retlw	(D'02'*D'24')+D'15'	;scale=30bin=064octave=02note=16
	retlw	(D'02'*D'24')+D'15'	;scale=30bin=065octave=02note=17
	retlw	(D'02'*D'24')+D'18'	;scale=30bin=066octave=02note=18
	retlw	(D'02'*D'24')+D'18'	;scale=30bin=067octave=02note=19
	retlw	(D'02'*D'24')+D'18'	;scale=30bin=068octave=02note=20
	retlw	(D'02'*D'24')+D'21'	;scale=30bin=069octave=02note=21
	retlw	(D'02'*D'24')+D'21'	;scale=30bin=070octave=02note=22
	retlw	(D'02'*D'24')+D'21'	;scale=30bin=071octave=02note=23
	retlw	(D'03'*D'24')+D'00'	;scale=30bin=072octave=03note=00
	retlw	(D'03'*D'24')+D'00'	;scale=30bin=073octave=03note=01
	retlw	(D'03'*D'24')+D'00'	;scale=30bin=074octave=03note=02
	retlw	(D'03'*D'24')+D'03'	;scale=30bin=075octave=03note=03
	retlw	(D'03'*D'24')+D'03'	;scale=30bin=076octave=03note=04
	retlw	(D'03'*D'24')+D'03'	;scale=30bin=077octave=03note=05
	retlw	(D'03'*D'24')+D'06'	;scale=30bin=078octave=03note=06
	retlw	(D'03'*D'24')+D'06'	;scale=30bin=079octave=03note=07
	retlw	(D'03'*D'24')+D'06'	;scale=30bin=080octave=03note=08
	retlw	(D'03'*D'24')+D'09'	;scale=30bin=081octave=03note=09
	retlw	(D'03'*D'24')+D'09'	;scale=30bin=082octave=03note=10
	retlw	(D'03'*D'24')+D'09'	;scale=30bin=083octave=03note=11
	retlw	(D'03'*D'24')+D'12'	;scale=30bin=084octave=03note=12
	retlw	(D'03'*D'24')+D'12'	;scale=30bin=085octave=03note=13
	retlw	(D'03'*D'24')+D'12'	;scale=30bin=086octave=03note=14
	retlw	(D'03'*D'24')+D'15'	;scale=30bin=087octave=03note=15
	retlw	(D'03'*D'24')+D'15'	;scale=30bin=088octave=03note=16
	retlw	(D'03'*D'24')+D'15'	;scale=30bin=089octave=03note=17
	retlw	(D'03'*D'24')+D'18'	;scale=30bin=090octave=03note=18
	retlw	(D'03'*D'24')+D'18'	;scale=30bin=091octave=03note=19
	retlw	(D'03'*D'24')+D'18'	;scale=30bin=092octave=03note=20
	retlw	(D'03'*D'24')+D'21'	;scale=30bin=093octave=03note=21
	retlw	(D'03'*D'24')+D'21'	;scale=30bin=094octave=03note=22
	retlw	(D'03'*D'24')+D'21'	;scale=30bin=095octave=03note=23
	retlw	(D'04'*D'24')+D'00'	;scale=30bin=096octave=04note=00
	retlw	(D'04'*D'24')+D'00'	;scale=30bin=097octave=04note=01
	retlw	(D'04'*D'24')+D'00'	;scale=30bin=098octave=04note=02
	retlw	(D'04'*D'24')+D'03'	;scale=30bin=099octave=04note=03
	retlw	(D'04'*D'24')+D'03'	;scale=30bin=100octave=04note=04
	retlw	(D'04'*D'24')+D'03'	;scale=30bin=101octave=04note=05
	retlw	(D'04'*D'24')+D'06'	;scale=30bin=102octave=04note=06
	retlw	(D'04'*D'24')+D'06'	;scale=30bin=103octave=04note=07
	retlw	(D'04'*D'24')+D'06'	;scale=30bin=104octave=04note=08
	retlw	(D'04'*D'24')+D'09'	;scale=30bin=105octave=04note=09
	retlw	(D'04'*D'24')+D'09'	;scale=30bin=106octave=04note=10
	retlw	(D'04'*D'24')+D'09'	;scale=30bin=107octave=04note=11
	retlw	(D'04'*D'24')+D'12'	;scale=30bin=108octave=04note=12
	retlw	(D'04'*D'24')+D'12'	;scale=30bin=109octave=04note=13
	retlw	(D'04'*D'24')+D'12'	;scale=30bin=110octave=04note=14
	retlw	(D'04'*D'24')+D'15'	;scale=30bin=111octave=04note=15
	retlw	(D'04'*D'24')+D'15'	;scale=30bin=112octave=04note=16
	retlw	(D'04'*D'24')+D'15'	;scale=30bin=113octave=04note=17
	retlw	(D'04'*D'24')+D'18'	;scale=30bin=114octave=04note=18
	retlw	(D'04'*D'24')+D'18'	;scale=30bin=115octave=04note=19
	retlw	(D'04'*D'24')+D'18'	;scale=30bin=116octave=04note=20
	retlw	(D'04'*D'24')+D'21'	;scale=30bin=117octave=04note=21
	retlw	(D'04'*D'24')+D'21'	;scale=30bin=118octave=04note=22
	retlw	(D'04'*D'24')+D'21'	;scale=30bin=119octave=04note=23
	retlw	(D'05'*D'24')+D'00'	;scale=30bin=120octave=05note=00
	retlw	(D'05'*D'24')+D'00'	;scale=30bin=121octave=05note=01
	retlw	(D'05'*D'24')+D'00'	;scale=30bin=122octave=05note=02
	retlw	(D'05'*D'24')+D'03'	;scale=30bin=123octave=05note=03
	retlw	(D'05'*D'24')+D'03'	;scale=30bin=124octave=05note=04
	retlw	(D'05'*D'24')+D'03'	;scale=30bin=125octave=05note=05
	retlw	(D'05'*D'24')+D'06'	;scale=30bin=126octave=05note=06
	retlw	(D'05'*D'24')+D'06'	;scale=30bin=127octave=05note=07
	retlw	(D'05'*D'24')+D'06'	;scale=30bin=128octave=05note=08
	retlw	(D'05'*D'24')+D'09'	;scale=30bin=129octave=05note=09
	retlw	(D'05'*D'24')+D'09'	;scale=30bin=130octave=05note=10
	retlw	(D'05'*D'24')+D'09'	;scale=30bin=131octave=05note=11
	retlw	(D'05'*D'24')+D'12'	;scale=30bin=132octave=05note=12
	retlw	(D'05'*D'24')+D'12'	;scale=30bin=133octave=05note=13
	retlw	(D'05'*D'24')+D'12'	;scale=30bin=134octave=05note=14
	retlw	(D'05'*D'24')+D'15'	;scale=30bin=135octave=05note=15
	retlw	(D'05'*D'24')+D'15'	;scale=30bin=136octave=05note=16
	retlw	(D'05'*D'24')+D'15'	;scale=30bin=137octave=05note=17
	retlw	(D'05'*D'24')+D'18'	;scale=30bin=138octave=05note=18
	retlw	(D'05'*D'24')+D'18'	;scale=30bin=139octave=05note=19
	retlw	(D'05'*D'24')+D'18'	;scale=30bin=140octave=05note=20
	retlw	(D'05'*D'24')+D'21'	;scale=30bin=141octave=05note=21
	retlw	(D'05'*D'24')+D'21'	;scale=30bin=142octave=05note=22
	retlw	(D'05'*D'24')+D'21'	;scale=30bin=143octave=05note=23
	retlw	(D'06'*D'24')+D'00'	;scale=30bin=144octave=06note=00
	retlw	(D'06'*D'24')+D'00'	;scale=30bin=145octave=06note=01
	retlw	(D'06'*D'24')+D'00'	;scale=30bin=146octave=06note=02
	retlw	(D'06'*D'24')+D'03'	;scale=30bin=147octave=06note=03
	retlw	(D'06'*D'24')+D'03'	;scale=30bin=148octave=06note=04
	retlw	(D'06'*D'24')+D'03'	;scale=30bin=149octave=06note=05
	retlw	(D'06'*D'24')+D'06'	;scale=30bin=150octave=06note=06
	retlw	(D'06'*D'24')+D'06'	;scale=30bin=151octave=06note=07
	retlw	(D'06'*D'24')+D'06'	;scale=30bin=152octave=06note=08
	retlw	(D'06'*D'24')+D'09'	;scale=30bin=153octave=06note=09
	retlw	(D'06'*D'24')+D'09'	;scale=30bin=154octave=06note=10
	retlw	(D'06'*D'24')+D'09'	;scale=30bin=155octave=06note=11
	retlw	(D'06'*D'24')+D'12'	;scale=30bin=156octave=06note=12
	retlw	(D'06'*D'24')+D'12'	;scale=30bin=157octave=06note=13
	retlw	(D'06'*D'24')+D'12'	;scale=30bin=158octave=06note=14
	retlw	(D'06'*D'24')+D'15'	;scale=30bin=159octave=06note=15
	retlw	(D'06'*D'24')+D'15'	;scale=30bin=160octave=06note=16
	retlw	(D'06'*D'24')+D'15'	;scale=30bin=161octave=06note=17
	retlw	(D'06'*D'24')+D'18'	;scale=30bin=162octave=06note=18
	retlw	(D'06'*D'24')+D'18'	;scale=30bin=163octave=06note=19
	retlw	(D'06'*D'24')+D'18'	;scale=30bin=164octave=06note=20
	retlw	(D'06'*D'24')+D'21'	;scale=30bin=165octave=06note=21
	retlw	(D'06'*D'24')+D'21'	;scale=30bin=166octave=06note=22
	retlw	(D'06'*D'24')+D'21'	;scale=30bin=167octave=06note=23
	retlw	(D'07'*D'24')+D'00'	;scale=30bin=168octave=07note=00
	retlw	(D'07'*D'24')+D'00'	;scale=30bin=169octave=07note=01
	retlw	(D'07'*D'24')+D'00'	;scale=30bin=170octave=07note=02
	retlw	(D'07'*D'24')+D'03'	;scale=30bin=171octave=07note=03
	retlw	(D'07'*D'24')+D'03'	;scale=30bin=172octave=07note=04
	retlw	(D'07'*D'24')+D'03'	;scale=30bin=173octave=07note=05
	retlw	(D'07'*D'24')+D'06'	;scale=30bin=174octave=07note=06
	retlw	(D'07'*D'24')+D'06'	;scale=30bin=175octave=07note=07
	retlw	(D'07'*D'24')+D'06'	;scale=30bin=176octave=07note=08
	retlw	(D'07'*D'24')+D'09'	;scale=30bin=177octave=07note=09
	retlw	(D'07'*D'24')+D'09'	;scale=30bin=178octave=07note=10
	retlw	(D'07'*D'24')+D'09'	;scale=30bin=179octave=07note=11
	retlw	(D'07'*D'24')+D'12'	;scale=30bin=180octave=07note=12
	retlw	(D'07'*D'24')+D'12'	;scale=30bin=181octave=07note=13
	retlw	(D'07'*D'24')+D'12'	;scale=30bin=182octave=07note=14
	retlw	(D'07'*D'24')+D'15'	;scale=30bin=183octave=07note=15
	retlw	(D'07'*D'24')+D'15'	;scale=30bin=184octave=07note=16
	retlw	(D'07'*D'24')+D'15'	;scale=30bin=185octave=07note=17
	retlw	(D'07'*D'24')+D'18'	;scale=30bin=186octave=07note=18
	retlw	(D'07'*D'24')+D'18'	;scale=30bin=187octave=07note=19
	retlw	(D'07'*D'24')+D'18'	;scale=30bin=188octave=07note=20
	retlw	(D'07'*D'24')+D'21'	;scale=30bin=189octave=07note=21
	retlw	(D'07'*D'24')+D'21'	;scale=30bin=190octave=07note=22
	retlw	(D'07'*D'24')+D'21'	;scale=30bin=191octave=07note=23
	retlw	(D'08'*D'24')+D'00'	;scale=30bin=192octave=08note=00
	retlw	(D'08'*D'24')+D'00'	;scale=30bin=193octave=08note=01
	retlw	(D'08'*D'24')+D'00'	;scale=30bin=194octave=08note=02
	retlw	(D'08'*D'24')+D'03'	;scale=30bin=195octave=08note=03
	retlw	(D'08'*D'24')+D'03'	;scale=30bin=196octave=08note=04
	retlw	(D'08'*D'24')+D'03'	;scale=30bin=197octave=08note=05
	retlw	(D'08'*D'24')+D'06'	;scale=30bin=198octave=08note=06
	retlw	(D'08'*D'24')+D'06'	;scale=30bin=199octave=08note=07
	retlw	(D'08'*D'24')+D'06'	;scale=30bin=200octave=08note=08
	retlw	(D'08'*D'24')+D'09'	;scale=30bin=201octave=08note=09
	retlw	(D'08'*D'24')+D'09'	;scale=30bin=202octave=08note=10
	retlw	(D'08'*D'24')+D'09'	;scale=30bin=203octave=08note=11
	retlw	(D'08'*D'24')+D'12'	;scale=30bin=204octave=08note=12
	retlw	(D'08'*D'24')+D'12'	;scale=30bin=205octave=08note=13
	retlw	(D'08'*D'24')+D'12'	;scale=30bin=206octave=08note=14
	retlw	(D'08'*D'24')+D'15'	;scale=30bin=207octave=08note=15
	retlw	(D'08'*D'24')+D'15'	;scale=30bin=208octave=08note=16
	retlw	(D'08'*D'24')+D'15'	;scale=30bin=209octave=08note=17
	retlw	(D'08'*D'24')+D'18'	;scale=30bin=210octave=08note=18
	retlw	(D'08'*D'24')+D'18'	;scale=30bin=211octave=08note=19
	retlw	(D'08'*D'24')+D'18'	;scale=30bin=212octave=08note=20
	retlw	(D'08'*D'24')+D'21'	;scale=30bin=213octave=08note=21
	retlw	(D'08'*D'24')+D'21'	;scale=30bin=214octave=08note=22
	retlw	(D'08'*D'24')+D'21'	;scale=30bin=215octave=08note=23
	retlw	(D'09'*D'24')+D'00'	;scale=30bin=216octave=09note=00
	retlw	(D'09'*D'24')+D'00'	;scale=30bin=217octave=09note=01
	retlw	(D'09'*D'24')+D'00'	;scale=30bin=218octave=09note=02
	retlw	(D'09'*D'24')+D'03'	;scale=30bin=219octave=09note=03
	retlw	(D'09'*D'24')+D'03'	;scale=30bin=220octave=09note=04
	retlw	(D'09'*D'24')+D'03'	;scale=30bin=221octave=09note=05
	retlw	(D'09'*D'24')+D'06'	;scale=30bin=222octave=09note=06
	retlw	(D'09'*D'24')+D'06'	;scale=30bin=223octave=09note=07
	retlw	(D'09'*D'24')+D'06'	;scale=30bin=224octave=09note=08
	retlw	(D'09'*D'24')+D'09'	;scale=30bin=225octave=09note=09
	retlw	(D'09'*D'24')+D'09'	;scale=30bin=226octave=09note=10
	retlw	(D'09'*D'24')+D'09'	;scale=30bin=227octave=09note=11
	retlw	(D'09'*D'24')+D'12'	;scale=30bin=228octave=09note=12
	retlw	(D'09'*D'24')+D'12'	;scale=30bin=229octave=09note=13
	retlw	(D'09'*D'24')+D'12'	;scale=30bin=230octave=09note=14
	retlw	(D'09'*D'24')+D'15'	;scale=30bin=231octave=09note=15
	retlw	(D'09'*D'24')+D'15'	;scale=30bin=232octave=09note=16
	retlw	(D'09'*D'24')+D'15'	;scale=30bin=233octave=09note=17
	retlw	(D'09'*D'24')+D'18'	;scale=30bin=234octave=09note=18
	retlw	(D'09'*D'24')+D'18'	;scale=30bin=235octave=09note=19
	retlw	(D'09'*D'24')+D'18'	;scale=30bin=236octave=09note=20
	retlw	(D'09'*D'24')+D'21'	;scale=30bin=237octave=09note=21
	retlw	(D'09'*D'24')+D'21'	;scale=30bin=238octave=09note=22
	retlw	(D'09'*D'24')+D'21'	;scale=30bin=239octave=09note=23
	retlw	(D'10'*D'24')+D'00'	;scale=30bin=240octave=10note=00
	retlw	(D'10'*D'24')+D'00'	;scale=30bin=241octave=10note=01
	retlw	(D'10'*D'24')+D'00'	;scale=30bin=242octave=10note=02
	retlw	(D'10'*D'24')+D'00'	;scale=30bin=243octave=10note=03
	retlw	(D'10'*D'24')+D'00'	;scale=30bin=244octave=10note=04
	retlw	(D'10'*D'24')+D'00'	;scale=30bin=245octave=10note=05
	retlw	(D'10'*D'24')+D'00'	;scale=30bin=246octave=10note=06
	retlw	(D'10'*D'24')+D'00'	;scale=30bin=247octave=10note=07
	retlw	(D'10'*D'24')+D'00'	;scale=30bin=248octave=10note=08
	retlw	(D'10'*D'24')+D'00'	;scale=30bin=249octave=10note=09
	retlw	(D'10'*D'24')+D'00'	;scale=30bin=250octave=10note=10
	retlw	(D'10'*D'24')+D'00'	;scale=30bin=251octave=10note=11
	retlw	(D'10'*D'24')+D'00'	;scale=30bin=252octave=10note=12
	retlw	(D'10'*D'24')+D'00'	;scale=30bin=253octave=10note=13
	retlw	(D'10'*D'24')+D'00'	;scale=30bin=254octave=10note=14
	retlw	(D'10'*D'24')+D'00'	;scale=30bin=255octave=10note=15

;	END OF PROGRAM
	end